// Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
export * from '@aws-crypto/encrypt-node';
export * from '@aws-crypto/decrypt-node';
export * from '@aws-crypto/material-management-node';
export * from '@aws-crypto/caching-materials-manager-node';
export * from '@aws-crypto/kms-keyring-node';
export * from '@aws-crypto/raw-aes-keyring-node';
export * from '@aws-crypto/raw-rsa-keyring-node';
export * from '@aws-crypto/branch-keystore-node';
import { buildEncrypt } from '@aws-crypto/encrypt-node';
import { buildDecrypt } from '@aws-crypto/decrypt-node';
export function buildClient(options) {
    return {
        ...buildEncrypt(options),
        ...buildDecrypt(options),
    };
}
//# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiaW5kZXguanMiLCJzb3VyY2VSb290IjoiIiwic291cmNlcyI6WyIuLi8uLi8uLi9zcmMvaW5kZXgudHMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IkFBQUEsb0VBQW9FO0FBQ3BFLHNDQUFzQztBQUV0QyxjQUFjLDBCQUEwQixDQUFBO0FBQ3hDLGNBQWMsMEJBQTBCLENBQUE7QUFDeEMsY0FBYyxzQ0FBc0MsQ0FBQTtBQUNwRCxjQUFjLDRDQUE0QyxDQUFBO0FBQzFELGNBQWMsOEJBQThCLENBQUE7QUFDNUMsY0FBYyxrQ0FBa0MsQ0FBQTtBQUNoRCxjQUFjLGtDQUFrQyxDQUFBO0FBQ2hELGNBQWMsa0NBQWtDLENBQUE7QUFRaEQsT0FBTyxFQUFFLFlBQVksRUFBRSxNQUFNLDBCQUEwQixDQUFBO0FBQ3ZELE9BQU8sRUFBRSxZQUFZLEVBQUUsTUFBTSwwQkFBMEIsQ0FBQTtBQUV2RCxNQUFNLFVBQVUsV0FBVyxDQUN6QixPQUEwQztJQUUxQyxPQUFPO1FBQ0wsR0FBRyxZQUFZLENBQUMsT0FBTyxDQUFDO1FBQ3hCLEdBQUcsWUFBWSxDQUFDLE9BQU8sQ0FBQztLQUN6QixDQUFBO0FBQ0gsQ0FBQyJ9