"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiColorPalettePicker", {
  enumerable: true,
  get: function get() {
    return _color_palette_picker.OuiColorPalettePicker;
  }
});
Object.defineProperty(exports, "EuiColorPalettePicker", {
  enumerable: true,
  get: function get() {
    return _color_palette_picker2.EuiColorPalettePicker;
  }
});
var _color_palette_picker = require("./color_palette_picker");
var _color_palette_picker2 = require("../../../eui_components/color_picker/color_palette_picker/color_palette_picker");