/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export { OuiTable } from './table';
export { OuiTableBody } from './table_body';
export { OuiTableFooter } from './table_footer';
export { OuiTableFooterCell } from './table_footer_cell';
export { OuiTableHeader } from './table_header';
export { OuiTableHeaderButton } from './table_header_button';
export { OuiTableHeaderCell } from './table_header_cell';
export { OuiTableHeaderCellCheckbox } from './table_header_cell_checkbox';
export { OuiTablePagination } from './table_pagination';
export { OuiTableHeaderMobile } from './mobile/table_header_mobile';
export { OuiTableSortMobile } from './mobile/table_sort_mobile';
export { OuiTableSortMobileItem } from './mobile/table_sort_mobile_item';
export { OuiTableRow } from './table_row';
export { OuiTableRowCell } from './table_row_cell';
export { OuiTableRowCellCheckbox } from './table_row_cell_checkbox';

/* OUI -> EUI Aliases: Build-Time */
export { EuiTable } from '../../eui_components/table/table';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTableBody } from '../../eui_components/table/table_body';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTableFooter } from '../../eui_components/table/table_footer';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTableFooterCell } from '../../eui_components/table/table_footer_cell';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTableHeader } from '../../eui_components/table/table_header';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTableHeaderButton } from '../../eui_components/table/table_header_button';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTableHeaderCell } from '../../eui_components/table/table_header_cell';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTableHeaderCellCheckbox } from '../../eui_components/table/table_header_cell_checkbox';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTablePagination } from '../../eui_components/table/table_pagination';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTableHeaderMobile } from '../../eui_components/table/mobile/table_header_mobile';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTableSortMobile } from '../../eui_components/table/mobile/table_sort_mobile';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTableSortMobileItem } from '../../eui_components/table/mobile/table_sort_mobile_item';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTableRow } from '../../eui_components/table/table_row';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTableRowCell } from '../../eui_components/table/table_row_cell';
/* OUI -> EUI Aliases: Build-Time */
export { EuiTableRowCellCheckbox } from '../../eui_components/table/table_row_cell_checkbox';