"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiColorPaletteDisplay", {
  enumerable: true,
  get: function get() {
    return _color_palette_display.EuiColorPaletteDisplay;
  }
});
Object.defineProperty(exports, "EuiColorPaletteDisplayFixed", {
  enumerable: true,
  get: function get() {
    return _color_palette_display_fixed.EuiColorPaletteDisplayFixed;
  }
});
Object.defineProperty(exports, "EuiColorPaletteDisplayGradient", {
  enumerable: true,
  get: function get() {
    return _color_palette_display_gradient.EuiColorPaletteDisplayGradient;
  }
});
var _color_palette_display = require("./color_palette_display");
var _color_palette_display_fixed = require("./color_palette_display_fixed");
var _color_palette_display_gradient = require("./color_palette_display_gradient");