"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _typeof = require("@babel/runtime/helpers/typeof");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.icon = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var React = _interopRequireWildcard(require("react"));
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function _interopRequireWildcard(e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, default: e }; if (null === e || "object" != _typeof(e) && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (var _t in e) { "default" !== _t && {}.hasOwnProperty.call(e, _t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, _t)) && (i.get || i.set) ? o(f, _t, i) : f[_t] = e[_t]); } return f; })(e, t); }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

var EuiIconNavSlos = function EuiIconNavSlos(_ref) {
  var title = _ref.title,
    titleId = _ref.titleId,
    props = (0, _objectWithoutProperties2.default)(_ref, ["title", "titleId"]);
  return /*#__PURE__*/React.createElement("svg", (0, _extends2.default)({
    xmlns: "http://www.w3.org/2000/svg",
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    "aria-labelledby": titleId
  }, props), title ? /*#__PURE__*/React.createElement("title", {
    id: titleId
  }, title) : null, /*#__PURE__*/React.createElement("path", {
    d: "M8.16 2.805a4.138 4.138 0 0 1 5.849 5.825l-5.227 5.244c-.41.41-1.063.431-1.497.062l-.074-.068-5.22-5.238a4.14 4.14 0 0 1 5.85-5.825l.16.137.159-.137Zm-.975.576a3.278 3.278 0 0 0-4.251.137l-.004.004-.104.098-.004.004a3.277 3.277 0 0 0-.106 4.523l.004.004.098.103L8 13.436l3.747-3.748.171-.172L9.192 6.79l-.172.172-.715.715A1.78 1.78 0 0 1 5.788 5.16l1.608-1.61-.211-.169Zm5.993.243a3.277 3.277 0 0 0-4.4-.212l-.123.106-.004.004-.104.098-2.149 2.15a.918.918 0 0 0-.07 1.217l.003.006.005.004.052.06.01.01a.918.918 0 0 0 1.217.07l.006-.004.004-.005.06-.052.005-.004 1.196-1.197a.432.432 0 0 1 .611 0l3.032 3.031.649-.648a3.277 3.277 0 0 0 0-4.634Z",
    clipRule: "evenodd"
  }));
};
var icon = EuiIconNavSlos;
exports.icon = icon;