"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "getSecureRelForTarget", {
  enumerable: true,
  get: function get() {
    return _get_secure_rel_for_target.getSecureRelForTarget;
  }
});
var _get_secure_rel_for_target = require("./get_secure_rel_for_target");