"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiTextArea", {
  enumerable: true,
  get: function get() {
    return _text_area.EuiTextArea;
  }
});
Object.defineProperty(exports, "EuiCompressedTextArea", {
  enumerable: true,
  get: function get() {
    return _text_area.EuiCompressedTextArea;
  }
});
var _text_area = require("./text_area");