"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "useInnerText", {
  enumerable: true,
  get: function get() {
    return _inner_text.useInnerText;
  }
});
Object.defineProperty(exports, "EuiInnerText", {
  enumerable: true,
  get: function get() {
    return _inner_text.EuiInnerText;
  }
});
Object.defineProperty(exports, "useRenderToText", {
  enumerable: true,
  get: function get() {
    return _render_to_text.useRenderToText;
  }
});
var _inner_text = require("./inner_text");
var _render_to_text = require("./render_to_text");