"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiNotificationEventReadIcon", {
  enumerable: true,
  get: function get() {
    return _notification_event_read_icon.EuiNotificationEventReadIcon;
  }
});
exports.OuiNotificationEventReadIcon = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _i18n = require("../i18n");
var _classnames = _interopRequireDefault(require("classnames"));
var _icon = require("../icon");
var _notification_event_read_icon = require("../../eui_components/notification/notification_event_read_icon");
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

var OuiNotificationEventReadIcon = function OuiNotificationEventReadIcon(_ref) {
  var id = _ref.id,
    isRead = _ref.isRead,
    eventName = _ref.eventName,
    rest = (0, _objectWithoutProperties2.default)(_ref, ["id", "isRead", "eventName"]);
  var classesReadState = (0, _classnames.default)('ouiNotificationEventReadIcon', {
    'ouiNotificationEventReadIcon--isRead': isRead
  });
  var readAria = (0, _i18n.useOuiI18n)('ouiNotificationEventReadIcon.readAria', '{eventName} is read', {
    eventName: eventName
  });
  var unreadAria = (0, _i18n.useOuiI18n)('ouiNotificationEventReadIcon.unreadAria', '{eventName} is unread', {
    eventName: eventName
  });
  var readTitle = (0, _i18n.useOuiI18n)('ouiNotificationEventReadIcon.read', 'Read');
  var unreadTitle = (0, _i18n.useOuiI18n)('ouiNotificationEventReadIcon.unread', 'Unread');
  var iconAriaLabel = isRead ? readAria : unreadAria;
  var iconTitle = isRead ? readTitle : unreadTitle;
  return /*#__PURE__*/_react.default.createElement("div", {
    className: classesReadState
  }, /*#__PURE__*/_react.default.createElement(_icon.OuiIcon, (0, _extends2.default)({
    type: "dot",
    "aria-label": iconAriaLabel,
    title: iconTitle,
    color: "primary",
    "data-test-subj": "".concat(id, "-notificationEventReadIcon")
  }, rest)));
};

/* OUI -> EUI Aliases: Build-Time */
exports.OuiNotificationEventReadIcon = OuiNotificationEventReadIcon;
OuiNotificationEventReadIcon.propTypes = {
  id: _propTypes.default.string.isRequired,
  /**
     * Shows an indicator of the read state of the event
     */
  isRead: _propTypes.default.bool.isRequired,
  /**
     * A unique, human-friendly name for the event to be used in aria attributes (e.g. "alert-critical-01", "cloud-no-severity-12", etc..).
     */
  eventName: _propTypes.default.string.isRequired
};
/* OUI -> EUI Aliases: Build-Time */