"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiIcon", {
  enumerable: true,
  get: function get() {
    return _icon.OuiIcon;
  }
});
Object.defineProperty(exports, "ICON_TYPES", {
  enumerable: true,
  get: function get() {
    return _icon.TYPES;
  }
});
Object.defineProperty(exports, "ICON_SIZES", {
  enumerable: true,
  get: function get() {
    return _icon.SIZES;
  }
});
Object.defineProperty(exports, "ICON_COLORS", {
  enumerable: true,
  get: function get() {
    return _icon.COLORS;
  }
});
Object.defineProperty(exports, "EuiIcon", {
  enumerable: true,
  get: function get() {
    return _icon2.EuiIcon;
  }
});
var _icon = require("./icon");
var _icon2 = require("../../eui_components/icon/icon");