"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DonutSegment = void 0;
var _react = _interopRequireDefault(require("react"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */

const DonutSegment = ({
  center,
  radius,
  stroke,
  strokeWidth,
  fill = 'transparent',
  dashArray,
  dashOffset = 0,
  ariaLabel = 'Health donut segment',
  description,
  className = ''
}) => /*#__PURE__*/(0, _jsxRuntime.jsx)("circle", {
  className: className,
  cx: center,
  cy: center,
  r: radius,
  fill: fill,
  stroke: stroke,
  strokeWidth: strokeWidth,
  strokeLinecap: "butt",
  strokeDasharray: dashArray,
  strokeDashoffset: dashOffset,
  transform: `rotate(-90 ${center} ${center})`,
  role: "img",
  "aria-label": description ? `${ariaLabel} - ${description}` : ariaLabel
});
exports.DonutSegment = DonutSegment;