"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiNotificationEvent", {
  enumerable: true,
  get: function get() {
    return _notification_event.EuiNotificationEvent;
  }
});
var _notification_event = require("./notification_event");