"use strict";
/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DQLParserVisitor = exports.KeyValueExpressionContext = exports.GroupExpressionContext = exports.GroupContentContext = exports.DQLParser = exports.DQLLexer = void 0;
var DQLLexer_1 = require("./.generated/DQLLexer");
Object.defineProperty(exports, "DQLLexer", { enumerable: true, get: function () { return DQLLexer_1.DQLLexer; } });
var DQLParser_1 = require("./.generated/DQLParser");
Object.defineProperty(exports, "DQLParser", { enumerable: true, get: function () { return DQLParser_1.DQLParser; } });
Object.defineProperty(exports, "GroupContentContext", { enumerable: true, get: function () { return DQLParser_1.GroupContentContext; } });
Object.defineProperty(exports, "GroupExpressionContext", { enumerable: true, get: function () { return DQLParser_1.GroupExpressionContext; } });
Object.defineProperty(exports, "KeyValueExpressionContext", { enumerable: true, get: function () { return DQLParser_1.KeyValueExpressionContext; } });
var DQLParserVisitor_1 = require("./.generated/DQLParserVisitor");
Object.defineProperty(exports, "DQLParserVisitor", { enumerable: true, get: function () { return DQLParserVisitor_1.DQLParserVisitor; } });
//# sourceMappingURL=index.js.map