"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Random = void 0;
var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _moment = _interopRequireDefault(require("moment"));
var _predicate = require("./predicate");
var _utils = require("./utils");
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { (0, _defineProperty2.default)(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; } /*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */ /*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
var defaultRand = Math.random;
var Random = function Random() {
  var _this = this;
  var rand = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultRand;
  (0, _classCallCheck2.default)(this, Random);
  (0, _defineProperty2.default)(this, "rand", void 0);
  (0, _defineProperty2.default)(this, "boolean", function () {
    return _this.rand() > 0.5;
  });
  (0, _defineProperty2.default)(this, "number", function () {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var min = (0, _predicate.isNil)(options.min) ? Number.MIN_VALUE : options.min;
    var max = (0, _predicate.isNil)(options.max) ? Number.MAX_VALUE : options.max;
    var delta = _this.rand() * (max - min);
    return min + delta;
  });
  (0, _defineProperty2.default)(this, "integer", function () {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var min = Math.ceil((0, _predicate.isNil)(options.min) ? Number.MIN_VALUE : options.min);
    var max = Math.floor((0, _predicate.isNil)(options.max) ? Number.MAX_VALUE : options.max);
    var delta = Math.floor(_this.rand() * (max - min + 1));
    return min + delta;
  });
  (0, _defineProperty2.default)(this, "oneOf", function (values) {
    return values[Math.floor(_this.rand() * values.length)];
  });
  (0, _defineProperty2.default)(this, "oneToOne", function (values, index) {
    return values[index];
  });
  (0, _defineProperty2.default)(this, "setOf", function (values) {
    var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var count = _this.integer(_objectSpread({
      min: 0,
      max: values.length
    }, options));
    var copy = (0, _toConsumableArray2.default)(values);
    return (0, _utils.times)(count, function () {
      var value = _this.oneOf(copy);
      copy.splice(copy.indexOf(value), 1);
      return value;
    });
  });
  (0, _defineProperty2.default)(this, "date", function () {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var min = (0, _predicate.isNil)(options.min) ? new Date(0) : options.min;
    var max = (0, _predicate.isNil)(options.max) ? new Date(Date.now()) : options.max;
    var minMls = min.getTime();
    var maxMls = max.getTime();
    var time = _this.integer({
      min: minMls,
      max: maxMls
    });
    return new Date(time);
  });
  (0, _defineProperty2.default)(this, "moment", function () {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var min = (0, _predicate.isNil)(options.min) ? (0, _moment.default)(0) : options.min;
    var max = (0, _predicate.isNil)(options.max) ? (0, _moment.default)() : options.max;
    var minMls = +min;
    var maxMls = +max;
    var time = _this.integer({
      min: minMls,
      max: maxMls
    });
    return (0, _moment.default)(time);
  });
  this.rand = rand;
};
exports.Random = Random;