/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */
import React from 'react';
import { SliStatusIcon } from '../sli_status_icon';
import { Label } from './label';
import { jsx as _jsx } from "react/jsx-runtime";
export const RecoveredLabel = _ref => {
  let {
    text,
    children = /*#__PURE__*/_jsx(SliStatusIcon, {
      status: "recovered",
      size: 22
    })
  } = _ref;
  return /*#__PURE__*/_jsx(Label, {
    text: text,
    className: "osd:gap-0.5",
    children: children
  });
};