"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiFieldText", {
  enumerable: true,
  get: function get() {
    return _field_text.OuiFieldText;
  }
});
Object.defineProperty(exports, "OuiCompressedFieldText", {
  enumerable: true,
  get: function get() {
    return _field_text.OuiCompressedFieldText;
  }
});
Object.defineProperty(exports, "EuiFieldText", {
  enumerable: true,
  get: function get() {
    return _field_text2.EuiFieldText;
  }
});
Object.defineProperty(exports, "EuiCompressedFieldText", {
  enumerable: true,
  get: function get() {
    return _field_text2.EuiCompressedFieldText;
  }
});
var _field_text = require("./field_text");
var _field_text2 = require("../../../eui_components/form/field_text/field_text");