"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiPageSideBar", {
  enumerable: true,
  get: function get() {
    return _page_side_bar.OuiPageSideBar;
  }
});
Object.defineProperty(exports, "EuiPageSideBar", {
  enumerable: true,
  get: function get() {
    return _page_side_bar2.EuiPageSideBar;
  }
});
var _page_side_bar = require("./page_side_bar");
var _page_side_bar2 = require("../../../eui_components/page/page_side_bar/page_side_bar");