"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiPageBody", {
  enumerable: true,
  get: function get() {
    return _page_body.OuiPageBody;
  }
});
Object.defineProperty(exports, "EuiPageBody", {
  enumerable: true,
  get: function get() {
    return _page_body2.EuiPageBody;
  }
});
var _page_body = require("./page_body");
var _page_body2 = require("../../../eui_components/page/page_body/page_body");