"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiProgress", {
  enumerable: true,
  get: function get() {
    return _progress.OuiProgress;
  }
});
Object.defineProperty(exports, "EuiProgress", {
  enumerable: true,
  get: function get() {
    return _progress2.EuiProgress;
  }
});
var _progress = require("./progress");
var _progress2 = require("../../eui_components/progress/progress");