"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Loader = void 0;
var _react = _interopRequireDefault(require("react"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */

const Loader = () => /*#__PURE__*/(0, _jsxRuntime.jsx)("span", {
  className: "osd:w-24 osd:h-24 osd:border-8 osd:border-spinner osd:rounded-full osd:animate-spin osd:border-b-transparent"
});
exports.Loader = Loader;