"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiAspectRatio", {
  enumerable: true,
  get: function get() {
    return _aspect_ratio.OuiAspectRatio;
  }
});
Object.defineProperty(exports, "EuiAspectRatio", {
  enumerable: true,
  get: function get() {
    return _aspect_ratio2.EuiAspectRatio;
  }
});
var _aspect_ratio = require("./aspect_ratio");
var _aspect_ratio2 = require("../../eui_components/aspect_ratio/aspect_ratio");