"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiNotificationBadge", {
  enumerable: true,
  get: function get() {
    return _badge_notification.OuiNotificationBadge;
  }
});
Object.defineProperty(exports, "EuiNotificationBadge", {
  enumerable: true,
  get: function get() {
    return _badge_notification2.EuiNotificationBadge;
  }
});
var _badge_notification = require("./badge_notification");
var _badge_notification2 = require("../../../eui_components/badge/notification_badge/badge_notification");