"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiPanel", {
  enumerable: true,
  get: function get() {
    return _panel.OuiPanel;
  }
});
Object.defineProperty(exports, "SIZES", {
  enumerable: true,
  get: function get() {
    return _panel.SIZES;
  }
});
Object.defineProperty(exports, "OuiSplitPanel", {
  enumerable: true,
  get: function get() {
    return _split_panel.OuiSplitPanel;
  }
});
Object.defineProperty(exports, "EuiPanel", {
  enumerable: true,
  get: function get() {
    return _panel2.EuiPanel;
  }
});
Object.defineProperty(exports, "EuiSplitPanel", {
  enumerable: true,
  get: function get() {
    return _split_panel2.EuiSplitPanel;
  }
});
var _panel = require("./panel");
var _split_panel = require("./split_panel");
var _panel2 = require("../../eui_components/panel/panel");
var _split_panel2 = require("../../eui_components/panel/split_panel");