"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stsRegionDefaultResolver = stsRegionDefaultResolver;
function stsRegionDefaultResolver() {
    return async () => "us-east-1";
}
