"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiOutsideClickDetector", {
  enumerable: true,
  get: function get() {
    return _outside_click_detector.EuiOutsideClickDetector;
  }
});
var _outside_click_detector = require("./outside_click_detector");