"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiFormFieldset", {
  enumerable: true,
  get: function get() {
    return _form_fieldset.OuiFormFieldset;
  }
});
Object.defineProperty(exports, "OuiFormLegend", {
  enumerable: true,
  get: function get() {
    return _form_legend.OuiFormLegend;
  }
});
Object.defineProperty(exports, "OuiCompressedFormLegend", {
  enumerable: true,
  get: function get() {
    return _form_legend.OuiCompressedFormLegend;
  }
});
Object.defineProperty(exports, "EuiFormFieldset", {
  enumerable: true,
  get: function get() {
    return _form_fieldset2.EuiFormFieldset;
  }
});
Object.defineProperty(exports, "EuiFormLegend", {
  enumerable: true,
  get: function get() {
    return _form_legend2.EuiFormLegend;
  }
});
Object.defineProperty(exports, "EuiCompressedFormLegend", {
  enumerable: true,
  get: function get() {
    return _form_legend2.EuiCompressedFormLegend;
  }
});
var _form_fieldset = require("./form_fieldset");
var _form_legend = require("./form_legend");
var _form_fieldset2 = require("../../../eui_components/form/form_fieldset/form_fieldset");
var _form_legend2 = require("../../../eui_components/form/form_fieldset/form_legend");