"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "injectI18n", {
  enumerable: true,
  get: function () {
    return _reactIntl.injectIntl;
  }
});
var _reactIntl = require("react-intl");