"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiHealth", {
  enumerable: true,
  get: function get() {
    return _health.OuiHealth;
  }
});
Object.defineProperty(exports, "EuiHealth", {
  enumerable: true,
  get: function get() {
    return _health2.EuiHealth;
  }
});
var _health = require("./health");
var _health2 = require("../../eui_components/health/health");