"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _typeof = require("@babel/runtime/helpers/typeof");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.icon = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var React = _interopRequireWildcard(require("react"));
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function _interopRequireWildcard(e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, default: e }; if (null === e || "object" != _typeof(e) && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (var _t in e) { "default" !== _t && {}.hasOwnProperty.call(e, _t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, _t)) && (i.get || i.set) ? o(f, _t, i) : f[_t] = e[_t]); } return f; })(e, t); }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

var EuiIconSparkleFilled = function EuiIconSparkleFilled(_ref) {
  var title = _ref.title,
    titleId = _ref.titleId,
    props = (0, _objectWithoutProperties2.default)(_ref, ["title", "titleId"]);
  return /*#__PURE__*/React.createElement("svg", (0, _extends2.default)({
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 16 16",
    "aria-labelledby": titleId
  }, props), title ? /*#__PURE__*/React.createElement("title", {
    id: titleId
  }, title) : null, /*#__PURE__*/React.createElement("path", {
    d: "m7.917 4.25 1.178 2.988 2.988 1.179-2.988 1.178-1.178 2.988-1.179-2.988L3.75 8.417l2.988-1.179L7.917 4.25Z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M7.917 3.833c.17 0 .325.105.387.264l1.112 2.82 2.82 1.112a.417.417 0 0 1 0 .775l-2.82 1.112-1.112 2.82a.417.417 0 0 1-.775 0l-1.112-2.82-2.82-1.112a.417.417 0 0 1 0-.775l2.82-1.112 1.112-2.82a.417.417 0 0 1 .388-.264Zm0 1.553L7.126 7.39a.417.417 0 0 1-.235.235l-2.005.79 2.005.792a.417.417 0 0 1 .235.234l.79 2.006.792-2.006a.417.417 0 0 1 .234-.234l2.006-.791-2.006-.791a.417.417 0 0 1-.234-.235l-.791-2.005ZM4.167 3l.53 1.136 1.136.53-1.136.531-.53 1.136-.53-1.136-1.137-.53 1.136-.53L4.166 3Z"
  }));
};
var icon = EuiIconSparkleFilled;
exports.icon = icon;