function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) { ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } } return n; }, _extends.apply(null, arguments); }
function _objectWithoutProperties(e, t) { if (null == e) return {}; var o, r, i = _objectWithoutPropertiesLoose(e, t); if (Object.getOwnPropertySymbols) { var n = Object.getOwnPropertySymbols(e); for (r = 0; r < n.length; r++) { o = n[r], -1 === t.indexOf(o) && {}.propertyIsEnumerable.call(e, o) && (i[o] = e[o]); } } return i; }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) { if ({}.hasOwnProperty.call(r, n)) { if (-1 !== e.indexOf(n)) continue; t[n] = r[n]; } } return t; }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

import * as React from 'react';
var EuiIconNavAlerting = function EuiIconNavAlerting(_ref) {
  var title = _ref.title,
    titleId = _ref.titleId,
    props = _objectWithoutProperties(_ref, ["title", "titleId"]);
  return /*#__PURE__*/React.createElement("svg", _extends({
    xmlns: "http://www.w3.org/2000/svg",
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    "aria-labelledby": titleId
  }, props), title ? /*#__PURE__*/React.createElement("title", {
    id: titleId
  }, title) : null, /*#__PURE__*/React.createElement("path", {
    d: "M14.195 4.508a.374.374 0 0 1-.501-.16 5.976 5.976 0 0 0-2.127-2.344.373.373 0 0 1 .397-.631 6.776 6.776 0 0 1 2.391 2.632.374.374 0 0 1-.16.503M2.87 4.348a5.976 5.976 0 0 1 2.127-2.344.374.374 0 0 0-.397-.631 6.776 6.776 0 0 0-2.39 2.632.374.374 0 1 0 .66.344m11.135 6.855a.872.872 0 0 1-.746 1.31h-2.644a2.364 2.364 0 0 1-4.665 0H3.305a.872.872 0 0 1-.749-1.31c.571-.986.875-2.383.875-4.04a4.852 4.852 0 0 1 9.704 0c0 1.679.295 3.04.875 4.04zm-4.15 1.31H6.709a1.617 1.617 0 0 0 3.146 0m3.511-.934c-.649-1.12-.979-2.603-.979-4.416a4.105 4.105 0 0 0-8.211 0c0 1.814-.329 3.297-.977 4.416a.122.122 0 0 0 0 .125.122.122 0 0 0 .105.062h9.954a.122.122 0 0 0 .106-.062.122.122 0 0 0 0-.125"
  }));
};
export var icon = EuiIconNavAlerting;