"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiDualRange", {
  enumerable: true,
  get: function get() {
    return _dual_range.EuiDualRange;
  }
});
Object.defineProperty(exports, "EuiCompressedDualRange", {
  enumerable: true,
  get: function get() {
    return _dual_range.EuiCompressedDualRange;
  }
});
Object.defineProperty(exports, "EuiRange", {
  enumerable: true,
  get: function get() {
    return _range.EuiRange;
  }
});
Object.defineProperty(exports, "EuiCompressedRange", {
  enumerable: true,
  get: function get() {
    return _range.EuiCompressedRange;
  }
});
var _dual_range = require("./dual_range");
var _range = require("./range");