"use strict";
// Generated from ./src/plugins/data/public/antlr/promql/grammar/PromQLParser.g4 by ANTLR 4.13.1
Object.defineProperty(exports, "__esModule", { value: true });
exports.PromQLParserVisitor = void 0;
const antlr4ng_1 = require("antlr4ng");
/**
 * This interface defines a complete generic visitor for a parse tree produced
 * by `PromQLParser`.
 *
 * @param <Result> The return type of the visit operation. Use `void` for
 * operations with no return type.
 */
class PromQLParserVisitor extends antlr4ng_1.AbstractParseTreeVisitor {
    /**
     * Visit a parse tree produced by `PromQLParser.expression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitExpression;
    /**
     * Visit a parse tree produced by `PromQLParser.vectorOperation`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitVectorOperation;
    /**
     * Visit a parse tree produced by `PromQLParser.unaryOp`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitUnaryOp;
    /**
     * Visit a parse tree produced by `PromQLParser.powOp`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitPowOp;
    /**
     * Visit a parse tree produced by `PromQLParser.multOp`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitMultOp;
    /**
     * Visit a parse tree produced by `PromQLParser.addOp`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitAddOp;
    /**
     * Visit a parse tree produced by `PromQLParser.compareOp`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitCompareOp;
    /**
     * Visit a parse tree produced by `PromQLParser.andUnlessOp`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitAndUnlessOp;
    /**
     * Visit a parse tree produced by `PromQLParser.orOp`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitOrOp;
    /**
     * Visit a parse tree produced by `PromQLParser.vectorMatchOp`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitVectorMatchOp;
    /**
     * Visit a parse tree produced by `PromQLParser.subqueryOp`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSubqueryOp;
    /**
     * Visit a parse tree produced by `PromQLParser.offsetOp`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitOffsetOp;
    /**
     * Visit a parse tree produced by `PromQLParser.vector`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitVector;
    /**
     * Visit a parse tree produced by `PromQLParser.parens`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitParens;
    /**
     * Visit a parse tree produced by `PromQLParser.metricName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitMetricName;
    /**
     * Visit a parse tree produced by `PromQLParser.instantSelector`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitInstantSelector;
    /**
     * Visit a parse tree produced by `PromQLParser.labelMatcher`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitLabelMatcher;
    /**
     * Visit a parse tree produced by `PromQLParser.labelValue`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitLabelValue;
    /**
     * Visit a parse tree produced by `PromQLParser.labelMatcherOperator`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitLabelMatcherOperator;
    /**
     * Visit a parse tree produced by `PromQLParser.labelMatcherList`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitLabelMatcherList;
    /**
     * Visit a parse tree produced by `PromQLParser.matrixSelector`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitMatrixSelector;
    /**
     * Visit a parse tree produced by `PromQLParser.timeRange`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTimeRange;
    /**
     * Visit a parse tree produced by `PromQLParser.subqueryRange`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSubqueryRange;
    /**
     * Visit a parse tree produced by `PromQLParser.duration`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitDuration;
    /**
     * Visit a parse tree produced by `PromQLParser.offset`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitOffset;
    /**
     * Visit a parse tree produced by `PromQLParser.function`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitFunction;
    /**
     * Visit a parse tree produced by `PromQLParser.parameter`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitParameter;
    /**
     * Visit a parse tree produced by `PromQLParser.parameterList`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitParameterList;
    /**
     * Visit a parse tree produced by `PromQLParser.functionNames`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitFunctionNames;
    /**
     * Visit a parse tree produced by `PromQLParser.aggregation`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitAggregation;
    /**
     * Visit a parse tree produced by `PromQLParser.by`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitBy;
    /**
     * Visit a parse tree produced by `PromQLParser.without`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitWithout;
    /**
     * Visit a parse tree produced by `PromQLParser.aggregationOperators`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitAggregationOperators;
    /**
     * Visit a parse tree produced by `PromQLParser.grouping`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitGrouping;
    /**
     * Visit a parse tree produced by `PromQLParser.on_`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitOn_;
    /**
     * Visit a parse tree produced by `PromQLParser.ignoring`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitIgnoring;
    /**
     * Visit a parse tree produced by `PromQLParser.groupLeft`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitGroupLeft;
    /**
     * Visit a parse tree produced by `PromQLParser.groupRight`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitGroupRight;
    /**
     * Visit a parse tree produced by `PromQLParser.labelName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitLabelName;
    /**
     * Visit a parse tree produced by `PromQLParser.labelNameList`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitLabelNameList;
    /**
     * Visit a parse tree produced by `PromQLParser.keyword`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitKeyword;
    /**
     * Visit a parse tree produced by `PromQLParser.literal`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitLiteral;
}
exports.PromQLParserVisitor = PromQLParserVisitor;
//# sourceMappingURL=PromQLParserVisitor.js.map