"use strict";

function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OuiResizableContainerContextProvider = OuiResizableContainerContextProvider;
Object.defineProperty(exports, "EuiResizableContainerContextProvider", {
  enumerable: true,
  get: function get() {
    return _context.EuiResizableContainerContextProvider;
  }
});
Object.defineProperty(exports, "useEuiResizableContainerContext", {
  enumerable: true,
  get: function get() {
    return _context.useEuiResizableContainerContext;
  }
});
exports.useOuiResizableContainerContext = void 0;
var _react = _interopRequireWildcard(require("react"));
var _context = require("../../eui_components/resizable_container/context");
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function _interopRequireWildcard(e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, default: e }; if (null === e || "object" != _typeof(e) && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (var _t in e) { "default" !== _t && {}.hasOwnProperty.call(e, _t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, _t)) && (i.get || i.set) ? o(f, _t, i) : f[_t] = e[_t]); } return f; })(e, t); }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

var OuiResizableContainerContext = /*#__PURE__*/(0, _react.createContext)({});
function OuiResizableContainerContextProvider(_ref) {
  var children = _ref.children,
    registry = _ref.registry;
  return /*#__PURE__*/_react.default.createElement(OuiResizableContainerContext.Provider, {
    value: {
      registry: registry
    }
  }, children);
}
var useOuiResizableContainerContext = function useOuiResizableContainerContext() {
  var context = (0, _react.useContext)(OuiResizableContainerContext);
  if (!context.registry) {
    throw new Error('useOuiResizableContainerContext must be used within a <OuiResizableContainerContextProvider />');
  }
  return context;
};

/* OUI -> EUI Aliases: Build-Time */
exports.useOuiResizableContainerContext = useOuiResizableContainerContext;