"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiHighlight", {
  enumerable: true,
  get: function get() {
    return _highlight.OuiHighlight;
  }
});
Object.defineProperty(exports, "EuiHighlight", {
  enumerable: true,
  get: function get() {
    return _highlight2.EuiHighlight;
  }
});
var _highlight = require("./highlight");
var _highlight2 = require("../../eui_components/highlight/highlight");