"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiResizableContainer", {
  enumerable: true,
  get: function get() {
    return _resizable_container.OuiResizableContainer;
  }
});
Object.defineProperty(exports, "EuiResizableContainer", {
  enumerable: true,
  get: function get() {
    return _resizable_container2.EuiResizableContainer;
  }
});
var _resizable_container = require("./resizable_container");
var _resizable_container2 = require("../../eui_components/resizable_container/resizable_container");