"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiBasicTable", {
  enumerable: true,
  get: function get() {
    return _basic_table.OuiBasicTable;
  }
});
Object.defineProperty(exports, "OuiInMemoryTable", {
  enumerable: true,
  get: function get() {
    return _in_memory_table.OuiInMemoryTable;
  }
});
Object.defineProperty(exports, "EuiBasicTable", {
  enumerable: true,
  get: function get() {
    return _basic_table2.EuiBasicTable;
  }
});
Object.defineProperty(exports, "EuiInMemoryTable", {
  enumerable: true,
  get: function get() {
    return _in_memory_table2.EuiInMemoryTable;
  }
});
var _basic_table = require("./basic_table");
var _in_memory_table = require("./in_memory_table");
require("./table_types");
require("./pagination_bar");
require("./action_types");
var _basic_table2 = require("../../eui_components/basic_table/basic_table");
var _in_memory_table2 = require("../../eui_components/basic_table/in_memory_table");
require("../../eui_components/basic_table/table_types");