"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiToolTip", {
  enumerable: true,
  get: function get() {
    return _tool_tip.OuiToolTip;
  }
});
Object.defineProperty(exports, "OuiIconTip", {
  enumerable: true,
  get: function get() {
    return _icon_tip.OuiIconTip;
  }
});
Object.defineProperty(exports, "EuiToolTip", {
  enumerable: true,
  get: function get() {
    return _tool_tip2.EuiToolTip;
  }
});
Object.defineProperty(exports, "EuiIconTip", {
  enumerable: true,
  get: function get() {
    return _icon_tip2.EuiIconTip;
  }
});
var _tool_tip = require("./tool_tip");
var _icon_tip = require("./icon_tip");
var _tool_tip2 = require("../../eui_components/tool_tip/tool_tip");
var _icon_tip2 = require("../../eui_components/tool_tip/icon_tip");