"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTooltipTypeSelector = void 0;
var settings_1 = require("../../../../specs/settings");
var create_selector_1 = require("../../../../state/create_selector");
var get_settings_specs_1 = require("../../../../state/selectors/get_settings_specs");
exports.getTooltipTypeSelector = create_selector_1.createCustomCachedSelector([get_settings_specs_1.getSettingsSpecSelector], settings_1.getTooltipType);
//# sourceMappingURL=get_tooltip_type.js.map