"use strict";
/* eslint-disable @typescript-eslint/no-explicit-any */
Object.defineProperty(exports, "__esModule", { value: true });
exports.isSyncTransform = void 0;
const isSyncTransform = (transform) => {
    return transform.length === 1;
};
exports.isSyncTransform = isSyncTransform;
//# sourceMappingURL=types.js.map