/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */
import React from 'react';
import { ColorScheme } from '../../shared/utils/colors.utils';
import { ColorSwatch } from './color_swatch';
import { jsx as _jsx } from "react/jsx-runtime";
export const FaultsSwatch = () => /*#__PURE__*/_jsx(ColorSwatch, {
  color: ColorScheme.faults
});