"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiWindowEvent", {
  enumerable: true,
  get: function get() {
    return _window_event.OuiWindowEvent;
  }
});
Object.defineProperty(exports, "EuiWindowEvent", {
  enumerable: true,
  get: function get() {
    return _window_event.OuiWindowEvent;
  }
});
var _window_event = require("./window_event");