"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _celestial_controls = require("./celestial_controls");
Object.keys(_celestial_controls).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _celestial_controls[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _celestial_controls[key];
    }
  });
});