"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiFormErrorText", {
  enumerable: true,
  get: function get() {
    return _form_error_text.OuiFormErrorText;
  }
});
Object.defineProperty(exports, "EuiFormErrorText", {
  enumerable: true,
  get: function get() {
    return _form_error_text2.EuiFormErrorText;
  }
});
var _form_error_text = require("./form_error_text");
var _form_error_text2 = require("../../../eui_components/form/form_error_text/form_error_text");