"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiFacetButton", {
  enumerable: true,
  get: function get() {
    return _facet_button.OuiFacetButton;
  }
});
Object.defineProperty(exports, "OuiFacetGroup", {
  enumerable: true,
  get: function get() {
    return _facet_group.OuiFacetGroup;
  }
});
Object.defineProperty(exports, "EuiFacetButton", {
  enumerable: true,
  get: function get() {
    return _facet_button2.EuiFacetButton;
  }
});
Object.defineProperty(exports, "EuiFacetGroup", {
  enumerable: true,
  get: function get() {
    return _facet_group2.EuiFacetGroup;
  }
});
var _facet_button = require("./facet_button");
var _facet_group = require("./facet_group");
var _facet_button2 = require("../../eui_components/facet/facet_button");
var _facet_group2 = require("../../eui_components/facet/facet_group");