"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiSelect", {
  enumerable: true,
  get: function get() {
    return _select.OuiSelect;
  }
});
Object.defineProperty(exports, "OuiCompressedSelect", {
  enumerable: true,
  get: function get() {
    return _select.OuiCompressedSelect;
  }
});
Object.defineProperty(exports, "EuiSelect", {
  enumerable: true,
  get: function get() {
    return _select2.EuiSelect;
  }
});
Object.defineProperty(exports, "EuiCompressedSelect", {
  enumerable: true,
  get: function get() {
    return _select2.EuiCompressedSelect;
  }
});
var _select = require("./select");
var _select2 = require("../../../eui_components/form/select/select");