"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiCollapsibleNavGroup", {
  enumerable: true,
  get: function get() {
    return _collapsible_nav_group.OuiCollapsibleNavGroup;
  }
});
Object.defineProperty(exports, "OuiCollapsibleNav", {
  enumerable: true,
  get: function get() {
    return _collapsible_nav.OuiCollapsibleNav;
  }
});
Object.defineProperty(exports, "EuiCollapsibleNavGroup", {
  enumerable: true,
  get: function get() {
    return _collapsible_nav_group2.EuiCollapsibleNavGroup;
  }
});
Object.defineProperty(exports, "EuiCollapsibleNav", {
  enumerable: true,
  get: function get() {
    return _collapsible_nav2.EuiCollapsibleNav;
  }
});
var _collapsible_nav_group = require("./collapsible_nav_group");
var _collapsible_nav = require("./collapsible_nav");
var _collapsible_nav_group2 = require("../../eui_components/collapsible_nav/collapsible_nav_group");
var _collapsible_nav2 = require("../../eui_components/collapsible_nav/collapsible_nav");