"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiSimplifiedBreadcrumbs", {
  enumerable: true,
  get: function get() {
    return _simplified_breadcrumbs.OuiSimplifiedBreadcrumbs;
  }
});
Object.defineProperty(exports, "EuiSimplifiedBreadcrumbs", {
  enumerable: true,
  get: function get() {
    return _simplified_breadcrumbs2.EuiSimplifiedBreadcrumbs;
  }
});
var _simplified_breadcrumbs = require("./simplified_breadcrumbs");
var _simplified_breadcrumbs2 = require("../../../eui_components/breadcrumbs/simplified_breadcrumbs/simplified_breadcrumbs");