"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiHeaderLink", {
  enumerable: true,
  get: function get() {
    return _header_link.OuiHeaderLink;
  }
});
Object.defineProperty(exports, "OuiHeaderLinks", {
  enumerable: true,
  get: function get() {
    return _header_links.OuiHeaderLinks;
  }
});
Object.defineProperty(exports, "EuiHeaderLink", {
  enumerable: true,
  get: function get() {
    return _header_link2.EuiHeaderLink;
  }
});
Object.defineProperty(exports, "EuiHeaderLinks", {
  enumerable: true,
  get: function get() {
    return _header_links2.EuiHeaderLinks;
  }
});
var _header_link = require("./header_link");
var _header_links = require("./header_links");
var _header_link2 = require("../../../eui_components/header/header_links/header_link");
var _header_links2 = require("../../../eui_components/header/header_links/header_links");