"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GlassBackground = void 0;
var _react = _interopRequireDefault(require("react"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */

const GlassBackground = ({
  children
}) => {
  return /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
    className: "osd:bg-container-default/0.2 osd:backdrop-blur-xs osd:absolute osd:inset-0 osd:flex osd:justify-center osd:items-center osd:z-10",
    children: children
  });
};
exports.GlassBackground = GlassBackground;