function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(e, r, t) { return (r = _toPropertyKey(r)) in e ? Object.defineProperty(e, r, { value: t, enumerable: !0, configurable: !0, writable: !0 }) : e[r] = t, e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == typeof i ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != typeof t || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != typeof i) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */

import { MarkerType } from '@xyflow/react';
import { useMemo } from 'react';
import { TopologyNodeTransformer } from '../transformers/celestial_node.transformer';
import { TopologyNodeModel } from '../models/topology_node.model';
import { DEFAULT_GRID_CONFIG, calculatePosition, computeDependencyTypes } from '../utils/celestial_node.utils';
export const useCelestialNodes = data => useMemo(() => {
  var _data$Edges2;
  const nodes = data.Nodes.map((node, idx) => {
    var _data$Edges;
    const position = calculatePosition(idx, DEFAULT_GRID_CONFIG);
    const enhancedNode = _objectSpread(_objectSpread({}, node), {}, {
      DependencyTypes: computeDependencyTypes(node, (_data$Edges = data.Edges) !== null && _data$Edges !== void 0 ? _data$Edges : [], data.Nodes)
    });
    const model = new TopologyNodeModel(enhancedNode);
    return {
      id: node.NodeId,
      type: 'celestialNode',
      position,
      data: new TopologyNodeTransformer(model).toCelestialCard(),
      selectable: true,
      deletable: false
    };
  });
  const edges = ((_data$Edges2 = data.Edges) !== null && _data$Edges2 !== void 0 ? _data$Edges2 : []).map(edge => ({
    id: edge.EdgeId,
    source: edge.SourceNodeId,
    target: edge.DestinationNodeId,
    sourceHandle: 'source-right',
    targetHandle: 'target-left',
    markerEnd: {
      type: MarkerType.ArrowClosed
    },
    style: {
      strokeWidth: 2
    },
    type: 'bezier',
    data: {
      relationship: 'Invoke',
      statistics: edge.StatisticReferences
    }
  })) || [];
  return {
    nodes,
    edges
  };
}, [data]);