"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiSplitButton", {
  enumerable: true,
  get: function get() {
    return _split_button.OuiSplitButton;
  }
});
Object.defineProperty(exports, "OuiSplitButtonControl", {
  enumerable: true,
  get: function get() {
    return _split_button_control.OuiSplitButtonControl;
  }
});
Object.defineProperty(exports, "EuiSplitButton", {
  enumerable: true,
  get: function get() {
    return _split_button2.EuiSplitButton;
  }
});
Object.defineProperty(exports, "EuiSplitButtonControl", {
  enumerable: true,
  get: function get() {
    return _split_button_control2.EuiSplitButtonControl;
  }
});
var _split_button = require("./split_button");
var _split_button_control = require("./split_button_control");
var _split_button2 = require("../../eui_components/split_button/split_button");
var _split_button_control2 = require("../../eui_components/split_button/split_button_control");