"use strict";
// Generated from ./src/dql/grammar/DQLParser.g4 by ANTLR 4.13.1
Object.defineProperty(exports, "__esModule", { value: true });
exports.DQLParserVisitor = void 0;
const antlr4ng_1 = require("antlr4ng");
/**
 * This interface defines a complete generic visitor for a parse tree produced
 * by `DQLParser`.
 *
 * @param <Result> The return type of the visit operation. Use `void` for
 * operations with no return type.
 */
class DQLParserVisitor extends antlr4ng_1.AbstractParseTreeVisitor {
    /**
     * Visit a parse tree produced by `DQLParser.query`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitQuery;
    /**
     * Visit a parse tree produced by `DQLParser.operatorExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitOperatorExpression;
    /**
     * Visit a parse tree produced by `DQLParser.booleanOperator`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitBooleanOperator;
    /**
     * Visit a parse tree produced by `DQLParser.notExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitNotExpression;
    /**
     * Visit a parse tree produced by `DQLParser.primaryExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitPrimaryExpression;
    /**
     * Visit a parse tree produced by `DQLParser.comparisonExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitComparisonExpression;
    /**
     * Visit a parse tree produced by `DQLParser.keyValueExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitKeyValueExpression;
    /**
     * Visit a parse tree produced by `DQLParser.tokenSearch`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTokenSearch;
    /**
     * Visit a parse tree produced by `DQLParser.groupExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitGroupExpression;
    /**
     * Visit a parse tree produced by `DQLParser.groupContent`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitGroupContent;
    /**
     * Visit a parse tree produced by `DQLParser.field`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitField;
    /**
     * Visit a parse tree produced by `DQLParser.value`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitValue;
    /**
     * Visit a parse tree produced by `DQLParser.comparisonOperator`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitComparisonOperator;
}
exports.DQLParserVisitor = DQLParserVisitor;
//# sourceMappingURL=DQLParserVisitor.js.map