"use strict";(self.webpackChunk_osdSharedDeps_=self.webpackChunk_osdSharedDeps_||[]).push([["598"],{50685:function(t,e,a){a.r(e),a.d(e,{encodeSemanticTokensDto:()=>l});var r=a(4591),n=a(90670);function l(t){var e,a=new Uint32Array(function(t){var e;if(e=2,"full"===t.type)e+=1+t.data.length;else{e+=1,e+=3*t.deltas.length;var a=!0,r=!1,n=void 0;try{for(var l,d=t.deltas[Symbol.iterator]();!(a=(l=d.next()).done);a=!0){var f=l.value;f.data&&(e+=f.data.length)}}catch(t){r=!0,n=t}finally{try{a||null==d.return||d.return()}finally{if(r)throw n}}}return e}(t)),l=0;if(a[l++]=t.id,"full"===t.type)a[l++]=1,a[l++]=t.data.length,a.set(t.data,l),l+=t.data.length;else{a[l++]=2,a[l++]=t.deltas.length;var d=!0,f=!1,o=void 0;try{for(var u,i=t.deltas[Symbol.iterator]();!(d=(u=i.next()).done);d=!0){var s=u.value;a[l++]=s.start,a[l++]=s.deleteCount,s.data?(a[l++]=s.data.length,a.set(s.data,l),l+=s.data.length):a[l++]=0}}catch(t){f=!0,o=t}finally{try{d||null==i.return||i.return()}finally{if(f)throw o}}}return e=new Uint8Array(a.buffer,a.byteOffset,4*a.length),n.cm()||function(t){for(var e=0,a=t.length;e<a;e+=4){var r=t[e+0],n=t[e+1],l=t[e+2],d=t[e+3];t[e+0]=d,t[e+1]=l,t[e+2]=n,t[e+3]=r}}(e),r.MB.wrap(e)}}}]);