"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiFormControlLayout", {
  enumerable: true,
  get: function get() {
    return _form_control_layout.EuiFormControlLayout;
  }
});
Object.defineProperty(exports, "EuiFormControlLayoutDelimited", {
  enumerable: true,
  get: function get() {
    return _form_control_layout_delimited.EuiFormControlLayoutDelimited;
  }
});
var _form_control_layout = require("./form_control_layout");
var _form_control_layout_delimited = require("./form_control_layout_delimited");