"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiFieldPassword", {
  enumerable: true,
  get: function get() {
    return _field_password.OuiFieldPassword;
  }
});
Object.defineProperty(exports, "OuiCompressedFieldPassword", {
  enumerable: true,
  get: function get() {
    return _field_password.OuiCompressedFieldPassword;
  }
});
Object.defineProperty(exports, "EuiFieldPassword", {
  enumerable: true,
  get: function get() {
    return _field_password2.EuiFieldPassword;
  }
});
Object.defineProperty(exports, "EuiCompressedFieldPassword", {
  enumerable: true,
  get: function get() {
    return _field_password2.EuiCompressedFieldPassword;
  }
});
var _field_password = require("./field_password");
var _field_password2 = require("../../../eui_components/form/field_password/field_password");