"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiValidatableControl", {
  enumerable: true,
  get: function get() {
    return _validatable_control.OuiValidatableControl;
  }
});
Object.defineProperty(exports, "EuiValidatableControl", {
  enumerable: true,
  get: function get() {
    return _validatable_control2.EuiValidatableControl;
  }
});
var _validatable_control = require("./validatable_control");
var _validatable_control2 = require("../../../eui_components/form/validatable_control/validatable_control");