"use strict";
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.registerLexerRules = void 0;
const tslib_1 = require("tslib");
const xJson = tslib_1.__importStar(require("./xjson"));
const opensearchql = tslib_1.__importStar(require("./opensearchql"));
const painless = tslib_1.__importStar(require("./painless"));
const opensearchsql = tslib_1.__importStar(require("./opensearchsql"));
const promql = tslib_1.__importStar(require("./promql"));
const registerLexerRules = (m) => {
    m.languages.register({ id: xJson.ID });
    m.languages.setMonarchTokensProvider(xJson.ID, xJson.lexerRules);
    m.languages.register({ id: painless.ID });
    m.languages.setMonarchTokensProvider(painless.ID, painless.lexerRules);
    m.languages.register({ id: opensearchql.ID });
    m.languages.setMonarchTokensProvider(opensearchql.ID, opensearchql.lexerRules);
    m.languages.register({ id: opensearchsql.ID });
    m.languages.setMonarchTokensProvider(opensearchsql.ID, opensearchsql.lexerRules);
    m.languages.register({ id: 'kuery' });
    m.languages.register({ id: 'AI' });
    m.languages.register({ id: promql.ID });
    m.languages.setMonarchTokensProvider(promql.ID, promql.lexerRules);
};
exports.registerLexerRules = registerLexerRules;
//# sourceMappingURL=index.js.map