"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiFieldSearch", {
  enumerable: true,
  get: function get() {
    return _field_search.OuiFieldSearch;
  }
});
Object.defineProperty(exports, "OuiCompressedFieldSearch", {
  enumerable: true,
  get: function get() {
    return _field_search.OuiCompressedFieldSearch;
  }
});
Object.defineProperty(exports, "EuiFieldSearch", {
  enumerable: true,
  get: function get() {
    return _field_search2.EuiFieldSearch;
  }
});
Object.defineProperty(exports, "EuiCompressedFieldSearch", {
  enumerable: true,
  get: function get() {
    return _field_search2.EuiCompressedFieldSearch;
  }
});
var _field_search = require("./field_search");
var _field_search2 = require("../../../eui_components/form/field_search/field_search");