"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiInputPopover", {
  enumerable: true,
  get: function get() {
    return _input_popover.OuiInputPopover;
  }
});
Object.defineProperty(exports, "OuiPopover", {
  enumerable: true,
  get: function get() {
    return _popover.OuiPopover;
  }
});
Object.defineProperty(exports, "OuiPopoverTitle", {
  enumerable: true,
  get: function get() {
    return _popover_title.OuiPopoverTitle;
  }
});
Object.defineProperty(exports, "OuiPopoverFooter", {
  enumerable: true,
  get: function get() {
    return _popover_footer.OuiPopoverFooter;
  }
});
Object.defineProperty(exports, "OuiWrappingPopover", {
  enumerable: true,
  get: function get() {
    return _wrapping_popover.OuiWrappingPopover;
  }
});
Object.defineProperty(exports, "EuiInputPopover", {
  enumerable: true,
  get: function get() {
    return _input_popover2.EuiInputPopover;
  }
});
Object.defineProperty(exports, "EuiPopover", {
  enumerable: true,
  get: function get() {
    return _popover2.EuiPopover;
  }
});
Object.defineProperty(exports, "EuiPopoverTitle", {
  enumerable: true,
  get: function get() {
    return _popover_title2.EuiPopoverTitle;
  }
});
Object.defineProperty(exports, "EuiPopoverFooter", {
  enumerable: true,
  get: function get() {
    return _popover_footer2.EuiPopoverFooter;
  }
});
Object.defineProperty(exports, "EuiWrappingPopover", {
  enumerable: true,
  get: function get() {
    return _wrapping_popover2.EuiWrappingPopover;
  }
});
var _input_popover = require("./input_popover");
var _popover = require("./popover");
var _popover_title = require("./popover_title");
var _popover_footer = require("./popover_footer");
var _wrapping_popover = require("./wrapping_popover");
var _input_popover2 = require("../../eui_components/popover/input_popover");
var _popover2 = require("../../eui_components/popover/popover");
var _popover_title2 = require("../../eui_components/popover/popover_title");
var _popover_footer2 = require("../../eui_components/popover/popover_footer");
var _wrapping_popover2 = require("../../eui_components/popover/wrapping_popover");