"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _typeof = require("@babel/runtime/helpers/typeof");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.icon = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var React = _interopRequireWildcard(require("react"));
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function _interopRequireWildcard(e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, default: e }; if (null === e || "object" != _typeof(e) && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (var _t in e) { "default" !== _t && {}.hasOwnProperty.call(e, _t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, _t)) && (i.get || i.set) ? o(f, _t, i) : f[_t] = e[_t]); } return f; })(e, t); }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

var EuiIconGenContent = function EuiIconGenContent(_ref) {
  var title = _ref.title,
    titleId = _ref.titleId,
    props = (0, _objectWithoutProperties2.default)(_ref, ["title", "titleId"]);
  return /*#__PURE__*/React.createElement("svg", (0, _extends2.default)({
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 16 16",
    "aria-labelledby": titleId
  }, props), title ? /*#__PURE__*/React.createElement("title", {
    id: titleId
  }, title) : null, /*#__PURE__*/React.createElement("path", {
    d: "M12 2H2V13H8.5L9 14H1V1H13V8.5L12 7.5V2Z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M3 5H10.999V4H3V5Z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M3 8V7H9L8.5 8H3Z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M3 11V10H5.5V11H3Z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M10.6865 14.5283L10.6533 14.584C10.5751 14.6784 10.4249 14.6784 10.3467 14.584L10.3135 14.5283L10.2441 14.3535L10.5 14.4541L10.7549 14.3535L10.6865 14.5283ZM10.3135 6.47165C10.3801 6.30282 10.6199 6.30282 10.6865 6.47165L11.2949 8.01462C11.5999 8.78779 12.2122 9.40012 12.9854 9.70505L14.3535 10.2441L14.4541 10.5L14.3535 10.7549L12.9854 11.2949L12.8418 11.3554C12.1364 11.6768 11.5808 12.2605 11.2949 12.9853L10.7549 14.3535L10.5 14.4541L10.2441 14.3535L9.70508 12.9853C9.41921 12.2605 8.86362 11.6768 8.15821 11.3554L8.01465 11.2949L6.47168 10.6865C6.30286 10.6199 6.30286 10.38 6.47168 10.3135L6.64551 10.2441L8.01465 9.70505C8.73949 9.41918 9.32321 8.86359 9.64454 8.15818L9.70508 8.01462L10.3135 6.47165ZM10.5 8.68357C10.1108 9.47256 9.47259 10.1107 8.6836 10.5C9.47233 10.8891 10.1107 11.5268 10.5 12.3154C10.8892 11.527 11.5271 10.8891 12.3154 10.5C11.5268 10.1107 10.8891 9.4723 10.5 8.68357ZM14.5283 10.3135C14.6972 10.38 14.6972 10.6199 14.5283 10.6865L14.3535 10.7549L14.4541 10.5L14.3535 10.2441L14.5283 10.3135Z"
  }));
};
var icon = EuiIconGenContent;
exports.icon = icon;