"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiErrorBoundary", {
  enumerable: true,
  get: function get() {
    return _error_boundary.OuiErrorBoundary;
  }
});
Object.defineProperty(exports, "EuiErrorBoundary", {
  enumerable: true,
  get: function get() {
    return _error_boundary2.EuiErrorBoundary;
  }
});
var _error_boundary = require("./error_boundary");
var _error_boundary2 = require("../../eui_components/error_boundary/error_boundary");