"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiFormFieldset", {
  enumerable: true,
  get: function get() {
    return _form_fieldset.EuiFormFieldset;
  }
});
Object.defineProperty(exports, "EuiFormLegend", {
  enumerable: true,
  get: function get() {
    return _form_legend.EuiFormLegend;
  }
});
Object.defineProperty(exports, "EuiCompressedFormLegend", {
  enumerable: true,
  get: function get() {
    return _form_legend.EuiCompressedFormLegend;
  }
});
var _form_fieldset = require("./form_fieldset");
var _form_legend = require("./form_legend");