"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiCheckbox", {
  enumerable: true,
  get: function get() {
    return _checkbox.OuiCheckbox;
  }
});
Object.defineProperty(exports, "OuiCompressedCheckbox", {
  enumerable: true,
  get: function get() {
    return _checkbox.OuiCompressedCheckbox;
  }
});
Object.defineProperty(exports, "OuiCheckboxGroup", {
  enumerable: true,
  get: function get() {
    return _checkbox_group.OuiCheckboxGroup;
  }
});
Object.defineProperty(exports, "OuiCompressedCheckboxGroup", {
  enumerable: true,
  get: function get() {
    return _checkbox_group.OuiCompressedCheckboxGroup;
  }
});
Object.defineProperty(exports, "EuiCheckbox", {
  enumerable: true,
  get: function get() {
    return _checkbox2.EuiCheckbox;
  }
});
Object.defineProperty(exports, "EuiCompressedCheckbox", {
  enumerable: true,
  get: function get() {
    return _checkbox2.EuiCompressedCheckbox;
  }
});
Object.defineProperty(exports, "EuiCheckboxGroup", {
  enumerable: true,
  get: function get() {
    return _checkbox_group2.EuiCheckboxGroup;
  }
});
Object.defineProperty(exports, "EuiCompressedCheckboxGroup", {
  enumerable: true,
  get: function get() {
    return _checkbox_group2.EuiCompressedCheckboxGroup;
  }
});
var _checkbox = require("./checkbox");
var _checkbox_group = require("./checkbox_group");
var _checkbox2 = require("../../../eui_components/form/checkbox/checkbox");
var _checkbox_group2 = require("../../../eui_components/form/checkbox/checkbox_group");