"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiFieldNumber", {
  enumerable: true,
  get: function get() {
    return _field_number.OuiFieldNumber;
  }
});
Object.defineProperty(exports, "OuiCompressedFieldNumber", {
  enumerable: true,
  get: function get() {
    return _field_number.OuiCompressedFieldNumber;
  }
});
Object.defineProperty(exports, "EuiFieldNumber", {
  enumerable: true,
  get: function get() {
    return _field_number2.EuiFieldNumber;
  }
});
Object.defineProperty(exports, "EuiCompressedFieldNumber", {
  enumerable: true,
  get: function get() {
    return _field_number2.EuiCompressedFieldNumber;
  }
});
var _field_number = require("./field_number");
var _field_number2 = require("../../../eui_components/form/field_number/field_number");