"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiSwitch", {
  enumerable: true,
  get: function get() {
    return _switch.OuiSwitch;
  }
});
Object.defineProperty(exports, "OuiCompressedSwitch", {
  enumerable: true,
  get: function get() {
    return _switch.OuiCompressedSwitch;
  }
});
Object.defineProperty(exports, "EuiSwitch", {
  enumerable: true,
  get: function get() {
    return _switch2.EuiSwitch;
  }
});
Object.defineProperty(exports, "EuiCompressedSwitch", {
  enumerable: true,
  get: function get() {
    return _switch2.EuiCompressedSwitch;
  }
});
var _switch = require("./switch");
var _switch2 = require("../../../eui_components/form/switch/switch");