"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiSwitch", {
  enumerable: true,
  get: function get() {
    return _switch.EuiSwitch;
  }
});
Object.defineProperty(exports, "EuiCompressedSwitch", {
  enumerable: true,
  get: function get() {
    return _switch.EuiCompressedSwitch;
  }
});
var _switch = require("./switch");