"use strict";
/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.PPLLang = exports.setPPLValidationContext = exports.resolvePPLValidationResult = exports.registerPPLValidationProvider = exports.clearPPLValidationContext = exports.revalidatePPLModel = void 0;
/**
 * This import registers the PPL monaco language contribution
 */
require("./language");
var language_1 = require("./language");
Object.defineProperty(exports, "revalidatePPLModel", { enumerable: true, get: function () { return language_1.revalidatePPLModel; } });
const constants_1 = require("./constants");
var validation_provider_1 = require("./validation_provider");
Object.defineProperty(exports, "clearPPLValidationContext", { enumerable: true, get: function () { return validation_provider_1.clearPPLValidationContext; } });
Object.defineProperty(exports, "registerPPLValidationProvider", { enumerable: true, get: function () { return validation_provider_1.registerPPLValidationProvider; } });
Object.defineProperty(exports, "resolvePPLValidationResult", { enumerable: true, get: function () { return validation_provider_1.resolvePPLValidationResult; } });
Object.defineProperty(exports, "setPPLValidationContext", { enumerable: true, get: function () { return validation_provider_1.setPPLValidationContext; } });
exports.PPLLang = { ID: constants_1.ID };
//# sourceMappingURL=index.js.map