"use strict";
// Generated from ./src/opensearch_ppl/grammar/OpenSearchPPLParser.g4 by ANTLR 4.13.1
Object.defineProperty(exports, "__esModule", { value: true });
exports.OpenSearchPPLParserVisitor = void 0;
const antlr4ng_1 = require("antlr4ng");
/**
 * This interface defines a complete generic visitor for a parse tree produced
 * by `OpenSearchPPLParser`.
 *
 * @param <Result> The return type of the visit operation. Use `void` for
 * operations with no return type.
 */
class OpenSearchPPLParserVisitor extends antlr4ng_1.AbstractParseTreeVisitor {
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.root`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitRoot;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.pplStatement`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitPplStatement;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.dmlStatement`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitDmlStatement;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.queryStatement`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitQueryStatement;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.pplCommands`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitPplCommands;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.commands`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitCommands;
    /**
     * Visit a parse tree produced by the `searchFrom`
     * labeled alternative in `OpenSearchPPLParser.searchCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSearchFrom;
    /**
     * Visit a parse tree produced by the `searchFromFilter`
     * labeled alternative in `OpenSearchPPLParser.searchCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSearchFromFilter;
    /**
     * Visit a parse tree produced by the `searchFilterFrom`
     * labeled alternative in `OpenSearchPPLParser.searchCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSearchFilterFrom;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.describeCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitDescribeCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.showDataSourcesCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitShowDataSourcesCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.whereCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitWhereCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.fieldsCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitFieldsCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.renameCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitRenameCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.statsCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitStatsCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.dedupCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitDedupCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.sortCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSortCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.evalCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitEvalCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.headCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitHeadCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.topCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTopCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.rareCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitRareCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.grokCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitGrokCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.parseCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitParseCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.patternsCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitPatternsCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.patternsParameter`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitPatternsParameter;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.patternsMethod`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitPatternsMethod;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.kmeansCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitKmeansCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.kmeansParameter`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitKmeansParameter;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.adCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitAdCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.adParameter`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitAdParameter;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.mlCommand`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitMlCommand;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.mlArg`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitMlArg;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.fromClause`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitFromClause;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.tableSourceClause`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTableSourceClause;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.renameClasue`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitRenameClasue;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.byClause`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitByClause;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.statsByClause`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitStatsByClause;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.bySpanClause`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitBySpanClause;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.spanClause`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSpanClause;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.sortbyClause`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSortbyClause;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.evalClause`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitEvalClause;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.statsAggTerm`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitStatsAggTerm;
    /**
     * Visit a parse tree produced by the `statsFunctionCall`
     * labeled alternative in `OpenSearchPPLParser.statsFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitStatsFunctionCall;
    /**
     * Visit a parse tree produced by the `countAllFunctionCall`
     * labeled alternative in `OpenSearchPPLParser.statsFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitCountAllFunctionCall;
    /**
     * Visit a parse tree produced by the `distinctCountFunctionCall`
     * labeled alternative in `OpenSearchPPLParser.statsFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitDistinctCountFunctionCall;
    /**
     * Visit a parse tree produced by the `percentileAggFunctionCall`
     * labeled alternative in `OpenSearchPPLParser.statsFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitPercentileAggFunctionCall;
    /**
     * Visit a parse tree produced by the `takeAggFunctionCall`
     * labeled alternative in `OpenSearchPPLParser.statsFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTakeAggFunctionCall;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.statsFunctionName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitStatsFunctionName;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.takeAggFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTakeAggFunction;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.percentileAggFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitPercentileAggFunction;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.expression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitExpression;
    /**
     * Visit a parse tree produced by the `relevanceExpr`
     * labeled alternative in `OpenSearchPPLParser.logicalExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitRelevanceExpr;
    /**
     * Visit a parse tree produced by the `logicalNot`
     * labeled alternative in `OpenSearchPPLParser.logicalExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitLogicalNot;
    /**
     * Visit a parse tree produced by the `booleanExpr`
     * labeled alternative in `OpenSearchPPLParser.logicalExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitBooleanExpr;
    /**
     * Visit a parse tree produced by the `logicalAnd`
     * labeled alternative in `OpenSearchPPLParser.logicalExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitLogicalAnd;
    /**
     * Visit a parse tree produced by the `comparsion`
     * labeled alternative in `OpenSearchPPLParser.logicalExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitComparsion;
    /**
     * Visit a parse tree produced by the `logicalXor`
     * labeled alternative in `OpenSearchPPLParser.logicalExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitLogicalXor;
    /**
     * Visit a parse tree produced by the `logicalOr`
     * labeled alternative in `OpenSearchPPLParser.logicalExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitLogicalOr;
    /**
     * Visit a parse tree produced by the `compareExpr`
     * labeled alternative in `OpenSearchPPLParser.comparisonExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitCompareExpr;
    /**
     * Visit a parse tree produced by the `inExpr`
     * labeled alternative in `OpenSearchPPLParser.comparisonExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitInExpr;
    /**
     * Visit a parse tree produced by the `positionFunctionCall`
     * labeled alternative in `OpenSearchPPLParser.valueExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitPositionFunctionCall;
    /**
     * Visit a parse tree produced by the `valueExpressionDefault`
     * labeled alternative in `OpenSearchPPLParser.valueExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitValueExpressionDefault;
    /**
     * Visit a parse tree produced by the `parentheticValueExpr`
     * labeled alternative in `OpenSearchPPLParser.valueExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitParentheticValueExpr;
    /**
     * Visit a parse tree produced by the `getFormatFunctionCall`
     * labeled alternative in `OpenSearchPPLParser.valueExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitGetFormatFunctionCall;
    /**
     * Visit a parse tree produced by the `extractFunctionCall`
     * labeled alternative in `OpenSearchPPLParser.valueExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitExtractFunctionCall;
    /**
     * Visit a parse tree produced by the `binaryArithmetic`
     * labeled alternative in `OpenSearchPPLParser.valueExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitBinaryArithmetic;
    /**
     * Visit a parse tree produced by the `timestampFunctionCall`
     * labeled alternative in `OpenSearchPPLParser.valueExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTimestampFunctionCall;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.primaryExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitPrimaryExpression;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.positionFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitPositionFunction;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.booleanExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitBooleanExpression;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.relevanceExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitRelevanceExpression;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.singleFieldRelevanceFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSingleFieldRelevanceFunction;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.multiFieldRelevanceFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitMultiFieldRelevanceFunction;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.tableSource`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTableSource;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.tableFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTableFunction;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.fieldList`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitFieldList;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.wcFieldList`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitWcFieldList;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.sortField`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSortField;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.sortFieldExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSortFieldExpression;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.fieldExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitFieldExpression;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.wcFieldExpression`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitWcFieldExpression;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.evalFunctionCall`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitEvalFunctionCall;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.dataTypeFunctionCall`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitDataTypeFunctionCall;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.booleanFunctionCall`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitBooleanFunctionCall;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.convertedDataType`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitConvertedDataType;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.evalFunctionName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitEvalFunctionName;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.functionArgs`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitFunctionArgs;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.functionArg`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitFunctionArg;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.relevanceArg`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitRelevanceArg;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.relevanceArgName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitRelevanceArgName;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.relevanceFieldAndWeight`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitRelevanceFieldAndWeight;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.relevanceFieldWeight`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitRelevanceFieldWeight;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.relevanceField`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitRelevanceField;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.relevanceQuery`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitRelevanceQuery;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.relevanceArgValue`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitRelevanceArgValue;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.mathematicalFunctionName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitMathematicalFunctionName;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.trigonometricFunctionName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTrigonometricFunctionName;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.dateTimeFunctionName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitDateTimeFunctionName;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.getFormatFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitGetFormatFunction;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.getFormatType`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitGetFormatType;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.extractFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitExtractFunction;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.simpleDateTimePart`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSimpleDateTimePart;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.complexDateTimePart`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitComplexDateTimePart;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.datetimePart`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitDatetimePart;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.timestampFunction`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTimestampFunction;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.timestampFunctionName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTimestampFunctionName;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.conditionFunctionBase`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitConditionFunctionBase;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.systemFunctionName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSystemFunctionName;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.textFunctionName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTextFunctionName;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.positionFunctionName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitPositionFunctionName;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.comparisonOperator`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitComparisonOperator;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.singleFieldRelevanceFunctionName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitSingleFieldRelevanceFunctionName;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.multiFieldRelevanceFunctionName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitMultiFieldRelevanceFunctionName;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.literalValue`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitLiteralValue;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.intervalLiteral`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitIntervalLiteral;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.stringLiteral`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitStringLiteral;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.integerLiteral`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitIntegerLiteral;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.decimalLiteral`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitDecimalLiteral;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.booleanLiteral`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitBooleanLiteral;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.datetimeLiteral`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitDatetimeLiteral;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.dateLiteral`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitDateLiteral;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.timeLiteral`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTimeLiteral;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.timestampLiteral`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTimestampLiteral;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.intervalUnit`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitIntervalUnit;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.timespanUnit`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTimespanUnit;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.valueList`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitValueList;
    /**
     * Visit a parse tree produced by the `identsAsQualifiedName`
     * labeled alternative in `OpenSearchPPLParser.qualifiedName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitIdentsAsQualifiedName;
    /**
     * Visit a parse tree produced by the `identsAsTableQualifiedName`
     * labeled alternative in `OpenSearchPPLParser.tableQualifiedName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitIdentsAsTableQualifiedName;
    /**
     * Visit a parse tree produced by the `identsAsWildcardQualifiedName`
     * labeled alternative in `OpenSearchPPLParser.wcQualifiedName`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitIdentsAsWildcardQualifiedName;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.ident`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitIdent;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.tableIdent`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitTableIdent;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.wildcard`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitWildcard;
    /**
     * Visit a parse tree produced by `OpenSearchPPLParser.keywordsCanBeId`.
     * @param ctx the parse tree
     * @return the visitor result
     */
    visitKeywordsCanBeId;
}
exports.OpenSearchPPLParserVisitor = OpenSearchPPLParserVisitor;
//# sourceMappingURL=OpenSearchPPLParserVisitor.js.map