"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _breadcrumb_trail = require("./breadcrumb_trail");
Object.keys(_breadcrumb_trail).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _breadcrumb_trail[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _breadcrumb_trail[key];
    }
  });
});
var _celestial_node = require("./celestial_node");
Object.keys(_celestial_node).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _celestial_node[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _celestial_node[key];
    }
  });
});