function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(e, r, t) { return (r = _toPropertyKey(r)) in e ? Object.defineProperty(e, r, { value: t, enumerable: !0, configurable: !0, writable: !0 }) : e[r] = t, e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == typeof i ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != typeof t || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != typeof i) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */

import { getIcon } from '../utils/icons.utils';
import { TopologyNodePresenter } from '../presenters/topology_node.presenter';
import { DEFAULT_METRICS } from '../constants/common.constants';
export class TopologyNodeTransformer {
  constructor(model) {
    _defineProperty(this, "model", void 0);
    _defineProperty(this, "presenter", void 0);
    this.model = model;
    this.presenter = new TopologyNodePresenter(model);
  }
  toCelestialCard() {
    return {
      id: this.model.id,
      icon: getIcon(this.model.type),
      title: this.model.name,
      subtitle: this.presenter.subtitle,
      isGroup: this.model.isGroup,
      aggregatedNodeId: this.model.aggregatedNodeId,
      platform: this.presenter.platform,
      type: this.presenter.type,
      isInstrumented: this.model.isInstrumented,
      numberOfServices: this.presenter.numberOfServices,
      percentOfUninstrumentedServices: this.presenter.percentOfUninstrumentedServices,
      keyAttributes: this.model.node.KeyAttributes,
      statisticReferences: this.model.node.StatisticReferences,
      attributes: this.model.node.AttributeMaps,
      applications: this.model.node.Applications,
      isDirectService: this.model.isDirectService,
      metrics: _objectSpread({}, DEFAULT_METRICS),
      dependencyTypes: this.model.node.DependencyTypes
    };
  }
}