"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiPortal", {
  enumerable: true,
  get: function get() {
    return _portal.OuiPortal;
  }
});
Object.defineProperty(exports, "EuiPortal", {
  enumerable: true,
  get: function get() {
    return _portal2.EuiPortal;
  }
});
var _portal = require("./portal");
var _portal2 = require("../../eui_components/portal/portal");