function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) { ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } } return n; }, _extends.apply(null, arguments); }
function _objectWithoutProperties(e, t) { if (null == e) return {}; var o, r, i = _objectWithoutPropertiesLoose(e, t); if (Object.getOwnPropertySymbols) { var n = Object.getOwnPropertySymbols(e); for (r = 0; r < n.length; r++) { o = n[r], -1 === t.indexOf(o) && {}.propertyIsEnumerable.call(e, o) && (i[o] = e[o]); } } return i; }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) { if ({}.hasOwnProperty.call(r, n)) { if (-1 !== e.indexOf(n)) continue; t[n] = r[n]; } } return t; }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

import * as React from 'react';
var OuiIconNavDevtools = function OuiIconNavDevtools(_ref) {
  var title = _ref.title,
    titleId = _ref.titleId,
    props = _objectWithoutProperties(_ref, ["title", "titleId"]);
  return /*#__PURE__*/React.createElement("svg", _extends({
    xmlns: "http://www.w3.org/2000/svg",
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    "aria-labelledby": titleId
  }, props), title ? /*#__PURE__*/React.createElement("title", {
    id: titleId
  }, title) : null, /*#__PURE__*/React.createElement("path", {
    d: "M7.863 8a.412.412 0 0 1-.155.322l-2.745 2.196a.412.412 0 1 1-.514-.644L6.792 8 4.45 6.126a.412.412 0 0 1 .514-.644l2.745 2.196A.412.412 0 0 1 7.863 8Zm3.431 1.784H8.55a.412.412 0 1 0 0 .824h2.745a.411.411 0 1 0 0-.824ZM15 3.06v9.882a.96.96 0 0 1-.96.961H1.96a.961.961 0 0 1-.96-.96V3.058a.96.96 0 0 1 .96-.96h12.08a.96.96 0 0 1 .96.96Zm-.823 0a.137.137 0 0 0-.138-.137H1.961a.137.137 0 0 0-.137.137v9.882a.137.137 0 0 0 .137.137h12.078a.137.137 0 0 0 .138-.137V3.06Z"
  }));
};
export var icon = OuiIconNavDevtools;