"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiFormRow", {
  enumerable: true,
  get: function get() {
    return _form_row.EuiFormRow;
  }
});
Object.defineProperty(exports, "EuiCompressedFormRow", {
  enumerable: true,
  get: function get() {
    return _form_row.EuiCompressedFormRow;
  }
});
var _form_row = require("./form_row");