"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiBeacon", {
  enumerable: true,
  get: function get() {
    return _beacon.OuiBeacon;
  }
});
Object.defineProperty(exports, "EuiBeacon", {
  enumerable: true,
  get: function get() {
    return _beacon2.EuiBeacon;
  }
});
var _beacon = require("./beacon");
var _beacon2 = require("../../eui_components/beacon/beacon");