"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isChartAnimatableSelector = void 0;
var create_selector_1 = require("../../../../state/create_selector");
var get_settings_specs_1 = require("../../../../state/selectors/get_settings_specs");
var compute_series_geometries_1 = require("./compute_series_geometries");
exports.isChartAnimatableSelector = create_selector_1.createCustomCachedSelector([compute_series_geometries_1.computeSeriesGeometriesSelector, get_settings_specs_1.getSettingsSpecSelector], function () {
    return false;
});
//# sourceMappingURL=is_chart_animatable.js.map