// Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
export * from './node_cryptographic_materials_manager';
export { getEncryptHelper, getDecryptionHelper, } from './material_helpers';
export { NodeDecryptionMaterial, NodeEncryptionMaterial, NodeAlgorithmSuite, AlgorithmSuiteIdentifier, EncryptedDataKey, KeyringTraceFlag, needs, NotSupported, KeyringNode, MultiKeyringNode, immutableBaseClass, immutableClass, frozenClass, readOnlyProperty, unwrapDataKey, CommitmentPolicy, CommitmentPolicySuites, SignaturePolicySuites, SignaturePolicy, MessageFormat, getCompatibleCommitmentPolicy, } from '@aws-crypto/material-management';
//# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiaW5kZXguanMiLCJzb3VyY2VSb290IjoiIiwic291cmNlcyI6WyIuLi8uLi8uLi9zcmMvaW5kZXgudHMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IkFBQUEsb0VBQW9FO0FBQ3BFLHNDQUFzQztBQUV0QyxjQUFjLHdDQUF3QyxDQUFBO0FBQ3RELE9BQU8sRUFDTCxnQkFBZ0IsRUFDaEIsbUJBQW1CLEdBT3BCLE1BQU0sb0JBQW9CLENBQUE7QUFDM0IsT0FBTyxFQUNMLHNCQUFzQixFQUN0QixzQkFBc0IsRUFDdEIsa0JBQWtCLEVBQ2xCLHdCQUF3QixFQUV4QixnQkFBZ0IsRUFFaEIsZ0JBQWdCLEVBQ2hCLEtBQUssRUFDTCxZQUFZLEVBQ1osV0FBVyxFQUNYLGdCQUFnQixFQUNoQixrQkFBa0IsRUFDbEIsY0FBYyxFQUNkLFdBQVcsRUFDWCxnQkFBZ0IsRUFFaEIsYUFBYSxFQUViLGdCQUFnQixFQUNoQixzQkFBc0IsRUFDdEIscUJBQXFCLEVBQ3JCLGVBQWUsRUFDZixhQUFhLEVBR2IsNkJBQTZCLEdBQzlCLE1BQU0saUNBQWlDLENBQUEifQ==