function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) { ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } } return n; }, _extends.apply(null, arguments); }
function _objectWithoutProperties(e, t) { if (null == e) return {}; var o, r, i = _objectWithoutPropertiesLoose(e, t); if (Object.getOwnPropertySymbols) { var n = Object.getOwnPropertySymbols(e); for (r = 0; r < n.length; r++) { o = n[r], -1 === t.indexOf(o) && {}.propertyIsEnumerable.call(e, o) && (i[o] = e[o]); } } return i; }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) { if ({}.hasOwnProperty.call(r, n)) { if (-1 !== e.indexOf(n)) continue; t[n] = r[n]; } } return t; }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

import * as React from 'react';
var OuiIconNavSecurityFindings = function OuiIconNavSecurityFindings(_ref) {
  var title = _ref.title,
    titleId = _ref.titleId,
    props = _objectWithoutProperties(_ref, ["title", "titleId"]);
  return /*#__PURE__*/React.createElement("svg", _extends({
    xmlns: "http://www.w3.org/2000/svg",
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    "aria-labelledby": titleId
  }, props), title ? /*#__PURE__*/React.createElement("title", {
    id: titleId
  }, title) : null, /*#__PURE__*/React.createElement("path", {
    d: "M7.558 7.511V4.824a.404.404 0 1 1 .807 0v2.687a.404.404 0 1 1-.807 0m.403 1.749a.672.672 0 1 0 0 1.344.672.672 0 0 0 0-1.344m6.32-7.126v3.765c0 3.492-1.689 5.607-3.106 6.765-1.528 1.251-3.044 1.673-3.108 1.691a.405.405 0 0 1-.212 0c-.068-.019-1.579-.44-3.108-1.691-1.417-1.159-3.106-3.273-3.106-6.765V2.134a.941.941 0 0 1 .941-.941h10.757a.941.941 0 0 1 .941.941m-.807 0a.135.135 0 0 0-.135-.135H2.583a.135.135 0 0 0-.135.135v3.765c0 2.537.937 4.598 2.786 6.121a8.847 8.847 0 0 0 2.727 1.523 8.847 8.847 0 0 0 2.727-1.523c1.849-1.525 2.786-3.584 2.786-6.121z"
  }));
};
export var icon = OuiIconNavSecurityFindings;