"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RecoveredLabel = void 0;
var _react = _interopRequireDefault(require("react"));
var _sli_status_icon = require("../sli_status_icon");
var _label = require("./label");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */

const RecoveredLabel = ({
  text,
  children = /*#__PURE__*/(0, _jsxRuntime.jsx)(_sli_status_icon.SliStatusIcon, {
    status: "recovered",
    size: 22
  })
}) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_label.Label, {
  text: text,
  className: "osd:gap-0.5",
  children: children
});
exports.RecoveredLabel = RecoveredLabel;