"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiSimplifiedBreadcrumbs", {
  enumerable: true,
  get: function get() {
    return _simplified_breadcrumbs.EuiSimplifiedBreadcrumbs;
  }
});
var _simplified_breadcrumbs = require("./simplified_breadcrumbs");