"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiBadge", {
  enumerable: true,
  get: function get() {
    return _badge.EuiBadge;
  }
});
Object.defineProperty(exports, "EuiBetaBadge", {
  enumerable: true,
  get: function get() {
    return _beta_badge.EuiBetaBadge;
  }
});
Object.defineProperty(exports, "EuiNotificationBadge", {
  enumerable: true,
  get: function get() {
    return _notification_badge.EuiNotificationBadge;
  }
});
Object.defineProperty(exports, "EuiBadgeGroup", {
  enumerable: true,
  get: function get() {
    return _badge_group.EuiBadgeGroup;
  }
});
var _badge = require("./badge");
var _beta_badge = require("./beta_badge");
var _notification_badge = require("./notification_badge");
var _badge_group = require("./badge_group");