"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiLink", {
  enumerable: true,
  get: function get() {
    return _link.EuiLink;
  }
});
var _link = require("./link");