"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AbsolutePosition = void 0;
var _react = _interopRequireDefault(require("react"));
require("./styles.scss");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */

const AbsolutePosition = ({
  children,
  ...positioning
}) => /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
  className: "celAbsolute",
  style: {
    ...positioning
  },
  children: children
});
exports.AbsolutePosition = AbsolutePosition;