"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _label = require("./label");
Object.keys(_label).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _label[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _label[key];
    }
  });
});
var _alarm_label = require("./alarm_label");
Object.keys(_alarm_label).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _alarm_label[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _alarm_label[key];
    }
  });
});
var _breached_label = require("./breached_label");
Object.keys(_breached_label).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _breached_label[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _breached_label[key];
    }
  });
});
var _errors_label = require("./errors_label");
Object.keys(_errors_label).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _errors_label[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _errors_label[key];
    }
  });
});
var _faults_label = require("./faults_label");
Object.keys(_faults_label).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _faults_label[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _faults_label[key];
    }
  });
});
var _recovered_label = require("./recovered_label");
Object.keys(_recovered_label).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _recovered_label[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _recovered_label[key];
    }
  });
});
var _ok_label = require("./ok_label");
Object.keys(_ok_label).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (key in exports && exports[key] === _ok_label[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _ok_label[key];
    }
  });
});