"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiLink", {
  enumerable: true,
  get: function get() {
    return _link.OuiLink;
  }
});
Object.defineProperty(exports, "EuiLink", {
  enumerable: true,
  get: function get() {
    return _link2.EuiLink;
  }
});
var _link = require("./link");
var _link2 = require("../../eui_components/link/link");