"use strict";
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.applyConfigOverrides = void 0;
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
const safer_lodash_set_1 = require("@elastic/safer-lodash-set");
const read_argv_1 = require("./read_argv");
/**
 * Manually applies the specific configuration overrides we need to load the APM config.
 * Currently, only these are needed:
 *   - server.uuid
 *   - path.data
 */
const applyConfigOverrides = (config, argv) => {
    const serverUuid = (0, read_argv_1.getArgValue)(argv, '--server.uuid');
    if (serverUuid) {
        (0, safer_lodash_set_1.set)(config, 'server.uuid', serverUuid);
    }
    const dataPath = (0, read_argv_1.getArgValue)(argv, '--path.data');
    if (dataPath) {
        (0, safer_lodash_set_1.set)(config, 'path.data', dataPath);
    }
};
exports.applyConfigOverrides = applyConfigOverrides;
