"use strict";
// Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildAwsKmsMrkAwareDiscoveryMultiKeyringNode = void 0;
const kms_keyring_1 = require("@aws-crypto/kms-keyring");
const material_management_1 = require("@aws-crypto/material-management");
const _1 = require(".");
const kms_mrk_discovery_keyring_node_1 = require("./kms_mrk_discovery_keyring_node");
exports.buildAwsKmsMrkAwareDiscoveryMultiKeyringNode = (0, kms_keyring_1.getAwsKmsMrkAwareDiscoveryMultiKeyringBuilder)(kms_mrk_discovery_keyring_node_1.AwsKmsMrkAwareSymmetricDiscoveryKeyringNode, material_management_1.MultiKeyringNode, _1.getKmsClient);
//# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoia21zX21ya19kaXNjb3ZlcnlfbXVsdGlfa2V5cmluZ19ub2RlLmpzIiwic291cmNlUm9vdCI6IiIsInNvdXJjZXMiOlsiLi4vLi4vLi4vc3JjL2ttc19tcmtfZGlzY292ZXJ5X211bHRpX2tleXJpbmdfbm9kZS50cyJdLCJuYW1lcyI6W10sIm1hcHBpbmdzIjoiO0FBQUEsb0VBQW9FO0FBQ3BFLHNDQUFzQzs7O0FBRXRDLHlEQUlnQztBQUNoQyx5RUFHd0M7QUFDeEMsd0JBQWdDO0FBQ2hDLHFGQUE4RjtBQVlqRixRQUFBLDRDQUE0QyxHQUN2RCxJQUFBLDJEQUE2QyxFQUczQyw0RUFBMkMsRUFBRSxzQ0FBZ0IsRUFBRSxlQUFZLENBQUMsQ0FBQSJ9