"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiKeyPadMenu", {
  enumerable: true,
  get: function get() {
    return _key_pad_menu.EuiKeyPadMenu;
  }
});
Object.defineProperty(exports, "EuiKeyPadMenuItem", {
  enumerable: true,
  get: function get() {
    return _key_pad_menu_item.EuiKeyPadMenuItem;
  }
});
var _key_pad_menu = require("./key_pad_menu");
var _key_pad_menu_item = require("./key_pad_menu_item");