"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OkLabel = void 0;
var _react = _interopRequireDefault(require("react"));
var _ok_swatch = require("../swatches/ok_swatch");
var _label = require("./label");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */

const OkLabel = ({
  text,
  children = /*#__PURE__*/(0, _jsxRuntime.jsx)(_ok_swatch.OkSwatch, {})
}) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_label.Label, {
  text: text,
  className: "osd:gap-1.5",
  children: children
});
exports.OkLabel = OkLabel;