"use strict";
// Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildClient = void 0;
__exportStar(require("@aws-crypto/encrypt-node"), exports);
__exportStar(require("@aws-crypto/decrypt-node"), exports);
__exportStar(require("@aws-crypto/material-management-node"), exports);
__exportStar(require("@aws-crypto/caching-materials-manager-node"), exports);
__exportStar(require("@aws-crypto/kms-keyring-node"), exports);
__exportStar(require("@aws-crypto/raw-aes-keyring-node"), exports);
__exportStar(require("@aws-crypto/raw-rsa-keyring-node"), exports);
__exportStar(require("@aws-crypto/branch-keystore-node"), exports);
const encrypt_node_1 = require("@aws-crypto/encrypt-node");
const decrypt_node_1 = require("@aws-crypto/decrypt-node");
function buildClient(options) {
    return {
        ...(0, encrypt_node_1.buildEncrypt)(options),
        ...(0, decrypt_node_1.buildDecrypt)(options),
    };
}
exports.buildClient = buildClient;
//# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiaW5kZXguanMiLCJzb3VyY2VSb290IjoiIiwic291cmNlcyI6WyIuLi8uLi8uLi9zcmMvaW5kZXgudHMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IjtBQUFBLG9FQUFvRTtBQUNwRSxzQ0FBc0M7Ozs7Ozs7Ozs7Ozs7Ozs7O0FBRXRDLDJEQUF3QztBQUN4QywyREFBd0M7QUFDeEMsdUVBQW9EO0FBQ3BELDZFQUEwRDtBQUMxRCwrREFBNEM7QUFDNUMsbUVBQWdEO0FBQ2hELG1FQUFnRDtBQUNoRCxtRUFBZ0Q7QUFRaEQsMkRBQXVEO0FBQ3ZELDJEQUF1RDtBQUV2RCxTQUFnQixXQUFXLENBQ3pCLE9BQTBDO0lBRTFDLE9BQU87UUFDTCxHQUFHLElBQUEsMkJBQVksRUFBQyxPQUFPLENBQUM7UUFDeEIsR0FBRyxJQUFBLDJCQUFZLEVBQUMsT0FBTyxDQUFDO0tBQ3pCLENBQUE7QUFDSCxDQUFDO0FBUEQsa0NBT0MifQ==