"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiHorizontalRule", {
  enumerable: true,
  get: function get() {
    return _horizontal_rule.OuiHorizontalRule;
  }
});
Object.defineProperty(exports, "EuiHorizontalRule", {
  enumerable: true,
  get: function get() {
    return _horizontal_rule2.EuiHorizontalRule;
  }
});
var _horizontal_rule = require("./horizontal_rule");
var _horizontal_rule2 = require("../../eui_components/horizontal_rule/horizontal_rule");