"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiMutationObserver", {
  enumerable: true,
  get: function get() {
    return _mutation_observer.EuiMutationObserver;
  }
});
Object.defineProperty(exports, "useMutationObserver", {
  enumerable: true,
  get: function get() {
    return _mutation_observer.useMutationObserver;
  }
});
var _mutation_observer = require("./mutation_observer");