"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiBottomBar", {
  enumerable: true,
  get: function get() {
    return _bottom_bar.OuiBottomBar;
  }
});
Object.defineProperty(exports, "EuiBottomBar", {
  enumerable: true,
  get: function get() {
    return _bottom_bar2.EuiBottomBar;
  }
});
var _bottom_bar = require("./bottom_bar");
var _bottom_bar2 = require("../../eui_components/bottom_bar/bottom_bar");