"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.render = void 0;
var common_1 = require("../../../../utils/common");
var config_1 = require("../../layout/config/config");
var viewmodel_1 = require("../../layout/viewmodel/viewmodel");
function render(spec, parentDimensions) {
    var width = parentDimensions.width, height = parentDimensions.height;
    var config = spec.config;
    var partialConfig = __assign(__assign({}, config), { width: width, height: height });
    var cfg = common_1.mergePartial(config_1.config, partialConfig);
    return viewmodel_1.shapeViewModel(spec, cfg);
}
exports.render = render;
//# sourceMappingURL=scenegraph.js.map