"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiSpacer", {
  enumerable: true,
  get: function get() {
    return _spacer.EuiSpacer;
  }
});
var _spacer = require("./spacer");