"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiSplitPanel", {
  enumerable: true,
  get: function get() {
    return _split_panel.EuiSplitPanel;
  }
});
var _split_panel = require("./split_panel");