"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiSpacer", {
  enumerable: true,
  get: function get() {
    return _spacer.OuiSpacer;
  }
});
Object.defineProperty(exports, "EuiSpacer", {
  enumerable: true,
  get: function get() {
    return _spacer2.EuiSpacer;
  }
});
var _spacer = require("./spacer");
var _spacer2 = require("../../eui_components/spacer/spacer");