"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiToken", {
  enumerable: true,
  get: function get() {
    return _token.OuiToken;
  }
});
Object.defineProperty(exports, "TOKEN_SIZES", {
  enumerable: true,
  get: function get() {
    return _token.SIZES;
  }
});
Object.defineProperty(exports, "TOKEN_SHAPES", {
  enumerable: true,
  get: function get() {
    return _token.SHAPES;
  }
});
Object.defineProperty(exports, "TOKEN_COLORS", {
  enumerable: true,
  get: function get() {
    return _token.COLORS;
  }
});
Object.defineProperty(exports, "EuiToken", {
  enumerable: true,
  get: function get() {
    return _token2.EuiToken;
  }
});
var _token = require("./token");
var _token2 = require("../../eui_components/token/token");