"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiFormErrorText", {
  enumerable: true,
  get: function get() {
    return _form_error_text.EuiFormErrorText;
  }
});
var _form_error_text = require("./form_error_text");