"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiBadgeGroup", {
  enumerable: true,
  get: function get() {
    return _badge_group.OuiBadgeGroup;
  }
});
Object.defineProperty(exports, "EuiBadgeGroup", {
  enumerable: true,
  get: function get() {
    return _badge_group2.EuiBadgeGroup;
  }
});
var _badge_group = require("./badge_group");
var _badge_group2 = require("../../../eui_components/badge/badge_group/badge_group");