"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiHeaderAlert", {
  enumerable: true,
  get: function get() {
    return _header_alert.OuiHeaderAlert;
  }
});
Object.defineProperty(exports, "EuiHeaderAlert", {
  enumerable: true,
  get: function get() {
    return _header_alert2.EuiHeaderAlert;
  }
});
var _header_alert = require("./header_alert");
var _header_alert2 = require("../../../eui_components/header/header_alert/header_alert");