"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiOverlayMask", {
  enumerable: true,
  get: function get() {
    return _overlay_mask.OuiOverlayMask;
  }
});
Object.defineProperty(exports, "EuiOverlayMask", {
  enumerable: true,
  get: function get() {
    return _overlay_mask2.EuiOverlayMask;
  }
});
var _overlay_mask = require("./overlay_mask");
var _overlay_mask2 = require("../../eui_components/overlay_mask/overlay_mask");