// Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
import { getAwsKmsMrkAwareDiscoveryMultiKeyringBuilder, } from '@aws-crypto/kms-keyring';
import { MultiKeyringNode, } from '@aws-crypto/material-management';
import { getKmsClient } from '.';
import { AwsKmsMrkAwareSymmetricDiscoveryKeyringNode } from './kms_mrk_discovery_keyring_node';
export const buildAwsKmsMrkAwareDiscoveryMultiKeyringNode = getAwsKmsMrkAwareDiscoveryMultiKeyringBuilder(AwsKmsMrkAwareSymmetricDiscoveryKeyringNode, MultiKeyringNode, getKmsClient);
//# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoia21zX21ya19kaXNjb3ZlcnlfbXVsdGlfa2V5cmluZ19ub2RlLmpzIiwic291cmNlUm9vdCI6IiIsInNvdXJjZXMiOlsiLi4vLi4vLi4vc3JjL2ttc19tcmtfZGlzY292ZXJ5X211bHRpX2tleXJpbmdfbm9kZS50cyJdLCJuYW1lcyI6W10sIm1hcHBpbmdzIjoiQUFBQSxvRUFBb0U7QUFDcEUsc0NBQXNDO0FBRXRDLE9BQU8sRUFDTCw2Q0FBNkMsR0FHOUMsTUFBTSx5QkFBeUIsQ0FBQTtBQUNoQyxPQUFPLEVBQ0wsZ0JBQWdCLEdBRWpCLE1BQU0saUNBQWlDLENBQUE7QUFDeEMsT0FBTyxFQUFFLFlBQVksRUFBRSxNQUFNLEdBQUcsQ0FBQTtBQUNoQyxPQUFPLEVBQUUsMkNBQTJDLEVBQUUsTUFBTSxrQ0FBa0MsQ0FBQTtBQVk5RixNQUFNLENBQUMsTUFBTSw0Q0FBNEMsR0FDdkQsNkNBQTZDLENBRzNDLDJDQUEyQyxFQUFFLGdCQUFnQixFQUFFLFlBQVksQ0FBQyxDQUFBIn0=