"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "getDurationAndPerformOnFrame", {
  enumerable: true,
  get: function get() {
    return _transition.getDurationAndPerformOnFrame;
  }
});
Object.defineProperty(exports, "getTransitionTimings", {
  enumerable: true,
  get: function get() {
    return _transition.getTransitionTimings;
  }
});
Object.defineProperty(exports, "getWaitDuration", {
  enumerable: true,
  get: function get() {
    return _transition.getWaitDuration;
  }
});
Object.defineProperty(exports, "performOnFrame", {
  enumerable: true,
  get: function get() {
    return _transition.performOnFrame;
  }
});
var _transition = require("./transition");