"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _typeof = require("@babel/runtime/helpers/typeof");
Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "getDefaultEuiMarkdownParsingPlugins", {
  enumerable: true,
  get: function get() {
    return _markdown_default_plugins.getDefaultEuiMarkdownParsingPlugins;
  }
});
Object.defineProperty(exports, "getDefaultEuiMarkdownProcessingPlugins", {
  enumerable: true,
  get: function get() {
    return _markdown_default_plugins.getDefaultEuiMarkdownProcessingPlugins;
  }
});
Object.defineProperty(exports, "getDefaultEuiMarkdownUiPlugins", {
  enumerable: true,
  get: function get() {
    return _markdown_default_plugins.getDefaultEuiMarkdownUiPlugins;
  }
});
exports.defaultUiPlugins = exports.getDefaultOuiMarkdownUiPlugins = exports.defaultProcessingPlugins = exports.getDefaultOuiMarkdownProcessingPlugins = exports.defaultParsingPlugins = exports.getDefaultOuiMarkdownParsingPlugins = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _react = _interopRequireWildcard(require("react"));
var _all = _interopRequireDefault(require("mdast-util-to-hast/lib/all"));
var _rehypeReact = _interopRequireDefault(require("rehype-react"));
var _remarkParse = _interopRequireDefault(require("remark-parse"));
var _remarkEmoji = _interopRequireDefault(require("remark-emoji"));
var _remarkRehype = _interopRequireDefault(require("remark-rehype"));
var _rehypeSlug = _interopRequireDefault(require("rehype-slug"));
var _remark_prismjs = _interopRequireDefault(require("./remark/remark_prismjs"));
var MarkdownTooltip = _interopRequireWildcard(require("./markdown_tooltip"));
var MarkdownCheckbox = _interopRequireWildcard(require("./markdown_checkbox"));
var _markdown_link_validator = require("./markdown_link_validator");
var _link = require("../../link");
var _code = require("../../code");
var _markdown_default_plugins = require("../../../eui_components/markdown_editor/plugins/markdown_default_plugins");
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function _interopRequireWildcard(e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, default: e }; if (null === e || "object" != _typeof(e) && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (var _t in e) { "default" !== _t && {}.hasOwnProperty.call(e, _t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, _t)) && (i.get || i.set) ? o(f, _t, i) : f[_t] = e[_t]); } return f; })(e, t); }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

// Importing seemingly unused types from `unified` because the definitions
// are exported for two versions of TypeScript (3.4, 4.0) and implicit
// imports during oui.d.ts generation default to the incorrect version (3.4).
// Explicit imports here resolve the version mismatch.

var getDefaultOuiMarkdownParsingPlugins = function getDefaultOuiMarkdownParsingPlugins() {
  return [[_remarkParse.default, {}], [_remark_prismjs.default, {}], [_remarkEmoji.default, {
    emoticon: false
  }], [MarkdownTooltip.parser, {}], [MarkdownCheckbox.parser, {}], [_markdown_link_validator.markdownLinkValidator, {}]];
};
exports.getDefaultOuiMarkdownParsingPlugins = getDefaultOuiMarkdownParsingPlugins;
var defaultParsingPlugins = getDefaultOuiMarkdownParsingPlugins();
exports.defaultParsingPlugins = defaultParsingPlugins;
var unknownHandler = function unknownHandler(h, node) {
  return h(node, node.type, node, (0, _all.default)(h, node));
};
var getDefaultOuiMarkdownProcessingPlugins = function getDefaultOuiMarkdownProcessingPlugins() {
  return [[_remarkRehype.default, {
    allowDangerousHtml: true,
    unknownHandler: unknownHandler,
    handlers: {} // intentionally empty, allows plugins to extend if they need to
  }], [_rehypeSlug.default, {}], [_rehypeReact.default, {
    createElement: _react.createElement,
    components: {
      a: _link.OuiLink,
      code: function code(props) {
        return (
          // If there are linebreaks use codeblock, otherwise code
          /\r|\n/.exec(props.children) ? /*#__PURE__*/_react.default.createElement(_code.OuiCodeBlock, (0, _extends2.default)({
            fontSize: "m",
            paddingSize: "s"
          }, props)) : /*#__PURE__*/_react.default.createElement(_code.OuiCode, props)
        );
      },
      tooltipPlugin: MarkdownTooltip.renderer,
      checkboxPlugin: MarkdownCheckbox.renderer
    }
  }]];
};
exports.getDefaultOuiMarkdownProcessingPlugins = getDefaultOuiMarkdownProcessingPlugins;
var defaultProcessingPlugins = getDefaultOuiMarkdownProcessingPlugins();
exports.defaultProcessingPlugins = defaultProcessingPlugins;
var getDefaultOuiMarkdownUiPlugins = function getDefaultOuiMarkdownUiPlugins() {
  var array = [MarkdownTooltip.plugin];
  // @ts-ignore __originatedFromOui is a custom property
  array.__originatedFromOui = true;
  return array;
};
exports.getDefaultOuiMarkdownUiPlugins = getDefaultOuiMarkdownUiPlugins;
var defaultUiPlugins = getDefaultOuiMarkdownUiPlugins();

/* OUI -> EUI Aliases: Build-Time */
exports.defaultUiPlugins = defaultUiPlugins;