function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) { ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } } return n; }, _extends.apply(null, arguments); }
function _objectWithoutProperties(e, t) { if (null == e) return {}; var o, r, i = _objectWithoutPropertiesLoose(e, t); if (Object.getOwnPropertySymbols) { var n = Object.getOwnPropertySymbols(e); for (r = 0; r < n.length; r++) { o = n[r], -1 === t.indexOf(o) && {}.propertyIsEnumerable.call(e, o) && (i[o] = e[o]); } } return i; }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) { if ({}.hasOwnProperty.call(r, n)) { if (-1 !== e.indexOf(n)) continue; t[n] = r[n]; } } return t; }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

import * as React from 'react';
var OuiIconLogoDropwizard = function OuiIconLogoDropwizard(_ref) {
  var title = _ref.title,
    titleId = _ref.titleId,
    props = _objectWithoutProperties(_ref, ["title", "titleId"]);
  return /*#__PURE__*/React.createElement("svg", _extends({
    xmlns: "http://www.w3.org/2000/svg",
    width: 32,
    height: 32,
    fill: "none",
    viewBox: "0 0 32 32",
    "aria-labelledby": titleId
  }, props), title ? /*#__PURE__*/React.createElement("title", {
    id: titleId
  }, title) : null, /*#__PURE__*/React.createElement("path", {
    fill: "url(#paint0_linear)",
    d: "M8 29.61s9.55 4.74 16.856-.893c-1.905-5.114-5.25-19.867-7.226-26.383-.422-1.389-.49-1.527-.663-1.909-.964-2.134-1.978 4.142-3.628 10.459C12.749 13.148 8 29.61 8 29.61"
  }), /*#__PURE__*/React.createElement("path", {
    fill: "url(#paint1_linear)",
    d: "M9.926 28.563s8.17 4.794 14.93.154c-.18-.807-.642-2.103-.955-3.311-1.664-6.416-4.676-17.248-6.144-22.626-1.59-5.822-2.105.986-3.961 8.23-.564 2.204-3.87 17.553-3.87 17.553"
  }), /*#__PURE__*/React.createElement("path", {
    fill: "#F9A72B",
    d: "m12.14 24.41.85-1.466.793 1.544-.908 1.99-.735-2.069Zm6.934-5.545.85-1.465.793 1.543-.908 1.99-.735-2.068Zm-4.747-5.851.85-1.465.792 1.543-.908 1.99-.734-2.068"
  }), /*#__PURE__*/React.createElement("path", {
    fill: "#FFF200",
    d: "m12.14 24.41.85-1.716.793 1.794-.907 1.468-.736-1.546Zm6.934-5.545.851-1.716.792 1.794-.906 1.468-.737-1.546Zm-4.747-5.851.85-1.716.792 1.794-.906 1.468-.736-1.546"
  }), /*#__PURE__*/React.createElement("path", {
    fill: "#24265D",
    d: "M12.987 28.422s6.082 1.015 10.086-1.549c-.502 1.55-4.991 3.314-10.086 1.55"
  }), /*#__PURE__*/React.createElement("defs", null, /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint0_linear",
    x1: 33.473,
    x2: 7.751,
    y1: 7.674,
    y2: 21.331,
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#3871C1"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: 0.515,
    stopColor: "#2C3792"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: 0.865,
    stopColor: "#24265D"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: 1,
    stopColor: "#252761"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint1_linear",
    x1: 21.028,
    x2: 6.017,
    y1: 14.928,
    y2: 18.844,
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#3871C1"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: 0.515,
    stopColor: "#2C3792"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: 0.865,
    stopColor: "#24265D"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: 1,
    stopColor: "#252761"
  }))));
};
export var icon = OuiIconLogoDropwizard;