"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiHideFor", {
  enumerable: true,
  get: function get() {
    return _hide_for.OuiHideFor;
  }
});
Object.defineProperty(exports, "OuiShowFor", {
  enumerable: true,
  get: function get() {
    return _show_for.OuiShowFor;
  }
});
Object.defineProperty(exports, "EuiHideFor", {
  enumerable: true,
  get: function get() {
    return _hide_for2.EuiHideFor;
  }
});
Object.defineProperty(exports, "EuiShowFor", {
  enumerable: true,
  get: function get() {
    return _show_for2.EuiShowFor;
  }
});
var _hide_for = require("./hide_for");
var _show_for = require("./show_for");
var _hide_for2 = require("../../eui_components/responsive/hide_for");
var _show_for2 = require("../../eui_components/responsive/show_for");