"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiTreeView", {
  enumerable: true,
  get: function get() {
    return _tree_view.OuiTreeView;
  }
});
Object.defineProperty(exports, "EuiTreeView", {
  enumerable: true,
  get: function get() {
    return _tree_view2.EuiTreeView;
  }
});
var _tree_view = require("./tree_view");
var _tree_view2 = require("../../eui_components/tree_view/tree_view");