"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiEmptyPrompt", {
  enumerable: true,
  get: function get() {
    return _empty_prompt.EuiEmptyPrompt;
  }
});
var _empty_prompt = require("./empty_prompt");