"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiFocusTrap", {
  enumerable: true,
  get: function get() {
    return _focus_trap.EuiFocusTrap;
  }
});
var _focus_trap = require("./focus_trap");