/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */
import React from 'react';
import { t } from '../../../shared/i18n/t';
import { Label } from '../../labels/label';
import { SliStatusIcon } from '../../sli_status_icon';
import { jsx as _jsx } from "react/jsx-runtime";
export const SliStatus = _ref => {
  let {
    status
  } = _ref;
  const isBreached = status === 'breached';
  return /*#__PURE__*/_jsx(Label, {
    text: t("node.sliStatus.".concat(status)),
    className: "osd:gap-0.5 ".concat(isBreached ? 'osd:text-faults' : 'osd:text-errors'),
    children: /*#__PURE__*/_jsx(SliStatusIcon, {
      status: status,
      size: 16
    })
  });
};