"use strict";

function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.icon = void 0;
var React = _interopRequireWildcard(require("react"));
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function _interopRequireWildcard(e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, default: e }; if (null === e || "object" != _typeof(e) && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (var _t in e) { "default" !== _t && {}.hasOwnProperty.call(e, _t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, _t)) && (i.get || i.set) ? o(f, _t, i) : f[_t] = e[_t]); } return f; })(e, t); }
function _extends() { return _extends = Object.assign ? Object.assign.bind() : function (n) { for (var e = 1; e < arguments.length; e++) { var t = arguments[e]; for (var r in t) { ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]); } } return n; }, _extends.apply(null, arguments); }
function _objectWithoutProperties(e, t) { if (null == e) return {}; var o, r, i = _objectWithoutPropertiesLoose(e, t); if (Object.getOwnPropertySymbols) { var n = Object.getOwnPropertySymbols(e); for (r = 0; r < n.length; r++) { o = n[r], -1 === t.indexOf(o) && {}.propertyIsEnumerable.call(e, o) && (i[o] = e[o]); } } return i; }
function _objectWithoutPropertiesLoose(r, e) { if (null == r) return {}; var t = {}; for (var n in r) { if ({}.hasOwnProperty.call(r, n)) { if (-1 !== e.indexOf(n)) continue; t[n] = r[n]; } } return t; } /*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */
var EuiIconAddBookmark = function EuiIconAddBookmark(_ref) {
  var title = _ref.title,
    titleId = _ref.titleId,
    props = _objectWithoutProperties(_ref, ["title", "titleId"]);
  return /*#__PURE__*/React.createElement("svg", _extends({
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    "aria-labelledby": titleId
  }, props), title ? /*#__PURE__*/React.createElement("title", {
    id: titleId
  }, title) : null, /*#__PURE__*/React.createElement("path", {
    d: "M3.83333 5.13133V1.59019C3.83333 1.26424 4.10694 1 4.44444 1C4.78195 1 5.05556 1.26424 5.05556 1.59019V5.13133C5.05556 5.45728 4.78195 5.72152 4.44444 5.72152C4.10694 5.72152 3.83333 5.45728 3.83333 5.13133Z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M6.27778 2.77057C6.61528 2.77057 6.88889 3.03481 6.88889 3.36076C6.88889 3.68671 6.61528 3.95095 6.27778 3.95095H2.61111C2.2736 3.95095 2 3.68671 2 3.36076C2 3.03481 2.2736 2.77057 2.61111 2.77057H6.27778Z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M8.45725 10.7773C8.26632 10.5929 7.9559 10.5929 7.76497 10.7773L4.65332 13.7825L4.62229 13.8044C4.54553 13.843 4.44463 13.7915 4.44444 13.6995V7.49209C4.44444 7.16614 4.17084 6.9019 3.83333 6.9019C3.49583 6.9019 3.22222 7.16614 3.22222 7.49209V13.6995C3.22243 14.8561 4.67058 15.4349 5.51747 14.617L8.11111 12.1122L10.7048 14.617L10.8707 14.7542C11.7276 15.3601 12.9998 14.7837 13 13.6995V3.83337C13 2.9207 12.2334 2.18038 11.2884 2.18038H8.72222C8.38471 2.18038 8.11111 2.44462 8.11111 2.77057C8.11111 3.09652 8.38471 3.36076 8.72222 3.36076H11.2884L11.3875 3.36998C11.6103 3.414 11.7778 3.6052 11.7778 3.83337V13.6995L11.7718 13.7363C11.7454 13.8156 11.6362 13.8474 11.5689 13.7825L8.45725 10.7773Z"
  }));
};
var icon = EuiIconAddBookmark;
exports.icon = icon;