"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiDelayRender", {
  enumerable: true,
  get: function get() {
    return _delay_render.OuiDelayRender;
  }
});
Object.defineProperty(exports, "EuiDelayRender", {
  enumerable: true,
  get: function get() {
    return _delay_render2.EuiDelayRender;
  }
});
var _delay_render = require("./delay_render");
var _delay_render2 = require("../../eui_components/delay_render/delay_render");