"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  OuiDatePicker: true,
  OuiDatePickerRange: true,
  EuiDatePicker: true,
  EuiDatePickerRange: true
};
Object.defineProperty(exports, "OuiDatePicker", {
  enumerable: true,
  get: function get() {
    return _date_picker.OuiDatePicker;
  }
});
Object.defineProperty(exports, "OuiDatePickerRange", {
  enumerable: true,
  get: function get() {
    return _date_picker_range.OuiDatePickerRange;
  }
});
Object.defineProperty(exports, "EuiDatePicker", {
  enumerable: true,
  get: function get() {
    return _date_picker2.EuiDatePicker;
  }
});
Object.defineProperty(exports, "EuiDatePickerRange", {
  enumerable: true,
  get: function get() {
    return _date_picker_range2.EuiDatePickerRange;
  }
});
var _super_date_picker = require("./super_date_picker");
Object.keys(_super_date_picker).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function get() {
      return _super_date_picker[key];
    }
  });
});
var _date_picker = require("./date_picker");
var _date_picker_range = require("./date_picker_range");
require("./types");
var _date_picker2 = require("../../eui_components/date_picker/date_picker");
var _date_picker_range2 = require("../../eui_components/date_picker/date_picker_range");
require("../../eui_components/date_picker/types");