"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "COLORS", {
  enumerable: true,
  get: function get() {
    return _button_empty.COLORS;
  }
});
Object.defineProperty(exports, "EuiButtonEmpty", {
  enumerable: true,
  get: function get() {
    return _button_empty.EuiButtonEmpty;
  }
});
Object.defineProperty(exports, "EuiSmallButtonEmpty", {
  enumerable: true,
  get: function get() {
    return _button_empty.EuiSmallButtonEmpty;
  }
});
var _button_empty = require("./button_empty");