"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiFormHelpText", {
  enumerable: true,
  get: function get() {
    return _form_help_text.OuiFormHelpText;
  }
});
Object.defineProperty(exports, "EuiFormHelpText", {
  enumerable: true,
  get: function get() {
    return _form_help_text2.EuiFormHelpText;
  }
});
var _form_help_text = require("./form_help_text");
var _form_help_text2 = require("../../../eui_components/form/form_help_text/form_help_text");