"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _typeof = require("@babel/runtime/helpers/typeof");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.icon = void 0;
var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var React = _interopRequireWildcard(require("react"));
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function _interopRequireWildcard(e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, default: e }; if (null === e || "object" != _typeof(e) && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (var _t in e) { "default" !== _t && {}.hasOwnProperty.call(e, _t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, _t)) && (i.get || i.set) ? o(f, _t, i) : f[_t] = e[_t]); } return f; })(e, t); }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

var EuiIconNavInfra = function EuiIconNavInfra(_ref) {
  var title = _ref.title,
    titleId = _ref.titleId,
    props = (0, _objectWithoutProperties2.default)(_ref, ["title", "titleId"]);
  return /*#__PURE__*/React.createElement("svg", (0, _extends2.default)({
    xmlns: "http://www.w3.org/2000/svg",
    width: 16,
    height: 16,
    viewBox: "0 0 16 16",
    "aria-labelledby": titleId
  }, props), title ? /*#__PURE__*/React.createElement("title", {
    id: titleId
  }, title) : null, /*#__PURE__*/React.createElement("path", {
    d: "M9.572 6.036H6.43a.393.393 0 0 0-.393.393v3.142a.393.393 0 0 0 .393.393h3.142a.393.393 0 0 0 .392-.393V6.429a.393.393 0 0 0-.392-.393Zm-.393 3.142H6.823V6.822h2.356v2.356Zm5.63 0h-1.18V6.822h1.18a.393.393 0 0 0 0-.786h-1.18V3.287a.917.917 0 0 0-.915-.916h-2.75V1.193a.393.393 0 0 0-.785 0V2.37H6.823V1.193a.393.393 0 0 0-.786 0V2.37H3.288a.916.916 0 0 0-.916.916v2.75H1.194a.393.393 0 0 0 0 .785h1.178v2.356H1.194a.393.393 0 0 0 0 .786h1.178v2.749a.916.916 0 0 0 .916.916h2.75v1.178a.393.393 0 1 0 .785 0V13.63h2.356v1.178a.393.393 0 1 0 .785 0V13.63h2.75a.916.916 0 0 0 .916-.916v-2.75h1.178a.393.393 0 0 0 0-.785Zm-1.965 3.535a.13.13 0 0 1-.13.13H3.287a.13.13 0 0 1-.13-.13V3.287a.13.13 0 0 1 .13-.13h9.425a.131.131 0 0 1 .131.13v9.426Z"
  }));
};
var icon = EuiIconNavInfra;
exports.icon = icon;