"use strict";
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.applyDeprecations = exports.configDeprecationFactory = void 0;
var deprecation_factory_1 = require("./deprecation_factory");
Object.defineProperty(exports, "configDeprecationFactory", { enumerable: true, get: function () { return deprecation_factory_1.configDeprecationFactory; } });
var apply_deprecations_1 = require("./apply_deprecations");
Object.defineProperty(exports, "applyDeprecations", { enumerable: true, get: function () { return apply_deprecations_1.applyDeprecations; } });
