function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(e, r, t) { return (r = _toPropertyKey(r)) in e ? Object.defineProperty(e, r, { value: t, enumerable: !0, configurable: !0, writable: !0 }) : e[r] = t, e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == typeof i ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != typeof t || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != typeof i) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */

import { useReactFlow } from '@xyflow/react';
import { useCallback } from 'react';
import { useCelestialLayout } from '../../shared/hooks/use_celestial_layout.hook';
import { useCelestialStateContext } from '../../shared/contexts/celestial_state_context';
export const useLayoutControls = () => {
  const {
    layoutOptions
  } = useCelestialStateContext();
  const {
    getLaidOutElements
  } = useCelestialLayout(layoutOptions);
  const {
    getNodes,
    setNodes,
    getEdges,
    setEdges,
    fitView
  } = useReactFlow();

  /**
   * Handler for zooming in the view
   * @param e Mouse event from zoom button click
   */
  const onLayoutChange = useCallback(e => {
    e.stopPropagation();
    const nodes = getNodes();
    const edges = getEdges();
    const layout = getLaidOutElements(nodes, edges);
    setNodes(layout.nodes);
    setEdges(layout.edges);
    fitView({
      duration: 300
    });
  },
  // eslint-disable-next-line react-hooks/exhaustive-deps
  [getLaidOutElements, getNodes, setNodes, getEdges, setEdges]);
  const onExpandAll = useCallback(e => {
    e.stopPropagation();
    const nodes = getNodes().map(node => _objectSpread(_objectSpread({}, node), {}, {
      hidden: false
    }));
    const edges = getEdges().map(edge => _objectSpread(_objectSpread({}, edge), {}, {
      hidden: false
    }));
    const layout = getLaidOutElements(nodes, edges);
    setNodes(layout.nodes);
    setEdges(layout.edges);
    fitView({
      duration: 300
    });
  },
  // eslint-disable-next-line react-hooks/exhaustive-deps
  [getNodes, getEdges, setNodes, setEdges, fitView]);
  return {
    onLayoutChange,
    onExpandAll
  };
};