"use strict";
// Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCompatibleCommitmentPolicy = exports.MessageFormat = exports.SignaturePolicy = exports.SignaturePolicySuites = exports.CommitmentPolicySuites = exports.CommitmentPolicy = exports.unwrapDataKey = exports.readOnlyProperty = exports.frozenClass = exports.immutableClass = exports.immutableBaseClass = exports.MultiKeyringNode = exports.KeyringNode = exports.NotSupported = exports.needs = exports.KeyringTraceFlag = exports.EncryptedDataKey = exports.AlgorithmSuiteIdentifier = exports.NodeAlgorithmSuite = exports.NodeEncryptionMaterial = exports.NodeDecryptionMaterial = exports.getDecryptionHelper = exports.getEncryptHelper = void 0;
__exportStar(require("./node_cryptographic_materials_manager"), exports);
var material_helpers_1 = require("./material_helpers");
Object.defineProperty(exports, "getEncryptHelper", { enumerable: true, get: function () { return material_helpers_1.getEncryptHelper; } });
Object.defineProperty(exports, "getDecryptionHelper", { enumerable: true, get: function () { return material_helpers_1.getDecryptionHelper; } });
var material_management_1 = require("@aws-crypto/material-management");
Object.defineProperty(exports, "NodeDecryptionMaterial", { enumerable: true, get: function () { return material_management_1.NodeDecryptionMaterial; } });
Object.defineProperty(exports, "NodeEncryptionMaterial", { enumerable: true, get: function () { return material_management_1.NodeEncryptionMaterial; } });
Object.defineProperty(exports, "NodeAlgorithmSuite", { enumerable: true, get: function () { return material_management_1.NodeAlgorithmSuite; } });
Object.defineProperty(exports, "AlgorithmSuiteIdentifier", { enumerable: true, get: function () { return material_management_1.AlgorithmSuiteIdentifier; } });
Object.defineProperty(exports, "EncryptedDataKey", { enumerable: true, get: function () { return material_management_1.EncryptedDataKey; } });
Object.defineProperty(exports, "KeyringTraceFlag", { enumerable: true, get: function () { return material_management_1.KeyringTraceFlag; } });
Object.defineProperty(exports, "needs", { enumerable: true, get: function () { return material_management_1.needs; } });
Object.defineProperty(exports, "NotSupported", { enumerable: true, get: function () { return material_management_1.NotSupported; } });
Object.defineProperty(exports, "KeyringNode", { enumerable: true, get: function () { return material_management_1.KeyringNode; } });
Object.defineProperty(exports, "MultiKeyringNode", { enumerable: true, get: function () { return material_management_1.MultiKeyringNode; } });
Object.defineProperty(exports, "immutableBaseClass", { enumerable: true, get: function () { return material_management_1.immutableBaseClass; } });
Object.defineProperty(exports, "immutableClass", { enumerable: true, get: function () { return material_management_1.immutableClass; } });
Object.defineProperty(exports, "frozenClass", { enumerable: true, get: function () { return material_management_1.frozenClass; } });
Object.defineProperty(exports, "readOnlyProperty", { enumerable: true, get: function () { return material_management_1.readOnlyProperty; } });
Object.defineProperty(exports, "unwrapDataKey", { enumerable: true, get: function () { return material_management_1.unwrapDataKey; } });
Object.defineProperty(exports, "CommitmentPolicy", { enumerable: true, get: function () { return material_management_1.CommitmentPolicy; } });
Object.defineProperty(exports, "CommitmentPolicySuites", { enumerable: true, get: function () { return material_management_1.CommitmentPolicySuites; } });
Object.defineProperty(exports, "SignaturePolicySuites", { enumerable: true, get: function () { return material_management_1.SignaturePolicySuites; } });
Object.defineProperty(exports, "SignaturePolicy", { enumerable: true, get: function () { return material_management_1.SignaturePolicy; } });
Object.defineProperty(exports, "MessageFormat", { enumerable: true, get: function () { return material_management_1.MessageFormat; } });
Object.defineProperty(exports, "getCompatibleCommitmentPolicy", { enumerable: true, get: function () { return material_management_1.getCompatibleCommitmentPolicy; } });
//# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiaW5kZXguanMiLCJzb3VyY2VSb290IjoiIiwic291cmNlcyI6WyIuLi8uLi8uLi9zcmMvaW5kZXgudHMiXSwibmFtZXMiOltdLCJtYXBwaW5ncyI6IjtBQUFBLG9FQUFvRTtBQUNwRSxzQ0FBc0M7Ozs7Ozs7Ozs7Ozs7Ozs7O0FBRXRDLHlFQUFzRDtBQUN0RCx1REFTMkI7QUFSekIsb0hBQUEsZ0JBQWdCLE9BQUE7QUFDaEIsdUhBQUEsbUJBQW1CLE9BQUE7QUFRckIsdUVBNEJ3QztBQTNCdEMsNkhBQUEsc0JBQXNCLE9BQUE7QUFDdEIsNkhBQUEsc0JBQXNCLE9BQUE7QUFDdEIseUhBQUEsa0JBQWtCLE9BQUE7QUFDbEIsK0hBQUEsd0JBQXdCLE9BQUE7QUFFeEIsdUhBQUEsZ0JBQWdCLE9BQUE7QUFFaEIsdUhBQUEsZ0JBQWdCLE9BQUE7QUFDaEIsNEdBQUEsS0FBSyxPQUFBO0FBQ0wsbUhBQUEsWUFBWSxPQUFBO0FBQ1osa0hBQUEsV0FBVyxPQUFBO0FBQ1gsdUhBQUEsZ0JBQWdCLE9BQUE7QUFDaEIseUhBQUEsa0JBQWtCLE9BQUE7QUFDbEIscUhBQUEsY0FBYyxPQUFBO0FBQ2Qsa0hBQUEsV0FBVyxPQUFBO0FBQ1gsdUhBQUEsZ0JBQWdCLE9BQUE7QUFFaEIsb0hBQUEsYUFBYSxPQUFBO0FBRWIsdUhBQUEsZ0JBQWdCLE9BQUE7QUFDaEIsNkhBQUEsc0JBQXNCLE9BQUE7QUFDdEIsNEhBQUEscUJBQXFCLE9BQUE7QUFDckIsc0hBQUEsZUFBZSxPQUFBO0FBQ2Ysb0hBQUEsYUFBYSxPQUFBO0FBR2Isb0lBQUEsNkJBQTZCLE9BQUEifQ==