"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiBetaBadge", {
  enumerable: true,
  get: function get() {
    return _beta_badge.OuiBetaBadge;
  }
});
Object.defineProperty(exports, "EuiBetaBadge", {
  enumerable: true,
  get: function get() {
    return _beta_badge2.EuiBetaBadge;
  }
});
var _beta_badge = require("./beta_badge");
var _beta_badge2 = require("../../../eui_components/badge/beta_badge/beta_badge");