"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "OuiTablePagination", {
  enumerable: true,
  get: function get() {
    return _table_pagination.OuiTablePagination;
  }
});
Object.defineProperty(exports, "EuiTablePagination", {
  enumerable: true,
  get: function get() {
    return _table_pagination2.EuiTablePagination;
  }
});
var _table_pagination = require("./table_pagination");
var _table_pagination2 = require("../../../eui_components/table/table_pagination/table_pagination");