"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "EuiFilePicker", {
  enumerable: true,
  get: function get() {
    return _file_picker.EuiFilePicker;
  }
});
Object.defineProperty(exports, "EuiCompressedFilePicker", {
  enumerable: true,
  get: function get() {
    return _file_picker.EuiCompressedFilePicker;
  }
});
var _file_picker = require("./file_picker");