/*!
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */
/*!
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */
@keyframes euiAnimFadeIn{0%{opacity:0}to{opacity:1}}@keyframes euiGrow{0%{opacity:0}1%{opacity:0;transform:scale(0)}to{opacity:1;transform:scale(1)}}@keyframes focusRingAnimate{0%{box-shadow:0 0 0 6px rgba(21,157,141,0)}to{box-shadow:0 0 0 3px rgba(21,157,141,.3)}}@keyframes focusRingAnimateLarge{0%{box-shadow:0 0 0 10px rgba(21,157,141,0)}to{box-shadow:0 0 0 4px rgba(21,157,141,.3)}}@keyframes euiButtonActive{50%{transform:translateY(1px)}}.eui-alignBaseline{vertical-align:baseline!important}.eui-alignBottom{vertical-align:bottom!important}.eui-alignMiddle{vertical-align:middle!important}.eui-alignTop{vertical-align:top!important}.eui-displayBlock{display:block!important}.eui-displayInline{display:inline!important}.eui-displayInlineBlock{display:inline-block!important}.eui-displayNone{display:none!important}.eui-fullWidth{width:100%!important;display:block!important}.eui-textCenter{text-align:center!important}.eui-textLeft{text-align:left!important}.eui-textRight{text-align:right!important}.eui-textNoWrap{white-space:nowrap!important}.eui-textInheritColor{color:inherit!important}.eui-textBreakWord{word-break:break-word;overflow-wrap:break-word!important;word-wrap:break-word!important}.eui-textBreakAll{overflow-wrap:break-word!important;word-break:break-all!important}.eui-textBreakNormal{overflow-wrap:normal!important;word-wrap:normal!important;word-break:normal!important}.eui-textOverflowWrap{overflow-wrap:break-word!important}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.eui-textOverflowWrap{word-break:break-all!important}}.eui-textTruncate{max-width:100%;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}[class*=oui-showFor]{display:none!important}@media only screen and (max-width:574px){.eui-hideFor--xs{display:none!important}.eui-showFor--xs{display:inline!important}.eui-showFor--xs--block{display:block!important}.eui-showFor--xs--inlineBlock{display:inline-block!important}.eui-showFor--xs--flex{display:flex!important}}@media only screen and (min-width:575px) and (max-width:767px){.eui-hideFor--s{display:none!important}.eui-showFor--s{display:inline!important}.eui-showFor--s--block{display:block!important}.eui-showFor--s--inlineBlock{display:inline-block!important}.eui-showFor--s--flex{display:flex!important}}@media only screen and (min-width:768px) and (max-width:991px){.eui-hideFor--m{display:none!important}.eui-showFor--m{display:inline!important}.eui-showFor--m--block{display:block!important}.eui-showFor--m--inlineBlock{display:inline-block!important}.eui-showFor--m--flex{display:flex!important}}@media only screen and (min-width:992px) and (max-width:1199px){.eui-hideFor--l{display:none!important}.eui-showFor--l{display:inline!important}.eui-showFor--l--block{display:block!important}.eui-showFor--l--inlineBlock{display:inline-block!important}.eui-showFor--l--flex{display:flex!important}}@media only screen and (min-width:1200px) and (max-width:1679px){.eui-hideFor--xl{display:none!important}.eui-showFor--xl{display:inline!important}.eui-showFor--xl--block{display:block!important}.eui-showFor--xl--inlineBlock{display:inline-block!important}.eui-showFor--xl--flex{display:flex!important}}@media only screen and (min-width:1680px) and (max-width:1919px){.eui-hideFor--xxl{display:none!important}.eui-showFor--xxl{display:inline!important}.eui-showFor--xxl--block{display:block!important}.eui-showFor--xxl--inlineBlock{display:inline-block!important}.eui-showFor--xxl--flex{display:flex!important}}@media only screen and (min-width:1920px){.eui-hideFor--xxxl{display:none!important}.eui-showFor--xxxl{display:inline!important}.eui-showFor--xxxl--block{display:block!important}.eui-showFor--xxxl--inlineBlock{display:inline-block!important}.eui-showFor--xxxl--flex{display:flex!important}}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiIEFlexWrapFix{flex:1}}.eui-yScroll{scrollbar-width:thin;height:100%;overflow-x:hidden;overflow-y:auto}.eui-yScroll::-webkit-scrollbar{width:16px;height:16px}.eui-yScroll::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.eui-yScroll::-webkit-scrollbar-corner{background-color:transparent}.eui-yScroll::-webkit-scrollbar-track{background-color:transparent}.eui-yScroll:focus{outline:none}.eui-yScroll[tabindex="0"]:focus:focus-visible{outline-style:auto}.eui-xScroll{scrollbar-width:thin;overflow-x:auto}.eui-xScroll::-webkit-scrollbar{width:16px;height:16px}.eui-xScroll::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.eui-xScroll::-webkit-scrollbar-corner{background-color:transparent}.eui-xScroll::-webkit-scrollbar-track{background-color:transparent}.eui-xScroll:focus{outline:none}.eui-xScroll[tabindex="0"]:focus:focus-visible{outline-style:auto}.eui-yScrollWithShadows{scrollbar-width:thin;contain:paint;height:100%;overflow-x:hidden;overflow-y:auto;-webkit-mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%);mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%)}.eui-yScrollWithShadows::-webkit-scrollbar{width:16px;height:16px}.eui-yScrollWithShadows::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.eui-yScrollWithShadows::-webkit-scrollbar-corner{background-color:transparent}.eui-yScrollWithShadows::-webkit-scrollbar-track{background-color:transparent}.eui-yScrollWithShadows:focus{outline:none}.eui-yScrollWithShadows[tabindex="0"]:focus:focus-visible{outline-style:auto}.eui-xScrollWithShadows{scrollbar-width:thin;contain:paint;overflow-x:auto;-webkit-mask-image:linear-gradient(90deg,rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%);mask-image:linear-gradient(90deg,rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%)}.eui-xScrollWithShadows::-webkit-scrollbar{width:16px;height:16px}.eui-xScrollWithShadows::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.eui-xScrollWithShadows::-webkit-scrollbar-corner{background-color:transparent}.eui-xScrollWithShadows::-webkit-scrollbar-track{background-color:transparent}.eui-xScrollWithShadows:focus{outline:none}.eui-xScrollWithShadows[tabindex="0"]:focus:focus-visible{outline-style:auto}.euiYScrollWithShadows{scrollbar-width:thin;contain:paint;height:100%;overflow-x:hidden;overflow-y:auto;-webkit-mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%);mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%)}.euiYScrollWithShadows::-webkit-scrollbar{width:16px;height:16px}.euiYScrollWithShadows::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiYScrollWithShadows::-webkit-scrollbar-corner{background-color:transparent}.euiYScrollWithShadows::-webkit-scrollbar-track{background-color:transparent}.euiYScrollWithShadows:focus{outline:none}.euiYScrollWithShadows[tabindex="0"]:focus:focus-visible{outline-style:auto}.eui-isFocusable:focus{animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimateLarge!important}.eui-fullHeight{flex:auto;height:100%;overflow:hidden}:root{--eui-font-family:"Source Sans 3",-apple-system,BlinkMacSystemFont,"Segoe UI",Helvetica,Arial,sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol";--eui-code-font-family:"Source Code Pro",Consolas,Menlo,Courier,monospace}*,:before,:after{box-sizing:border-box}html,body,div,span,applet,object,iframe,h1,h2,h3,h4,h5,h6,p,blockquote,pre,a,abbr,acronym,address,big,cite,code,del,dfn,em,img,ins,kbd,q,s,samp,small,strike,strong,sub,sup,tt,var,b,u,i,center,dl,dt,dd,ol,ul,li,fieldset,form,label,legend,table,caption,tbody,tfoot,thead,tr,th,td,article,aside,canvas,details,embed,figure,figcaption,footer,header,hgroup,menu,nav,output,ruby,section,summary,time,mark,audio,video{vertical-align:baseline;border:none;margin:0;padding:0}code,pre,kbd,samp{font-family:var(--eui-code-font-family);line-height:1.5}h1,h2,h3,h4,h5,h6,p{font-family:inherit;font-weight:inherit;font-size:inherit}input,textarea,select,button{font-family:var(--eui-font-family)}em{font-style:italic}strong{font-weight:700}article,aside,details,figcaption,figure,footer,header,hgroup,menu,nav,section{display:block}html{font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;background-color:#172430;height:100%;font-size:18px;font-weight:400}body{line-height:1}:focus{outline:none}:focus::-moz-focus-inner{border:none}:focus:-moz-focusring{outline:none}a{color:#159d8d;text-decoration:none}a:hover{text-decoration:none}a:focus{outline:none;text-decoration:none}a:hover,button,[role=button]{cursor:pointer}input{margin:0;padding:0}input:disabled{opacity:1}button{font-size:inherit;color:inherit;background:0 0;border:none;border-radius:0;outline:none;margin:0;padding:0}button:hover{cursor:pointer}ol,ul{list-style:none}blockquote,q{quotes:none}blockquote:before,blockquote:after,q:before,q:after{content:"";content:none}table{border-collapse:collapse;border-spacing:0}hr{margin:0}fieldset{min-width:auto}svg text{letter-spacing:normal!important}html{scrollbar-width:thin;scrollbar-color:rgba(141,152,163,.5) transparent}.euiScreenReaderOnly,.euiScreenReaderOnly--showOnFocus:not(:focus):not(:active){-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;width:1px;height:1px;position:absolute;top:auto;left:-10000px;overflow:hidden}.euiSkipLink{transition:none!important}.euiSkipLink:focus{animation:none!important}.euiSkipLink.euiSkipLink--absolute:focus{position:absolute}.euiSkipLink.euiSkipLink--fixed:focus{z-index:1001;position:fixed;top:4px;left:4px}.euiAccordion__triggerWrapper{align-items:center;display:flex}.euiAccordion__button{text-align:left;flex-grow:1;align-items:center;width:100%;font-size:1rem;line-height:1.33333;display:flex}.euiAccordion__button:hover,.euiAccordion__button:focus{cursor:pointer;text-decoration:underline}.euiAccordion__button:focus .euiAccordion__iconWrapper{color:#159d8d;outline:none;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiAccordion__buttonReverse{flex-direction:row-reverse;justify-content:space-between}.euiAccordion__buttonReverse .euiAccordion__iconWrapper{margin-left:8px;margin-right:4px}.euiAccordion__iconWrapper{border-radius:4px;flex-shrink:0;width:16px;height:16px;margin-left:4px;margin-right:8px}.euiAccordion__iconWrapper .euiAccordion__icon{vertical-align:top;transition:transform .25s cubic-bezier(.694,.0482,.335,1)}.euiAccordion__iconWrapper .euiAccordion__icon-isOpen{transform:rotate(90deg)}.euiAccordion__iconButton{margin-left:8px;margin-right:4px}.euiAccordion__iconButton:focus{color:#159d8d;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiAccordion__optionalAction{flex-shrink:0}.euiAccordion__childWrapper{visibility:hidden;opacity:0;height:0;transition:height .25s cubic-bezier(.694,.0482,.335,1),opacity .25s cubic-bezier(.694,.0482,.335,1);overflow:hidden;transform:translateZ(0)}.euiAccordion__childWrapper:focus{outline:none}.euiAccordion__padding--xs{padding:4px}.euiAccordion__padding--s{padding:8px}.euiAccordion__padding--m{padding:16px}.euiAccordion__padding--l{padding:24px}.euiAccordion__padding--xl{padding:32px}.euiAccordion.euiAccordion-isOpen .euiAccordion__childWrapper{visibility:visible;opacity:1;height:auto}.euiAccordion__children-isLoading{align-items:center;line-height:1.33333;display:flex}.euiAccordion__children-isLoading .euiAccordion__spinner{margin-right:4px}.euiAccordionForm__extraAction{opacity:0;transition:opacity .25s cubic-bezier(.694,.0482,.335,1)}.euiAccordionForm__extraAction:focus{opacity:1}.euiAccordionForm__title{display:inline-block}.euiAccordionForm__button{padding:16px 16px 16px 0}.euiAccordionForm__button:hover{text-decoration:none}.euiAccordionForm__button:hover .euiAccordionForm__title{text-decoration:underline}.euiAccordionForm{border-top:1px solid #293847;border-bottom:1px solid #293847}.euiAccordionForm+.euiAccordionForm{border-top:none}.euiAccordionForm:hover .euiAccordionForm__extraAction{opacity:1;visibility:visible}.euiAspectRatio{position:relative}.euiAspectRatio>*{width:100%!important;height:100%!important;position:absolute!important;top:0!important;left:0!important}.euiAvatar{text-align:center;vertical-align:middle;background-size:cover;flex-shrink:0;justify-content:center;align-items:center;font-weight:500;display:inline-flex;overflow-x:hidden}.euiAvatar--user{border-radius:50%;position:relative}.euiAvatar--user:after{content:"";pointer-events:none;border:1px solid rgba(223,227,232,.05);border-radius:50%;position:absolute;top:0;bottom:0;left:0;right:0}.euiAvatar--space{border-radius:4px;position:relative}.euiAvatar--space:after{content:"";pointer-events:none;border:1px solid rgba(223,227,232,.05);border-radius:4px;position:absolute;top:0;bottom:0;left:0;right:0}.euiAvatar-isDisabled{cursor:not-allowed;-webkit-filter:grayscale();filter:grayscale()}.euiAvatar--plain{background-color:#0a121a}.euiAvatar--s{width:24px;height:24px;font-size:12px;line-height:24px}.euiAvatar--m{width:32px;height:32px;font-size:14.4px;line-height:32px}.euiAvatar--l{width:40px;height:40px;font-size:19.2px;line-height:40px}.euiAvatar--xl{width:64px;height:64px;font-size:25.6px;line-height:64px}.euiBadge{white-space:nowrap;vertical-align:middle;cursor:default;text-align:left;background-color:transparent;border:1px solid transparent;border-radius:2px;max-width:100%;padding:0 8px;font-size:13.5px;font-weight:500;line-height:18px;text-decoration:none;display:inline-block}.euiBadge.euiBadge-isDisabled{color:#80858b!important;background-color:#4a515a!important}.euiBadge:focus-within{animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiBadge+.euiBadge{margin-left:4px}.euiBadge .euiBadge__content{align-items:center;min-height:18px;display:flex;overflow:hidden}.euiBadge .euiBadge__childButton{max-width:100%;text-align:inherit;font-weight:inherit;line-height:inherit;color:inherit;flex:auto;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiBadge .euiBadge__childButton:disabled{cursor:not-allowed}.euiBadge .euiBadge__childButton:not(:disabled):hover,.euiBadge .euiBadge__childButton:not(:disabled):focus{text-decoration:underline}.euiBadge .euiBadge__iconButton{flex:none;margin-left:4px;font-size:0}.euiBadge .euiBadge__iconButton:focus{color:#0a121a;background-color:rgba(252,254,255,.8);border-radius:2px}.euiBadge .euiBadge__iconButton:disabled{cursor:not-allowed}.euiBadge .euiBadge__iconButton .euiBadge__icon{margin:0!important}.euiBadge .euiBadge__text{cursor:default;flex:auto;max-width:100%;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiBadge .euiBadge__icon{flex:none}.euiBadge .euiBadge__icon:not(:only-child){margin-left:4px}.euiBadge.euiBadge--iconLeft .euiBadge__content{flex-direction:row-reverse}.euiBadge.euiBadge--iconLeft .euiBadge__iconButton,.euiBadge.euiBadge--iconLeft .euiBadge__icon:not(:only-child){margin-left:0;margin-right:4px}.euiBadge-isClickable:not(:disabled):hover,.euiBadge-isClickable:not(:disabled):focus{text-decoration:underline}.euiBadge-isClickable.euiBadge-isDisabled{cursor:not-allowed}.euiBadge-isClickable:focus{animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiBadge-isClickable .euiBadge__text{cursor:inherit}.euiBadge--hollow{color:#dfe5ef;background-color:#0a121a;border-color:#495663}.euiBadgeGroup__item{max-width:100%;display:inline-block}.euiBadgeGroup--gutterExtraSmall{margin:-2px}.euiBadgeGroup--gutterExtraSmall>.euiBadgeGroup__item{max-width:calc(100% - 4px);margin:2px}.euiBadgeGroup--gutterSmall{margin:-4px}.euiBadgeGroup--gutterSmall>.euiBadgeGroup__item{max-width:calc(100% - 8px);margin:4px}.euiBetaBadge{vertical-align:super;text-transform:uppercase;letter-spacing:.05em;text-align:center;white-space:nowrap;cursor:default;border-radius:24px;padding:0 16px;font-size:13.5px;font-weight:700;line-height:24px;display:inline-block;box-shadow:inset 0 0 0 1px #293847}.euiBetaBadge:focus{outline-offset:2px;outline-color:#fcfeff;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiBetaBadge:not(.euiBetaBadge--hollow){box-shadow:none}.euiBetaBadge.euiBetaBadge--small{padding:0 12px;font-size:.625rem;line-height:20px}.euiBetaBadge--iconOnly{width:24px;padding:0}.euiBetaBadge--iconOnly .euiBetaBadge__icon{margin-top:-1px;position:relative}.euiBetaBadge--iconOnly.euiBetaBadge--small{width:20px;padding:0}.euiBetaBadge--singleLetter{width:24px;padding:0 0 0 1px}.euiBetaBadge--singleLetter.euiBetaBadge--small{width:20px;padding:0 0 0 1px}.euiBetaBadge--subdued{color:#fcfeff;background:#68737e}.euiBetaBadge--subdued.euiBetaBadge-isClickable,.euiBetaBadge--hollow.euiBetaBadge-isClickable{color:#fcfeff}.euiNotificationBadge{vertical-align:middle;text-align:center;cursor:default;color:#0a121a;background:#f990c0;border-radius:4px;flex-shrink:0;min-width:16px;height:16px;padding-left:4px;padding-right:4px;font-size:13.5px;font-weight:500;line-height:16px;transition:all .15s ease-in;display:inline-block}.euiNotificationBadge--medium{min-width:24px;height:20px;line-height:20px}.euiNotificationBadge--subdued{color:#fcfeff;background:#68737e}.euiBasicTable-loading{position:relative}.euiBasicTable-loading tbody{overflow:hidden}.euiBasicTable-loading tbody:before{content:"";background-color:#159d8d;width:100%;height:2px;animation:1s linear infinite euiBasicTableLoading;position:absolute}@keyframes euiBasicTableLoading{0%{width:0;left:0}20%{width:40%;left:0}80%{width:40%;left:60%}to{width:0;left:100%}}.euiBeacon{background-color:#54b399;border-radius:50%;position:relative}.euiBeacon:before,.euiBeacon:after{content:"";background-color:transparent;border-radius:50%;width:100%;height:100%;position:absolute;top:0;left:0;box-shadow:0 0 1px 1px #54b399}.euiBeacon:before{animation:2.5s ease-out infinite euiBeaconPulseLarge}.euiBeacon:after{animation:2.5s ease-out .25s infinite euiBeaconPulseSmall}@keyframes euiBeaconPulseLarge{0%{opacity:1;transform:scale(.1)}70%{opacity:0;transform:scale(3)}to{opacity:0}}@keyframes euiBeaconPulseSmall{0%{opacity:1;transform:scale(.1)}70%{opacity:0;transform:scale(2)}to{opacity:0}}.euiBottomBar{color:#fcfeff;background:#172430;bottom:0;left:0;right:0;box-shadow:0 0 12px -1px rgba(0,0,0,.2),0 0 4px -1px rgba(0,0,0,.2),0 0 2px rgba(0,0,0,.2)}@media screen and (prefers-reduced-motion:no-preference){.euiBottomBar{animation:.35s cubic-bezier(.694,.0482,.335,1) euiBottomBarAppear}}.euiBottomBar--fixed{z-index:998;position:fixed}.euiBottomBar--sticky{z-index:998;position:-webkit-sticky;position:sticky}.euiBottomBar--paddingSmall{padding:8px}.euiBottomBar--paddingMedium{padding:16px}.euiBottomBar--paddingLarge{padding:24px}@keyframes euiBottomBarAppear{0%{opacity:0;transform:translateY(100%)}to{opacity:1;transform:translateY(0%)}}.euiButton{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;cursor:pointer;text-align:center;white-space:nowrap;vertical-align:middle;max-width:100%;height:40px;line-height:40px;font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;border:1px solid transparent;border-radius:4px;min-width:112px;font-size:.875rem;font-weight:400;line-height:1.33333;text-decoration:none;display:inline-block;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}@media screen and (prefers-reduced-motion:no-preference){.euiButton{transition:background .25s ease-in-out}}.euiButton:hover:not([class*=isDisabled]),.euiButton:focus{text-decoration:underline}.euiButton .euiButton__content{padding:0 12px}.euiButton .euiButton__text{text-overflow:ellipsis;overflow:hidden}.euiButton.euiButton--small{height:32px;line-height:32px}.euiButton:hover,.euiButton:active{box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton:not([class*=isDisabled]):hover,.euiButton:not([class*=isDisabled]):focus{background-color:rgba(21,157,141,.1)}.euiButton:not([class*=isDisabled]):focus-within{background-color:rgba(21,157,141,.1)}.euiButton.euiButton-isDisabled{pointer-events:auto;cursor:not-allowed;color:#535a62;border-color:#4a515a}.euiButton.euiButton-isDisabled .euiButtonContent__icon{fill:currentColor}.euiButton.euiButton-isDisabled .euiButtonContent__spinner{border-color:#159d8d currentColor currentColor}.euiButton.euiButton-isDisabled.euiButton--fill{color:#80858b;background-color:#4a515a;border-color:#4a515a}.euiButton.euiButton-isDisabled.euiButton--fill:hover,.euiButton.euiButton-isDisabled.euiButton--fill:focus{background-color:#4a515a;border-color:#4a515a}.euiButton.euiButton-isDisabled.euiButton--fill:focus-within{background-color:#4a515a;border-color:#4a515a}.euiButton.euiButton-isDisabled:hover,.euiButton.euiButton-isDisabled:focus{text-decoration:none;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButton.euiButton-isDisabled:focus-within{text-decoration:none;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--primary{color:#159d8d;border-color:#159d8d}.euiButton--primary.euiButton--fill{color:#0a121a;background-color:#159d8d;border-color:#159d8d}.euiButton--primary.euiButton--fill:not([class*=isDisabled]):hover,.euiButton--primary.euiButton--fill:not([class*=isDisabled]):focus{background-color:#128779;border-color:#128779}.euiButton--primary.euiButton--fill:not([class*=isDisabled]):focus-within{background-color:#128779;border-color:#128779}.euiButton--primary.euiButton--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(15,112,101,.4)}.euiButton--primary:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--primary:not([class*=isDisabled]):hover,.euiButton--primary:not([class*=isDisabled]):focus{background-color:rgba(21,157,141,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--primary:not([class*=isDisabled]):focus-within{background-color:rgba(21,157,141,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--primary:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(21,157,141,.15)}.euiButton--accent{color:#f990c0;border-color:#f990c0}.euiButton--accent.euiButton--fill{color:#0a121a;background-color:#f990c0;border-color:#f990c0}.euiButton--accent.euiButton--fill:not([class*=isDisabled]):hover,.euiButton--accent.euiButton--fill:not([class*=isDisabled]):focus{background-color:#f878b2;border-color:#f878b2}.euiButton--accent.euiButton--fill:not([class*=isDisabled]):focus-within{background-color:#f878b2;border-color:#f878b2}.euiButton--accent.euiButton--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(246,96,165,.4)}.euiButton--accent:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--accent:not([class*=isDisabled]):hover,.euiButton--accent:not([class*=isDisabled]):focus{background-color:rgba(249,144,192,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--accent:not([class*=isDisabled]):focus-within{background-color:rgba(249,144,192,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--accent:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(249,144,192,.15)}.euiButton--secondary{color:#7de2d1;border-color:#7de2d1}.euiButton--secondary.euiButton--fill{color:#0a121a;background-color:#7de2d1;border-color:#7de2d1}.euiButton--secondary.euiButton--fill:not([class*=isDisabled]):hover,.euiButton--secondary.euiButton--fill:not([class*=isDisabled]):focus{background-color:#68ddca;border-color:#68ddca}.euiButton--secondary.euiButton--fill:not([class*=isDisabled]):focus-within{background-color:#68ddca;border-color:#68ddca}.euiButton--secondary.euiButton--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(83,217,194,.4)}.euiButton--secondary:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--secondary:not([class*=isDisabled]):hover,.euiButton--secondary:not([class*=isDisabled]):focus{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--secondary:not([class*=isDisabled]):focus-within{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--secondary:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(125,226,209,.15)}.euiButton--success{color:#7de2d1;border-color:#7de2d1}.euiButton--success.euiButton--fill{color:#0a121a;background-color:#7de2d1;border-color:#7de2d1}.euiButton--success.euiButton--fill:not([class*=isDisabled]):hover,.euiButton--success.euiButton--fill:not([class*=isDisabled]):focus{background-color:#68ddca;border-color:#68ddca}.euiButton--success.euiButton--fill:not([class*=isDisabled]):focus-within{background-color:#68ddca;border-color:#68ddca}.euiButton--success.euiButton--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(83,217,194,.4)}.euiButton--success:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--success:not([class*=isDisabled]):hover,.euiButton--success:not([class*=isDisabled]):focus{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--success:not([class*=isDisabled]):focus-within{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--success:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(125,226,209,.15)}.euiButton--warning{color:#ffce7a;border-color:#ffce7a}.euiButton--warning.euiButton--fill{color:#0a121a;background-color:#ffce7a;border-color:#ffce7a}.euiButton--warning.euiButton--fill:not([class*=isDisabled]):hover,.euiButton--warning.euiButton--fill:not([class*=isDisabled]):focus{background-color:#ffc561;border-color:#ffc561}.euiButton--warning.euiButton--fill:not([class*=isDisabled]):focus-within{background-color:#ffc561;border-color:#ffc561}.euiButton--warning.euiButton--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(255,187,71,.4)}.euiButton--warning:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--warning:not([class*=isDisabled]):hover,.euiButton--warning:not([class*=isDisabled]):focus{background-color:rgba(255,206,122,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--warning:not([class*=isDisabled]):focus-within{background-color:rgba(255,206,122,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--warning:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(255,206,122,.15)}.euiButton--danger{color:#f66;border-color:#f66}.euiButton--danger.euiButton--fill{color:#0a121a;background-color:#f66;border-color:#f66}.euiButton--danger.euiButton--fill:not([class*=isDisabled]):hover,.euiButton--danger.euiButton--fill:not([class*=isDisabled]):focus{background-color:#ff4d4d;border-color:#ff4d4d}.euiButton--danger.euiButton--fill:not([class*=isDisabled]):focus-within{background-color:#ff4d4d;border-color:#ff4d4d}.euiButton--danger.euiButton--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(255,51,51,.4)}.euiButton--danger:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--danger:not([class*=isDisabled]):hover,.euiButton--danger:not([class*=isDisabled]):focus{background-color:rgba(255,102,102,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--danger:not([class*=isDisabled]):focus-within{background-color:rgba(255,102,102,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--danger:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(255,102,102,.15)}.euiButton--subdued{color:#9fa6af;border-color:#9fa6af}.euiButton--subdued.euiButton--fill{color:#0a121a;background-color:#9fa6af;border-color:#9fa6af}.euiButton--subdued.euiButton--fill:not([class*=isDisabled]):hover,.euiButton--subdued.euiButton--fill:not([class*=isDisabled]):focus{background-color:#9199a3;border-color:#9199a3}.euiButton--subdued.euiButton--fill:not([class*=isDisabled]):focus-within{background-color:#9199a3;border-color:#9199a3}.euiButton--subdued.euiButton--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(131,140,152,.4)}.euiButton--subdued:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--subdued:not([class*=isDisabled]):hover,.euiButton--subdued:not([class*=isDisabled]):focus{background-color:rgba(159,166,175,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--subdued:not([class*=isDisabled]):focus-within{background-color:rgba(159,166,175,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--subdued:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(159,166,175,.15)}.euiButton--ghost{color:#fcfeff;border-color:#fcfeff}.euiButton--ghost.euiButton--fill{color:#0a121a;background-color:#fcfeff;border-color:#fcfeff}.euiButton--ghost.euiButton--fill:not([class*=isDisabled]):hover,.euiButton--ghost.euiButton--fill:not([class*=isDisabled]):focus{background-color:#e3f6ff;border-color:#e3f6ff}.euiButton--ghost.euiButton--fill:not([class*=isDisabled]):focus-within{background-color:#e3f6ff;border-color:#e3f6ff}.euiButton--ghost.euiButton--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(201,237,255,.4)}.euiButton--ghost:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(10,18,26,.3)}.euiButton--ghost:not([class*=isDisabled]):hover,.euiButton--ghost:not([class*=isDisabled]):focus{background-color:rgba(252,254,255,.1);box-shadow:0 4px 8px rgba(10,18,26,.15),0 2px 2px -1px rgba(10,18,26,.3)}.euiButton--ghost:not([class*=isDisabled]):focus-within{background-color:rgba(252,254,255,.1);box-shadow:0 4px 8px rgba(10,18,26,.15),0 2px 2px -1px rgba(10,18,26,.3)}.euiButton--ghost:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(252,254,255,.15)}.euiButton--text{color:#dfe5ef;border-color:#8d98a3}.euiButton--text.euiButton--fill{color:#0a121a;background-color:#8d98a3;border-color:#8d98a3}.euiButton--text.euiButton--fill:not([class*=isDisabled]):hover,.euiButton--text.euiButton--fill:not([class*=isDisabled]):focus{background-color:#7f8b98;border-color:#7f8b98}.euiButton--text.euiButton--fill:not([class*=isDisabled]):focus-within{background-color:#7f8b98;border-color:#7f8b98}.euiButton--text.euiButton--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(113,127,140,.4)}.euiButton--text:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--text:not([class*=isDisabled]):hover,.euiButton--text:not([class*=isDisabled]):focus{background-color:rgba(141,152,163,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--text:not([class*=isDisabled]):focus-within{background-color:rgba(141,152,163,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButton--text:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(141,152,163,.15)}.euiButton.euiButton-isDisabled.euiButton--ghost,.euiButton.euiButton-isDisabled.euiButton--ghost:hover,.euiButton.euiButton-isDisabled.euiButton--ghost:focus{color:#293847;border-color:#293847;box-shadow:0 2px 2px -1px rgba(10,18,26,.3)}.euiButton.euiButton-isDisabled.euiButton--ghost:focus-within{color:#293847;border-color:#293847;box-shadow:0 2px 2px -1px rgba(10,18,26,.3)}.euiButton.euiButton-isDisabled.euiButton--ghost.euiButton--fill{color:#5a6571;background-color:#293847}.euiButton--fullWidth{width:100%;display:block}.euiButtonContent{vertical-align:middle;justify-content:center;align-items:center;width:100%;height:100%;display:flex}.euiButtonContent .euiButtonContent__icon,.euiButtonContent .euiButtonContent__spinner{flex-shrink:0}.euiButtonContent>*+*{-webkit-margin-start:8px}.euiButtonContent>*+:not(:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:8px}.euiButtonContent>*+:not(:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:8px}.euiButtonContent>*+:not(:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:8px}.euiButtonContent>*+:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:8px}.euiButtonContent>*+:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:8px}.euiButtonContent>*+:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:8px}.euiButtonContent.euiButtonContent--smallIconGap>*+*{-webkit-margin-start:2px}.euiButtonContent.euiButtonContent--smallIconGap>*+:not(:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:2px}.euiButtonContent.euiButtonContent--smallIconGap>*+:not(:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:2px}.euiButtonContent.euiButtonContent--smallIconGap>*+:not(:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:2px}.euiButtonContent.euiButtonContent--smallIconGap>*+:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:2px}.euiButtonContent.euiButtonContent--smallIconGap>*+:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:2px}.euiButtonContent.euiButtonContent--smallIconGap>*+:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:2px}.euiButtonContent.euiButtonContent--noIconGap>*+*{-webkit-margin-start:0}.euiButtonContent.euiButtonContent--noIconGap>*+:not(:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:0}.euiButtonContent.euiButtonContent--noIconGap>*+:not(:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:0}.euiButtonContent.euiButtonContent--noIconGap>*+:not(:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:0}.euiButtonContent.euiButtonContent--noIconGap>*+:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:0}.euiButtonContent.euiButtonContent--noIconGap>*+:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:0}.euiButtonContent.euiButtonContent--noIconGap>*+:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:0}.euiButtonContent--iconRight{vertical-align:middle;flex-direction:row-reverse;width:100%;height:100%}.euiButtonContent--iconRight .euiButtonContent__icon,.euiButtonContent--iconRight .euiButtonContent__spinner{flex-shrink:0}.euiButtonContent--iconRight>*+*{-webkit-margin-start:0;-webkit-margin-end:8px}.euiButtonContent--iconRight>*+:not(:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:0;margin-right:8px}.euiButtonContent--iconRight>*+:not(:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:0;margin-right:8px}.euiButtonContent--iconRight>*+:not(:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:0;margin-right:8px}.euiButtonContent--iconRight>*+:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-left:8px;margin-right:0}.euiButtonContent--iconRight>*+:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-left:8px;margin-right:0}.euiButtonContent--iconRight>*+:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-left:8px;margin-right:0}.euiButtonContent--iconRight.euiButtonContent--smallIconGap>*+*{-webkit-margin-start:0;-webkit-margin-end:2px}.euiButtonContent--iconRight.euiButtonContent--smallIconGap>*+:not(:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:0;margin-right:2px}.euiButtonContent--iconRight.euiButtonContent--smallIconGap>*+:not(:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:0;margin-right:2px}.euiButtonContent--iconRight.euiButtonContent--smallIconGap>*+:not(:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:0;margin-right:2px}.euiButtonContent--iconRight.euiButtonContent--smallIconGap>*+:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-left:2px;margin-right:0}.euiButtonContent--iconRight.euiButtonContent--smallIconGap>*+:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-left:2px;margin-right:0}.euiButtonContent--iconRight.euiButtonContent--smallIconGap>*+:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-left:2px;margin-right:0}.euiButtonContent--iconRight.euiButtonContent--noIconGap>*+*{-webkit-margin-start:0;-webkit-margin-end:0;margin-left:0;margin-right:0}.euiButtonEmpty{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;cursor:pointer;text-align:center;white-space:nowrap;vertical-align:middle;max-width:100%;height:40px;line-height:40px;font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;box-shadow:none;background-color:transparent;border:1px solid transparent;font-size:.875rem;font-weight:400;line-height:1.33333;text-decoration:none;transition-duration:.15s;transition-timing-function:ease-in;display:inline-block;animation:none!important;transform:none!important}@media screen and (prefers-reduced-motion:no-preference){.euiButtonEmpty{transition:background .25s ease-in-out}}.euiButtonEmpty:hover:not([class*=isDisabled]),.euiButtonEmpty:focus{text-decoration:underline}.euiButtonEmpty .euiButtonEmpty__content{padding:0 8px}.euiButtonEmpty .euiButtonEmpty__text{text-overflow:ellipsis;display:flex;overflow:hidden}.euiButtonEmpty.euiButtonEmpty--small{height:32px}.euiButtonEmpty.euiButtonEmpty--xSmall{height:24px;font-size:15.75px}.euiButtonEmpty:disabled{pointer-events:auto;cursor:not-allowed;color:#535a62}.euiButtonEmpty:disabled .euiButtonContent__icon{fill:currentColor}.euiButtonEmpty:disabled .euiButtonContent__spinner{border-color:#159d8d currentColor currentColor}.euiButtonEmpty:disabled:focus{background-color:transparent}.euiButtonEmpty:disabled:hover,.euiButtonEmpty:disabled:focus{text-decoration:none}.euiButtonEmpty--flushLeft .euiButtonEmpty__content,.euiButtonEmpty--flushRight .euiButtonEmpty__content,.euiButtonEmpty--flushBoth .euiButtonEmpty__content{padding-left:0;padding-right:0}.euiButtonEmpty--flushLeft{margin-right:8px}.euiButtonEmpty--flushRight{margin-left:8px}.euiButtonEmpty--primary{color:#159d8d}.euiButtonEmpty--primary:focus{background-color:rgba(21,157,141,.1)}.euiButtonEmpty--danger{color:#f66}.euiButtonEmpty--danger:focus{background-color:rgba(255,102,102,.1)}.euiButtonEmpty--disabled{color:#797f85}.euiButtonEmpty--disabled:focus{background-color:rgba(83,90,98,.1)}.euiButtonEmpty--disabled:hover{cursor:not-allowed}.euiButtonEmpty--ghost{color:#fcfeff}.euiButtonEmpty--ghost:focus{background-color:rgba(252,254,255,.1)}.euiButtonEmpty--text{color:#dfe5ef}.euiButtonEmpty--text:focus{background-color:rgba(223,229,239,.1)}.euiButtonEmpty--success{color:#7de2d1}.euiButtonEmpty--success:focus{background-color:rgba(125,226,209,.1)}.euiButtonEmpty--warning{color:#ffce7a}.euiButtonEmpty--warning:focus{background-color:rgba(255,206,122,.1)}.euiButtonIcon{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;cursor:pointer;text-align:center;white-space:nowrap;vertical-align:middle;max-width:100%;height:40px;line-height:40px;font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;border:1px solid transparent;border-radius:4px;justify-content:space-around;align-items:center;width:40px;font-size:.875rem;font-weight:400;line-height:1.33333;text-decoration:none;display:inline-flex;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}@media screen and (prefers-reduced-motion:no-preference){.euiButtonIcon{transition:background .25s ease-in-out}}.euiButtonIcon:hover:not([class*=isDisabled]),.euiButtonIcon:focus{text-decoration:underline}.euiButtonIcon>svg{pointer-events:none}.euiButtonIcon.euiButtonIcon--empty{border:none;box-shadow:none!important}.euiButtonIcon.euiButtonIcon-isDisabled{pointer-events:auto;cursor:not-allowed;color:#535a62;border-color:#4a515a}.euiButtonIcon.euiButtonIcon-isDisabled .euiButtonContent__icon{fill:currentColor}.euiButtonIcon.euiButtonIcon-isDisabled .euiButtonContent__spinner{border-color:#159d8d currentColor currentColor}.euiButtonIcon.euiButtonIcon-isDisabled.euiButtonIcon--fill{color:#80858b;background-color:#4a515a;border-color:#4a515a}.euiButtonIcon.euiButtonIcon-isDisabled.euiButtonIcon--fill:hover,.euiButtonIcon.euiButtonIcon-isDisabled.euiButtonIcon--fill:focus{background-color:#4a515a;border-color:#4a515a}.euiButtonIcon.euiButtonIcon-isDisabled.euiButtonIcon--fill:focus-within{background-color:#4a515a;border-color:#4a515a}.euiButtonIcon.euiButtonIcon-isDisabled:hover,.euiButtonIcon.euiButtonIcon-isDisabled:focus{text-decoration:none;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon.euiButtonIcon-isDisabled:focus-within{text-decoration:none;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--xSmall{width:24px;height:24px}.euiButtonIcon--small{width:32px;height:32px}.euiButtonIcon--primary{color:#159d8d;border-color:#159d8d}.euiButtonIcon--primary.euiButtonIcon--fill{color:#0a121a;background-color:#159d8d;border-color:#159d8d}.euiButtonIcon--primary.euiButtonIcon--fill:not([class*=isDisabled]):hover,.euiButtonIcon--primary.euiButtonIcon--fill:not([class*=isDisabled]):focus{background-color:#128779;border-color:#128779}.euiButtonIcon--primary.euiButtonIcon--fill:not([class*=isDisabled]):focus-within{background-color:#128779;border-color:#128779}.euiButtonIcon--primary.euiButtonIcon--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(15,112,101,.4)}.euiButtonIcon--primary:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--primary:not([class*=isDisabled]):hover,.euiButtonIcon--primary:not([class*=isDisabled]):focus{background-color:rgba(21,157,141,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--primary:not([class*=isDisabled]):focus-within{background-color:rgba(21,157,141,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--primary:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(21,157,141,.15)}.euiButtonIcon--accent{color:#f990c0;border-color:#f990c0}.euiButtonIcon--accent.euiButtonIcon--fill{color:#0a121a;background-color:#f990c0;border-color:#f990c0}.euiButtonIcon--accent.euiButtonIcon--fill:not([class*=isDisabled]):hover,.euiButtonIcon--accent.euiButtonIcon--fill:not([class*=isDisabled]):focus{background-color:#f878b2;border-color:#f878b2}.euiButtonIcon--accent.euiButtonIcon--fill:not([class*=isDisabled]):focus-within{background-color:#f878b2;border-color:#f878b2}.euiButtonIcon--accent.euiButtonIcon--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(246,96,165,.4)}.euiButtonIcon--accent:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--accent:not([class*=isDisabled]):hover,.euiButtonIcon--accent:not([class*=isDisabled]):focus{background-color:rgba(249,144,192,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--accent:not([class*=isDisabled]):focus-within{background-color:rgba(249,144,192,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--accent:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(249,144,192,.15)}.euiButtonIcon--secondary{color:#7de2d1;border-color:#7de2d1}.euiButtonIcon--secondary.euiButtonIcon--fill{color:#0a121a;background-color:#7de2d1;border-color:#7de2d1}.euiButtonIcon--secondary.euiButtonIcon--fill:not([class*=isDisabled]):hover,.euiButtonIcon--secondary.euiButtonIcon--fill:not([class*=isDisabled]):focus{background-color:#68ddca;border-color:#68ddca}.euiButtonIcon--secondary.euiButtonIcon--fill:not([class*=isDisabled]):focus-within{background-color:#68ddca;border-color:#68ddca}.euiButtonIcon--secondary.euiButtonIcon--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(83,217,194,.4)}.euiButtonIcon--secondary:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--secondary:not([class*=isDisabled]):hover,.euiButtonIcon--secondary:not([class*=isDisabled]):focus{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--secondary:not([class*=isDisabled]):focus-within{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--secondary:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(125,226,209,.15)}.euiButtonIcon--success{color:#7de2d1;border-color:#7de2d1}.euiButtonIcon--success.euiButtonIcon--fill{color:#0a121a;background-color:#7de2d1;border-color:#7de2d1}.euiButtonIcon--success.euiButtonIcon--fill:not([class*=isDisabled]):hover,.euiButtonIcon--success.euiButtonIcon--fill:not([class*=isDisabled]):focus{background-color:#68ddca;border-color:#68ddca}.euiButtonIcon--success.euiButtonIcon--fill:not([class*=isDisabled]):focus-within{background-color:#68ddca;border-color:#68ddca}.euiButtonIcon--success.euiButtonIcon--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(83,217,194,.4)}.euiButtonIcon--success:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--success:not([class*=isDisabled]):hover,.euiButtonIcon--success:not([class*=isDisabled]):focus{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--success:not([class*=isDisabled]):focus-within{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--success:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(125,226,209,.15)}.euiButtonIcon--warning{color:#ffce7a;border-color:#ffce7a}.euiButtonIcon--warning.euiButtonIcon--fill{color:#0a121a;background-color:#ffce7a;border-color:#ffce7a}.euiButtonIcon--warning.euiButtonIcon--fill:not([class*=isDisabled]):hover,.euiButtonIcon--warning.euiButtonIcon--fill:not([class*=isDisabled]):focus{background-color:#ffc561;border-color:#ffc561}.euiButtonIcon--warning.euiButtonIcon--fill:not([class*=isDisabled]):focus-within{background-color:#ffc561;border-color:#ffc561}.euiButtonIcon--warning.euiButtonIcon--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(255,187,71,.4)}.euiButtonIcon--warning:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--warning:not([class*=isDisabled]):hover,.euiButtonIcon--warning:not([class*=isDisabled]):focus{background-color:rgba(255,206,122,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--warning:not([class*=isDisabled]):focus-within{background-color:rgba(255,206,122,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--warning:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(255,206,122,.15)}.euiButtonIcon--danger{color:#f66;border-color:#f66}.euiButtonIcon--danger.euiButtonIcon--fill{color:#0a121a;background-color:#f66;border-color:#f66}.euiButtonIcon--danger.euiButtonIcon--fill:not([class*=isDisabled]):hover,.euiButtonIcon--danger.euiButtonIcon--fill:not([class*=isDisabled]):focus{background-color:#ff4d4d;border-color:#ff4d4d}.euiButtonIcon--danger.euiButtonIcon--fill:not([class*=isDisabled]):focus-within{background-color:#ff4d4d;border-color:#ff4d4d}.euiButtonIcon--danger.euiButtonIcon--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(255,51,51,.4)}.euiButtonIcon--danger:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--danger:not([class*=isDisabled]):hover,.euiButtonIcon--danger:not([class*=isDisabled]):focus{background-color:rgba(255,102,102,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--danger:not([class*=isDisabled]):focus-within{background-color:rgba(255,102,102,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--danger:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(255,102,102,.15)}.euiButtonIcon--subdued{color:#9fa6af;border-color:#9fa6af}.euiButtonIcon--subdued.euiButtonIcon--fill{color:#0a121a;background-color:#9fa6af;border-color:#9fa6af}.euiButtonIcon--subdued.euiButtonIcon--fill:not([class*=isDisabled]):hover,.euiButtonIcon--subdued.euiButtonIcon--fill:not([class*=isDisabled]):focus{background-color:#9199a3;border-color:#9199a3}.euiButtonIcon--subdued.euiButtonIcon--fill:not([class*=isDisabled]):focus-within{background-color:#9199a3;border-color:#9199a3}.euiButtonIcon--subdued.euiButtonIcon--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(131,140,152,.4)}.euiButtonIcon--subdued:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--subdued:not([class*=isDisabled]):hover,.euiButtonIcon--subdued:not([class*=isDisabled]):focus{background-color:rgba(159,166,175,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--subdued:not([class*=isDisabled]):focus-within{background-color:rgba(159,166,175,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--subdued:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(159,166,175,.15)}.euiButtonIcon--ghost{color:#fcfeff;border-color:#fcfeff}.euiButtonIcon--ghost.euiButtonIcon--fill{color:#0a121a;background-color:#fcfeff;border-color:#fcfeff}.euiButtonIcon--ghost.euiButtonIcon--fill:not([class*=isDisabled]):hover,.euiButtonIcon--ghost.euiButtonIcon--fill:not([class*=isDisabled]):focus{background-color:#e3f6ff;border-color:#e3f6ff}.euiButtonIcon--ghost.euiButtonIcon--fill:not([class*=isDisabled]):focus-within{background-color:#e3f6ff;border-color:#e3f6ff}.euiButtonIcon--ghost.euiButtonIcon--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(201,237,255,.4)}.euiButtonIcon--ghost:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(10,18,26,.3)}.euiButtonIcon--ghost:not([class*=isDisabled]):hover,.euiButtonIcon--ghost:not([class*=isDisabled]):focus{background-color:rgba(252,254,255,.1);box-shadow:0 4px 8px rgba(10,18,26,.15),0 2px 2px -1px rgba(10,18,26,.3)}.euiButtonIcon--ghost:not([class*=isDisabled]):focus-within{background-color:rgba(252,254,255,.1);box-shadow:0 4px 8px rgba(10,18,26,.15),0 2px 2px -1px rgba(10,18,26,.3)}.euiButtonIcon--ghost:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(252,254,255,.15)}.euiButtonIcon--text{color:#dfe5ef;border-color:#8d98a3}.euiButtonIcon--text.euiButtonIcon--fill{color:#0a121a;background-color:#8d98a3;border-color:#8d98a3}.euiButtonIcon--text.euiButtonIcon--fill:not([class*=isDisabled]):hover,.euiButtonIcon--text.euiButtonIcon--fill:not([class*=isDisabled]):focus{background-color:#7f8b98;border-color:#7f8b98}.euiButtonIcon--text.euiButtonIcon--fill:not([class*=isDisabled]):focus-within{background-color:#7f8b98;border-color:#7f8b98}.euiButtonIcon--text.euiButtonIcon--fill:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(113,127,140,.4)}.euiButtonIcon--text:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--text:not([class*=isDisabled]):hover,.euiButtonIcon--text:not([class*=isDisabled]):focus{background-color:rgba(141,152,163,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--text:not([class*=isDisabled]):focus-within{background-color:rgba(141,152,163,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonIcon--text:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(141,152,163,.15)}.euiButtonIcon.euiButtonIcon-isDisabled.euiButtonIcon--ghost,.euiButtonIcon.euiButtonIcon-isDisabled.euiButtonIcon--ghost:hover,.euiButtonIcon.euiButtonIcon-isDisabled.euiButtonIcon--ghost:focus{color:#293847;border-color:#293847;box-shadow:0 2px 2px -1px rgba(10,18,26,.3)}.euiButtonIcon.euiButtonIcon-isDisabled.euiButtonIcon--ghost:focus-within{color:#293847;border-color:#293847;box-shadow:0 2px 2px -1px rgba(10,18,26,.3)}.euiButtonIcon.euiButtonIcon-isDisabled.euiButtonIcon--ghost.euiButton--fill{color:#5a6571;background-color:#293847}.euiButtonGroup{max-width:100%;display:inline-block;position:relative}.euiButtonGroup--fullWidth{display:block}.euiButtonGroup--fullWidth .euiButtonGroup__buttons{width:100%}.euiButtonGroup--fullWidth .euiButtonGroup__buttons .euiButtonGroupButton{flex:1}.euiButtonGroup__buttons{border-radius:5px;max-width:100%;display:flex;overflow:hidden;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiButtonGroup--isDisabled .euiButtonGroup__buttons{box-shadow:none}.euiButtonGroup--compressed .euiButtonGroup__buttons{background-color:#0e1721;border:1px solid rgba(252,254,255,.1);border-radius:2px;height:32px;overflow:visible;box-shadow:none!important}.euiButtonGroup--vertical .euiButtonGroup__buttons{flex-direction:column;height:auto}.euiButtonGroupButton{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;cursor:pointer;text-align:center;white-space:nowrap;vertical-align:middle;max-width:100%;height:40px;line-height:40px;font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;flex-grow:0;flex-shrink:1;min-width:0;font-size:.875rem;font-weight:400;line-height:1.33333;transition:background-color .25s ease-in-out,border-color .25s ease-in-out,color .25s ease-in-out;display:inline-block}.euiButtonGroupButton .euiButton__content{padding:0 12px}.euiButtonGroupButton-isIconOnly .euiButton__content{padding:0 8px}.euiButtonGroupButton .euiButton__text{text-overflow:ellipsis;overflow:hidden}.euiButtonGroupButton.euiButtonGroupButton--small{height:32px;line-height:32px}.euiButtonGroupButton:not([class*=isDisabled]):hover,.euiButtonGroupButton:not([class*=isDisabled]):focus{background-color:rgba(21,157,141,.1);text-decoration:underline}.euiButtonGroupButton:not([class*=isDisabled]):focus-within{background-color:rgba(21,157,141,.1);text-decoration:underline}.euiButtonGroupButton.euiButtonGroupButton-isDisabled{pointer-events:auto;cursor:not-allowed;color:#535a62}.euiButtonGroupButton.euiButtonGroupButton-isDisabled .euiButtonContent__icon{fill:currentColor}.euiButtonGroupButton.euiButtonGroupButton-isDisabled .euiButtonContent__spinner{border-color:#159d8d currentColor currentColor}.euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton-isSelected{color:#80858b;background-color:#4a515a;border-color:#4a515a}.euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton-isSelected:hover,.euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton-isSelected:focus{background-color:#4a515a;border-color:#4a515a}.euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton-isSelected:focus-within{background-color:#4a515a;border-color:#4a515a}.euiButtonGroupButton.euiButtonGroupButton--primary:not([class*=isDisabled]){color:#159d8d}.euiButtonGroupButton.euiButtonGroupButton--primary:not([class*=isDisabled]).euiButtonGroupButton-isSelected{color:#0a121a;background-color:#159d8d;border-color:#159d8d}.euiButtonGroupButton.euiButtonGroupButton--primary:not([class*=isDisabled]).euiButtonGroupButton-isSelected:hover,.euiButtonGroupButton.euiButtonGroupButton--primary:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus{background-color:#128779;border-color:#128779}.euiButtonGroupButton.euiButtonGroupButton--primary:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus-within{background-color:#128779;border-color:#128779}.euiButtonGroupButton.euiButtonGroupButton--primary:not([class*=isDisabled]):hover,.euiButtonGroupButton.euiButtonGroupButton--primary:not([class*=isDisabled]):focus{background-color:rgba(21,157,141,.1)}.euiButtonGroupButton.euiButtonGroupButton--primary:not([class*=isDisabled]):focus-within{background-color:rgba(21,157,141,.1)}.euiButtonGroupButton.euiButtonGroupButton--accent:not([class*=isDisabled]){color:#f990c0}.euiButtonGroupButton.euiButtonGroupButton--accent:not([class*=isDisabled]).euiButtonGroupButton-isSelected{color:#0a121a;background-color:#f990c0;border-color:#f990c0}.euiButtonGroupButton.euiButtonGroupButton--accent:not([class*=isDisabled]).euiButtonGroupButton-isSelected:hover,.euiButtonGroupButton.euiButtonGroupButton--accent:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus{background-color:#f878b2;border-color:#f878b2}.euiButtonGroupButton.euiButtonGroupButton--accent:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus-within{background-color:#f878b2;border-color:#f878b2}.euiButtonGroupButton.euiButtonGroupButton--accent:not([class*=isDisabled]):hover,.euiButtonGroupButton.euiButtonGroupButton--accent:not([class*=isDisabled]):focus{background-color:rgba(249,144,192,.1)}.euiButtonGroupButton.euiButtonGroupButton--accent:not([class*=isDisabled]):focus-within{background-color:rgba(249,144,192,.1)}.euiButtonGroupButton.euiButtonGroupButton--secondary:not([class*=isDisabled]){color:#7de2d1}.euiButtonGroupButton.euiButtonGroupButton--secondary:not([class*=isDisabled]).euiButtonGroupButton-isSelected{color:#0a121a;background-color:#7de2d1;border-color:#7de2d1}.euiButtonGroupButton.euiButtonGroupButton--secondary:not([class*=isDisabled]).euiButtonGroupButton-isSelected:hover,.euiButtonGroupButton.euiButtonGroupButton--secondary:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus{background-color:#68ddca;border-color:#68ddca}.euiButtonGroupButton.euiButtonGroupButton--secondary:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus-within{background-color:#68ddca;border-color:#68ddca}.euiButtonGroupButton.euiButtonGroupButton--secondary:not([class*=isDisabled]):hover,.euiButtonGroupButton.euiButtonGroupButton--secondary:not([class*=isDisabled]):focus{background-color:rgba(125,226,209,.1)}.euiButtonGroupButton.euiButtonGroupButton--secondary:not([class*=isDisabled]):focus-within{background-color:rgba(125,226,209,.1)}.euiButtonGroupButton.euiButtonGroupButton--success:not([class*=isDisabled]){color:#7de2d1}.euiButtonGroupButton.euiButtonGroupButton--success:not([class*=isDisabled]).euiButtonGroupButton-isSelected{color:#0a121a;background-color:#7de2d1;border-color:#7de2d1}.euiButtonGroupButton.euiButtonGroupButton--success:not([class*=isDisabled]).euiButtonGroupButton-isSelected:hover,.euiButtonGroupButton.euiButtonGroupButton--success:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus{background-color:#68ddca;border-color:#68ddca}.euiButtonGroupButton.euiButtonGroupButton--success:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus-within{background-color:#68ddca;border-color:#68ddca}.euiButtonGroupButton.euiButtonGroupButton--success:not([class*=isDisabled]):hover,.euiButtonGroupButton.euiButtonGroupButton--success:not([class*=isDisabled]):focus{background-color:rgba(125,226,209,.1)}.euiButtonGroupButton.euiButtonGroupButton--success:not([class*=isDisabled]):focus-within{background-color:rgba(125,226,209,.1)}.euiButtonGroupButton.euiButtonGroupButton--warning:not([class*=isDisabled]){color:#ffce7a}.euiButtonGroupButton.euiButtonGroupButton--warning:not([class*=isDisabled]).euiButtonGroupButton-isSelected{color:#0a121a;background-color:#ffce7a;border-color:#ffce7a}.euiButtonGroupButton.euiButtonGroupButton--warning:not([class*=isDisabled]).euiButtonGroupButton-isSelected:hover,.euiButtonGroupButton.euiButtonGroupButton--warning:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus{background-color:#ffc561;border-color:#ffc561}.euiButtonGroupButton.euiButtonGroupButton--warning:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus-within{background-color:#ffc561;border-color:#ffc561}.euiButtonGroupButton.euiButtonGroupButton--warning:not([class*=isDisabled]):hover,.euiButtonGroupButton.euiButtonGroupButton--warning:not([class*=isDisabled]):focus{background-color:rgba(255,206,122,.1)}.euiButtonGroupButton.euiButtonGroupButton--warning:not([class*=isDisabled]):focus-within{background-color:rgba(255,206,122,.1)}.euiButtonGroupButton.euiButtonGroupButton--danger:not([class*=isDisabled]){color:#f66}.euiButtonGroupButton.euiButtonGroupButton--danger:not([class*=isDisabled]).euiButtonGroupButton-isSelected{color:#0a121a;background-color:#f66;border-color:#f66}.euiButtonGroupButton.euiButtonGroupButton--danger:not([class*=isDisabled]).euiButtonGroupButton-isSelected:hover,.euiButtonGroupButton.euiButtonGroupButton--danger:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus{background-color:#ff4d4d;border-color:#ff4d4d}.euiButtonGroupButton.euiButtonGroupButton--danger:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus-within{background-color:#ff4d4d;border-color:#ff4d4d}.euiButtonGroupButton.euiButtonGroupButton--danger:not([class*=isDisabled]):hover,.euiButtonGroupButton.euiButtonGroupButton--danger:not([class*=isDisabled]):focus{background-color:rgba(255,102,102,.1)}.euiButtonGroupButton.euiButtonGroupButton--danger:not([class*=isDisabled]):focus-within{background-color:rgba(255,102,102,.1)}.euiButtonGroupButton.euiButtonGroupButton--subdued:not([class*=isDisabled]){color:#9fa6af}.euiButtonGroupButton.euiButtonGroupButton--subdued:not([class*=isDisabled]).euiButtonGroupButton-isSelected{color:#0a121a;background-color:#9fa6af;border-color:#9fa6af}.euiButtonGroupButton.euiButtonGroupButton--subdued:not([class*=isDisabled]).euiButtonGroupButton-isSelected:hover,.euiButtonGroupButton.euiButtonGroupButton--subdued:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus{background-color:#9199a3;border-color:#9199a3}.euiButtonGroupButton.euiButtonGroupButton--subdued:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus-within{background-color:#9199a3;border-color:#9199a3}.euiButtonGroupButton.euiButtonGroupButton--subdued:not([class*=isDisabled]):hover,.euiButtonGroupButton.euiButtonGroupButton--subdued:not([class*=isDisabled]):focus{background-color:rgba(159,166,175,.1)}.euiButtonGroupButton.euiButtonGroupButton--subdued:not([class*=isDisabled]):focus-within{background-color:rgba(159,166,175,.1)}.euiButtonGroupButton.euiButtonGroupButton--ghost:not([class*=isDisabled]){color:#fcfeff}.euiButtonGroupButton.euiButtonGroupButton--ghost:not([class*=isDisabled]).euiButtonGroupButton-isSelected{color:#0a121a;background-color:#fcfeff;border-color:#fcfeff}.euiButtonGroupButton.euiButtonGroupButton--ghost:not([class*=isDisabled]).euiButtonGroupButton-isSelected:hover,.euiButtonGroupButton.euiButtonGroupButton--ghost:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus{background-color:#e3f6ff;border-color:#e3f6ff}.euiButtonGroupButton.euiButtonGroupButton--ghost:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus-within{background-color:#e3f6ff;border-color:#e3f6ff}.euiButtonGroupButton.euiButtonGroupButton--ghost:not([class*=isDisabled]):hover,.euiButtonGroupButton.euiButtonGroupButton--ghost:not([class*=isDisabled]):focus{background-color:rgba(252,254,255,.1)}.euiButtonGroupButton.euiButtonGroupButton--ghost:not([class*=isDisabled]):focus-within{background-color:rgba(252,254,255,.1)}.euiButtonGroupButton.euiButtonGroupButton--text:not([class*=isDisabled]){color:#dfe5ef}.euiButtonGroupButton.euiButtonGroupButton--text:not([class*=isDisabled]).euiButtonGroupButton-isSelected{color:#0a121a;background-color:#8d98a3;border-color:#8d98a3}.euiButtonGroupButton.euiButtonGroupButton--text:not([class*=isDisabled]).euiButtonGroupButton-isSelected:hover,.euiButtonGroupButton.euiButtonGroupButton--text:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus{background-color:#7f8b98;border-color:#7f8b98}.euiButtonGroupButton.euiButtonGroupButton--text:not([class*=isDisabled]).euiButtonGroupButton-isSelected:focus-within{background-color:#7f8b98;border-color:#7f8b98}.euiButtonGroupButton.euiButtonGroupButton--text:not([class*=isDisabled]):hover,.euiButtonGroupButton.euiButtonGroupButton--text:not([class*=isDisabled]):focus{background-color:rgba(141,152,163,.1)}.euiButtonGroupButton.euiButtonGroupButton--text:not([class*=isDisabled]):focus-within{background-color:rgba(141,152,163,.1)}.euiButtonGroupButton__textShift:after{content:attr(data-text);visibility:hidden;height:0;font-weight:700;display:block;overflow:hidden}.euiButtonGroup--medium .euiButtonGroupButton,.euiButtonGroup--small .euiButtonGroupButton{border:1px solid #293847}.euiButtonGroup--medium:not(.euiButtonGroup--vertical) .euiButtonGroupButton:not(:first-child),.euiButtonGroup--small:not(.euiButtonGroup--vertical) .euiButtonGroupButton:not(:first-child){margin-left:-1px}.euiButtonGroup--medium:not(.euiButtonGroup--vertical) .euiButtonGroupButton:first-child,.euiButtonGroup--small:not(.euiButtonGroup--vertical) .euiButtonGroupButton:first-child{border-radius:4px 0 0 4px}.euiButtonGroup--medium:not(.euiButtonGroup--vertical) .euiButtonGroupButton:last-child,.euiButtonGroup--small:not(.euiButtonGroup--vertical) .euiButtonGroupButton:last-child{border-radius:0 4px 4px 0}.euiButtonGroup--medium.euiButtonGroup--vertical .euiButtonGroupButton:not(:first-child),.euiButtonGroup--small.euiButtonGroup--vertical .euiButtonGroupButton:not(:first-child){margin-top:-1px}.euiButtonGroup--medium.euiButtonGroup--vertical .euiButtonGroupButton:first-child,.euiButtonGroup--small.euiButtonGroup--vertical .euiButtonGroupButton:first-child{border-radius:4px 4px 0 0}.euiButtonGroup--medium.euiButtonGroup--vertical .euiButtonGroupButton:last-child,.euiButtonGroup--small.euiButtonGroup--vertical .euiButtonGroupButton:last-child{border-radius:0 0 4px 4px}.euiButtonGroup--medium .euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton--ghost,.euiButtonGroup--medium .euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton--ghost:hover,.euiButtonGroup--medium .euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton--ghost:focus,.euiButtonGroup--small .euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton--ghost,.euiButtonGroup--small .euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton--ghost:hover,.euiButtonGroup--small .euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton--ghost:focus{color:#293847}.euiButtonGroup--medium .euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton--ghost:focus-within{color:#293847}.euiButtonGroup--small .euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton--ghost:focus-within{color:#293847}.euiButtonGroup--isDisabled .euiButtonGroup--medium .euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton--ghost,.euiButtonGroup--isDisabled .euiButtonGroup--small .euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton--ghost{border-color:#293847}.euiButtonGroup--medium .euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton--ghost.euiButtonGroupButton-isSelected,.euiButtonGroup--small .euiButtonGroupButton.euiButtonGroupButton-isDisabled.euiButtonGroupButton--ghost.euiButtonGroupButton-isSelected{color:#5a6571;background-color:#293847}.euiButtonGroup--medium .euiButtonGroupButton-isSelected,.euiButtonGroup--small .euiButtonGroupButton-isSelected{z-index:0}.euiButtonGroup--medium .euiButtonGroupButton-isSelected+.euiButtonGroupButton-isSelected,.euiButtonGroup--small .euiButtonGroupButton-isSelected+.euiButtonGroupButton-isSelected{box-shadow:-1px 0 rgba(10,18,26,.1)}.euiButtonGroup--compressed .euiButtonGroupButton{background-clip:content-box;border-radius:4px;height:30px;padding:2px;font-size:15.75px;line-height:30px}.euiButtonGroup--compressed .euiButtonGroupButton .euiButton__content{padding-left:8px;padding-right:8px}.euiButtonGroup--compressed .euiButtonGroupButton.euiButtonGroupButton-isSelected{font-weight:600}.euiButtonGroup--compressed .euiButtonGroupButton:not([class*=isDisabled]):focus{outline:2px solid rgba(21,157,141,.3)}.euiButtonGroup--compressed .euiButtonGroupButton:not([class*=isDisabled]):focus-within{outline:2px solid rgba(21,157,141,.3)}.euiBreadcrumbs{flex-wrap:wrap;align-items:center;min-width:0;margin-bottom:-4px;font-size:.875rem;line-height:1.33333;display:flex}.euiBreadcrumb{display:inline-block;color:#c1c6cd!important}.euiBreadcrumb:hover{color:#c5c9d0!important}.euiBreadcrumb.euiLink[class*=ouiLink--]:focus,.euiBreadcrumb__collapsedLink.euiLink[class*=ouiLink--]:focus{animation:none!important}.euiBreadcrumbs:not(.euiBreadcrumbs__inPopover) .euiBreadcrumbWrapper--last .euiBreadcrumb{font-weight:500}.euiBreadcrumb--collapsed{flex-shrink:0;color:#43b0a4!important;vertical-align:top!important}.euiBreadcrumb__collapsedLink:hover{color:#c5c9d0!important}.euiBreadcrumbs--truncate{white-space:nowrap;flex-wrap:nowrap}.euiBreadcrumbs--truncate .euiBreadcrumb:not(.euiBreadcrumb--collapsed){text-overflow:ellipsis;vertical-align:top;max-width:100%;overflow:hidden}.euiBreadcrumb--truncate{text-align:center;vertical-align:top;max-width:100%;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiBreadcrumbWrapper--truncate{max-width:160px}.euiBreadcrumbWrapper{z-index:0;padding:1.5px 24px 1.5px 20px;position:relative}.euiBreadcrumbWrapper:before{content:"";z-index:-1;background-color:#475461;border-radius:4px;position:absolute;top:0;bottom:0;left:4px;right:4px;transform:skew(-20deg)}.euiBreadcrumbs--truncate .euiBreadcrumbWrapper:not(.euiBreadcrumbWrapper--collapsed){text-overflow:ellipsis;min-width:calc(3ch + 44px);max-width:160px;overflow:hidden}.euiBreadcrumbs--truncate .euiBreadcrumbWrapper:not(.euiBreadcrumbWrapper--collapsed).euiBreadcrumbWrapper--last{max-width:none}.euiBreadcrumbWall:has(.euiBreadcrumbWrapper:not(.euiBreadcrumbWrapper--collapsed)){min-width:calc(3ch + 44px)}.euiBreadcrumbs:not(.euiBreadcrumbs__inPopover) .euiBreadcrumbWrapper.euiBreadcrumbWrapper--last .euiBreadcrumb,.euiBreadcrumbs:not(.euiBreadcrumbs__inPopover) .euiBreadcrumbWrapper.euiBreadcrumbWrapper--last .euiBreadcrumb:hover{color:inherit!important}.euiBreadcrumbs:not(.euiBreadcrumbs__inPopover) .euiBreadcrumbWrapper.euiBreadcrumbWrapper--last:before{background-color:#10645e}.euiBreadcrumbWrapper:has(.euiLink--subdued:focus):before{background-color:#3e464e}.euiBreadcrumbWrapper:not(.euiBreadcrumbWrapper--first){margin-bottom:4px;padding-left:24px}.euiBreadcrumbs--truncate .euiBreadcrumbWrapper:not(.euiBreadcrumbWrapper--first):not(.euiBreadcrumbWrapper--collapsed){min-width:calc(3ch + 48px)}.euiBreadcrumbWall{background-image:linear-gradient(90deg,#475461 0,#475461 12px,transparent 12px);border-radius:4px;margin-bottom:4px;overflow:hidden}.euiBreadcrumbWall:has(.euiLink--subdued:focus){background-image:linear-gradient(90deg,#3e464e 0,#3e464e 12px,transparent 12px)}.euiBreadcrumbWall--single{background-image:linear-gradient(90deg,#10645e 0,#10645e 12px,transparent 12px)}.euiLink.euiBreadcrumb{line-height:inherit;font-weight:inherit}.euiSimplifiedBreadcrumbs{flex-wrap:wrap;align-items:center;gap:8px;min-width:0;margin-left:0;font-size:.875rem;line-height:1.33333;display:flex}.euiSimplifiedBreadcrumbs .euiLink.euiLink--text:focus{background:0 0;animation:none}.euiSimplifiedBreadcrumbs--truncate{white-space:nowrap;flex-wrap:nowrap}.euiSimplifiedBreadcrumbs--truncate .euiSimplifiedBreadcrumb:not(.euiSimplifiedBreadcrumb--collapsed){width:100%;max-width:-webkit-fit-content;max-width:-moz-fit-content;text-overflow:ellipsis;max-width:fit-content;overflow:hidden}.euiSimplifiedBreadcrumb{display:block}.euiSimplifiedBreadcrumb.euiLink{line-height:inherit;font-weight:inherit}.euiSimplifiedBreadcrumb.euiLink[class*=ouiLink--]:focus{background-color:unset!important;animation:none!important}.euiSimplifiedBreadcrumb--collapsed{flex-shrink:0;color:#43b0a4!important;vertical-align:top!important}.euiSimplifiedBreadcrumb--collapsed:hover{color:#c5c9d0!important}.euiSimplifiedBreadcrumb--truncate{text-align:center;vertical-align:top;max-width:100%;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiBreadcrumbSeparator{color:#535a62;flex-shrink:0;width:8px;height:13.5px}.euiCallOut{border-left:2px solid transparent;padding:16px;position:relative}.euiCallOut.euiCallOut--small{padding:8px}.euiCallOut .euiCallOutHeader__icon{flex:none;transform:translateY(2px)}.euiCallOut .euiCallOutHeader__title{color:#dfe5ef;letter-spacing:-.02em;margin-bottom:0;font-size:1rem;font-weight:400;line-height:1.33333rem}.euiCallOut .euiCallOut__closeIcon{position:absolute;top:0;right:4px}.euiCallOut--small .euiCallOutHeader__title{color:#dfe5ef;letter-spacing:-.005em;font-size:.875rem;font-weight:400;line-height:1.33333rem}.euiCallOut--primary{background-color:#0d3c3d;border-color:#159d8d}.euiCallOut--primary .euiCallOutHeader__icon{fill:#66bfb5}.euiCallOut--primary .euiCallOutHeader__title{color:#66bfb5}.euiCallOut--primary .euiCallOut__closeIcon{fill:#66bfb5}.euiCallOut--success{background-color:#2d5051;border-color:#7de2d1}.euiCallOut--success .euiCallOutHeader__icon{fill:#96e8da}.euiCallOut--success .euiCallOutHeader__title{color:#96e8da}.euiCallOut--success .euiCallOut__closeIcon{fill:#96e8da}.euiCallOut--warning{background-color:#544a37;border-color:#ffce7a}.euiCallOut--warning .euiCallOutHeader__icon{fill:#fed895}.euiCallOut--warning .euiCallOutHeader__title{color:#fed895}.euiCallOut--warning .euiCallOut__closeIcon{fill:#fed895}.euiCallOut--danger{background-color:#542b31;border-color:#f66}.euiCallOut--danger .euiCallOutHeader__icon{fill:#fe9091}.euiCallOut--danger .euiCallOutHeader__title{color:#fe9091}.euiCallOut--danger .euiCallOut__closeIcon{fill:#fe9091}.euiCallOutHeader{align-items:baseline;display:flex}.euiCallOutHeader+*{margin-top:8px}.euiCallOutHeader>*+*{margin-left:8px}.euiCard{flex-direction:column;min-height:1px;display:flex}.euiCard.euiCard-isDisabled{color:#535a62;cursor:not-allowed!important;box-shadow:none!important;background-color:rgba(74,81,90,.1)!important;text-decoration:none!important;transform:none!important}.euiCard.euiCard-isDisabled .euiCard__top{-webkit-filter:grayscale();filter:grayscale()}.euiCard.euiCard-isDisabled .euiCard__titleAnchor,.euiCard.euiCard-isDisabled .euiCard__titleButton{color:#535a62;cursor:inherit}.euiCard.euiCard-isDisabled .euiCard__betaBadge:not(.euiBetaBadge-isClickable):not(.euiBetaBadge--hollow){color:inherit;background:0 0;box-shadow:inset 0 0 0 1px #293847}.euiCard.euiCard-isDisabled .euiCard__betaBadge:not(.euiBetaBadge-isClickable).euiBetaBadge--hollow{background-color:#0a121a}.euiCard.euiCard--isClickable{width:100%;display:flex}.euiCard.euiCard--isClickable:not(.euiCard-isDisabled):focus-within{box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3);animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimateLarge!important}.euiCard.euiCard--isClickable:not(.euiCard-isDisabled):focus .euiCard__title,.euiCard.euiCard--isClickable:not(.euiCard-isDisabled):focus .euiCard__titleAnchor,.euiCard.euiCard--isClickable:not(.euiCard-isDisabled):focus .euiCard__titleButton,.euiCard.euiCard--isClickable:not(.euiCard-isDisabled):hover .euiCard__title,.euiCard.euiCard--isClickable:not(.euiCard-isDisabled):hover .euiCard__titleAnchor,.euiCard.euiCard--isClickable:not(.euiCard-isDisabled):hover .euiCard__titleButton{text-decoration:underline}.euiCard .euiCard__top,.euiCard .euiCard__content,.euiCard .euiCard__footer{width:100%}.euiCard.euiCard--leftAligned{text-align:left;align-items:flex-start}.euiCard.euiCard--leftAligned .euiCard__titleButton{text-align:left}.euiCard.euiCard--centerAligned{text-align:center;align-items:center}.euiCard.euiCard--rightAligned{text-align:right;align-items:flex-end}.euiCard.euiCard--rightAligned .euiCard__titleButton{text-align:right}.euiCard.euiCard-isSelected{transition:all .15s cubic-bezier(.694,.0482,.335,1)}.euiCard--hasBetaBadge{position:relative;overflow:visible}.euiCard--hasBetaBadge .euiCard__betaBadgeWrapper{z-index:3;min-width:30%;max-width:calc(100% - 32px);position:absolute;top:-12px;left:50%;transform:translate(-50%)}.euiCard--hasBetaBadge .euiCard__betaBadgeWrapper .euiToolTipAnchor,.euiCard--hasBetaBadge .euiCard__betaBadgeWrapper .euiCard__betaBadge{width:100%}.euiCard--hasBetaBadge .euiCard__betaBadgeWrapper .euiCard__betaBadge{text-overflow:ellipsis;overflow:hidden}.euiCard__betaBadge.euiBetaBadge--hollow{background-color:#0a121a}.euiCard--isSelectable{position:relative}.euiCard[class*=paddingSmall]{padding:8px}.euiCard[class*=paddingSmall].euiCard--isSelectable{padding-bottom:48px}.euiCard[class*=paddingSmall] .euiCard__top .euiCard__image{width:calc(100% + 16px);margin-bottom:-8px;top:-8px;left:-8px}.euiCard[class*=paddingSmall] .euiCard__top .euiCard__image+.euiCard__icon{transform:translate(-50%,calc(-50% - 8px))}.euiCard[class*=paddingMedium]{padding:16px}.euiCard[class*=paddingMedium].euiCard--isSelectable{padding-bottom:56px}.euiCard[class*=paddingMedium] .euiCard__top .euiCard__image{width:calc(100% + 32px);margin-bottom:-16px;top:-16px;left:-16px}.euiCard[class*=paddingMedium] .euiCard__top .euiCard__image+.euiCard__icon{transform:translate(-50%,calc(-50% - 16px))}.euiCard[class*=paddingLarge]{padding:24px}.euiCard[class*=paddingLarge].euiCard--isSelectable{padding-bottom:64px}.euiCard[class*=paddingLarge] .euiCard__top .euiCard__image{width:calc(100% + 48px);margin-bottom:-24px;top:-24px;left:-24px}.euiCard[class*=paddingLarge] .euiCard__top .euiCard__image+.euiCard__icon{transform:translate(-50%,calc(-50% - 24px))}.euiCard__top{flex-grow:0;min-height:1px;font-size:0;position:relative}.euiCard__top .euiCard__image{border-top-left-radius:3px;border-top-right-radius:3px;position:relative;overflow:hidden}.euiCard__top .euiCard__image img{width:100%}.euiCard__top .euiCard__image+.euiCard__icon{position:absolute;top:50%;left:50%}.euiCard__top .euiCard__icon{margin-top:8px}.euiCard__footer:not(:empty){flex-grow:0;margin-top:16px}.euiCard[class*=transparent] .euiCard__image{border-radius:4px}.euiCard--isSelectable--text.euiCard-isSelected:not(.euiCard-isDisabled){border-color:#7de2d1!important}.euiCard--isSelectable--primary.euiCard-isSelected:not(.euiCard-isDisabled){border-color:#159d8d!important}.euiCard--isSelectable--success.euiCard-isSelected:not(.euiCard-isDisabled){border-color:#7de2d1!important}.euiCard--isSelectable--danger.euiCard-isSelected:not(.euiCard-isDisabled){border-color:#f66!important}.euiCard--isSelectable--ghost.euiCard-isSelected:not(.euiCard-isDisabled){border-color:#8d98a3!important}.euiCard__top+.euiCard__content{margin-top:16px}.euiCard__content{flex-grow:1}.euiCard__content .euiCard__description,.euiCard__content .euiCard__children{margin-top:8px}.euiCard__content .euiCard__titleAnchor,.euiCard__content .euiCard__titleButton{font:inherit;color:inherit;letter-spacing:inherit}.euiCard__content .euiCard__titleAnchor:focus,.euiCard__content .euiCard__titleButton:focus{text-decoration:underline}.euiCard.euiCard--horizontal .euiCard__content,.euiCard.euiCard--horizontal .euiCard__titleButton{text-align:left}.euiCard.euiCard--horizontal.euiCard--hasIcon{flex-direction:row;align-items:flex-start!important}.euiCard.euiCard--horizontal.euiCard--hasIcon .euiCard__top,.euiCard.euiCard--horizontal.euiCard--hasIcon .euiCard__content{width:auto;margin-top:0}.euiCard.euiCard--horizontal.euiCard--hasIcon .euiCard__top .euiCard__icon{margin-top:0;margin-right:16px}.euiCardSelect{border-bottom-right-radius:3px;border-bottom-left-radius:3px;width:100%;font-weight:700;position:absolute;bottom:0;left:0;overflow:hidden;height:40px!important}.euiCardSelect--text:enabled{background-color:#101b25}.euiCardSelect--primary:enabled{background-color:#0d3c3d}.euiCardSelect--success:enabled{color:#7de2d1;background-color:#2d5051}.euiCardSelect--danger:enabled{background-color:#542b31}.euiCardSelect--ghost:enabled{background-color:#8d98a3}.euiCardSelect:disabled{background-color:#172430}.euiCheckableCard{transition:border-color .25s ease-in}.euiCheckableCard:not(.euiCheckableCard-isDisabled).euiCheckableCard-isChecked{border-color:#159d8d}.euiCheckableCard__label{cursor:pointer;width:calc(100% + 32px);margin:-16px;padding:16px;display:block}.euiCheckableCard__label-isDisabled{color:#5b6875;cursor:not-allowed}.euiCheckableCard__children{margin-top:16px}.euiCodeBlock{color:#dfe5ef;background:#101b25;max-width:100%;display:block;position:relative}.euiCodeBlock .euiCodeBlock__pre{scrollbar-width:thin;height:100%;display:block;overflow:auto}.euiCodeBlock .euiCodeBlock__pre::-webkit-scrollbar{width:16px;height:16px}.euiCodeBlock .euiCodeBlock__pre::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiCodeBlock .euiCodeBlock__pre::-webkit-scrollbar-corner{background-color:transparent}.euiCodeBlock .euiCodeBlock__pre::-webkit-scrollbar-track{background-color:transparent}.euiCodeBlock .euiCodeBlock__pre--whiteSpacePre{white-space:pre}.euiCodeBlock .euiCodeBlock__pre--whiteSpacePreWrap{white-space:pre-wrap}.euiCodeBlock .euiCodeBlock__code{font-family:var(--eui-code-font-family);letter-spacing:normal;font-weight:400;line-height:1.33333;font-size:inherit;display:block}.euiCodeBlock .euiCodeBlock__controls{position:absolute;top:0;right:0}.euiCodeBlock .euiCodeBlock__fullScreenButton+.euiCodeBlock__copyButton{margin-top:4px}.euiCodeBlock .euiCodeBlock__line{display:block}.euiCodeBlock.euiCodeBlock-isFullScreen{position:fixed;top:0;bottom:0;left:0;right:0}.euiCodeBlock.euiCodeBlock-isFullScreen .euiCodeBlock__pre{padding:32px!important}.euiCodeBlock.euiCodeBlock-isFullScreen .euiCodeBlock__controls{top:4px;right:4px}.euiCodeBlock.euiCodeBlock--fontSmall{font-size:13.5px}.euiCodeBlock.euiCodeBlock--fontMedium{font-size:15.75px}.euiCodeBlock.euiCodeBlock--fontLarge{font-size:18px}.euiCodeBlock.euiCodeBlock--hasControls .euiCodeBlock__pre--whiteSpacePreWrap{padding-right:28px}.euiCodeBlock.euiCodeBlock--hasControls .euiCodeBlock__pre--whiteSpacePre{margin-right:28px}.euiCodeBlock.euiCodeBlock--paddingSmall .euiCodeBlock__pre{padding:8px}.euiCodeBlock.euiCodeBlock--paddingSmall .euiCodeBlock__controls{top:8px;right:8px}.euiCodeBlock.euiCodeBlock--paddingSmall.euiCodeBlock--hasControls .euiCodeBlock__pre--whiteSpacePreWrap{padding-right:36px}.euiCodeBlock.euiCodeBlock--paddingSmall.euiCodeBlock--hasControls .euiCodeBlock__pre--whiteSpacePre{margin-right:36px}.euiCodeBlock.euiCodeBlock--paddingMedium .euiCodeBlock__pre{padding:16px}.euiCodeBlock.euiCodeBlock--paddingMedium .euiCodeBlock__controls{top:16px;right:16px}.euiCodeBlock.euiCodeBlock--paddingMedium.euiCodeBlock--hasControls .euiCodeBlock__pre--whiteSpacePreWrap{padding-right:44px}.euiCodeBlock.euiCodeBlock--paddingMedium.euiCodeBlock--hasControls .euiCodeBlock__pre--whiteSpacePre{margin-right:44px}.euiCodeBlock.euiCodeBlock--paddingLarge .euiCodeBlock__pre{padding:24px}.euiCodeBlock.euiCodeBlock--paddingLarge .euiCodeBlock__controls{top:24px;right:24px}.euiCodeBlock.euiCodeBlock--paddingLarge.euiCodeBlock--hasControls .euiCodeBlock__pre--whiteSpacePreWrap{padding-right:52px}.euiCodeBlock.euiCodeBlock--paddingLarge.euiCodeBlock--hasControls .euiCodeBlock__pre--whiteSpacePre{margin-right:52px}.euiCodeBlock.euiCodeBlock--inline{white-space:pre;color:#dfe5ef;background:#101b25;padding:0 8px;font-size:90%;display:inline-block}.euiCodeBlock.euiCodeBlock--inline .euiCodeBlock__pre{padding:0 4px}.euiCodeBlock.euiCodeBlock--inline .euiCodeBlock__code{white-space:normal;display:inline}.euiCodeBlock.euiCodeBlock--transparentBackground{background:0 0}.euiCodeBlock .token.punctuation:not(.interpolation-punctuation):not([class*=attr-]){opacity:.7}.euiCodeBlock .token.comment,.euiCodeBlock .token.prolog,.euiCodeBlock .token.doctype,.euiCodeBlock .token.cdata,.euiCodeBlock .token.coord,.euiCodeBlock .token.blockquote{color:#838b93;font-style:italic}.euiCodeBlock .token.selector{color:inherit}.euiCodeBlock .token.string,.euiCodeBlock .token.interpolation,.euiCodeBlock .token.interpolation-punctuation,.euiCodeBlock .token.doc-comment .token.keyword,.euiCodeBlock .token.attr-value,.euiCodeBlock .token.url .token.content{color:#d0809b}.euiCodeBlock .token.number,.euiCodeBlock .token.boolean,.euiCodeBlock .token.keyword.nil,.euiCodeBlock .token.regex,.euiCodeBlock .token.variable,.euiCodeBlock .token.unit,.euiCodeBlock .token.hexcode,.euiCodeBlock .token.attr-name,.euiCodeBlock .token.attr-equals{color:#10b688}.euiCodeBlock .token.atrule .token.rule,.euiCodeBlock .token.keyword{color:#b174fc}.euiCodeBlock .token.function{color:inherit}.euiCodeBlock .token.tag{color:#6092c0}.euiCodeBlock .token.class-name{color:#6ab0f1}.euiCodeBlock .token.property{color:inherit}.euiCodeBlock .token.console,.euiCodeBlock .token.list-punctuation,.euiCodeBlock .token.url-reference,.euiCodeBlock .token.url .token.url{color:#e7664c}.euiCodeBlock .token.paramater{color:inherit}.euiCodeBlock .token.meta,.euiCodeBlock .token.important{color:#9fa6af}.euiCodeBlock .token.title{color:#dd8232}.euiCodeBlock .token.section{color:#e7664c}.euiCodeBlock .token.prefix.inserted,.euiCodeBlock .token.prefix.deleted{margin-left:-4px;padding-left:4px}.euiCodeBlock .token.prefix.inserted{color:#54b399;box-shadow:-4px 0 #54b399}.euiCodeBlock .token.prefix.deleted{color:#f66;box-shadow:-4px 0 #f66}.euiCodeBlock .token.selector .token.class,.euiCodeBlock .token.selector .token.id{color:inherit}.euiCodeBlock .token.italic{font-style:italic}.euiCodeBlock .token.important,.euiCodeBlock .token.bold{font-weight:700}.euiCodeBlock .token.url-reference,.euiCodeBlock .token.url .token.url{text-decoration:underline}.euiCodeBlock .token.entity{cursor:help}.euiCodeEditorWrapper{position:relative}.euiCodeEditorWrapper .ace_hidden-cursors{opacity:0}.euiCodeEditorWrapper.euiCodeEditorWrapper-isEditing .ace_hidden-cursors{opacity:1}.euiCodeEditorKeyboardHint{opacity:0;cursor:pointer;background:rgba(252,254,255,.7);flex-direction:column;justify-content:center;align-items:center;width:100%;height:100%;display:flex;position:absolute;top:0;left:0}.euiCodeEditorKeyboardHint:focus{opacity:1;z-index:1000;border:2px solid #159d8d}.euiCodeEditorKeyboardHint.euiCodeEditorKeyboardHint-isInactive{display:none}.euiCollapsibleNav:not([class*=push]){z-index:6000!important}.euiCollapsibleNav.euiFlyout,.euiCollapsibleNavGroup{background-color:#172430}.euiCollapsibleNavGroup:not(:first-child){border-top:1px solid #293847}.euiCollapsibleNavGroup .euiAccordion__triggerWrapper{padding:16px}.euiCollapsibleNavGroup--light{background-color:#172430}.euiCollapsibleNavGroup--dark{color:#fcfeff;background-color:#0d1720}.euiCollapsibleNavGroup--dark .euiCollapsibleNavGroup__heading:focus .euiAccordion__iconWrapper{color:#159d8d;animation-name:euiCollapsibleNavGroupDarkFocusRingAnimate!important}.euiCollapsibleNavGroup--dark .euiCollapsibleNavGroup__title{color:inherit;line-height:inherit}.euiCollapsibleNavGroup__heading{font-weight:600}.euiCollapsibleNavGroup__heading:not(.euiAccordion__button){padding:16px}.euiCollapsibleNavGroup__children{padding:8px}.euiCollapsibleNavGroup--withHeading .euiCollapsibleNavGroup__children{padding-top:0}@keyframes euiCollapsibleNavGroupDarkFocusRingAnimate{0%{box-shadow:0 0 0 6px rgba(21,157,141,0)}to{box-shadow:0 0 0 3px #159d8d}}.euiColorPicker{width:152px;position:relative}.euiColorPicker__popoverAnchor .euiColorPicker__input{padding-right:40px}.euiColorPicker__popoverAnchor .euiColorPicker__input[class*=--compressed]{padding-right:32px}.euiColorPicker__popoverAnchor .euiColorPicker__input+.euiFormControlLayoutIcons{color:inherit}.euiSwatchInput__stroke{fill:none;stroke:rgba(252,254,255,.2)}.euiColorPicker__popoverPanel--pickerOnly{padding-bottom:0!important}.euiColorPicker__input--inGroup{border-radius:0;height:38px!important;box-shadow:none!important}.euiColorPicker__input--inGroup.euiFieldText--compressed{border-radius:0;height:30px!important}.euiColorPicker__alphaRange .euiRangeInput{min-width:0}.euiColorPickerSwatch{cursor:pointer;border:1px solid rgba(252,254,255,.1);border-radius:2px;width:24px;height:24px;display:inline-block;box-shadow:inset 0 0 0 1px rgba(10,18,26,.05)}.euiColorPickerSwatch:focus{animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiHue{background:linear-gradient(90deg,#ff3232 0%,#fff130 20%,#45ff30 35%,#28fff0 52%,#282cff 71%,#ff28fb 88%,#ff0094 100%);height:24px;margin:4px 0;position:relative}.euiHue:before,.euiHue:after{content:"";background:#0a121a;width:100%;height:8px;position:absolute;left:0}.euiHue:after{bottom:0}.euiHue__range{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;z-index:2;background:0 0;width:calc(100% + 2px);height:24px;margin:0 -1px;position:relative}.euiHue__range::-webkit-slider-thumb{cursor:pointer;background:#0a121a 50% no-repeat;border:1px solid #8d98a3;border-radius:14px;width:16px;height:16px;padding:0;transition:background-color .15s ease-in,border-color .15s ease-in;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiHue__range::-moz-range-thumb{cursor:pointer;background:#0a121a 50% no-repeat;border:1px solid #8d98a3;border-radius:14px;width:16px;height:16px;padding:0;transition:background-color .15s ease-in,border-color .15s ease-in;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiHue__range::-ms-thumb{cursor:pointer;background:#0a121a 50% no-repeat;border:1px solid #8d98a3;border-radius:14px;width:16px;height:16px;padding:0;transition:background-color .15s ease-in,border-color .15s ease-in;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiHue__range::-webkit-slider-thumb{-webkit-appearance:none;margin-top:0}.euiHue__range::-ms-thumb{margin-top:0}.euiHue__range::-ms-track{color:transparent;background:0 0;border-color:transparent;height:24px}.euiHue__range::-moz-focus-outer{border:none}.euiHue__range::-ms-fill-lower{background:0 0}.euiHue__range::-ms-fill-upper{background:0 0}.euiHue__range:focus{outline:none}.euiHue__range:focus::-webkit-slider-thumb{border-color:#159d8d;box-shadow:0 0 0 3px rgba(21,157,141,.3)}.euiHue__range:focus::-moz-range-thumb{border-color:#159d8d;box-shadow:0 0 0 3px rgba(21,157,141,.3)}.euiHue__range:focus::-ms-thumb{border-color:#159d8d;box-shadow:0 0 0 3px rgba(21,157,141,.3)}.euiSaturation{touch-action:none;z-index:3;border-radius:2px;width:100%;padding-bottom:100%;position:relative}.euiSaturation .euiSaturation__lightness,.euiSaturation .euiSaturation__saturation{border-radius:2px;position:absolute;top:-1px;bottom:0;left:0;right:0}.euiSaturation .euiSaturation__lightness{background:linear-gradient(90deg,#fff,rgba(255,255,255,0))}.euiSaturation .euiSaturation__saturation{background:linear-gradient(transparent,#000)}.euiSaturation .euiSaturation__indicator{border:1px solid #dfe3e8;border-radius:100%;width:12px;height:12px;margin-top:-6px;margin-left:-6px;position:absolute}.euiSaturation .euiSaturation__indicator:before{content:"";border:1px solid #101b25;border-radius:100%;position:absolute;top:0;bottom:0;left:0;right:0}.euiSaturation:focus{outline:none}.euiSaturation:focus .euiSaturation__indicator{border-color:#159d8d;box-shadow:0 0 0 3px rgba(21,157,141,.3)}.euiColorStops:not(.euiColorStops-isDisabled):focus{outline:2px solid rgba(21,157,141,.3)}.euiColorStops__addContainer{height:16px;margin-top:-8px;display:block;position:absolute;top:50%;left:0;right:0}.euiColorStops__addContainer:hover:not(.euiColorStops__addContainer-isDisabled){cursor:pointer}.euiColorStops__addContainer:hover:not(.euiColorStops__addContainer-isDisabled) .euiColorStops__addTarget{opacity:.7}.euiColorStops__addTarget{cursor:pointer;pointer-events:none;opacity:0;background:#101b25 50% no-repeat;border:1px solid #8d98a3;border-radius:14px;width:16px;height:16px;padding:0;transition:opacity .15s;position:absolute;top:0;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiColorStop{width:152px}.euiColorStopPopover.euiPopover{width:16px;height:16px;margin-top:-8px;position:absolute;top:50%}.euiColorStopPopover-hasFocus{z-index:1}.euiColorStopPopover__anchor{width:100%;height:100%;position:absolute}.euiColorStopPopover__anchor:before{content:"";background:#0a121a;border-radius:16px;width:16px;height:16px;display:block;position:absolute;top:0;left:0}.euiColorStopThumb.euiRangeThumb:not(:disabled){pointer-events:auto;cursor:-webkit-grab;cursor:grab;border:3px solid #0a121a;margin-top:0;top:0;box-shadow:0 0 0 1px #5b6875,0 2px 2px -1px rgba(0,0,0,.2),0 1px 5px -2px rgba(0,0,0,.2)}.euiColorStopThumb.euiRangeThumb:not(:disabled):active{cursor:-webkit-grabbing;cursor:grabbing}.euiColorStopPopover-isLoadingPanel{visibility:hidden!important}.euiColorStops.euiColorStops-isDragging:not(.euiColorStops-isDisabled):not(.euiColorStops-isReadOnly){cursor:-webkit-grabbing;cursor:grabbing}.euiColorStops__highlight{color:#8d98a3}.euiColorPalettePicker__itemTitle{font-size:.75rem;line-height:1.33333}.euiColorPalettePicker__itemTitle+.euiColorPaletteDisplay{margin-top:4px}.euiColorPaletteDisplay{flex-direction:row;height:8px;display:flex;overflow:hidden}.euiColorPaletteDisplay--sizeExtraSmall{border-radius:4px;height:4px;position:relative}.euiColorPaletteDisplay--sizeExtraSmall:after{content:"";pointer-events:none;border:1px solid rgba(223,227,232,.2);border-radius:4px;position:absolute;top:0;bottom:0;left:0;right:0}.euiColorPaletteDisplay--sizeExtraSmall .euiColorPaletteDisplayFixed__bleedArea{height:4px}.euiColorPaletteDisplay--sizeSmall{border-radius:8px;height:8px;position:relative}.euiColorPaletteDisplay--sizeSmall:after{content:"";pointer-events:none;border:1px solid rgba(223,227,232,.2);border-radius:8px;position:absolute;top:0;bottom:0;left:0;right:0}.euiColorPaletteDisplay--sizeSmall .euiColorPaletteDisplayFixed__bleedArea{height:8px}.euiColorPaletteDisplay--sizeMedium{border-radius:16px;height:16px;position:relative}.euiColorPaletteDisplay--sizeMedium:after{content:"";pointer-events:none;border:1px solid rgba(223,227,232,.2);border-radius:16px;position:absolute;top:0;bottom:0;left:0;right:0}.euiColorPaletteDisplay--sizeMedium .euiColorPaletteDisplayFixed__bleedArea{height:16px}.euiColorPaletteDisplayFixed__bleedArea{width:calc(100% + 1px);height:8px;display:flex;position:absolute;top:0;left:0}.euiComboBox{width:100%;max-width:400px;height:auto;position:relative}.euiComboBox--fullWidth{max-width:100%}.euiComboBox--compressed{height:32px}.euiComboBox--inGroup{height:100%}.euiComboBox--compressed,.euiComboBox .euiFormControlLayout{height:auto}.euiComboBox .euiComboBox__inputWrap{width:100%;max-width:400px;height:40px;font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border:none;border-radius:0;outline:none;width:100%;max-width:400px;height:auto;padding:4px 40px 4px 8px;font-size:15.75px;font-weight:400;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;display:flex;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 3px 2px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiComboBox .euiComboBox__inputWrap{transition-property:box-shadow,background-image,background-size}}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiComboBox .euiComboBox__inputWrap{line-height:1em}}.euiComboBox .euiComboBox__inputWrap::-webkit-input-placeholder{color:#9fa6af;opacity:1}.euiComboBox .euiComboBox__inputWrap::placeholder{color:#9fa6af;opacity:1}.euiComboBox .euiComboBox__inputWrap::placeholder{color:#9fa6af;opacity:1}.euiComboBox .euiComboBox__inputWrap--compressed{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border-radius:2px;padding:8px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiComboBox .euiComboBox__inputWrap--compressed{transition-property:box-shadow,background-image,background-size}}.euiComboBox .euiComboBox__inputWrap--inGroup{border-radius:0;box-shadow:none!important}.euiComboBox .euiComboBox__inputWrap--withIcon{padding-left:40px}.euiComboBox .euiComboBox__inputWrap--fullWidth{max-width:100%}.euiComboBox .euiComboBox__inputWrap--compressed{height:32px}.euiComboBox .euiComboBox__inputWrap--inGroup{height:100%}.euiComboBox .euiComboBox__inputWrap .euiComboBoxPill{max-width:calc(100% - 18px)}.euiComboBox .euiComboBox__inputWrap .euiComboBoxIcon{align-self:center}.euiComboBox .euiComboBox__inputWrap:not(.euiComboBox__inputWrap--noWrap){flex-wrap:wrap;align-content:flex-start;height:auto;padding-top:4px;padding-bottom:4px;padding-left:4px}.euiComboBox .euiComboBox__inputWrap:not(.euiComboBox__inputWrap--noWrap):hover{cursor:text}.euiComboBox .euiComboBox__inputWrap.euiComboBox__inputWrap-isClearable,.euiComboBox .euiComboBox__inputWrap.euiComboBox__inputWrap-isLoading,.euiComboBox .euiComboBox__inputWrap.euiComboBox__inputWrap-isLoading .euiComboBoxPlaceholder{padding-right:62px}.euiComboBox .euiComboBox__inputWrap.euiComboBox__inputWrap-isLoading.euiComboBox__inputWrap-isClearable{padding-right:84px}.euiComboBox .euiComboBox__inputWrap--inGroup.euiComboBox .euiComboBox__inputWrap--compressed{height:30px;line-height:30px}.euiComboBox .euiComboBox__inputWrap--inGroup.euiComboBox .euiComboBox__inputWrap--compressed .euiComboBoxPill,.euiComboBox .euiComboBox__inputWrap--inGroup.euiComboBox .euiComboBox__inputWrap--compressed .euiComboBoxPill+.euiComboBoxPill{margin:4px 4px 0 0}.euiComboBox .euiComboBox__inputWrap--inGroup.euiComboBox .euiComboBox__inputWrap--compressed .euiComboBoxPill--plainText{line-height:22px}.euiComboBox .euiComboBox__input{height:32px;overflow:hidden;display:inline-flex!important}.euiComboBox .euiComboBox__input>input{font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;color:#dfe5ef;background:0 0;border:none;margin:4px;padding:0;font-size:15.75px;font-weight:400;line-height:1.33333}.euiComboBox.euiComboBox-isOpen .euiComboBox__inputWrap{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 4px 4px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiComboBox.euiComboBox-isOpen .euiComboBox__inputWrap--compressed{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiComboBox.euiComboBox-isInvalid .euiComboBox__inputWrap{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiComboBox.euiComboBox-isDisabled .euiComboBox__inputWrap{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;-webkit-text-fill-color:unset;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiComboBox.euiComboBox-isDisabled .euiComboBox__inputWrap::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiComboBox.euiComboBox-isDisabled .euiComboBox__inputWrap::placeholder{color:#5b6875;opacity:1}.euiComboBox.euiComboBox-isDisabled .euiComboBox__inputWrap::placeholder{color:#5b6875;opacity:1}.euiComboBox.euiComboBox-isDisabled .euiComboBoxPlaceholder,.euiComboBox.euiComboBox-isDisabled .euiComboBoxPill--plainText{color:#5b6875;-webkit-text-fill-color:#5b6875}.euiComboBox.euiComboBox-isDisabled .euiComboBox__inputWrap:not(.euiComboBox__inputWrap--noWrap):hover{cursor:not-allowed}.euiComboBox .euiFormControlLayout--group .euiComboBox__input,.euiComboBox.euiComboBox--compressed .euiFormControlLayout--group .euiComboBox__input{height:30px}.euiComboBox.euiComboBox--compressed .euiComboBox__inputWrap{padding-top:0;padding-bottom:0;padding-right:32px;line-height:32px}.euiComboBox.euiComboBox--compressed .euiComboBox__inputWrap.euiComboBox__inputWrap-isClearable,.euiComboBox.euiComboBox--compressed .euiComboBox__inputWrap.euiComboBox__inputWrap-isLoading,.euiComboBox.euiComboBox--compressed .euiComboBox__inputWrap.euiComboBox__inputWrap-isLoading .euiComboBoxPlaceholder{padding-right:54px}.euiComboBox.euiComboBox--compressed .euiComboBox__inputWrap.euiComboBox__inputWrap-isLoading.euiComboBox__inputWrap-isClearable{padding-right:76px}.euiComboBox .euiFormControlLayout--group .euiText{line-height:0!important}.euiComboBox .euiFormControlLayout__prepend,.euiComboBox .euiFormControlLayout__append{height:auto!important}.euiComboBox__input{max-width:100%}.euiComboBox__input input{box-shadow:none!important;border:none!important;outline:none!important}.euiComboBoxPill{vertical-align:baseline;height:22px;line-height:22px}.euiComboBoxPill.euiBadge{line-height:20px}.euiComboBoxPill,.euiComboBoxPill+.euiComboBoxPill{margin:4px}.euiFormControlLayout--group .euiComboBoxPill,.euiFormControlLayout--group .euiComboBoxPill+.euiComboBoxPill{margin:3px 5px 4px 3px}.euiComboBoxPill.euiBadge,.euiComboBoxPill.euiBadge+.euiComboBoxPill.euiBadge{margin:5px 4px}.euiComboBox--compressed .euiComboBoxPill,.euiComboBox--compressed .euiComboBoxPill+.euiComboBoxPill{margin:4px 4px 0 0;line-height:22px}.euiComboBox--compressed .euiFormControlLayout--group .euiComboBoxPill,.euiComboBox--compressed .euiFormControlLayout--group .euiComboBoxPill+.euiComboBoxPill{margin:3px 5px 0 -1px}.euiComboBox--compressed .euiComboBoxPill.euiBadge,.euiComboBox--compressed .euiComboBoxPill.euiBadge+.euiComboBoxPill.euiBadge{margin:5px 4px 0 0;line-height:20px}.euiComboBoxPill--plainText{font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;vertical-align:middle;max-width:100%;padding:0;font-size:15.75px;font-weight:400;line-height:24px;display:inline-block;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiComboBoxPlaceholder{pointer-events:none;color:#9fa6af;max-width:100%;padding-left:4px;padding-right:40px;line-height:32px;position:absolute;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;margin-bottom:0!important;overflow:hidden!important}.euiComboBoxOptionsList{top:0;transform:none!important}.euiComboBoxOptionsList.euiPopover__panel-isAttached.euiComboBoxOptionsList--top{box-shadow:0 0 12px -1px rgba(0,0,0,.2),0 0 4px -1px rgba(0,0,0,.2),0 0 2px rgba(0,0,0,.2)}.euiComboBoxOptionsList__empty{word-break:break-word;text-align:center;word-wrap:break-word;padding:8px;overflow-wrap:break-word!important;word-wrap:break-word!important}.euiComboBoxOptionsList__rowWrap{max-height:200px;padding:0;overflow:hidden}.euiComboBoxOptionsList__rowWrap>div{scrollbar-width:thin}.euiComboBoxOptionsList__rowWrap>div::-webkit-scrollbar{width:16px;height:16px}.euiComboBoxOptionsList__rowWrap>div::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiComboBoxOptionsList__rowWrap>div::-webkit-scrollbar-corner{background-color:transparent}.euiComboBoxOptionsList__rowWrap>div::-webkit-scrollbar-track{background-color:transparent}.euiComboBoxOption{text-align:left;border:1px solid transparent;align-items:center;width:100%;padding:4px 8px 4px 16px;font-size:15.75px;display:flex}.euiComboBoxOption:hover{text-decoration:underline}.euiComboBoxOption.euiComboBoxOption-isFocused{cursor:pointer;color:#159d8d;background-color:#0e4342}.euiComboBoxOption.euiComboBoxOption-isDisabled{color:#5b6875;cursor:not-allowed}.euiComboBoxOption.euiComboBoxOption-isDisabled:hover{text-decoration:none}.euiComboBoxOption__contentWrapper{display:flex}.euiComboBoxOption__contentWrapper .euiComboBoxOption__emptyStateText{text-align:left;flex:1;margin-bottom:0}.euiComboBoxOption__contentWrapper .euiComboBoxOption__enterBadge{align-self:flex-start;margin-left:4px}.euiComboBoxOption__content{text-overflow:ellipsis;white-space:nowrap;text-align:left;flex:1;overflow:hidden}.euiComboBoxTitle{color:#fcfeff;width:100%;padding:11px 8px 4px;font-size:13.5px;font-weight:700}.euiComment{min-height:56px;padding-bottom:16px;font-size:15.75px;display:flex}.euiComment .euiCommentEvent{flex-grow:1}.euiComment .euiCommentTimeline{flex-grow:0;margin-right:16px;position:relative}.euiComment .euiCommentTimeline:before{content:"";background-color:#293847;width:2px;height:calc(100% + 24px);position:absolute;top:24px;left:20px}.euiComment:last-of-type .euiCommentTimeline:before{display:none}.euiComment--update:not(.euiComment--hasBody){align-items:center}.euiCommentEvent--regular{background-color:#0a121a;border:1px solid #293847;border-radius:4px;flex-grow:1}.euiCommentEvent--regular.euiCommentEvent--regular--flexGrowZero{flex-grow:0}.euiCommentEvent--regular.euiCommentEvent--regular--noBorder{border:none}.euiCommentEvent--regular.euiCommentEvent--regular--hasShadow{border:1px solid #293847;box-shadow:0 2px 2px -1px rgba(0,0,0,.3),0 1px 5px -2px rgba(0,0,0,.3)}.euiCommentEvent--regular.euiCommentEvent--regular--isClickable{transition:all .15s cubic-bezier(.694,.0482,.335,1)}.euiCommentEvent--regular.euiCommentEvent--regular--isClickable:enabled{text-align:left;width:100%;display:block}.euiCommentEvent--regular.euiCommentEvent--regular--isClickable:hover,.euiCommentEvent--regular.euiCommentEvent--regular--isClickable:focus{cursor:pointer;transform:translateY(-2px);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiCommentEvent--regular.euiCommentEvent--regular--borderRadiusNone{border-radius:0}.euiCommentEvent--regular.euiCommentEvent--regular--borderRadiusMedium{border-radius:4px}.euiCommentEvent--regular.euiCommentEvent--regular--borderRadiusLarge{border-radius:8px}.euiCommentEvent--regular.euiCommentEvent--regular--borderRadiusXLarge{border-radius:16px}.euiCommentEvent--regular.euiCommentEvent--regular--transparent{background-color:transparent}.euiCommentEvent--regular.euiCommentEvent--regular--plain{background-color:#0a121a}.euiCommentEvent--regular.euiCommentEvent--regular--subdued{background-color:#172430}.euiCommentEvent--regular.euiCommentEvent--regular--accent{background-color:#52384c}.euiCommentEvent--regular.euiCommentEvent--regular--primary{background-color:#0d3c3d}.euiCommentEvent--regular.euiCommentEvent--regular--success{background-color:#2d5051}.euiCommentEvent--regular.euiCommentEvent--regular--warning{background-color:#544a37}.euiCommentEvent--regular.euiCommentEvent--regular--danger{background-color:#542b31}.euiCommentEvent{overflow:hidden}.euiCommentEvent__header{align-items:center;line-height:1.33333;display:flex}.euiCommentEvent__headerData{flex-wrap:wrap;align-items:center;display:flex}.euiCommentEvent__headerData>div{padding-right:4px}.euiCommentEvent__headerUsername{font-weight:600}.euiCommentEvent--regular{border:1px solid #293847;border-radius:4px;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiCommentEvent--regular .euiCommentEvent__header{background-color:#101b25;border-bottom:1px solid #293847;min-height:40px;padding:4px 8px}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiCommentEvent--regular .euiCommentEvent__header:after{content:"";min-height:32px;font-size:0;display:block}}.euiCommentEvent--regular .euiCommentEvent__headerData{flex-grow:1}.euiCommentEvent--regular .euiCommentEvent__body{padding:8px}.euiCommentEvent--update .euiCommentEvent__header{justify-content:flex-start;padding:4px 0}.euiCommentEvent--update .euiCommentEvent__headerData{padding-right:8px}.euiCommentEvent--update .euiCommentEvent__body{padding-top:4px}.euiCommentTimeline__content{justify-content:center;align-items:center;min-width:40px;display:flex;position:relative}.euiCommentTimeline__icon--default{background-color:#101b25;border-radius:50%;flex-shrink:0;justify-content:center;align-items:center;display:flex;overflow-x:hidden}.euiCommentTimeline__icon--default.euiCommentTimeline__icon--regular{width:40px;height:40px}.euiCommentTimeline__icon--default.euiCommentTimeline__icon--update{width:24px;height:24px}.euiContextMenu{border-radius:4px;width:256px;max-width:100%;transition:height .15s cubic-bezier(.694,.0482,.335,1);position:relative;overflow:hidden}.euiContextMenu .euiContextMenu__content{padding:8px}.euiContextMenu__panel{position:absolute}.euiContextMenu__icon{margin-right:8px}.euiContextMenuPanel{visibility:visible;outline-offset:-3px;width:100%}.euiContextMenuPanel:focus{outline:none}.euiContextMenuPanel.euiContextMenuPanel-txInLeft{pointer-events:none;animation:.25s cubic-bezier(.694,.0482,.335,1) euiContextMenuPanelTxInLeft}.euiContextMenuPanel.euiContextMenuPanel-txOutLeft{pointer-events:none;animation:.25s cubic-bezier(.694,.0482,.335,1) euiContextMenuPanelTxOutLeft}.euiContextMenuPanel.euiContextMenuPanel-txInRight{pointer-events:none;animation:.25s cubic-bezier(.694,.0482,.335,1) euiContextMenuPanelTxInRight}.euiContextMenuPanel.euiContextMenuPanel-txOutRight{pointer-events:none;animation:.25s cubic-bezier(.694,.0482,.335,1) euiContextMenuPanelTxOutRight}.euiContextMenuPanel--next{visibility:hidden;transform:translate(256px)}.euiContextMenuPanel--previous{visibility:hidden;transform:translate(-256px)}.euiContextMenuPanelTitle{color:#dfe5ef;letter-spacing:-.005em;text-transform:none;text-align:left;outline-offset:-3px;border-bottom:1px solid #293847;width:100%;padding:12px;font-size:.875rem;font-weight:700;line-height:1.33333rem}.euiContextMenuPanelTitle:enabled:hover,.euiContextMenuPanelTitle:enabled:focus{text-decoration:underline}.euiContextMenuPanelTitle--small{color:#dfe5ef;letter-spacing:-.005em;text-transform:none;border-bottom:1px solid #293847;padding:6px 8px;font-size:.875rem;font-weight:700;line-height:1.33333rem}@keyframes euiContextMenuPanelTxInLeft{0%{transform:translate(256px)}to{transform:translate(0)}}@keyframes euiContextMenuPanelTxOutLeft{0%{transform:translate(0)}to{transform:translate(-256px)}}@keyframes euiContextMenuPanelTxInRight{0%{transform:translate(-256px)}to{transform:translate(0)}}@keyframes euiContextMenuPanelTxOutRight{0%{transform:translate(0)}to{transform:translate(256px)}}.euiContextMenuItem{text-align:left;color:#dfe5ef;outline-offset:-3px;width:100%;padding:12px;display:block}.euiContextMenuItem:hover,.euiContextMenuItem:focus{text-decoration:underline}.euiContextMenuItem:focus{background-color:#0e4342}.euiContextMenuItem.euiContextMenuItem-isDisabled{color:#535a62;cursor:default}.euiContextMenuItem.euiContextMenuItem-isDisabled:hover,.euiContextMenuItem.euiContextMenuItem-isDisabled:focus{text-decoration:none}.euiContextMenuItem--small{padding:6px 8px}.euiContextMenuItem--small .euiContextMenuItem__text{font-size:.875rem;line-height:1.33333}.euiContextMenuItem__inner{display:flex}.euiContextMenuItem__text{flex-grow:1;overflow:hidden}.euiContextMenuItem__arrow{align-self:flex-end}.euiContextMenu__itemLayout{align-items:center;display:flex}.euiContextMenu__itemLayout.euiContextMenu__itemLayout--bottom{align-items:flex-end}.euiContextMenu__itemLayout.euiContextMenu__itemLayout--top{align-items:flex-start}.euiContextMenu__itemLayout .euiContextMenu__icon{flex-shrink:0}.euiControlBar{color:#abb0b4;background:#0a121a;flex-direction:column;height:40px;max-height:calc(100vh - 80px);display:flex;bottom:0;transform:translateY(0);box-shadow:inset 0 40px #0a121a,inset 0 600rem #172430}.euiControlBar--fixed{z-index:6000;position:fixed}.euiControlBar--absolute{z-index:1000;position:absolute}.euiControlBar--relative{position:relative}.euiControlBar-isOpen{animation-duration:.25s;animation-timing-function:cubic-bezier(.694,.0482,.335,1);animation-fill-mode:forwards}.euiControlBar-isOpen.euiControlBar--large{height:calc(100vh - 80px);animation-name:euiControlBarOpenPanelLarge;bottom:-100vh}.euiControlBar-isOpen.euiControlBar--medium{height:480px;animation-name:euiControlBarOpenPanelMedium;bottom:-480px}.euiControlBar-isOpen.euiControlBar--small{height:240px;animation-name:euiControlBarOpenPanelSmall;bottom:-240px}.euiControlBar__controls{align-items:center;width:100%;height:40px;padding:0 12px;display:flex;overflow-x:auto;overflow-y:hidden}.euiControlBar__content{scrollbar-width:thin;color:#dfe3e8;background-color:#172430;width:100%;height:calc(100% - 40px);animation-name:euiControlBarShowContent;animation-duration:.35s;animation-timing-function:cubic-bezier(.694,.0482,.335,1);animation-iteration-count:1;overflow-y:auto}.euiControlBar__content::-webkit-scrollbar{width:16px;height:16px}.euiControlBar__content::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiControlBar__content::-webkit-scrollbar-corner{background-color:transparent}.euiControlBar__content::-webkit-scrollbar-track{background-color:transparent}.euiControlBar__icon{flex-shrink:0;margin-left:8px;margin-right:8px}.euiControlBar__buttonIcon{flex-shrink:0;min-width:40px;min-height:40px}.euiControlBar__button{border-radius:2px;flex-shrink:0;margin-left:4px;font-size:15.75px}.euiControlBar__button:enabled:hover{box-shadow:none;transform:none}.euiControlBar__button:last-child{margin-right:4px}.euiControlBar__breadcrumbs .euiBreadcrumb:not(.euiBreadcrumb--last){color:#9fa6af}.euiControlBar__breadcrumbs .euiBreadcrumbSeparator{background:rgba(252,254,255,.2)}.euiControlBar__spacer{flex-grow:1;height:100%}.euiControlBar__divider{background-color:rgba(252,254,255,.2);flex-shrink:0;width:1px;height:100%}.euiControlBar__text{color:#abb0b4;max-width:100%;padding:0 8px;font-size:.875rem;line-height:1.33333;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiControlBar__text:last-child{padding-right:0}.euiControlBar__tab{color:#abb0b4;text-align:center;max-width:100%;height:100%;padding:0 16px;font-size:.875rem;line-height:1.33333;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiControlBar__tab:hover,.euiControlBar__tab:focus{cursor:pointer;text-decoration:underline}.euiControlBar__tab.euiControlBar__tab--active{color:#159d8d;background-color:#172430;box-shadow:inset 0 4px #159d8d}.euiControlBar__controls .euiLink.euiLink--primary{color:#159d8d}.euiControlBar__controls .euiLink.euiLink--primary:hover{color:#12736b}.euiControlBar__controls .euiControlBar__button.euiButton--primary:enabled{box-shadow:none}.euiControlBar__controls .euiControlBar__button.euiButton--primary:enabled:not(.euiButton--fill){color:#159d8d;border-color:#159d8d}.euiControlBar__controls .euiButtonIcon--primary{color:#159d8d}.euiControlBar__controls .euiLink.euiLink--accent{color:#f990c0}.euiControlBar__controls .euiLink.euiLink--accent:hover{color:#b16a8e}.euiControlBar__controls .euiControlBar__button.euiButton--accent:enabled{box-shadow:none}.euiControlBar__controls .euiControlBar__button.euiButton--accent:enabled:not(.euiButton--fill){color:#f990c0;border-color:#f990c0}.euiControlBar__controls .euiButtonIcon--accent{color:#f990c0}.euiControlBar__controls .euiLink.euiLink--secondary{color:#7de2d1}.euiControlBar__controls .euiLink.euiLink--secondary:hover{color:#5ba49a}.euiControlBar__controls .euiControlBar__button.euiButton--secondary:enabled{box-shadow:none}.euiControlBar__controls .euiControlBar__button.euiButton--secondary:enabled:not(.euiButton--fill){color:#7de2d1;border-color:#7de2d1}.euiControlBar__controls .euiButtonIcon--secondary,.euiControlBar__controls .euiLink.euiLink--success{color:#7de2d1}.euiControlBar__controls .euiLink.euiLink--success:hover{color:#5ba49a}.euiControlBar__controls .euiControlBar__button.euiButton--success:enabled{box-shadow:none}.euiControlBar__controls .euiControlBar__button.euiButton--success:enabled:not(.euiButton--fill){color:#7de2d1;border-color:#7de2d1}.euiControlBar__controls .euiButtonIcon--success{color:#7de2d1}.euiControlBar__controls .euiLink.euiLink--warning{color:#ffce7a}.euiControlBar__controls .euiLink.euiLink--warning:hover{color:#b6965d}.euiControlBar__controls .euiControlBar__button.euiButton--warning:enabled{box-shadow:none}.euiControlBar__controls .euiControlBar__button.euiButton--warning:enabled:not(.euiButton--fill){color:#ffce7a;border-color:#ffce7a}.euiControlBar__controls .euiButtonIcon--warning{color:#ffce7a}.euiControlBar__controls .euiLink.euiLink--danger{color:#f66}.euiControlBar__controls .euiLink.euiLink--danger:hover{color:#b64d4f}.euiControlBar__controls .euiControlBar__button.euiButton--danger:enabled{box-shadow:none}.euiControlBar__controls .euiControlBar__button.euiButton--danger:enabled:not(.euiButton--fill){color:#f66;border-color:#f66}.euiControlBar__controls .euiButtonIcon--danger{color:#f66}.euiControlBar__controls .euiLink.euiLink--subdued{color:#9fa6af}.euiControlBar__controls .euiLink.euiLink--subdued:hover{color:#727a82}.euiControlBar__controls .euiControlBar__button.euiButton--subdued:enabled{box-shadow:none}.euiControlBar__controls .euiControlBar__button.euiButton--subdued:enabled:not(.euiButton--fill){color:#9fa6af;border-color:#9fa6af}.euiControlBar__controls .euiButtonIcon--subdued{color:#9fa6af}.euiControlBar__controls .euiLink.euiLink--ghost{color:#fcfeff}.euiControlBar__controls .euiLink.euiLink--ghost:hover{color:#b3b7ba}.euiControlBar__controls .euiControlBar__button.euiButton--ghost:enabled{box-shadow:none}.euiControlBar__controls .euiControlBar__button.euiButton--ghost:enabled:not(.euiButton--fill){color:#fcfeff;border-color:#fcfeff}.euiControlBar__controls .euiButtonIcon--ghost{color:#fcfeff}.euiControlBar__controls .euiLink.euiLink--text:hover{color:#66707a}.euiControlBar__controls .euiLink.euiLink--text{color:#fcfeff}.euiControlBar__controls .euiControlBar__button.euiButton--text:enabled{box-shadow:none}.euiControlBar__controls .euiControlBar__button.euiButton--text:enabled:not(.euiButton--fill){color:#8d98a3;border-color:#8d98a3}.euiControlBar__controls .euiButtonIcon--text{color:#8d98a3}@media only screen and (max-width:574px){.euiControlBar:not(.euiControlBar--showOnMobile){display:none}}@media only screen and (min-width:575px) and (max-width:767px){.euiControlBar:not(.euiControlBar--showOnMobile){display:none}}@keyframes euiControlBarOpenPanelLarge{0%{transform:translateY(-120px)}to{transform:translateY(-100vh)}}@keyframes euiControlBarOpenPanelMedium{0%{transform:translateY(-40px)}to{transform:translateY(-480px)}}@keyframes euiControlBarOpenPanelSmall{0%{transform:translateY(-40px)}to{transform:translateY(-240px)}}@keyframes euiControlBarShowContent{0%{opacity:0}to{opacity:1}}.euiDatePicker .euiFormControlLayout{height:auto}.euiDatePicker.euiDatePicker--shadow .react-datepicker-popper{background-color:#0a121a;border:1px solid #293847;border-radius:0 0 4px 4px;box-shadow:0 6px 12px -1px rgba(0,0,0,.2),0 4px 4px -1px rgba(0,0,0,.2),0 2px 2px rgba(0,0,0,.2)}.euiDatePicker.euiDatePicker--shadow.euiDatePicker--inline .react-datepicker{background-color:#0a121a;border:1px solid #293847;border-radius:4px;box-shadow:0 6px 12px -1px rgba(0,0,0,.2),0 4px 4px -1px rgba(0,0,0,.2),0 2px 2px rgba(0,0,0,.2)}.react-datepicker{font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#fcfeff;border-radius:4px;font-size:13.5px;font-weight:400;display:flex;position:relative}.react-datepicker--time-only .react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box{width:100%}.react-datepicker--time-only .react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box .react-datepicker__time-list li.react-datepicker__time-list-item{text-align:left;color:#dfe5ef;padding-left:36px;padding-right:36px;font-size:15.75px}.react-datepicker--time-only .react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box .react-datepicker__time-list li.react-datepicker__time-list-item.react-datepicker__time-list-item--selected{color:#fcfeff}.react-datepicker--time-only .react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box .react-datepicker__time-list li.react-datepicker__time-list-item.react-datepicker__time-list-item--disabled{color:#535a62}.react-datepicker--time-only .react-datepicker__time-container{border-left:0}.euiDatePicker.euiDatePicker--shadow .react-datepicker-popper{z-index:2000;animation:.15s ease-in euiAnimFadeIn}.euiDatePicker.euiDatePicker--shadow .react-datepicker-popper[data-placement^=top]{border-radius:4px 4px 0 0;box-shadow:0 0 12px -1px rgba(0,0,0,.2),0 0 4px -1px rgba(0,0,0,.2),0 0 2px rgba(0,0,0,.2)}.euiDatePicker.euiDatePicker--shadow .react-datepicker-popper[data-placement^=right]{margin-left:0}.euiDatePicker.euiDatePicker--shadow .react-datepicker-popper[data-placement^=left]{margin-right:0}.react-datepicker__header{text-align:center;border-top-left-radius:4px;border-top-right-radius:4px}.react-datepicker__header--time{display:none}.react-datepicker__header__dropdown{padding:16px 0 8px}.react-datepicker__year-dropdown-container--select,.react-datepicker__month-dropdown-container--select,.react-datepicker__month-year-dropdown-container--select,.react-datepicker__year-dropdown-container--scroll,.react-datepicker__month-dropdown-container--scroll,.react-datepicker__month-year-dropdown-container--scroll{margin:0 4px;display:inline-block}.react-datepicker__current-month,.react-datepicker-time__header{display:none}.react-datepicker-time__header{text-overflow:ellipsis;white-space:nowrap;overflow:hidden}.react-datepicker__navigation{cursor:pointer;z-index:1;text-indent:-999em;width:0;padding:0;position:absolute;top:18px;overflow:hidden}.react-datepicker__navigation--previous{background-image:url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB3aWR0aD0iMTYiIGhlaWdodD0iMTYiIHZpZXdCb3g9IjAgMCAxNiAxNiI+ICA8ZGVmcz4gICAgPHBhdGggaWQ9ImRvd25hcnJvd3doaXRlLWEiIGQ9Ik0xMy4wNjg4NTA4LDUuMTU3MjUwMzggTDguMzg0MjM5NzUsOS43NjgyNzQyOCBDOC4xNzA1NDQxNSw5Ljk3ODYxMzA4IDcuODI5OTkyMTQsOS45NzkxNDA5NSA3LjYxNTc2MDI1LDkuNzY4Mjc0MjggTDIuOTMxMTQ5MTUsNS4xNTcyNTAzOCBDMi43MTgxMzU5LDQuOTQ3NTgzMjEgMi4zNzI3NzMxOSw0Ljk0NzU4MzIxIDIuMTU5NzU5OTQsNS4xNTcyNTAzOCBDMS45NDY3NDY2OSw1LjM2NjkxNzU2IDEuOTQ2NzQ2NjksNS43MDY4NTUyMiAyLjE1OTc1OTk0LDUuOTE2NTIyNCBMNi44NDQzNzEwNCwxMC41Mjc1NDYzIEM3LjQ4NTE3NDI0LDExLjE1ODI4MzYgOC41MTY0NDk3OSwxMS4xNTY2ODUxIDkuMTU1NjI4OTYsMTAuNTI3NTQ2MyBMMTMuODQwMjQwMSw1LjkxNjUyMjQgQzE0LjA1MzI1MzMsNS43MDY4NTUyMiAxNC4wNTMyNTMzLDUuMzY2OTE3NTYgMTMuODQwMjQwMSw1LjE1NzI1MDM4IEMxMy42MjcyMjY4LDQuOTQ3NTgzMjEgMTMuMjgxODY0MSw0Ljk0NzU4MzIxIDEzLjA2ODg1MDgsNS4xNTcyNTAzOCBaIi8+ICA8L2RlZnM+ICA8ZyBmaWxsPSJub25lIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiPiAgICA8dXNlIGZpbGw9IiNGRkYiIGZpbGwtcnVsZT0ibm9uemVybyIgeGxpbms6aHJlZj0iI2Rvd25hcnJvd3doaXRlLWEiLz4gIDwvZz48L3N2Zz4=);background-position:50%;width:16px;height:16px;transition:transform 90ms ease-in-out;left:20px;transform:rotate(90deg)}.react-datepicker__navigation--previous:hover,.react-datepicker__navigation--previous:focus{border-radius:4px;transform:scale(1.2)rotate(90deg)}.react-datepicker__navigation--previous:hover{background-color:#101b25;box-shadow:0 0 0 2px #101b25}.react-datepicker__navigation--previous:focus{background-color:#0e4342;box-shadow:0 0 0 2px #0e4342}.react-datepicker__navigation--previous--disabled,.react-datepicker__navigation--previous--disabled:hover{cursor:not-allowed;opacity:.2}.react-datepicker__navigation--next{background-image:url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOnhsaW5rPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5L3hsaW5rIiB3aWR0aD0iMTYiIGhlaWdodD0iMTYiIHZpZXdCb3g9IjAgMCAxNiAxNiI+ICA8ZGVmcz4gICAgPHBhdGggaWQ9ImRvd25hcnJvd3doaXRlLWEiIGQ9Ik0xMy4wNjg4NTA4LDUuMTU3MjUwMzggTDguMzg0MjM5NzUsOS43NjgyNzQyOCBDOC4xNzA1NDQxNSw5Ljk3ODYxMzA4IDcuODI5OTkyMTQsOS45NzkxNDA5NSA3LjYxNTc2MDI1LDkuNzY4Mjc0MjggTDIuOTMxMTQ5MTUsNS4xNTcyNTAzOCBDMi43MTgxMzU5LDQuOTQ3NTgzMjEgMi4zNzI3NzMxOSw0Ljk0NzU4MzIxIDIuMTU5NzU5OTQsNS4xNTcyNTAzOCBDMS45NDY3NDY2OSw1LjM2NjkxNzU2IDEuOTQ2NzQ2NjksNS43MDY4NTUyMiAyLjE1OTc1OTk0LDUuOTE2NTIyNCBMNi44NDQzNzEwNCwxMC41Mjc1NDYzIEM3LjQ4NTE3NDI0LDExLjE1ODI4MzYgOC41MTY0NDk3OSwxMS4xNTY2ODUxIDkuMTU1NjI4OTYsMTAuNTI3NTQ2MyBMMTMuODQwMjQwMSw1LjkxNjUyMjQgQzE0LjA1MzI1MzMsNS43MDY4NTUyMiAxNC4wNTMyNTMzLDUuMzY2OTE3NTYgMTMuODQwMjQwMSw1LjE1NzI1MDM4IEMxMy42MjcyMjY4LDQuOTQ3NTgzMjEgMTMuMjgxODY0MSw0Ljk0NzU4MzIxIDEzLjA2ODg1MDgsNS4xNTcyNTAzOCBaIi8+ICA8L2RlZnM+ICA8ZyBmaWxsPSJub25lIiBmaWxsLXJ1bGU9ImV2ZW5vZGQiPiAgICA8dXNlIGZpbGw9IiNGRkYiIGZpbGwtcnVsZT0ibm9uemVybyIgeGxpbms6aHJlZj0iI2Rvd25hcnJvd3doaXRlLWEiLz4gIDwvZz48L3N2Zz4=);background-position:50%;width:16px;height:16px;right:20px;transform:rotate(-90deg)}.react-datepicker__navigation--next--with-time:not(.react-datepicker__navigation--next--with-today-button){left:248px}.react-datepicker__navigation--next:hover,.react-datepicker__navigation--next:focus{border-radius:4px;transform:scale(1.2)rotate(-90deg)}.react-datepicker__navigation--next:hover{background-color:#101b25;box-shadow:0 0 0 2px #101b25}.react-datepicker__navigation--next:focus{background-color:#0e4342;box-shadow:0 0 0 2px #0e4342}.react-datepicker__navigation--next--disabled,.react-datepicker__navigation--next--disabled:hover{cursor:not-allowed;opacity:.2}.react-datepicker__navigation--years{margin-left:auto;margin-right:auto;display:block;position:relative;top:0}.react-datepicker__navigation--years-previous{border-top-color:#101b25;top:4px}.react-datepicker__navigation--years-previous:hover{border-top-color:#010101}.react-datepicker__navigation--years-upcoming{border-bottom-color:#101b25;top:-4px}.react-datepicker__navigation--years-upcoming:hover{border-bottom-color:#010101}.react-datepicker__month{text-align:center;border-radius:4px;margin:0 16px 16px}.react-datepicker__time-container{border-left:#293847;border-radius:0 4px 4px 0;flex-grow:1;width:auto;padding:16px 0;display:flex}.react-datepicker__time-container .react-datepicker__time{flex-direction:column;flex-grow:1;padding-left:4px;display:flex;position:relative}.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box{flex-direction:column;flex-grow:1;width:auto;display:flex}.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list{scrollbar-width:thin;flex-direction:column;flex-grow:1;align-items:center;display:flex;overflow-y:auto;height:204px!important}.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list::-webkit-scrollbar{width:16px;height:16px}.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list::-webkit-scrollbar-corner{background-color:transparent}.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list::-webkit-scrollbar-track{background-color:transparent}.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list li.react-datepicker__time-list-item{text-align:right;color:#8d98a3;white-space:nowrap;margin-bottom:4px;padding:4px 8px;line-height:12px}.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list li.react-datepicker__time-list-item:hover,.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list li.react-datepicker__time-list-item:focus{cursor:pointer;text-decoration:underline}.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list li.react-datepicker__time-list-item--selected{color:#fff;background-color:#159d8d;border-radius:2px}.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list li.react-datepicker__time-list-item--selected:hover{background-color:#159d8d}.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list li.react-datepicker__time-list-item--disabled{color:#293847}.react-datepicker__time-container .react-datepicker__time .react-datepicker__time-box ul.react-datepicker__time-list li.react-datepicker__time-list-item--disabled:hover{cursor:not-allowed;background-color:transparent;text-decoration:none}.react-datepicker__week-number{color:#101b25;text-align:center;width:32px;margin:0 4px;line-height:28px;display:inline-block}.react-datepicker__week-number.react-datepicker__week-number--clickable{cursor:pointer}.react-datepicker__week-number.react-datepicker__week-number--clickable:hover{background-color:#0a121a;border-radius:4px}.react-datepicker__day-names,.react-datepicker__week{white-space:nowrap}.react-datepicker__day-name,.react-datepicker__day,.react-datepicker__time-name{color:#fcfeff;text-align:center;width:32px;margin:0 2px;line-height:28px;display:inline-block}.react-datepicker__day-name{color:#8d98a3;text-transform:uppercase}.react-datepicker__day{cursor:pointer;border:2px solid transparent;transition:transform 90ms ease-in-out}.react-datepicker__day:hover:not(.react-datepicker__day--disabled){font-weight:700;text-decoration:underline;transform:scale(1.2)}.react-datepicker__day--today{color:#159d8d;font-weight:700}.react-datepicker__day--outside-month{color:#8d98a3}.react-datepicker__day--highlighted{color:#fcfeff;background-color:#7de2d1;border-radius:4px}.react-datepicker__day--highlighted:hover{background-color:#68ddca}.react-datepicker__day--in-range{color:#fcfeff;background-color:rgba(21,157,141,.1);border:6px solid #0a121a;border-left:none;border-right:none;border-radius:0;line-height:20px}.react-datepicker__day--selected,.react-datepicker__day--in-selecting-range{color:#fcfeff;background-color:#159d8d;border:2px solid #159d8d;border-radius:4px;height:32px;margin:0 2px;line-height:28px}.react-datepicker__day--selected:hover,.react-datepicker__day--in-selecting-range:hover{background-color:#128779}.react-datepicker__day--keyboard-selected{border:2px solid #159d8d;border-radius:4px;font-weight:700}.react-datepicker__day--keyboard-selected:hover{color:#fcfeff;background-color:#128779}.react-datepicker__day--in-selecting-range:not(.react-datepicker__day--in-range){background-color:rgba(21,157,141,.5)}.react-datepicker__month--selecting-range .react-datepicker__day--in-range:not(.react-datepicker__day--in-selecting-range){color:#fcfeff;background-color:#0a121a}.react-datepicker__day--disabled{cursor:not-allowed;color:#293847}.react-datepicker__day--disabled:hover{background-color:transparent}.react-datepicker__input-container{position:relative}.react-datepicker__year-read-view{color:#8d98a3;font-weight:300}.react-datepicker__month-read-view{font-weight:500}.react-datepicker__year-read-view,.react-datepicker__month-read-view,.react-datepicker__month-year-read-view{font-size:22.5px}.react-datepicker__year-read-view:hover,.react-datepicker__month-read-view:hover,.react-datepicker__month-year-read-view:hover{cursor:pointer;color:#159d8d}.react-datepicker__year-read-view:hover .react-datepicker__year-read-view--down-arrow,.react-datepicker__year-read-view:hover .react-datepicker__month-read-view--down-arrow,.react-datepicker__month-read-view:hover .react-datepicker__year-read-view--down-arrow,.react-datepicker__month-read-view:hover .react-datepicker__month-read-view--down-arrow,.react-datepicker__month-year-read-view:hover .react-datepicker__year-read-view--down-arrow,.react-datepicker__month-year-read-view:hover .react-datepicker__month-read-view--down-arrow{border-top-color:#010101}.react-datepicker__year-read-view--down-arrow,.react-datepicker__month-read-view--down-arrow,.react-datepicker__month-year-read-view--down-arrow{display:none}.react-datepicker__year-dropdown,.react-datepicker__month-dropdown,.react-datepicker__month-year-dropdown{z-index:1;text-align:center;background-color:#0a121a;border-radius:4px;flex-wrap:wrap;align-content:space-around;align-items:center;width:100%;height:100%;padding:8px;animation:.15s ease-in euiAnimFadeIn;display:flex;position:absolute;top:0;bottom:0;left:0;right:0}.react-datepicker__year-dropdown:hover,.react-datepicker__month-dropdown:hover,.react-datepicker__month-year-dropdown:hover{cursor:pointer}.react-datepicker__year-dropdown{flex-flow:row-reverse wrap-reverse;justify-content:flex-end}.react-datepicker__year-option:first-of-type,.react-datepicker__year-option:last-of-type{display:none}.react-datepicker__year-option,.react-datepicker__month-option,.react-datepicker__month-year-option{color:#dfe3e8;flex-basis:33.3%;padding:8px;font-size:13.5px}.react-datepicker__year-option:first-of-type,.react-datepicker__month-option:first-of-type,.react-datepicker__month-year-option:first-of-type{border-top-left-radius:4px;border-top-right-radius:4px}.react-datepicker__year-option:last-of-type,.react-datepicker__month-option:last-of-type,.react-datepicker__month-year-option:last-of-type{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;border-bottom-right-radius:4px;border-bottom-left-radius:4px}.react-datepicker__year-option:hover,.react-datepicker__month-option:hover,.react-datepicker__month-year-option:hover{background-color:#101b25}.react-datepicker__year-option:hover .react-datepicker__navigation--years-upcoming,.react-datepicker__month-option:hover .react-datepicker__navigation--years-upcoming,.react-datepicker__month-year-option:hover .react-datepicker__navigation--years-upcoming{border-bottom-color:#010101}.react-datepicker__year-option:hover .react-datepicker__navigation--years-previous,.react-datepicker__month-option:hover .react-datepicker__navigation--years-previous,.react-datepicker__month-year-option:hover .react-datepicker__navigation--years-previous{border-top-color:#010101}.react-datepicker__year-option--selected,.react-datepicker__month-option--selected,.react-datepicker__month-year-option--selected{display:none}.react-datepicker__screenReaderOnly{width:1px;height:1px;position:absolute;top:auto;left:-10000px;overflow:hidden}.react-datepicker__year-option--preselected,.react-datepicker__month-option--preselected{background:#0e4342}.react-datepicker__year-option--selected_year.react-datepicker__year-option--preselected,.react-datepicker__month-option--selected_month.react-datepicker__month-option--preselected{background:#159d8d}.react-datepicker__time-list-item--preselected,.react-datepicker__year-option--preselected,.react-datepicker__month-option--preselected{background:#0a2e2d}.react-datepicker__time-container--focus{background:#0e4342}.react-datepicker__month-read-view:focus,.react-datepicker__year-read-view:focus{text-decoration:underline}.react-datepicker__month--accessible:focus{background:#0e4342}.react-datepicker__month--accessible:focus .react-datepicker__day--in-range:not(.react-datepicker__day--selected){border-top-color:#0e4342;border-bottom-color:#0e4342}.react-datepicker__navigation:focus{background-color:#0e4342}.react-datepicker__year-option--selected_year,.react-datepicker__month-option--selected_month{color:#0a121a;background:#159d8d;border-radius:4px;font-weight:700}.react-datepicker__focusTrap{display:flex}.euiDatePickerRange{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;align-items:center;width:100%;max-width:400px;height:auto;padding:1px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;display:flex;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 3px 2px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiDatePickerRange--fullWidth{max-width:100%}.euiDatePickerRange--compressed{height:32px}.euiDatePickerRange--inGroup{height:100%}.euiDatePickerRange .euiDatePicker.euiFieldText--compressed{height:30px}@supports ((-moz-appearance:none)){.euiDatePickerRange{transition-property:box-shadow,background-image,background-size}}.euiDatePickerRange>*{flex-grow:1}.euiDatePickerRange .euiFieldText.euiDatePicker{text-align:center;box-shadow:none!important}.euiDatePickerRange .react-datepicker-popper .euiFieldText.euiDatePicker{text-align:left}.euiDatePickerRange--inGroup{box-shadow:none;padding:0}.euiDatePickerRange--inGroup .euiDatePicker{height:38px}.euiDatePickerRange>.euiDatePickerRange__delimeter{flex:none;padding-left:6px;padding-right:6px;background-color:transparent!important;line-height:1!important}.euiDatePickerRange--readOnly{background:#0d161e}.euiSuperDatePicker__absoluteDateFormRow{padding:0 8px 8px}.euiDatePopoverButton{font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;word-break:break-all;background-size:100%;width:100%;height:38px;padding:0 8px;font-size:15.75px;font-weight:400;line-height:38px;transition:background .15s ease-in;display:block}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiDatePopoverButton{line-height:1em}}.euiDatePopoverButton::-webkit-input-placeholder{color:#9fa6af;opacity:1}.euiDatePopoverButton::placeholder{color:#9fa6af;opacity:1}.euiDatePopoverButton::placeholder{color:#9fa6af;opacity:1}.euiDatePopoverButton:focus,.euiDatePopoverButton-isSelected{background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%)}.euiDatePopoverButton-needsUpdating{color:#7de2d1;background-color:#2d5051}.euiDatePopoverButton-needsUpdating:focus,.euiDatePopoverButton-needsUpdating.euiDatePopoverButton-isSelected{background-image:linear-gradient(0deg,#7de2d1,#7de2d1 2px,transparent 2px,transparent 100%)}.euiDatePopoverButton-isInvalid{color:#ff7575;background-color:#542b31}.euiDatePopoverButton-isInvalid:focus,.euiDatePopoverButton-isInvalid.euiDatePopoverButton-isSelected{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%)}.euiDatePopoverButton:disabled{color:#8d98a3;cursor:default;background-color:#0d161e}.euiDatePopoverButton-compressed{height:30px;line-height:30px}.euiDatePopoverButton--start{text-align:right}.euiDatePopoverButton--end{text-align:left}.euiDatePopoverContent{width:400px;max-width:100%}.euiDatePopoverContent__padded{padding:8px}.euiDatePopoverContent__padded--large{padding:16px}@media only screen and (max-width:574px){.euiDatePopoverContent{width:284px}}@media only screen and (min-width:575px) and (max-width:767px){.euiDatePopoverContent{width:284px}}.euiQuickSelectPopover__content{width:400px;max-width:100%}.euiQuickSelectPopover__section{scrollbar-width:thin;max-height:132px;padding:8px 0 4px;overflow-x:hidden;overflow-y:auto}.euiQuickSelectPopover__section::-webkit-scrollbar{width:16px;height:16px}.euiQuickSelectPopover__section::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiQuickSelectPopover__section::-webkit-scrollbar-corner{background-color:transparent}.euiQuickSelectPopover__section::-webkit-scrollbar-track{background-color:transparent}.euiQuickSelectPopover__buttonText{margin-right:2px!important}.euiQuickSelectPopover__anchor{height:100%}.euiQuickSelectPopover__sectionItem{font-size:15.75px;line-height:15.75px}.euiQuickSelectPopover__sectionItem:not(:last-of-type){margin-bottom:8px}.euiQuickSelect__applyButton{min-width:0}.euiRefreshInterval__startButton{min-width:90px}.euiSuperDatePicker__flexWrapper{width:606px;max-width:calc(100% + 8px)}.euiSuperDatePicker__flexWrapper--isAutoRefreshOnly{width:400px}.euiSuperDatePicker__flexWrapper--noUpdateButton{width:480px}.euiSuperDatePicker{max-width:100%!important}.euiSuperDatePicker>.euiFormControlLayout__childrenWrapper{flex:100%;overflow:hidden}.euiSuperDatePicker>.euiFormControlLayout__childrenWrapper>.euiDatePickerRange{border-radius:0;width:auto;max-width:none}.euiSuperDatePicker__startPopoverButton{margin-right:-12px}.euiSuperDatePicker__startPopoverButton.euiSuperDatePicker__startPopoverButton--compressed{margin-right:-8px}.euiSuperDatePicker__prettyFormat{font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;word-break:break-all;text-align:left;justify-content:space-between;width:100%;height:38px;padding:0 8px;font-size:15.75px;font-weight:400;line-height:38px;transition:background .15s ease-in;display:flex}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiSuperDatePicker__prettyFormat{line-height:1em}}.euiSuperDatePicker__prettyFormat::-webkit-input-placeholder{color:#9fa6af;opacity:1}.euiSuperDatePicker__prettyFormat::placeholder{color:#9fa6af;opacity:1}.euiSuperDatePicker__prettyFormat::placeholder{color:#9fa6af;opacity:1}.euiSuperDatePicker__prettyFormat:not(:disabled):hover,.euiSuperDatePicker__prettyFormat:focus{text-decoration:none}.euiSuperDatePicker__prettyFormat:not(:disabled):hover .euiSuperDatePicker__prettyFormatLink,.euiSuperDatePicker__prettyFormat:focus .euiSuperDatePicker__prettyFormatLink{text-decoration:underline}.euiSuperDatePicker__prettyFormat:disabled{color:#8d98a3;cursor:not-allowed;background-color:#0d161e}.euiSuperDatePicker__prettyFormat:disabled .euiSuperDatePicker__prettyFormatLink{display:none}.euiSuperDatePicker__prettyFormat--compressed{height:30px;line-height:30px}.euiSuperDatePicker__prettyFormatLink{color:#159d8d;flex-shrink:0;padding-left:4px}@media only screen and (max-width:574px){.euiSuperDatePicker__flexWrapper{width:calc(100% + 8px)}.euiSuperDatePicker__prettyFormatLink{flex-shrink:1;min-width:3em}}@media only screen and (min-width:575px) and (max-width:767px){.euiSuperDatePicker__flexWrapper{width:calc(100% + 8px)}.euiSuperDatePicker__prettyFormatLink{flex-shrink:1;min-width:3em}}.euiSuperUpdateButton{min-width:118px}@media only screen and (max-width:574px){.euiSuperUpdateButton{min-width:0}.euiSuperUpdateButton .euiSuperUpdateButton__text{display:none}}@media only screen and (min-width:575px) and (max-width:767px){.euiSuperUpdateButton{min-width:0}.euiSuperUpdateButton .euiSuperUpdateButton__text{display:none}}.euiDataGrid{flex-direction:column;align-items:stretch;height:100%;display:flex;overflow:hidden}.euiDataGrid--fullScreen{z-index:8000;background:#0a121a;height:100%;position:fixed;top:0;bottom:0;left:0;right:0}.euiDataGrid--fullScreen .euiDataGrid__pagination{background:#101b25;border-top:1px solid #293847;padding-bottom:4px}.euiDataGrid--fullScreen .euiDataGrid__verticalScroll .euiDataGridRow{will-change:transform}.euiDataGrid__content{font-feature-settings:"tnum" 1;z-index:2;background:#0a121a;width:100%;max-width:100%;height:100%}.euiDataGrid__controls{z-index:3;background:#172430;border:1px solid #293847;flex-grow:0;padding:4px;position:relative}.euiDataGrid__controls>*{margin-left:2px}.euiDataGrid__controlBtn{border-radius:4px}.euiDataGrid__controlBtn:focus{background:#28323b}.euiDataGrid__controlBtn--active,.euiDataGrid__controlBtn--active:focus{color:#fcfeff;font-weight:600}.euiDataGrid--bordersNone .euiDataGrid__controls{background:#0a121a;border:none}.euiDataGrid--bordersHorizontal .euiDataGrid__controls{background:#0a121a;border-top:none;border-left:none;border-right:none}.euiDataGrid__pagination{flex-grow:0;padding-top:4px}.euiDataGrid__verticalScroll{flex-grow:1;height:100%;overflow-y:hidden}.euiDataGrid__overflow{background:#0a121a;height:100%;overflow-y:hidden}.euiDataGrid__restrictBody{height:100vh;overflow:hidden}.euiDataGrid__controlScroll{scrollbar-width:thin;contain:paint;height:100%;max-height:400px;margin:-8px;padding:8px;overflow-x:hidden;overflow-y:auto;-webkit-mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%);mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%)}.euiDataGrid__controlScroll::-webkit-scrollbar{width:16px;height:16px}.euiDataGrid__controlScroll::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiDataGrid__controlScroll::-webkit-scrollbar-corner{background-color:transparent}.euiDataGrid__controlScroll::-webkit-scrollbar-track{background-color:transparent}.euiDataGrid__controlScroll:focus{outline:none}.euiDataGrid__controlScroll[tabindex="0"]:focus:focus-visible{outline-style:auto}.euiDataGrid__focusWrap{height:100%}.euiDataGrid__virtualized{scrollbar-width:thin;scroll-padding:0}.euiDataGrid__virtualized::-webkit-scrollbar{width:16px;height:16px}.euiDataGrid__virtualized::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid #0a121a}.euiDataGrid__virtualized::-webkit-scrollbar-corner{background-color:#0a121a}.euiDataGrid__virtualized::-webkit-scrollbar-track{background-color:#0a121a}.euiDataGridHeader{z-index:3;background:#0a121a;display:flex;position:-webkit-sticky;position:sticky;top:0}.euiDataGridHeaderCell{flex:none;align-items:center;padding:6px;font-size:.875rem;font-weight:700;line-height:1.33333;display:flex;position:relative}.euiDataGridHeaderCell>*{width:100%;max-width:100%}.euiDataGridHeaderCell.euiDataGridHeaderCell--numeric,.euiDataGridHeaderCell.euiDataGridHeaderCell--currency{text-align:right}.euiDataGridHeaderCell:focus{z-index:2;border:1px solid transparent;border-top:none;border-radius:1px;outline:none;box-shadow:0 0 0 2px rgba(21,157,141,.3)}.euiDataGridHeaderCell:not(.euiDataGridHeaderCell--controlColumn):focus-within{z-index:2;border:1px solid transparent;border-top:none;border-radius:1px;outline:none;box-shadow:0 0 0 2px rgba(21,157,141,.3)}.euiDataGridHeaderCell:not(.euiDataGridHeaderCell--controlColumn) .euiDataGridHeaderCell__sortingArrow{margin-right:4px}.euiDataGridHeaderCell:not(.euiDataGridHeaderCell--controlColumn) .euiDataGridHeaderCell__anchor{width:100%}.euiDataGridHeaderCell:not(.euiDataGridHeaderCell--controlColumn) .euiDataGridHeaderCell__button{outline:none;flex:none;align-items:center;width:100%;font-weight:700;display:flex;position:relative}.euiDataGridHeaderCell:not(.euiDataGridHeaderCell--controlColumn) .euiDataGridHeaderCell__button .euiDataGridHeaderCell__sortingArrow{flex-grow:0}.euiDataGridHeaderCell:not(.euiDataGridHeaderCell--controlColumn) .euiDataGridHeaderCell__content{white-space:nowrap;text-align:left;flex-grow:1;align-self:baseline;max-width:100%;overflow:hidden;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiDataGridHeaderCell:not(.euiDataGridHeaderCell--controlColumn) .euiDataGridHeaderCell__icon{flex-grow:0;flex-basis:auto;width:auto;padding-left:4px}.euiDataGridHeader__action--selected{font-weight:700!important}.euiDataGrid--bordersNone.euiDataGrid--bordersHorizontal .euiDataGridHeader{background:#0a121a}.euiDataGrid--headerUnderline .euiDataGridHeaderCell{border:none;border-bottom:2px solid #dfe5ef}.euiDataGrid--bordersNone.euiDataGrid--headerUnderline .euiDataGridHeaderCell{border-color:#dfe5ef;border-bottom-style:solid;border-bottom-width:2px}.euiDataGrid--headerShade .euiDataGridHeaderCell{background:#0f1a24}.euiDataGrid--headerShade.euiDataGrid--bordersAll .euiDataGridHeaderCell{border-bottom:1px solid #293847;border-left:none;border-right:1px solid #293847}.euiDataGrid--headerShade.euiDataGrid--bordersAll .euiDataGridHeaderCell:first-of-type{border-left:1px solid #293847}.euiDataGrid--headerShade.euiDataGrid--bordersHorizontal .euiDataGridHeaderCell{border-top:none;border-bottom:1px solid #293847}.euiDataGrid--bordersNone .euiDataGridHeaderCell{border:none}.euiDataGrid--borderhorizontal .euiDataGridHeaderCell{border-top:none;border-left:none;border-right:none}.euiDataGrid--fontSizeSmall .euiDataGridHeaderCell{font-size:.75rem;line-height:1.33333}.euiDataGrid--fontSizeLarge .euiDataGridHeaderCell{font-size:1rem;line-height:1.33333}.euiDataGrid--paddingSmall .euiDataGridHeaderCell{padding:4px}.euiDataGrid--paddingLarge .euiDataGridHeaderCell{padding:8px}.euiDataGrid--noControls.euiDataGrid--bordersAll .euiDataGridHeaderCell,.euiDataGrid--noControls.euiDataGrid--bordersHorizontal .euiDataGridHeaderCell{border-top:1px solid #293847}.euiDataGridRowCell.euiDataGridFooterCell{font-weight:700}.euiDataGrid--stickyFooter .euiDataGridFooter{position:-webkit-sticky;position:sticky;bottom:0}.euiDataGrid--footerOverline .euiDataGridRowCell.euiDataGridFooterCell{border-top:2px solid #293847;background:#0a121a!important;border-top-color:#dfe5ef!important}.euiDataGrid--bordersNone .euiDataGridRowCell.euiDataGridFooterCell,.euiDataGrid--bordersHorizontal .euiDataGridRowCell.euiDataGridFooterCell{border-left:none;border-right:none}.euiDataGrid--footerShade .euiDataGridRowCell.euiDataGridFooterCell{background:#0f1a24}.euiDataGridColumnResizer{cursor:ew-resize;opacity:0;z-index:2;width:16px;height:100%;position:absolute;top:0;right:-8px}.euiDataGridColumnResizer:after{content:"";background-color:#159d8d;width:3px;position:absolute;top:0;bottom:0;left:7px}.euiDataGridColumnResizer:hover,.euiDataGridColumnResizer:active{opacity:1}.euiDataGridColumnResizer:hover~.euiDataGridHeaderCell__content,.euiDataGridColumnResizer:active~.euiDataGridHeaderCell__content{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.euiDataGridHeaderCell:last-child .euiDataGridColumnResizer{width:8px;right:0}.euiDataGridHeaderCell:last-child .euiDataGridColumnResizer:after{left:auto;right:0}.euiDataGridRow{display:flex}.euiDataGridRowCell{background:#0a121a;border-bottom:1px solid #293847;border-right:1px solid #202d3a;flex:none;align-items:center;padding:6px;font-size:.875rem;line-height:1.33333;display:flex;position:relative}.euiDataGridRowCell>*{width:100%;max-width:100%}.euiDataGridRowCell.euiDataGridRowCell--firstColumn{border-left:1px solid #293847}.euiDataGridRowCell.euiDataGridRowCell--lastColumn{border-right-color:#293847}.euiDataGridRowCell:focus{z-index:2;border:1px solid transparent;border-radius:1px;outline:none;margin-top:-1px;box-shadow:0 0 0 2px rgba(21,157,141,.3)}.euiDataGridRowCell:hover .euiDataGridRowCell__expandButtonIcon,.euiDataGridRowCell:hover .euiDataGridRowCell__actionButtonIcon{animation-name:euiDataGridCellButtonSlideIn;animation-duration:90ms;animation-iteration-count:1;animation-delay:.25s;animation-fill-mode:forwards}.euiDataGridRowCell:not(:hover) .euiDataGridRowCell__expandButtonIcon,.euiDataGridRowCell.euiDataGridRowCell--open .euiDataGridRowCell__expandButtonIcon,.euiDataGridRowCell:not(:hover) .euiDataGridRowCell__actionButtonIcon,.euiDataGridRowCell.euiDataGridRowCell--open .euiDataGridRowCell__actionButtonIcon{width:12px;margin-left:6px;animation:none}.euiDataGridRowCell:focus .euiDataGridRowCell__actionButtonIcon{width:12px;margin-left:6px}.euiDataGridRowCell:not(:hover):not(:focus):not(.euiDataGridRowCell--open) .euiDataGridRowCell__expandButtonIcon,.euiDataGridRowCell:not(:hover):not(:focus):not(.euiDataGridRowCell--open) .euiDataGridRowCell__actionButtonIcon{display:none}.euiDataGridRowCell:focus:not(:first-of-type){padding-left:5px}.euiDataGridRowCell.euiDataGridRowCell--numeric,.euiDataGridRowCell.euiDataGridRowCell--currency{text-align:right}.euiDataGridRowCell.euiDataGridRowCell--uppercase{text-transform:uppercase}.euiDataGridRowCell.euiDataGridRowCell--lowercase{text-transform:lowercase}.euiDataGridRowCell.euiDataGridRowCell--capitalize{text-transform:capitalize}.euiDataGridRowCell:not(.euiDataGridRowCell--controlColumn) .euiDataGridRowCell__content,.euiDataGridRowCell:not(.euiDataGridRowCell--controlColumn) .euiDataGridRowCell__truncate,.euiDataGridRowCell:not(.euiDataGridRowCell--controlColumn).euiDataGridRowCell__truncate,.euiDataGridRowCell:not(.euiDataGridRowCell--controlColumn) .euiDataGridRowCell__expandContent{white-space:nowrap;width:100%;max-width:100%;overflow:hidden;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiDataGridRowCell__popover{scrollbar-width:thin;overflow:auto;max-width:400px!important;max-height:400px!important}.euiDataGridRowCell__popover::-webkit-scrollbar{width:16px;height:16px}.euiDataGridRowCell__popover::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiDataGridRowCell__popover::-webkit-scrollbar-corner{background-color:transparent}.euiDataGridRowCell__popover::-webkit-scrollbar-track{background-color:transparent}.euiDataGridRowCell__expand{width:100%;max-width:100%}.euiDataGridRowCell__expandFlex{align-items:center;height:100%;display:flex}.euiDataGridRowCell__expandContent{flex-grow:1}.euiDataGridRowCell__contentByHeight{flex-grow:1;height:100%}.euiDataGridRowCell__alignBaseLine{align-items:baseline}.euiDataGridRowCell__actionButtonIcon,.euiDataGridRowCell__expandButtonIcon{border-radius:2px;width:0;height:12px;transition:none;overflow:hidden}.euiDataGridRowCell__expandButtonIcon{border:none;box-shadow:none!important}.euiDataGridRowCell__expandButtonIcon-isActive{width:12px;margin-left:6px}.euiDataGridRowCell__expandButton{z-index:1;flex-grow:0;padding:6px 6px 6px 12px;display:flex;position:absolute;top:calc(.666667em + 6px);right:0;transform:translateY(-50%)}.euiDataGridRowCell__expandButton:before{content:"";z-index:1;background-image:linear-gradient(90deg,transparent 0,#0a121a 12px);width:100%;height:100%;display:block;position:absolute;top:0;right:0}.euiDataGridRowCell__expandButton>*{z-index:2}.euiDataGrid--rowHoverHighlight .euiDataGridRow:hover .euiDataGridRowCell{background-color:#2e2d25!important}.euiDataGrid--stripes .euiDataGridRowCell.euiDataGridRowCell--stripe{background:#101b25}.euiDataGrid--bordersNone .euiDataGridRowCell{border-color:transparent!important}.euiDataGrid--bordersHorizontal .euiDataGridRowCell{border-left-color:transparent;border-right-color:transparent}.euiDataGrid--fontSizeSmall .euiDataGridRowCell,.euiDataGridRowCell--fontSizeSmall{font-size:.75rem;line-height:1.33333}.euiDataGrid--fontSizeLarge .euiDataGridRowCell,.euiDataGridRowCell--fontSizeLarge{font-size:1rem;line-height:1.33333}.euiDataGrid--paddingSmall .euiDataGridRowCell{padding:4px}.euiDataGrid--paddingSmall .euiDataGridRowCell:focus:not(:first-of-type){padding-left:3px}.euiDataGridRowCell--paddingSmall{padding:4px}.euiDataGrid--paddingLarge .euiDataGridRowCell{padding:8px}.euiDataGrid--paddingLarge .euiDataGridRowCell:focus:not(:first-of-type){padding-left:7px}.euiDataGridRowCell--paddingLarge{padding:8px}@keyframes euiDataGridCellButtonSlideIn{0%{width:0;margin-left:0}to{width:12px;margin-left:6px}}.euiDataGridColumnSelector__item{padding:4px}.euiDataGridColumnSelector__item-isDragging{background:#0a121a;box-shadow:0 12px 24px rgba(0,0,0,.1),0 6px 12px rgba(0,0,0,.1),0 4px 4px rgba(0,0,0,.1),0 2px 2px rgba(0,0,0,.1)}.euiDataGridColumnSelector__columnList{scrollbar-width:thin;contain:paint;height:100%;max-height:400px;margin:0 -8px;overflow-x:hidden;overflow-y:auto;-webkit-mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%);mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%)}.euiDataGridColumnSelector__columnList::-webkit-scrollbar{width:16px;height:16px}.euiDataGridColumnSelector__columnList::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiDataGridColumnSelector__columnList::-webkit-scrollbar-corner{background-color:transparent}.euiDataGridColumnSelector__columnList::-webkit-scrollbar-track{background-color:transparent}.euiDataGridColumnSelector__columnList:focus{outline:none}.euiDataGridColumnSelector__columnList[tabindex="0"]:focus:focus-visible{outline-style:auto}.euiDataGridColumnSelector__itemLabel{font-size:.75rem;line-height:1.33333}.euiDataGridColumnSelectorPopover{min-width:192px;margin-top:-8px;transition:none!important;transform:none!important}.euiDataGridColumnSorting__item-isDragging{background:#0a121a;box-shadow:0 12px 24px rgba(0,0,0,.1),0 6px 12px rgba(0,0,0,.1),0 4px 4px rgba(0,0,0,.1),0 2px 2px rgba(0,0,0,.1)}.euiDataGridColumnSortingPopover{min-width:192px;margin-top:-8px;transition:none!important;transform:none!important}.euiDataGridColumnSorting__fieldList{scrollbar-width:thin;contain:paint;height:100%;max-height:300px;padding-top:4px;padding-bottom:4px;overflow-x:hidden;overflow-y:auto;-webkit-mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%);mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%)}.euiDataGridColumnSorting__fieldList::-webkit-scrollbar{width:16px;height:16px}.euiDataGridColumnSorting__fieldList::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiDataGridColumnSorting__fieldList::-webkit-scrollbar-corner{background-color:transparent}.euiDataGridColumnSorting__fieldList::-webkit-scrollbar-track{background-color:transparent}.euiDataGridColumnSorting__fieldList:focus{outline:none}.euiDataGridColumnSorting__fieldList[tabindex="0"]:focus:focus-visible{outline-style:auto}.euiDataGridColumnSorting__field{outline-offset:-3px;width:100%;padding:4px 8px;display:block}.euiDataGridColumnSorting__field:hover{cursor:pointer;text-decoration:underline}.euiDataGridColumnSorting__field:focus{cursor:pointer;background-color:#0e4342;text-decoration:underline}.euiDataGridColumnSorting__field:disabled{cursor:not-allowed;color:#535a62;text-decoration:none}.euiDataGridColumnSorting__orderButtons{padding-left:24px}@media only screen and (max-width:574px){.euiDataGridColumnSorting__orderButtons{padding-left:4px}}@media only screen and (min-width:575px) and (max-width:767px){.euiDataGridColumnSorting__orderButtons{padding-left:4px}}.euiDataGridColumnSorting__orderButtons .euiDataGridColumnSorting__order{border:none;min-width:200px}@media only screen and (max-width:574px){.euiDataGridColumnSorting__orderButtons .euiDataGridColumnSorting__order{min-width:unset}}@media only screen and (min-width:575px) and (max-width:767px){.euiDataGridColumnSorting__orderButtons .euiDataGridColumnSorting__order{min-width:unset}}.euiDataGridColumnSorting__orderButtons .euiDataGridColumnSorting__order button{font-size:13.5px!important}.euiDescriptionList.euiDescriptionList--row .euiDescriptionList__title{color:#dfe5ef;letter-spacing:-.02em;margin-top:16px;font-size:1rem;font-weight:600;line-height:1.33333}.euiDescriptionList.euiDescriptionList--row .euiDescriptionList__title:first-of-type{margin-top:0}.euiDescriptionList.euiDescriptionList--row .euiDescriptionList__description{font-size:.875rem;line-height:1.33333}.euiDescriptionList.euiDescriptionList--row.euiDescriptionList--center{text-align:center}.euiDescriptionList.euiDescriptionList--row.euiDescriptionList--reverse .euiDescriptionList__title{color:#dfe5ef;font-size:.875rem;font-weight:400;line-height:1.33333}.euiDescriptionList.euiDescriptionList--row.euiDescriptionList--reverse .euiDescriptionList__description{color:#dfe5ef;letter-spacing:-.02em;font-size:1rem;font-weight:600;line-height:1.33333rem}.euiDescriptionList.euiDescriptionList--row.euiDescriptionList--compressed .euiDescriptionList__title{color:#dfe5ef;letter-spacing:-.005em;font-size:.875rem;font-weight:700;line-height:1.33333}.euiDescriptionList.euiDescriptionList--row.euiDescriptionList--compressed .euiDescriptionList__description{font-size:.875rem;line-height:1.33333}.euiDescriptionList.euiDescriptionList--row.euiDescriptionList--compressed.euiDescriptionList--reverse .euiDescriptionList__title{color:#dfe5ef;font-size:.875rem;font-weight:400;line-height:1.33333}.euiDescriptionList.euiDescriptionList--row.euiDescriptionList--compressed.euiDescriptionList--reverse .euiDescriptionList__description{color:#dfe5ef;letter-spacing:-.005em;font-size:.875rem;font-weight:700;line-height:1.33333}.euiDescriptionList.euiDescriptionList--column,.euiDescriptionList.euiDescriptionList--responsiveColumn{flex-wrap:wrap;align-items:stretch;display:flex}.euiDescriptionList.euiDescriptionList--column>*,.euiDescriptionList.euiDescriptionList--responsiveColumn>*{margin-top:16px}.euiDescriptionList.euiDescriptionList--column>:first-child,.euiDescriptionList.euiDescriptionList--column>:nth-child(2),.euiDescriptionList.euiDescriptionList--responsiveColumn>:first-child,.euiDescriptionList.euiDescriptionList--responsiveColumn>:nth-child(2){margin-top:0}.euiDescriptionList.euiDescriptionList--column .euiDescriptionList__title,.euiDescriptionList.euiDescriptionList--responsiveColumn .euiDescriptionList__title{color:#dfe5ef;letter-spacing:-.02em;width:50%;padding-right:8px;font-size:1rem;font-weight:600;line-height:1.33333}.euiDescriptionList.euiDescriptionList--column .euiDescriptionList__description,.euiDescriptionList.euiDescriptionList--responsiveColumn .euiDescriptionList__description{width:50%;padding-left:8px;font-size:1rem;line-height:1.33333}.euiDescriptionList.euiDescriptionList--column.euiDescriptionList--center .euiDescriptionList__title,.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--center .euiDescriptionList__title{text-align:right}.euiDescriptionList.euiDescriptionList--column.euiDescriptionList--reverse .euiDescriptionList__title,.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--reverse .euiDescriptionList__title{color:#dfe5ef;font-size:1rem;font-weight:400;line-height:1.33333}.euiDescriptionList.euiDescriptionList--column.euiDescriptionList--reverse .euiDescriptionList__description,.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--reverse .euiDescriptionList__description{color:#dfe5ef;letter-spacing:-.02em;font-size:1rem;font-weight:600;line-height:1.33333}.euiDescriptionList.euiDescriptionList--column.euiDescriptionList--compressed .euiDescriptionList__title,.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--compressed .euiDescriptionList__title{color:#dfe5ef;letter-spacing:-.005em;font-size:.875rem;font-weight:700;line-height:1.33333}.euiDescriptionList.euiDescriptionList--column.euiDescriptionList--compressed .euiDescriptionList__description,.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--compressed .euiDescriptionList__description{font-size:.875rem;line-height:1.33333}.euiDescriptionList.euiDescriptionList--column.euiDescriptionList--compressed.euiDescriptionList--reverse .euiDescriptionList__title,.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--compressed.euiDescriptionList--reverse .euiDescriptionList__title{color:#dfe5ef;font-size:.875rem;font-weight:400;line-height:1.33333}.euiDescriptionList.euiDescriptionList--column.euiDescriptionList--compressed.euiDescriptionList--reverse .euiDescriptionList__description,.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--compressed.euiDescriptionList--reverse .euiDescriptionList__description{color:#dfe5ef;letter-spacing:-.005em;font-size:.875rem;font-weight:700;line-height:1.33333}@media only screen and (max-width:574px){.euiDescriptionList.euiDescriptionList--responsiveColumn{display:block}.euiDescriptionList.euiDescriptionList--responsiveColumn .euiDescriptionList__title,.euiDescriptionList.euiDescriptionList--responsiveColumn .euiDescriptionList__description{width:100%;padding:0}.euiDescriptionList.euiDescriptionList--responsiveColumn .euiDescriptionList__description{margin-top:0;font-size:.875rem;line-height:1.33333}.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--center .euiDescriptionList__title,.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--center .euiDescriptionList__description{text-align:center}.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--reverse .euiDescriptionList__title{font-size:.875rem;line-height:1.33333}.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--reverse .euiDescriptionList__description{color:#dfe5ef;letter-spacing:-.02em;font-size:1rem;font-weight:600;line-height:1.33333rem}}@media only screen and (min-width:575px) and (max-width:767px){.euiDescriptionList.euiDescriptionList--responsiveColumn{display:block}.euiDescriptionList.euiDescriptionList--responsiveColumn .euiDescriptionList__title,.euiDescriptionList.euiDescriptionList--responsiveColumn .euiDescriptionList__description{width:100%;padding:0}.euiDescriptionList.euiDescriptionList--responsiveColumn .euiDescriptionList__description{margin-top:0;font-size:.875rem;line-height:1.33333}.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--center .euiDescriptionList__title,.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--center .euiDescriptionList__description{text-align:center}.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--reverse .euiDescriptionList__title{font-size:.875rem;line-height:1.33333}.euiDescriptionList.euiDescriptionList--responsiveColumn.euiDescriptionList--reverse .euiDescriptionList__description{color:#dfe5ef;letter-spacing:-.02em;font-size:1rem;font-weight:600;line-height:1.33333rem}}.euiDescriptionList.euiDescriptionList--inline .euiDescriptionList__title{background:#101b25;border:1px solid #293847;border-radius:4px;margin:0 4px;padding:0 4px;font-size:.875rem;font-weight:400;line-height:1.33333;display:inline}.euiDescriptionList.euiDescriptionList--inline .euiDescriptionList__title:first-of-type{margin-left:0}.euiDescriptionList.euiDescriptionList--inline .euiDescriptionList__description{word-break:break-all;font-size:.875rem;line-height:1.33333;display:inline}.euiDescriptionList.euiDescriptionList--inline.euiDescriptionList--compressed .euiDescriptionList__title,.euiDescriptionList.euiDescriptionList--inline.euiDescriptionList--compressed .euiDescriptionList__description{font-size:.75rem;line-height:1.33333}.euiDescriptionList.euiDescriptionList--inline.euiDescriptionList--center{text-align:center}.euiDraggable.euiDraggable--isDragging{z-index:9000!important}.euiDraggable.euiDraggable--hasClone:not(.euiDraggable--isDragging){transform:none!important}.euiDraggable.euiDraggable--withoutDropAnimation{transition-duration:1ms!important}.euiDraggable:focus>.euiDraggable__item,.euiDraggable.euiDraggable--hasCustomDragHandle>.euiDraggable__item [data-react-beautiful-dnd-drag-handle]:focus{animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiDraggable .euiDraggable__item.euiDraggable__item--isDisabled{cursor:not-allowed}.euiDraggable--s{padding:2px}.euiDraggable--m{padding:4px}.euiDraggable--l{padding:8px}.euiDroppable{transition:background-color .5s}.euiDroppable.euiDroppable--isDraggingType:not(.euiDroppable--isDisabled){background-color:rgba(125,226,209,.1)}.euiDroppable.euiDroppable--isDraggingType:not(.euiDroppable--isDisabled).euiDroppable--isDraggingOver{background-color:rgba(125,226,209,.25)}.euiDroppable .euiDroppable__placeholder.euiDroppable__placeholder--isHidden{display:none!important}.euiDroppable--withPanel{background-color:#0a121a;border:1px solid #293847;border-radius:4px;flex-grow:1}.euiDroppable--withPanel.euiDroppable--withPanel--flexGrowZero{flex-grow:0}.euiDroppable--withPanel.euiDroppable--withPanel--noBorder{border:none}.euiDroppable--withPanel.euiDroppable--withPanel--hasShadow{border:1px solid #293847;box-shadow:0 2px 2px -1px rgba(0,0,0,.3),0 1px 5px -2px rgba(0,0,0,.3)}.euiDroppable--withPanel.euiDroppable--withPanel--isClickable{transition:all .15s cubic-bezier(.694,.0482,.335,1)}.euiDroppable--withPanel.euiDroppable--withPanel--isClickable:enabled{text-align:left;width:100%;display:block}.euiDroppable--withPanel.euiDroppable--withPanel--isClickable:hover,.euiDroppable--withPanel.euiDroppable--withPanel--isClickable:focus{cursor:pointer;transform:translateY(-2px);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiDroppable--withPanel.euiDroppable--withPanel--borderRadiusNone{border-radius:0}.euiDroppable--withPanel.euiDroppable--withPanel--borderRadiusMedium{border-radius:4px}.euiDroppable--withPanel.euiDroppable--withPanel--borderRadiusLarge{border-radius:8px}.euiDroppable--withPanel.euiDroppable--withPanel--borderRadiusXLarge{border-radius:16px}.euiDroppable--withPanel.euiDroppable--withPanel--transparent{background-color:transparent}.euiDroppable--withPanel.euiDroppable--withPanel--plain{background-color:#0a121a}.euiDroppable--withPanel.euiDroppable--withPanel--subdued{background-color:#172430}.euiDroppable--withPanel.euiDroppable--withPanel--accent{background-color:#52384c}.euiDroppable--withPanel.euiDroppable--withPanel--primary{background-color:#0d3c3d}.euiDroppable--withPanel.euiDroppable--withPanel--success{background-color:#2d5051}.euiDroppable--withPanel.euiDroppable--withPanel--warning{background-color:#544a37}.euiDroppable--withPanel.euiDroppable--withPanel--danger{background-color:#542b31}.euiDroppable--withPanel{border-radius:4px;box-shadow:0 6px 12px -1px rgba(0,0,0,.2),0 4px 4px -1px rgba(0,0,0,.2),0 2px 2px rgba(0,0,0,.2)}.euiDroppable--noGrow{flex-grow:0}.euiDroppable--grow{flex-grow:1}.euiDroppable--s{padding:2px}.euiDroppable--m{padding:4px}.euiDroppable--l{padding:8px}.euiEmptyPrompt{text-align:center;max-width:36em;margin:auto;padding:24px}.euiErrorBoundary{background:repeating-linear-gradient(45deg,rgba(255,102,102,.25),rgba(255,102,102,.25) 1px,rgba(255,102,102,.05) 1px,rgba(255,102,102,.05) 20px);padding:16px;overflow:auto}.euiErrorBoundary__text{background-color:#0a121a;padding:8px}.euiErrorBoundary__stack{white-space:pre-wrap}.euiExpression{word-break:break-word;font-size:.875rem;line-height:1.33333;font-family:var(--eui-code-font-family);letter-spacing:normal;text-align:left;color:#dfe5ef;border-bottom:2px solid transparent;padding:2px 0;line-height:1.5;transition:all .25s ease-in-out;display:inline-block;overflow-wrap:break-word!important;word-wrap:break-word!important}.euiExpression:focus{border-bottom-style:solid}.euiExpression+.euiExpression{margin-left:8px}.euiExpression.euiExpression--columns{border-color:transparent;border-bottom-style:solid;margin-bottom:4px}.euiExpression.euiExpression--truncate{max-width:100%}.euiExpression.euiExpression--truncate .euiExpression__description,.euiExpression.euiExpression--truncate .euiExpression__value{vertical-align:bottom;max-width:100%;display:inline-block;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiExpression-isUppercase .euiExpression__description{text-transform:uppercase}.euiExpression-isClickable{cursor:pointer;border-bottom:2px dotted #293847}.euiExpression-isClickable:hover:not(:disabled){border-bottom-style:solid;transform:translateY(-1px)}.euiExpression__icon{margin-left:4px}.euiExpression-isActive{border-bottom-style:solid}.euiExpression--columns{border-radius:4px;width:100%;padding:4px;display:flex}.euiExpression--columns.euiExpression-isClickable{background-color:#101b25}.euiExpression--columns.euiExpression-isClickable:focus .euiExpression__description,.euiExpression--columns.euiExpression-isClickable:focus .euiExpression__value,.euiExpression--columns.euiExpression-isClickable:hover:not(:disabled) .euiExpression__description,.euiExpression--columns.euiExpression-isClickable:hover:not(:disabled) .euiExpression__value{text-decoration:underline}.euiExpression--columns .euiExpression__description{text-align:right;flex-shrink:0;margin-right:8px}.euiExpression--columns .euiExpression__value{flex-grow:1}.euiExpression--columns .euiExpression__icon{margin-top:4px}.euiExpression--subdued:focus{background-color:rgba(159,166,175,.1)}.euiExpression--subdued.euiExpression-isActive{border-color:#9fa6af}.euiExpression--subdued .euiExpression__description{color:#9fa6af}.euiExpression--primary:focus{background-color:rgba(21,157,141,.1)}.euiExpression--primary.euiExpression-isActive{border-color:#159d8d}.euiExpression--primary .euiExpression__description{color:#159d8d}.euiExpression--success:focus{background-color:rgba(125,226,209,.1)}.euiExpression--success.euiExpression-isActive{border-color:#7de2d1}.euiExpression--success .euiExpression__description{color:#7de2d1}.euiExpression--secondary:focus{background-color:rgba(125,226,209,.1)}.euiExpression--secondary.euiExpression-isActive{border-color:#7de2d1}.euiExpression--secondary .euiExpression__description{color:#7de2d1}.euiExpression--warning:focus{background-color:rgba(255,206,122,.1)}.euiExpression--warning.euiExpression-isActive{border-color:#ffce7a}.euiExpression--warning .euiExpression__description{color:#ffce7a}.euiExpression--danger:focus{background-color:rgba(255,102,102,.1)}.euiExpression--danger.euiExpression-isActive{border-color:#f66}.euiExpression--danger .euiExpression__description{color:#f66}.euiExpression--accent:focus{background-color:rgba(249,144,192,.1)}.euiExpression--accent.euiExpression-isActive{border-color:#f990c0}.euiExpression--accent .euiExpression__description{color:#f990c0}.euiFacetButton{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;cursor:pointer;text-align:center;white-space:nowrap;vertical-align:middle;max-width:100%;height:40px;line-height:40px;font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;text-align:left;height:32px;font-size:.875rem;font-weight:400;line-height:1.33333;text-decoration:none;transition:all .15s ease-in;display:inline-block}.euiFacetButton:hover:not(:disabled) .euiFacetButton__text,.euiFacetButton:focus:not(:disabled) .euiFacetButton__text{text-decoration:underline}.euiFacetButton:focus{background-color:#0e4342;box-shadow:-4px 0 #0e4342,4px 0 #0e4342}.euiFacetButton:disabled{color:#535a62;pointer-events:none}.euiFacetButton:disabled .euiFacetButton__content{pointer-events:auto;cursor:not-allowed}.euiFacetButton:disabled .euiFacetButton__icon,.euiFacetButton:disabled .euiFacetButton__quantity{opacity:.5}.euiFacetButton:disabled:focus{background-color:transparent}.euiFacetButton:disabled:hover,.euiFacetButton:disabled:focus{text-decoration:none}.euiFacetButton__content{vertical-align:middle;justify-content:center;align-items:center;width:100%;height:100%;display:flex}.euiFacetButton__content .euiButtonContent__icon,.euiFacetButton__content .euiButtonContent__spinner{flex-shrink:0}.euiFacetButton__content>*+*{-webkit-margin-start:8px}.euiFacetButton__content>*+:not(:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:8px}.euiFacetButton__content>*+:not(:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:8px}.euiFacetButton__content>*+:not(:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:8px}.euiFacetButton__content>*+:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:8px}.euiFacetButton__content>*+:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:8px}.euiFacetButton__content>*+:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:8px}.euiFacetButton__content.euiButtonContent--smallIconGap>*+*{-webkit-margin-start:2px}.euiFacetButton__content.euiButtonContent--smallIconGap>*+:not(:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:2px}.euiFacetButton__content.euiButtonContent--smallIconGap>*+:not(:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:2px}.euiFacetButton__content.euiButtonContent--smallIconGap>*+:not(:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:2px}.euiFacetButton__content.euiButtonContent--smallIconGap>*+:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:2px}.euiFacetButton__content.euiButtonContent--smallIconGap>*+:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:2px}.euiFacetButton__content.euiButtonContent--smallIconGap>*+:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:2px}.euiFacetButton__content.euiButtonContent--noIconGap>*+*{-webkit-margin-start:0}.euiFacetButton__content.euiButtonContent--noIconGap>*+:not(:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:0}.euiFacetButton__content.euiButtonContent--noIconGap>*+:not(:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:0}.euiFacetButton__content.euiButtonContent--noIconGap>*+:not(:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi))){margin-left:0}.euiFacetButton__content.euiButtonContent--noIconGap>*+:-webkit-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:0}.euiFacetButton__content.euiButtonContent--noIconGap>*+:-moz-any(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:0}.euiFacetButton__content.euiButtonContent--noIconGap>*+:is(:lang(ae),:lang(ar),:lang(arc),:lang(bcc),:lang(bqi),:lang(ckb),:lang(dv),:lang(fa),:lang(glk),:lang(he),:lang(ku),:lang(mzn),:lang(nqo),:lang(pnb),:lang(ps),:lang(sd),:lang(ug),:lang(ur),:lang(yi)){margin-right:0}.euiFacetButton__text{vertical-align:middle;flex-grow:1;max-width:100%;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiFacetButton__text:after{content:attr(data-text);visibility:hidden;height:0;font-weight:700;display:block;overflow:hidden}.euiFacetButton--isSelected .euiFacetButton__text{font-weight:700}.euiFacetButton__icon{transition:all .15s ease-in}.euiFacetGroup--gutterNone .euiFacetButton{margin-top:0;margin-bottom:0}.euiFacetGroup--gutterNone.euiFacetGroup--horizontal{margin-left:-12px}.euiFacetGroup--gutterNone.euiFacetGroup--horizontal .euiFacetButton{max-width:calc(100% - 12px);margin-left:12px}.euiFacetGroup--gutterSmall .euiFacetButton{margin-top:2px;margin-bottom:2px}.euiFacetGroup--gutterSmall.euiFacetGroup--horizontal{margin-left:-16px}.euiFacetGroup--gutterSmall.euiFacetGroup--horizontal .euiFacetButton{max-width:calc(100% - 16px);margin-left:16px}.euiFacetGroup--gutterMedium .euiFacetButton{margin-top:4px;margin-bottom:4px}.euiFacetGroup--gutterMedium.euiFacetGroup--horizontal{margin-left:-20px}.euiFacetGroup--gutterMedium.euiFacetGroup--horizontal .euiFacetButton{max-width:calc(100% - 20px);margin-left:20px}.euiFacetGroup--gutterLarge .euiFacetButton{margin-top:6px;margin-bottom:6px}.euiFacetGroup--gutterLarge.euiFacetGroup--horizontal{margin-left:-24px}.euiFacetGroup--gutterLarge.euiFacetGroup--horizontal .euiFacetButton{max-width:calc(100% - 24px);margin-left:24px}.euiFilterGroup{border-right:1px solid rgba(252,254,255,.1);max-width:100%;display:inline-flex;overflow:hidden;box-shadow:0 1px 2px -1px rgba(0,0,0,.2),0 3px 3px -2px rgba(0,0,0,.2)}.euiFilterGroup>*{flex:auto;min-width:48px}.euiFilterGroup>.euiFilterButton--noGrow{flex-grow:0}.euiFilterGroup>.euiFilterButton-hasNotification{min-width:96px}.euiFilterGroup>.euiFilterButton--hasIcon{min-width:128px}.euiFilterGroup .euiPopover__anchor{display:block}.euiFilterGroup .euiPopover__anchor .euiFilterButton{width:100%}.euiFilterGroup--fullWidth{display:flex}@media only screen and (max-width:574px){.euiFilterGroup{flex-wrap:wrap}}@media only screen and (min-width:575px) and (max-width:767px){.euiFilterGroup{flex-wrap:wrap}}@media only screen and (max-width:574px){.euiFilterGroup{display:flex}.euiFilterGroup .euiFilterButton{flex-grow:1!important}}.euiFilterButton{background-color:#0e1721;border:1px solid rgba(252,254,255,.1);border-right:none;width:auto;height:40px;font-size:15.75px}.euiFilterButton:disabled{color:#535a62;pointer-events:none}.euiFilterButton:disabled .euiFilterButton__notification{opacity:.5}.euiFilterButton:hover:not(:disabled),.euiFilterButton:focus:not(:disabled){text-decoration:none}.euiFilterButton:hover:not(:disabled) .euiFilterButton__textShift,.euiFilterButton:focus:not(:disabled) .euiFilterButton__textShift{text-decoration:underline}.euiFilterButton-hasActiveFilters{font-weight:700}.euiFilterButton--hasIcon .euiButtonEmpty__content{justify-content:space-between}.euiFilterButton--withNext+.euiFilterButton{border-left:none;margin-left:-4px}.euiFilterButton-isSelected{background-color:#101b25}.euiFilterButton__text-hasNotification{align-items:center;display:flex}.euiFilterButton__notification{vertical-align:text-bottom;margin-left:8px}.euiFilterButton__textShift{min-width:48px;max-width:100%;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiFilterButton__textShift:after{content:attr(data-text);visibility:hidden;height:0;font-weight:700;display:block;overflow:hidden}.euiFilterSelectItem{text-align:left;color:#dfe5ef;outline-offset:-3px;border-color:#0d161e;border-bottom-style:solid;border-bottom-width:1px;width:100%;padding:4px 12px;font-size:.875rem;line-height:1.33333;display:block}.euiFilterSelectItem:hover{cursor:pointer;text-decoration:underline}.euiFilterSelectItem:focus{cursor:pointer;background-color:#0e4342;text-decoration:underline}.euiFilterSelectItem:disabled{cursor:not-allowed;color:#535a62;text-decoration:none}.euiFilterSelectItem:focus,.euiFilterSelectItem-isFocused{color:#159d8d;background-color:#0e4342}.euiFilterSelectItem__content{max-width:100%;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiFilterSelect__items{scrollbar-width:thin;max-height:480px;overflow-y:auto}.euiFilterSelect__items::-webkit-scrollbar{width:16px;height:16px}.euiFilterSelect__items::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiFilterSelect__items::-webkit-scrollbar-corner{background-color:transparent}.euiFilterSelect__items::-webkit-scrollbar-track{background-color:transparent}.euiFilterSelect__note{text-align:center;justify-content:space-around;align-items:center;height:64px;display:flex}.euiFilterSelect__noteContent{color:#8d98a3;font-size:15.75px}.euiFlexGroup{flex-grow:1;align-items:stretch;display:flex}.euiFlexGroup .euiFlexItem{flex-grow:1;flex-basis:0%}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiFlexGroup .euiFlexItem{min-width:1px}}.euiFlexGroup--gutterExtraSmall{margin:-2px}.euiFlexGroup--gutterExtraSmall>.euiFlexItem{margin:2px}.euiFlexGroup--gutterSmall{margin:-4px}.euiFlexGroup--gutterSmall>.euiFlexItem{margin:4px}.euiFlexGroup--gutterMedium{margin:-8px}.euiFlexGroup--gutterMedium>.euiFlexItem{margin:8px}.euiFlexGroup--gutterLarge{margin:-12px}.euiFlexGroup--gutterLarge>.euiFlexItem{margin:12px}.euiFlexGroup--gutterExtraLarge{margin:-20px}.euiFlexGroup--gutterExtraLarge>.euiFlexItem{margin:20px}.euiFlexGroup--justifyContentSpaceEvenly{justify-content:space-evenly}.euiFlexGroup--justifyContentSpaceBetween{justify-content:space-between}.euiFlexGroup--justifyContentSpaceAround{justify-content:space-around}.euiFlexGroup--justifyContentCenter{justify-content:center}.euiFlexGroup--justifyContentFlexEnd{justify-content:flex-end}.euiFlexGroup--alignItemsFlexStart{align-items:flex-start}.euiFlexGroup--alignItemsCenter{align-items:center}.euiFlexGroup--alignItemsFlexEnd{align-items:flex-end}.euiFlexGroup--alignItemsBaseline{align-items:baseline}.euiFlexGroup--directionRow{flex-direction:row}.euiFlexGroup--directionRowReverse{flex-direction:row-reverse}.euiFlexGroup--directionColumn{flex-direction:column}.euiFlexGroup--directionColumnReverse{flex-direction:column-reverse}.euiFlexGroup--wrap{flex-wrap:wrap}@media only screen and (max-width:574px){.euiFlexGroup--responsive{flex-wrap:wrap;margin-left:0;margin-right:0}}@media only screen and (min-width:575px) and (max-width:767px){.euiFlexGroup--responsive{flex-wrap:wrap;margin-left:0;margin-right:0}}.euiFlexGrid{flex-wrap:wrap;margin-bottom:0;display:flex}.euiFlexGrid>.euiFlexItem{flex-grow:0}.euiFlexGrid>.euiFlexItem.euiFlexItem--flexGrowZero{flex-grow:0!important;flex-basis:auto!important}.euiFlexGrid--directionColumn{-webkit-column-gap:0;-moz-column-gap:0;column-gap:0;display:block}.euiFlexGrid--directionColumn>.euiFlexItem{line-height:initial;display:inline-block}.euiFlexGrid--gutterNone{align-items:stretch;margin:0}.euiFlexGrid--gutterNone>.euiFlexItem{margin:0}.euiFlexGrid--gutterNone.euiFlexGrid--fourths>.euiFlexItem{flex-basis:25%}.euiFlexGrid--gutterNone.euiFlexGrid--fourths.euiFlexGrid--directionColumn{-webkit-column-count:4;-moz-column-count:4;column-count:4}.euiFlexGrid--gutterNone.euiFlexGrid--fourths.euiFlexGrid--directionColumn>.euiFlexItem{width:100%}.euiFlexGrid--gutterNone.euiFlexGrid--thirds>.euiFlexItem{flex-basis:33.3%}.euiFlexGrid--gutterNone.euiFlexGrid--thirds.euiFlexGrid--directionColumn{-webkit-column-count:3;-moz-column-count:3;column-count:3}.euiFlexGrid--gutterNone.euiFlexGrid--thirds.euiFlexGrid--directionColumn>.euiFlexItem{width:100%}.euiFlexGrid--gutterNone.euiFlexGrid--halves>.euiFlexItem{flex-basis:50%}.euiFlexGrid--gutterNone.euiFlexGrid--halves.euiFlexGrid--directionColumn{-webkit-column-count:2;-moz-column-count:2;column-count:2}.euiFlexGrid--gutterNone.euiFlexGrid--halves.euiFlexGrid--directionColumn>.euiFlexItem{width:100%}.euiFlexGrid--gutterNone.euiFlexGrid--single>.euiFlexItem{flex-basis:100%}.euiFlexGrid--gutterNone.euiFlexGrid--single.euiFlexGrid--directionColumn{-webkit-column-count:1;-moz-column-count:1;column-count:1}.euiFlexGrid--gutterNone.euiFlexGrid--single.euiFlexGrid--directionColumn>.euiFlexItem{width:100%}.euiFlexGrid--gutterSmall{align-items:stretch;margin:-4px}.euiFlexGrid--gutterSmall>.euiFlexItem{margin:4px}.euiFlexGrid--gutterSmall.euiFlexGrid--fourths>.euiFlexItem{flex-basis:calc(25% - 8px)}.euiFlexGrid--gutterSmall.euiFlexGrid--fourths.euiFlexGrid--directionColumn{-webkit-column-count:4;-moz-column-count:4;column-count:4}.euiFlexGrid--gutterSmall.euiFlexGrid--fourths.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 8px)}.euiFlexGrid--gutterSmall.euiFlexGrid--thirds>.euiFlexItem{flex-basis:calc(33.3% - 8px)}.euiFlexGrid--gutterSmall.euiFlexGrid--thirds.euiFlexGrid--directionColumn{-webkit-column-count:3;-moz-column-count:3;column-count:3}.euiFlexGrid--gutterSmall.euiFlexGrid--thirds.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 8px)}.euiFlexGrid--gutterSmall.euiFlexGrid--halves>.euiFlexItem{flex-basis:calc(50% - 8px)}.euiFlexGrid--gutterSmall.euiFlexGrid--halves.euiFlexGrid--directionColumn{-webkit-column-count:2;-moz-column-count:2;column-count:2}.euiFlexGrid--gutterSmall.euiFlexGrid--halves.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 8px)}.euiFlexGrid--gutterSmall.euiFlexGrid--single>.euiFlexItem{flex-basis:calc(100% - 8px)}.euiFlexGrid--gutterSmall.euiFlexGrid--single.euiFlexGrid--directionColumn{-webkit-column-count:1;-moz-column-count:1;column-count:1}.euiFlexGrid--gutterSmall.euiFlexGrid--single.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 8px)}.euiFlexGrid--gutterMedium{align-items:stretch;margin:-8px}.euiFlexGrid--gutterMedium>.euiFlexItem{margin:8px}.euiFlexGrid--gutterMedium.euiFlexGrid--fourths>.euiFlexItem{flex-basis:calc(25% - 16px)}.euiFlexGrid--gutterMedium.euiFlexGrid--fourths.euiFlexGrid--directionColumn{-webkit-column-count:4;-moz-column-count:4;column-count:4}.euiFlexGrid--gutterMedium.euiFlexGrid--fourths.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 16px)}.euiFlexGrid--gutterMedium.euiFlexGrid--thirds>.euiFlexItem{flex-basis:calc(33.3% - 16px)}.euiFlexGrid--gutterMedium.euiFlexGrid--thirds.euiFlexGrid--directionColumn{-webkit-column-count:3;-moz-column-count:3;column-count:3}.euiFlexGrid--gutterMedium.euiFlexGrid--thirds.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 16px)}.euiFlexGrid--gutterMedium.euiFlexGrid--halves>.euiFlexItem{flex-basis:calc(50% - 16px)}.euiFlexGrid--gutterMedium.euiFlexGrid--halves.euiFlexGrid--directionColumn{-webkit-column-count:2;-moz-column-count:2;column-count:2}.euiFlexGrid--gutterMedium.euiFlexGrid--halves.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 16px)}.euiFlexGrid--gutterMedium.euiFlexGrid--single>.euiFlexItem{flex-basis:calc(100% - 16px)}.euiFlexGrid--gutterMedium.euiFlexGrid--single.euiFlexGrid--directionColumn{-webkit-column-count:1;-moz-column-count:1;column-count:1}.euiFlexGrid--gutterMedium.euiFlexGrid--single.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 16px)}.euiFlexGrid--gutterLarge{align-items:stretch;margin:-12px}.euiFlexGrid--gutterLarge>.euiFlexItem{margin:12px}.euiFlexGrid--gutterLarge.euiFlexGrid--fourths>.euiFlexItem{flex-basis:calc(25% - 24px)}.euiFlexGrid--gutterLarge.euiFlexGrid--fourths.euiFlexGrid--directionColumn{-webkit-column-count:4;-moz-column-count:4;column-count:4}.euiFlexGrid--gutterLarge.euiFlexGrid--fourths.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 24px)}.euiFlexGrid--gutterLarge.euiFlexGrid--thirds>.euiFlexItem{flex-basis:calc(33.3% - 24px)}.euiFlexGrid--gutterLarge.euiFlexGrid--thirds.euiFlexGrid--directionColumn{-webkit-column-count:3;-moz-column-count:3;column-count:3}.euiFlexGrid--gutterLarge.euiFlexGrid--thirds.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 24px)}.euiFlexGrid--gutterLarge.euiFlexGrid--halves>.euiFlexItem{flex-basis:calc(50% - 24px)}.euiFlexGrid--gutterLarge.euiFlexGrid--halves.euiFlexGrid--directionColumn{-webkit-column-count:2;-moz-column-count:2;column-count:2}.euiFlexGrid--gutterLarge.euiFlexGrid--halves.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 24px)}.euiFlexGrid--gutterLarge.euiFlexGrid--single>.euiFlexItem{flex-basis:calc(100% - 24px)}.euiFlexGrid--gutterLarge.euiFlexGrid--single.euiFlexGrid--directionColumn{-webkit-column-count:1;-moz-column-count:1;column-count:1}.euiFlexGrid--gutterLarge.euiFlexGrid--single.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 24px)}.euiFlexGrid--gutterXLarge{align-items:stretch;margin:-16px}.euiFlexGrid--gutterXLarge>.euiFlexItem{margin:16px}.euiFlexGrid--gutterXLarge.euiFlexGrid--fourths>.euiFlexItem{flex-basis:calc(25% - 32px)}.euiFlexGrid--gutterXLarge.euiFlexGrid--fourths.euiFlexGrid--directionColumn{-webkit-column-count:4;-moz-column-count:4;column-count:4}.euiFlexGrid--gutterXLarge.euiFlexGrid--fourths.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 32px)}.euiFlexGrid--gutterXLarge.euiFlexGrid--thirds>.euiFlexItem{flex-basis:calc(33.3% - 32px)}.euiFlexGrid--gutterXLarge.euiFlexGrid--thirds.euiFlexGrid--directionColumn{-webkit-column-count:3;-moz-column-count:3;column-count:3}.euiFlexGrid--gutterXLarge.euiFlexGrid--thirds.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 32px)}.euiFlexGrid--gutterXLarge.euiFlexGrid--halves>.euiFlexItem{flex-basis:calc(50% - 32px)}.euiFlexGrid--gutterXLarge.euiFlexGrid--halves.euiFlexGrid--directionColumn{-webkit-column-count:2;-moz-column-count:2;column-count:2}.euiFlexGrid--gutterXLarge.euiFlexGrid--halves.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 32px)}.euiFlexGrid--gutterXLarge.euiFlexGrid--single>.euiFlexItem{flex-basis:calc(100% - 32px)}.euiFlexGrid--gutterXLarge.euiFlexGrid--single.euiFlexGrid--directionColumn{-webkit-column-count:1;-moz-column-count:1;column-count:1}.euiFlexGrid--gutterXLarge.euiFlexGrid--single.euiFlexGrid--directionColumn>.euiFlexItem{width:calc(100% - 32px)}@media only screen and (max-width:574px){.euiFlexGrid.euiFlexGrid--responsive{-webkit-column-count:1!important;-moz-column-count:1!important;column-count:1!important;margin-left:0!important;margin-right:0!important}}@media only screen and (min-width:575px) and (max-width:767px){.euiFlexGrid.euiFlexGrid--responsive{-webkit-column-count:1!important;-moz-column-count:1!important;column-count:1!important;margin-left:0!important;margin-right:0!important}}.euiFlexItem{flex-direction:column;display:flex}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiFlexItem{min-width:1px}}.euiFlexItem.euiFlexItem--flexGrowZero{flex-grow:0;flex-basis:auto}.euiFlexItem.euiFlexItem--flexGrow1{flex-grow:1}.euiFlexItem.euiFlexItem--flexGrow2{flex-grow:2}.euiFlexItem.euiFlexItem--flexGrow3{flex-grow:3}.euiFlexItem.euiFlexItem--flexGrow4{flex-grow:4}.euiFlexItem.euiFlexItem--flexGrow5{flex-grow:5}.euiFlexItem.euiFlexItem--flexGrow6{flex-grow:6}.euiFlexItem.euiFlexItem--flexGrow7{flex-grow:7}.euiFlexItem.euiFlexItem--flexGrow8{flex-grow:8}.euiFlexItem.euiFlexItem--flexGrow9{flex-grow:9}.euiFlexItem.euiFlexItem--flexGrow10{flex-grow:10}@media only screen and (max-width:574px){.euiFlexGroup--responsive>.euiFlexItem,.euiFlexGrid--responsive>.euiFlexItem{flex-basis:100%!important;width:100%!important;margin-bottom:16px!important;margin-left:0!important;margin-right:0!important}}@media only screen and (min-width:575px) and (max-width:767px){.euiFlexGroup--responsive>.euiFlexItem,.euiFlexGrid--responsive>.euiFlexItem{flex-basis:100%!important;width:100%!important;margin-bottom:16px!important;margin-left:0!important;margin-right:0!important}}.euiFlyout{z-index:1000;-webkit-clip-path:polygon(-50% 0,100% 0,100% 100%,-50% 100%);clip-path:polygon(-50% 0,100% 0,100% 100%,-50% 100%);background:#0a121a;border-left:1px solid #293847;flex-direction:column;align-items:stretch;height:100%;animation:.25s cubic-bezier(.694,.0482,.335,1) euiFlyout;display:flex;position:fixed;top:0;bottom:0;right:0;box-shadow:0 40px 64px rgba(0,0,0,.1),0 24px 32px rgba(0,0,0,.1),0 16px 16px rgba(0,0,0,.1),0 8px 8px rgba(0,0,0,.1),0 4px 4px rgba(0,0,0,.1),0 2px 2px rgba(0,0,0,.1)}.euiFlyout:focus{outline:none}.euiFlyout__closeButton{z-index:3;background-color:rgba(10,18,26,.9);position:absolute;top:8px;right:8px}.euiFlyout__closeButton--outside{left:0;right:auto;box-shadow:0 40px 64px rgba(0,0,0,.1),0 24px 32px rgba(0,0,0,.1),0 16px 16px rgba(0,0,0,.1),0 8px 8px rgba(0,0,0,.1),0 4px 4px rgba(0,0,0,.1),0 2px 2px rgba(0,0,0,.1);animation:none!important;transform:translate(calc(-100% - 24px))!important}.euiFlyout--left .euiFlyout__closeButton--outside{left:auto;right:0;transform:translate(calc(100% + 24px))!important}.euiFlyoutBody__banner{overflow-x:hidden}.euiFlyout--small{width:25vw;min-width:384px}.euiFlyout--small.euiFlyout--maxWidth-default{max-width:403px}.euiFlyout--medium{width:50vw;min-width:424px}.euiFlyout--medium.euiFlyout--maxWidth-default{max-width:768px}.euiFlyout--large{width:75vw;min-width:691px}.euiFlyout--large.euiFlyout--maxWidth-default{max-width:992px}.euiFlyout--paddingNone .euiFlyoutHeader{padding:0}.euiFlyout--paddingNone .euiFlyoutHeader--hasBorder{padding-bottom:0}.euiFlyout--paddingNone .euiFlyoutBody__overflowContent{padding:0}.euiFlyout--paddingNone .euiFlyoutBody__banner .euiCallOut{padding-left:0;padding-right:0}.euiFlyout--paddingNone .euiFlyoutFooter{padding:0}.euiFlyout--paddingSmall .euiFlyoutHeader{padding:8px 8px 0}.euiFlyout--paddingSmall .euiFlyoutHeader--hasBorder{padding-bottom:8px}.euiFlyout--paddingSmall .euiFlyoutBody__overflowContent{padding:8px}.euiFlyout--paddingSmall .euiFlyoutBody__banner .euiCallOut{padding-left:8px;padding-right:8px}.euiFlyout--paddingSmall .euiFlyoutFooter{padding:8px}.euiFlyout--paddingMedium .euiFlyoutHeader{padding:16px 16px 0}.euiFlyout--paddingMedium .euiFlyoutHeader--hasBorder{padding-bottom:16px}.euiFlyout--paddingMedium .euiFlyoutBody__overflowContent{padding:16px}.euiFlyout--paddingMedium .euiFlyoutBody__banner .euiCallOut{padding-left:16px;padding-right:16px}.euiFlyout--paddingMedium .euiFlyoutFooter{padding:12px 16px}.euiFlyout--paddingLarge .euiFlyoutHeader{padding:24px 24px 0}.euiFlyout--paddingLarge .euiFlyoutHeader--hasBorder{padding-bottom:24px}.euiFlyout--paddingLarge .euiFlyoutBody__overflowContent{padding:24px}.euiFlyout--paddingLarge .euiFlyoutBody__banner .euiCallOut{padding-left:24px;padding-right:24px}.euiFlyout--paddingLarge .euiFlyoutFooter{padding:16px 24px}@keyframes euiFlyout{0%{opacity:0;transform:translate(100%)}75%{opacity:1;transform:translate(0%)}}@media only screen and (max-width:574px){.euiFlyout{max-width:90vw!important}.euiFlyout--small{width:384px;min-width:0}.euiFlyout--medium{width:424px;min-width:0}.euiFlyout--large{width:691px;min-width:0}.euiFlyout__closeButton--outside{transform:translate(calc(-100% - 4px))!important}.euiFlyout--left .euiFlyout__closeButton--outside{transform:translate(calc(100% + 4px))!important}}@media only screen and (min-width:575px) and (max-width:767px){.euiFlyout{max-width:90vw!important}.euiFlyout--small{width:384px;min-width:0}.euiFlyout--medium{width:424px;min-width:0}.euiFlyout--large{width:691px;min-width:0}.euiFlyout__closeButton--outside{transform:translate(calc(-100% - 4px))!important}.euiFlyout--left .euiFlyout__closeButton--outside{transform:translate(calc(100% + 4px))!important}}.euiFlyout--left{-webkit-clip-path:polygon(0 0,150% 0,150% 100%,0 100%);clip-path:polygon(0 0,150% 0,150% 100%,0 100%);border-left:none;border-right:1px solid #293847;animation-name:euiFlyoutLeft;left:0;right:auto}@keyframes euiFlyoutLeft{0%{opacity:0;transform:translate(-100%)}75%{opacity:1;transform:translate(0%)}}.euiFlyout.euiFlyout--push{box-shadow:none;-webkit-clip-path:none;clip-path:none;z-index:999;border-left:2px solid #293847;animation-duration:0s}.euiFlyout.euiFlyout--push.euiFlyout--left{border-left:none;border-right:2px solid #293847}.euiFlyoutBody{flex-grow:1;height:100%;overflow-y:hidden}.euiFlyoutBody .euiFlyoutBody__overflow{scrollbar-width:thin;contain:paint;height:100%;overflow-x:hidden;overflow-y:auto;-webkit-mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%);mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%)}.euiFlyoutBody .euiFlyoutBody__overflow::-webkit-scrollbar{width:16px;height:16px}.euiFlyoutBody .euiFlyoutBody__overflow::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiFlyoutBody .euiFlyoutBody__overflow::-webkit-scrollbar-corner{background-color:transparent}.euiFlyoutBody .euiFlyoutBody__overflow::-webkit-scrollbar-track{background-color:transparent}.euiFlyoutBody .euiFlyoutBody__overflow:focus{outline:none}.euiFlyoutBody .euiFlyoutBody__overflow[tabindex="0"]:focus:focus-visible{outline-style:auto}.euiFlyoutBody .euiFlyoutBody__overflow.euiFlyoutBody__overflow--hasBanner{contain:paint;-webkit-mask-image:linear-gradient(red calc(100% - 7.5px),rgba(255,0,0,.1) 100%);mask-image:linear-gradient(red calc(100% - 7.5px),rgba(255,0,0,.1) 100%)}.euiFlyoutBody .euiFlyoutBody__banner .euiCallOut{border:none;border-radius:0}.euiFlyoutFooter{background:#101b25;flex-grow:0}.euiFlyoutHeader{flex-grow:0}.euiFlyoutHeader--hasBorder{border-bottom:1px solid #293847}.euiCheckbox{position:relative}.euiCheckbox .euiCheckbox__input{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;width:1px;height:1px;position:absolute;top:auto;left:-10000px;overflow:hidden}.euiCheckbox .euiCheckbox__input~.euiCheckbox__label{z-index:2;cursor:pointer;padding-left:24px;font-size:15.75px;line-height:24px;display:inline-block;position:relative}.euiCheckbox .euiCheckbox__input+.euiCheckbox__square{background:#0a121a 50% no-repeat;border:1px solid #575f66;border-radius:4px;padding:7px;transition:background-color .15s ease-in,border-color .15s ease-in;display:inline-block;position:absolute;top:3px;left:0;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiCheckbox .euiCheckbox__input:checked+.euiCheckbox__square{background-color:#159d8d;background-image:url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='10' height='8' viewBox='0 0 10 8'%3E%3Cpath d='M.375 2.625L3.375 5.625M3.375 5.625L8.625.375' fill='none' fill-rule='evenodd' stroke='rgb%2810, 18, 26%29' stroke-linecap='round' stroke-width='1.5' transform='translate(.5 1)'/%3E%3C/svg%3E");border-color:#159d8d}.euiCheckbox .euiCheckbox__input:indeterminate+.euiCheckbox__square{background-color:#159d8d;background-image:url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='6' height='6' viewBox='0 0 6 6'%3E%3Crect width='6' height='6' fill='rgb%2810, 18, 26%29' fill-rule='evenodd'/%3E%3C/svg%3E");border-color:#159d8d}.euiCheckbox .euiCheckbox__input[disabled]{cursor:not-allowed!important}.euiCheckbox .euiCheckbox__input[disabled]~.euiCheckbox__label{color:#5b6875;cursor:not-allowed!important}.euiCheckbox .euiCheckbox__input[disabled]+.euiCheckbox__square{box-shadow:none;background-color:#293847;border-color:#293847}.euiCheckbox .euiCheckbox__input:checked[disabled]+.euiCheckbox__square{box-shadow:none;background-color:#293847;background-image:url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='10' height='8' viewBox='0 0 10 8'%3E%3Cpath d='M.375 2.625L3.375 5.625M3.375 5.625L8.625.375' fill='none' fill-rule='evenodd' stroke='rgb%28169, 177, 184%29' stroke-linecap='round' stroke-width='1.5' transform='translate(.5 1)'/%3E%3C/svg%3E");border-color:#293847}.euiCheckbox .euiCheckbox__input:indeterminate[disabled]+.euiCheckbox__square{box-shadow:none;background-color:#293847;background-image:url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='6' height='6' viewBox='0 0 6 6'%3E%3Ccircle cx='8' cy='11' r='3' fill='rgb%28169, 177, 184%29' fill-rule='evenodd' transform='translate(-5 -8)'/%3E%3C/svg%3E");border-color:#293847}.euiCheckbox .euiCheckbox__input:focus+.euiCheckbox__square,.euiCheckbox .euiCheckbox__input:active:not(:disabled)+.euiCheckbox__square{border-color:#159d8d;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiCheckbox.euiCheckbox--inList,.euiCheckbox.euiCheckbox--noLabel{min-width:16px;min-height:16px}.euiCheckbox.euiCheckbox--inList .euiCheckbox__square,.euiCheckbox.euiCheckbox--noLabel .euiCheckbox__square{top:0}.euiCheckbox.euiCheckbox--inList .euiCheckbox__input,.euiCheckbox.euiCheckbox--noLabel .euiCheckbox__input{opacity:0;z-index:1;cursor:pointer;width:16px;height:16px;margin:0;position:absolute;left:0}.euiCheckboxGroup__item+.euiCheckboxGroup__item{margin-top:4px}.euiCheckboxGroup__item+.euiCheckboxGroup__item.euiCheckbox--compressed{margin-top:0}.euiDescribedFormGroup{max-width:800px}.euiDescribedFormGroup+*{margin-top:24px}.euiDescribedFormGroup.euiDescribedFormGroup--fullWidth{max-width:100%}.euiDescribedFormGroup .euiDescribedFormGroup__description{padding-top:8px}.euiDescribedFormGroup .euiDescribedFormGroup__fields{min-width:0}.euiDescribedFormGroup .euiDescribedFormGroup__fieldPadding--xxxsmall{padding-top:8.75px}.euiDescribedFormGroup .euiDescribedFormGroup__fieldPadding--xxsmall{padding-top:12.125px}.euiDescribedFormGroup .euiDescribedFormGroup__fieldPadding--xsmall{padding-top:15.5px}.euiDescribedFormGroup .euiDescribedFormGroup__fieldPadding--small{padding-top:22.25px}.euiDescribedFormGroup .euiDescribedFormGroup__fieldPadding--medium{padding-top:35.75px}.euiDescribedFormGroup .euiDescribedFormGroup__fieldPadding--large{padding-top:49.25px}@media only screen and (max-width:574px){.euiDescribedFormGroup .euiDescribedFormGroup__fields,.euiDescribedFormGroup .euiDescribedFormGroup__fields>.euiFormRow--hasEmptyLabelSpace:first-child{padding-top:0}}@media only screen and (min-width:575px) and (max-width:767px){.euiDescribedFormGroup .euiDescribedFormGroup__fields,.euiDescribedFormGroup .euiDescribedFormGroup__fields>.euiFormRow--hasEmptyLabelSpace:first-child{padding-top:0}}.euiFieldNumber{width:100%;max-width:400px;height:40px;font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border:none;border-radius:0;padding:12px;font-size:15.75px;font-weight:400;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 3px 2px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldNumber--fullWidth{max-width:100%}.euiFieldNumber--compressed{height:32px}.euiFieldNumber--inGroup{height:100%}@supports ((-moz-appearance:none)){.euiFieldNumber{transition-property:box-shadow,background-image,background-size}}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiFieldNumber{line-height:1em}}.euiFieldNumber::-webkit-input-placeholder{color:#9fa6af;opacity:1}.euiFieldNumber::placeholder{color:#9fa6af;opacity:1}.euiFieldNumber::placeholder{color:#9fa6af;opacity:1}.euiFieldNumber:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiFieldNumber:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 4px 4px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldNumber:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldNumber:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiFieldNumber:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldNumber:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldNumber[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldNumber:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldNumber:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldNumber:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldNumber:autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldNumber:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldNumber:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldNumber:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldNumber:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldNumber:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldNumber--compressed{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border-radius:2px;padding:8px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiFieldNumber--compressed{transition-property:box-shadow,background-image,background-size}}.euiFieldNumber--compressed:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiFieldNumber--compressed:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldNumber--compressed:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldNumber--compressed:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiFieldNumber--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldNumber--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldNumber--compressed[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldNumber--inGroup{border-radius:0;box-shadow:none!important}.euiFieldNumber--withIcon{padding-left:40px}.euiFieldNumber-isLoading{padding-right:40px}.euiFieldNumber-isLoading.euiFieldNumber--compressed{padding-right:32px}.euiFieldNumber--withIcon.euiFieldNumber--compressed{padding-left:32px}.euiFieldPassword{width:100%;max-width:400px;height:40px;font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border:none;border-radius:0;padding:12px 12px 12px 40px;font-size:15.75px;font-weight:400;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 3px 2px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldPassword--fullWidth{max-width:100%}.euiFieldPassword--compressed{height:32px}.euiFieldPassword--inGroup{height:100%}@supports ((-moz-appearance:none)){.euiFieldPassword{transition-property:box-shadow,background-image,background-size}}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiFieldPassword{line-height:1em}}.euiFieldPassword::-webkit-input-placeholder{color:#9fa6af;opacity:1}.euiFieldPassword::placeholder{color:#9fa6af;opacity:1}.euiFieldPassword::placeholder{color:#9fa6af;opacity:1}.euiFieldPassword:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiFieldPassword:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 4px 4px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldPassword:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldPassword:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiFieldPassword:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldPassword:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldPassword[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldPassword:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldPassword:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldPassword:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldPassword:autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldPassword:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldPassword:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldPassword:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldPassword:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldPassword:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldPassword--compressed{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border-radius:2px;padding:8px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiFieldPassword--compressed{transition-property:box-shadow,background-image,background-size}}.euiFieldPassword--compressed:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiFieldPassword--compressed:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldPassword--compressed:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldPassword--compressed:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiFieldPassword--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldPassword--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldPassword--compressed[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldPassword--inGroup{border-radius:0;box-shadow:none!important}.euiFieldPassword-isLoading{padding-right:40px}.euiFieldPassword-isLoading.euiFieldPassword--compressed{padding-right:32px}.euiFieldPassword.euiFieldPassword--compressed{padding-left:32px}.euiFieldPassword--withToggle::-ms-reveal{display:none}.euiFieldSearch{width:100%;max-width:400px;height:40px;font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;-webkit-appearance:textfield;background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border:none;border-radius:0;padding:12px 12px 12px 40px;font-size:15.75px;font-weight:400;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 3px 2px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldSearch--fullWidth{max-width:100%}.euiFieldSearch--compressed{height:32px}.euiFieldSearch--inGroup{height:100%}@supports ((-moz-appearance:none)){.euiFieldSearch{transition-property:box-shadow,background-image,background-size}}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiFieldSearch{line-height:1em}}.euiFieldSearch::-webkit-input-placeholder{color:#9fa6af;opacity:1}.euiFieldSearch::placeholder{color:#9fa6af;opacity:1}.euiFieldSearch::placeholder{color:#9fa6af;opacity:1}.euiFieldSearch:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiFieldSearch:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 4px 4px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldSearch:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldSearch:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiFieldSearch:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldSearch:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldSearch[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldSearch:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldSearch:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldSearch:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldSearch:autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldSearch:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldSearch:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldSearch:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldSearch:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldSearch:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldSearch--compressed{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border-radius:2px;padding:8px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiFieldSearch--compressed{transition-property:box-shadow,background-image,background-size}}.euiFieldSearch--compressed:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiFieldSearch--compressed:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldSearch--compressed:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldSearch--compressed:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiFieldSearch--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldSearch--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldSearch--compressed[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldSearch--inGroup{border-radius:0;box-shadow:none!important}.euiFieldSearch-isLoading{padding-right:40px}.euiFieldSearch-isLoading.euiFieldSearch--compressed{padding-right:32px}.euiFieldSearch::-webkit-search-decoration{-webkit-appearance:none}.euiFieldSearch::-webkit-search-cancel-button{-webkit-appearance:none}.euiFieldSearch::-ms-clear{display:none}.euiFieldSearch.euiFieldSearch-isClearable,.euiFieldSearch.euiFieldSearch-isLoading{padding-right:40px}.euiFieldSearch.euiFieldSearch-isLoading.euiFieldSearch-isClearable{padding-right:62px}.euiFieldSearch.euiFieldSearch--compressed{padding-left:32px}.euiFieldSearch.euiFieldSearch--compressed.euiFieldSearch-isClearable,.euiFieldSearch.euiFieldSearch--compressed.euiFieldSearch-isLoading{padding-right:32px}.euiFieldSearch.euiFieldSearch--compressed.euiFieldSearch-isLoading.euiFieldSearch-isClearable{padding-right:54px}.euiFieldText{width:100%;max-width:400px;height:40px;font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border:none;border-radius:0;padding:12px;font-size:15.75px;font-weight:400;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 3px 2px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldText--fullWidth{max-width:100%}.euiFieldText--compressed{height:32px}.euiFieldText--inGroup{height:100%}@supports ((-moz-appearance:none)){.euiFieldText{transition-property:box-shadow,background-image,background-size}}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiFieldText{line-height:1em}}.euiFieldText::-webkit-input-placeholder{color:#9fa6af;opacity:1}.euiFieldText::placeholder{color:#9fa6af;opacity:1}.euiFieldText::placeholder{color:#9fa6af;opacity:1}.euiFieldText:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiFieldText:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 4px 4px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldText:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldText:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiFieldText:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldText:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldText[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldText:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldText:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldText:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldText:autofill{-webkit-text-fill-color:#dfe5ef}.euiFieldText:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldText:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldText:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldText:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldText:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiFieldText--compressed{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border-radius:2px;padding:8px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiFieldText--compressed{transition-property:box-shadow,background-image,background-size}}.euiFieldText--compressed:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiFieldText--compressed:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldText--compressed:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldText--compressed:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiFieldText--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldText--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiFieldText--compressed[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFieldText--inGroup{border-radius:0;box-shadow:none!important}.euiFieldText--withIcon{padding-left:40px}.euiFieldText-isLoading{padding-right:40px}.euiFieldText-isLoading.euiFieldText--compressed{padding-right:32px}.euiFieldText.euiFieldText-isInvalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiFieldText--withIcon.euiFieldText--compressed{padding-left:32px}.euiFilePicker{width:100%;max-width:400px;height:40px;position:relative}.euiFilePicker--fullWidth{max-width:100%}.euiFilePicker--compressed{height:32px}.euiFilePicker--inGroup{height:100%}.euiFilePicker.euiFilePicker--large{border-radius:0;height:auto;overflow:hidden}.euiFilePicker.euiFilePicker--large.euiFilePicker--compressed{border-radius:2px}.euiFilePicker__input{opacity:0;width:100%;height:100%;position:absolute;top:0;left:0;overflow:hidden}.euiFilePicker__input:hover{cursor:pointer}.euiFilePicker__input:hover:disabled{cursor:not-allowed}.euiFilePicker__input:disabled{opacity:0}.euiFilePicker__input:disabled~.euiFilePicker__prompt{color:#5b6875}.euiFilePicker__icon{transition:transform .15s cubic-bezier(.694,.0482,.335,1);position:absolute;top:12px;left:12px}.euiFilePicker--compressed .euiFilePicker__icon{top:8px;left:8px}.euiFilePicker--large .euiFilePicker__icon{margin-bottom:16px;position:static}.euiFilePicker__prompt{pointer-events:none;background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border-radius:0;height:40px;padding:12px 12px 12px 40px;transition:box-shadow .15s ease-in,background-color .15s ease-in,background-image .15s ease-in,background-size .15s ease-in .15s;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 3px 2px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiFilePicker__prompt{transition-property:box-shadow,background-image,background-size}}.euiFilePicker--compressed .euiFilePicker__prompt{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border-radius:2px;height:32px;padding:8px 8px 8px 32px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiFilePicker--compressed .euiFilePicker__prompt{transition-property:box-shadow,background-image,background-size}}.euiFilePicker--large .euiFilePicker__prompt{flex-direction:column;justify-content:center;align-items:center;height:128px;padding:0 24px;display:flex}.euiFilePicker--large.euiFilePicker--compressed .euiFilePicker__prompt{height:104px}.euiFilePicker-isInvalid .euiFilePicker__prompt{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiFilePicker__promptText{max-width:100%;font-size:.875rem;line-height:16px;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiFilePicker:not(.euiFilePicker--large):not(.euiFilePicker-hasFiles) .euiFilePicker__promptText{color:#5b6875}.euiFilePicker__clearButton,.euiFilePicker__loadingSpinner{position:absolute;top:12px;right:12px}.euiFilePicker--compressed .euiFilePicker__clearButton,.euiFilePicker--compressed .euiFilePicker__loadingSpinner{top:8px}.euiFilePicker__clearButton{pointer-events:auto}.euiFilePicker:not(.euiFilePicker--large) .euiFilePicker__clearButton{pointer-events:all;background-color:#8d98a3;border-radius:16px;width:16px;height:16px;line-height:0}.euiFilePicker:not(.euiFilePicker--large) .euiFilePicker__clearButton:focus{animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiFilePicker:not(.euiFilePicker--large) .euiFilePicker__clearButton .euiFilePicker__clearIcon{fill:#0a121a;stroke:#0a121a;stroke-width:2px;width:8px;height:8px}.euiFilePicker--large .euiFilePicker__clearButton{position:relative;top:0;right:0}.euiFilePicker__showDrop .euiFilePicker__prompt,.euiFilePicker__input:focus+.euiFilePicker__prompt{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 4px 4px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiFilePicker--compressed .euiFilePicker__showDrop .euiFilePicker__prompt,.euiFilePicker--compressed .euiFilePicker__input:focus+.euiFilePicker__prompt{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFilePicker__input:disabled+.euiFilePicker__prompt{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFilePicker__input:disabled+.euiFilePicker__prompt::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiFilePicker__input:disabled+.euiFilePicker__prompt::placeholder{color:#5b6875;opacity:1}.euiFilePicker__input:disabled+.euiFilePicker__prompt::placeholder{color:#5b6875;opacity:1}.euiFilePicker:not(.euiFilePicker--large).euiFilePicker-isLoading .euiFilePicker__prompt,.euiFilePicker:not(.euiFilePicker--large).euiFilePicker-hasFiles .euiFilePicker__prompt{padding-right:40px}.euiFilePicker-hasFiles .euiFilePicker__promptText{color:#dfe5ef}.euiFilePicker--large .euiFilePicker__input:hover:not(:disabled)+.euiFilePicker__prompt .euiFilePicker__promptText,.euiFilePicker--large .euiFilePicker__input:focus+.euiFilePicker__prompt .euiFilePicker__promptText{text-decoration:underline}.euiFilePicker--large .euiFilePicker__input:hover:not(:disabled)+.euiFilePicker__prompt .euiFilePicker__icon,.euiFilePicker--large .euiFilePicker__input:focus+.euiFilePicker__prompt .euiFilePicker__icon{transform:scale(1.1)}.euiFilePicker--large.euiFilePicker__showDrop .euiFilePicker__prompt .euiFilePicker__promptText{text-decoration:underline}.euiFilePicker--large.euiFilePicker__showDrop .euiFilePicker__prompt .euiFilePicker__icon{transform:scale(1.1)}.euiFilePicker--large.euiFilePicker-hasFiles .euiFilePicker__promptText{font-weight:700}.euiForm__error{font-size:.875rem;line-height:1.33333;list-style:outside}.euiForm__errors{margin-bottom:16px}.euiFormControlLayout{width:100%;max-width:400px;height:40px}.euiFormControlLayout--fullWidth{max-width:100%}.euiFormControlLayout--compressed{height:32px}.euiFormControlLayout--inGroup{height:100%}.euiFormControlLayout__childrenWrapper{position:relative}.euiFormControlLayout--group{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;align-items:stretch;padding:1px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;display:flex;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 3px 2px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiFormControlLayout--group{transition-property:box-shadow,background-image,background-size}}.euiFormControlLayout--group>*,.euiFormControlLayout--group>.euiFormControlLayout>*,.euiFormControlLayout--group .euiPopover__anchor,.euiFormControlLayout--group .euiButtonEmpty,.euiFormControlLayout--group .euiText,.euiFormControlLayout--group .euiFormLabel,.euiFormControlLayout--group .euiButtonIcon{height:100%}.euiFormControlLayout--group .euiFormControlLayout__childrenWrapper{flex-grow:1;overflow:hidden}.euiFormControlLayout--group .euiFormControlLayout__prepend,.euiFormControlLayout--group .euiFormControlLayout__append{border-radius:0;flex-shrink:0;max-width:100%;height:100%;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiFormControlLayout--group .euiFormControlLayout__prepend.euiIcon,.euiFormControlLayout--group .euiFormControlLayout__prepend .euiIcon,.euiFormControlLayout--group .euiFormControlLayout__append.euiIcon,.euiFormControlLayout--group .euiFormControlLayout__append .euiIcon{background-color:#293847;border-radius:0;width:32px;padding:0 8px}.euiFormControlLayout--group .euiFormControlLayout__prepend.euiButtonIcon,.euiFormControlLayout--group .euiFormControlLayout__prepend.euiButtonEmpty,.euiFormControlLayout--group .euiFormControlLayout__prepend .euiButtonIcon,.euiFormControlLayout--group .euiFormControlLayout__prepend .euiButtonEmpty,.euiFormControlLayout--group .euiFormControlLayout__append.euiButtonIcon,.euiFormControlLayout--group .euiFormControlLayout__append.euiButtonEmpty,.euiFormControlLayout--group .euiFormControlLayout__append .euiButtonIcon,.euiFormControlLayout--group .euiFormControlLayout__append .euiButtonEmpty{transform:none!important}.euiFormControlLayout--group .euiFormControlLayout__prepend.euiButtonIcon .euiIcon,.euiFormControlLayout--group .euiFormControlLayout__prepend.euiButtonEmpty .euiIcon,.euiFormControlLayout--group .euiFormControlLayout__prepend .euiButtonIcon .euiIcon,.euiFormControlLayout--group .euiFormControlLayout__prepend .euiButtonEmpty .euiIcon,.euiFormControlLayout--group .euiFormControlLayout__append.euiButtonIcon .euiIcon,.euiFormControlLayout--group .euiFormControlLayout__append.euiButtonEmpty .euiIcon,.euiFormControlLayout--group .euiFormControlLayout__append .euiButtonIcon .euiIcon,.euiFormControlLayout--group .euiFormControlLayout__append .euiButtonEmpty .euiIcon{width:16px;padding:0;background:0 0!important}.euiFormControlLayout--group .euiFieldText.euiFormControlLayout__prepend,.euiFormControlLayout--group .euiFieldText.euiFormControlLayout__append,.euiFormControlLayout--group .euiFieldNumber.euiFormControlLayout__prepend,.euiFormControlLayout--group .euiFieldNumber.euiFormControlLayout__append,.euiFormControlLayout--group .euiFieldSearch.euiFormControlLayout__prepend,.euiFormControlLayout--group .euiFieldSearch.euiFormControlLayout__append,.euiFormControlLayout--group .euiFieldPassword.euiFormControlLayout__prepend,.euiFormControlLayout--group .euiFieldPassword.euiFormControlLayout__append,.euiFormControlLayout--group .euiSelect.euiFormControlLayout__prepend,.euiFormControlLayout--group .euiSelect.euiFormControlLayout__append{height:calc(100% + 2px);margin:-1px -1px 0 1px}.euiFormControlLayout--group .euiFieldText.euiFormControlLayout__prepend:focus,.euiFormControlLayout--group .euiFieldText.euiFormControlLayout__append:focus,.euiFormControlLayout--group .euiFieldNumber.euiFormControlLayout__prepend:focus,.euiFormControlLayout--group .euiFieldNumber.euiFormControlLayout__append:focus,.euiFormControlLayout--group .euiFieldSearch.euiFormControlLayout__prepend:focus,.euiFormControlLayout--group .euiFieldSearch.euiFormControlLayout__append:focus,.euiFormControlLayout--group .euiFieldPassword.euiFormControlLayout__prepend:focus,.euiFormControlLayout--group .euiFieldPassword.euiFormControlLayout__append:focus,.euiFormControlLayout--group .euiSelect.euiFormControlLayout__prepend:focus,.euiFormControlLayout--group .euiSelect.euiFormControlLayout__append:focus{background-position:1px -1px}.euiFormControlLayout--group .euiFieldText.euiFormControlLayout__prepend,.euiFormControlLayout--group .euiFieldNumber.euiFormControlLayout__prepend,.euiFormControlLayout--group .euiFieldSearch.euiFormControlLayout__prepend,.euiFormControlLayout--group .euiFieldPassword.euiFormControlLayout__prepend,.euiFormControlLayout--group .euiSelect.euiFormControlLayout__prepend{margin:-1px 1px 0 -1px}.euiFormControlLayout--group .euiFieldText.euiFormControlLayout__prepend:focus,.euiFormControlLayout--group .euiFieldNumber.euiFormControlLayout__prepend:focus,.euiFormControlLayout--group .euiFieldSearch.euiFormControlLayout__prepend:focus,.euiFormControlLayout--group .euiFieldPassword.euiFormControlLayout__prepend:focus,.euiFormControlLayout--group .euiSelect.euiFormControlLayout__prepend:focus{background-position:-1px -1px}.euiFormControlLayout--group .euiButtonIcon{border-radius:0;width:32px;padding:0 8px}.euiFormControlLayout--group .euiButtonIcon:not(:focus){background-color:#293847}.euiFormControlLayout--group .euiButtonIcon:focus-visible{outline-offset:-2px;outline:2px solid rgba(21,157,141,.3)}.euiFormControlLayout--group .euiToolTipAnchor>.euiIcon{background-color:#293847;border-radius:0;width:32px;height:100%;padding:0 8px}.euiFormControlLayout--group>.euiFormControlLayout__prepend,.euiFormControlLayout--group>.euiFormControlLayout__append{max-width:50%}.euiFormControlLayout--group .euiFormLabel,.euiFormControlLayout--group .euiText{background-color:#293847;padding:12px;cursor:default!important;line-height:14px!important}.euiFormControlLayout--group .euiFormLabel+:not(.euiFormControlLayout__childrenWrapper):not(input),.euiFormControlLayout--group .euiText+:not(.euiFormControlLayout__childrenWrapper):not(input),.euiFormControlLayout--group>:not(.euiFormControlLayout__childrenWrapper)+.euiFormLabel,.euiFormControlLayout--group>:not(.euiFormControlLayout__childrenWrapper)+.euiText{margin-left:-12px}.euiFormControlLayout--group .euiButtonEmpty{border-right:1px solid #31404e}.euiFormControlLayout--group .euiFormControlLayout__childrenWrapper~.euiButtonEmpty,.euiFormControlLayout--group .euiFormControlLayout__childrenWrapper~* .euiButtonEmpty{border-left:1px solid #31404e;border-right:none}.euiFormControlLayout--group.euiFormControlLayout--compressed{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border-radius:2px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;overflow:hidden;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiFormControlLayout--group.euiFormControlLayout--compressed{transition-property:box-shadow,background-image,background-size}}.euiFormControlLayout--group.euiFormControlLayout--compressed .euiFormLabel,.euiFormControlLayout--group.euiFormControlLayout--compressed .euiText{padding:8px}.euiFormControlLayout--group.euiFormControlLayout--compressed .euiFormLabel+:not(.euiFormControlLayout__childrenWrapper),.euiFormControlLayout--group.euiFormControlLayout--compressed .euiText+:not(.euiFormControlLayout__childrenWrapper),.euiFormControlLayout--group.euiFormControlLayout--compressed>:not(.euiFormControlLayout__childrenWrapper)+.euiFormLabel,.euiFormControlLayout--group.euiFormControlLayout--compressed>:not(.euiFormControlLayout__childrenWrapper)+.euiText{margin-left:-8px}.euiFormControlLayout--group.euiFormControlLayout--readOnly{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFormControlLayout--group.euiFormControlLayout--readOnly input{background-color:transparent}.euiFormControlLayoutDelimited{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;align-items:stretch;padding:1px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;display:flex;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 3px 2px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiFormControlLayoutDelimited{transition-property:box-shadow,background-image,background-size}}.euiFormControlLayoutDelimited .euiFormControlLayoutDelimited__delimeter{background-color:#0e1721}.euiFormControlLayoutDelimited>.euiFormControlLayout__childrenWrapper{align-items:center;width:100%;display:flex}.euiFormControlLayoutDelimited[class*=--compressed]{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border-radius:2px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiFormControlLayoutDelimited[class*=--compressed]{transition-property:box-shadow,background-image,background-size}}.euiFormControlLayoutDelimited[class*=--compressed] .euiFormControlLayoutDelimited__input{height:100%;padding:0 8px}.euiFormControlLayoutDelimited[class*=--compressed] .euiFormControlLayoutIcons{padding-left:8px;padding-right:8px}.euiFormControlLayoutDelimited[class*=--fullWidth] .euiFormControlLayout__childrenWrapper,.euiFormControlLayoutDelimited[class*=--fullWidth] input{width:100%;max-width:none}.euiFormControlLayoutDelimited[class*=-isDisabled]{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFormControlLayoutDelimited[class*=-isDisabled]::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiFormControlLayoutDelimited[class*=-isDisabled]::placeholder{color:#5b6875;opacity:1}.euiFormControlLayoutDelimited[class*=-isDisabled]::placeholder{color:#5b6875;opacity:1}.euiFormControlLayoutDelimited[class*=-isDisabled] .euiFormControlLayoutDelimited__delimeter{background-color:#0d161e}.euiFormControlLayoutDelimited[class*=--readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiFormControlLayoutDelimited[class*=--readOnly] input,.euiFormControlLayoutDelimited[class*=--readOnly] .euiFormControlLayoutDelimited__delimeter{background-color:rgba(10,18,26,.05)}.euiFormControlLayoutDelimited .euiFormControlLayoutIcons{flex-shrink:0;padding-left:12px;padding-right:12px;position:static}.euiFormControlLayoutDelimited .euiFormControlLayoutIcons:not(.euiFormControlLayoutIcons--right){order:-1}.euiFormControlLayoutDelimited__input{text-align:center;min-width:0;height:100%;box-shadow:none!important;border-radius:0!important}.euiFormControlLayoutDelimited[class*=--compressed] .euiFormControlLayoutDelimited__input{max-width:none}.euiFormControlLayoutDelimited__delimeter{flex:none;padding-left:6px;padding-right:6px;line-height:1!important}.euiFormControlLayoutIcons{pointer-events:none;align-items:center;display:flex;position:absolute;top:0;bottom:0;left:12px}.euiFormControlLayoutIcons>*+*{margin-left:6px}.euiFormControlLayout--compressed .euiFormControlLayoutIcons{left:8px}.euiFormControlLayoutIcons--right{left:auto;right:12px}.euiFormControlLayout--compressed .euiFormControlLayoutIcons--right{left:auto;right:8px}:disabled+.euiFormControlLayoutIcons{cursor:not-allowed;color:#5b6875}.euiFormControlLayoutClearButton{pointer-events:all;background-color:#8d98a3;border-radius:16px;width:16px;height:16px;line-height:0}.euiFormControlLayoutClearButton:focus{animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiFormControlLayoutClearButton .euiFormControlLayoutClearButton__icon{fill:#0a121a;stroke:#0a121a;stroke-width:2px;width:8px;height:8px}.euiFormControlLayoutClearButton--small{pointer-events:all;background-color:#8d98a3;border-radius:12px;width:12px;height:12px;line-height:0}.euiFormControlLayoutClearButton--small:focus{animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiFormControlLayoutClearButton--small .euiFormControlLayoutClearButton__icon{fill:#0a121a;stroke:#0a121a;stroke-width:4px;width:6px;height:6px}.euiFormControlLayoutCustomIcon{pointer-events:none;font-size:0}.euiFormControlLayoutCustomIcon--clickable{pointer-events:all;width:16px;height:16px}.euiFormControlLayoutCustomIcon--clickable .euiFormControlLayoutCustomIcon__icon{vertical-align:baseline;transform:none}.euiFormControlLayoutCustomIcon--clickable:focus{animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiFormControlLayoutCustomIcon--clickable:disabled{cursor:not-allowed;color:#5b6875}.euiFormErrorText{color:#f66;padding-top:4px;font-size:.75rem;line-height:1.33333}.euiFormLegend{color:#dfe5ef;font-size:.75rem;font-weight:600;line-height:1.33333}.euiFormLegend:not(.euiFormLegend-isHidden){margin-bottom:8px}.euiFormLegend:not(.euiFormLegend-isHidden).euiFormLegend--compressed{margin-bottom:4px}.euiFormHelpText{color:#8d98a3;padding-top:4px;font-size:.75rem;line-height:1.33333}.euiFormLabel{color:#dfe5ef;font-size:.75rem;font-weight:600;line-height:1.33333;transition:all .15s cubic-bezier(.694,.0482,.335,1);display:inline-block}.euiFormLabel.euiFormLabel-isInvalid{color:#f66}.euiFormLabel.euiFormLabel-isFocused{color:#159d8d}.euiFormLabel[for]{cursor:pointer}.euiFormRow{flex-direction:column;max-width:400px;display:flex}.euiFormRow+.euiFormRow,.euiFormRow+.euiButton{margin-top:16px}.euiFormRow--fullWidth{max-width:100%}.euiFormRow--hasEmptyLabelSpace{justify-content:center;min-height:40px;margin-top:22px;padding-bottom:0}.euiFormRow__labelWrapper{flex-wrap:wrap;justify-content:space-between;margin-bottom:4px;display:flex}.euiFormRow--horizontal{flex-direction:row;align-items:stretch}.euiFormRow--horizontal .euiFormRow__label{word-break:break-word;-webkit-hyphens:auto;-ms-hyphens:auto;hyphens:auto;max-width:100%;overflow-wrap:break-word!important;word-wrap:break-word!important}.euiFormRow--horizontal .euiFormRow__labelWrapper{width:calc(33% - 8px);margin-bottom:0;margin-right:8px;line-height:31px;display:block}.euiFormRow--horizontal .euiFormRow__fieldWrapper{width:67%}.euiFormRow--horizontal+.euiFormRow--horizontal{margin-top:8px}.euiFormRow--horizontal+.euiFormRow--horizontal.euiFormRow--hasSwitch{margin-top:12px}.euiFormRow--horizontal.euiFormRow--hasSwitch .euiFormRow__labelWrapper{width:auto;min-width:calc(33% - 8px);line-height:19px}.euiFormRow--horizontal.euiFormRow--hasSwitch .euiFormRow__fieldWrapper{width:auto}.euiFormRow--horizontal.euiFormRow--hasSwitch .euiFormRow__fieldWrapper .euiSwitch--compressed{margin-top:2px}.euiFormRow--horizontal.euiFormRow--hasSwitch+.euiFormRow--horizontal{margin-top:12px}.euiFormRow__fieldWrapperDisplayOnly{align-items:center;min-height:40px;display:flex}.euiFormRow--compressed.euiFormRow--hasEmptyLabelSpace,.euiFormRow--compressed .euiFormRow__fieldWrapperDisplayOnly{min-height:32px}.euiRadio{position:relative}.euiRadio .euiRadio__input{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;width:1px;height:1px;position:absolute;top:auto;left:-10000px;overflow:hidden}.euiRadio .euiRadio__input~.euiRadio__label{z-index:2;cursor:pointer;padding-left:24px;font-size:15.75px;line-height:24px;display:inline-block;position:relative}.euiRadio .euiRadio__input+.euiRadio__circle{background:#0a121a 50% no-repeat;border:1px solid #575f66;border-radius:14px;padding:7px;transition:background-color .15s ease-in,border-color .15s ease-in;display:inline-block;position:absolute;top:3px;left:0;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiRadio .euiRadio__input:checked+.euiRadio__circle{background-color:#159d8d;background-image:url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='6' height='6' viewBox='0 0 6 6'%3E%3Ccircle cx='8' cy='11' r='3' fill='rgb%2810, 18, 26%29' fill-rule='evenodd' transform='translate(-5 -8)'/%3E%3C/svg%3E");border-color:#159d8d}.euiRadio .euiRadio__input[disabled]{cursor:not-allowed!important}.euiRadio .euiRadio__input[disabled]~.euiRadio__label{color:#5b6875;cursor:not-allowed!important}.euiRadio .euiRadio__input[disabled]+.euiRadio__circle{box-shadow:none;background-color:#293847;border-color:#293847}.euiRadio .euiRadio__input:checked[disabled]+.euiRadio__circle{box-shadow:none;background-color:#293847;background-image:url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='6' height='6' viewBox='0 0 6 6'%3E%3Ccircle cx='8' cy='11' r='3' fill='rgb%28169, 177, 184%29' fill-rule='evenodd' transform='translate(-5 -8)'/%3E%3C/svg%3E");border-color:#293847}.euiRadio .euiRadio__input:focus+.euiRadio__circle,.euiRadio .euiRadio__input:active:not(:disabled)+.euiRadio__circle{border-color:#159d8d;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiRadio.euiRadio--inList,.euiRadio.euiRadio--noLabel{min-width:16px;min-height:16px}.euiRadio.euiRadio--inList .euiRadio__circle,.euiRadio.euiRadio--noLabel .euiRadio__circle{top:0}.euiRadio.euiRadio--inList .euiRadio__input,.euiRadio.euiRadio--noLabel .euiRadio__input{opacity:0;z-index:1;cursor:pointer;width:16px;height:16px;margin:0;position:absolute;left:0}.euiRadioGroup__item+.euiRadioGroup__item{margin-top:4px}.euiRadioGroup__item+.euiRadioGroup__item.euiRadio--compressed{margin-top:0}.euiRange__horizontalSpacer{width:16px}.euiRange__slimHorizontalSpacer{width:8px}.euiRangeDraggable{pointer-events:none;z-index:2;height:20px;position:absolute;top:10px}.euiRangeDraggable.euiRangeDraggable--compressed{height:16px;top:8px}.euiRangeDraggable.euiRangeDraggable--hasTicks{top:0}.euiRangeDraggable .euiRangeDraggle__inner{position:absolute;top:0;bottom:0;left:16px;right:16px}.euiRangeDraggable:not(.euiRangeDraggable--disabled) .euiRangeDraggle__inner{cursor:-webkit-grab;cursor:grab;pointer-events:all}.euiRangeDraggable:not(.euiRangeDraggable--disabled) .euiRangeDraggle__inner:active{cursor:-webkit-grabbing;cursor:grabbing}.euiRangeHighlight{width:100%;position:absolute;top:calc(50% - 2px);left:0;overflow:hidden}.euiRangeHighlight__progress{background-color:#8d98a3;border-radius:4px;height:4px}.euiRangeHighlight__progress--hasFocus{background-color:#159d8d}.euiRangeHighlight--hasTicks{top:8px}.euiRangeHighlight--hasTicks.euiRangeHighlight--compressed{top:6px}.euiRangeInput{width:auto;min-width:64px}.euiRange__popover .euiRangeInput{width:100%;margin:0!important}.euiRangeLabel--min,.euiRangeLabel--max{font-size:13.5px}.euiRangeLabel--min{margin-right:8px}.euiRangeLabel--max{margin-left:8px}.euiRangeLabel--isDisabled{opacity:.25}.euiRangeLevels{justify-content:stretch;display:flex;position:absolute;top:22px;left:0;right:0}.euiRangeLevels--hasTicks{top:12px}.euiRangeLevels--compressed{top:18px}.euiRangeLevels--compressed.euiRangeLevels--hasTicks{top:10px}.euiRangeLevel{border-radius:6px;height:6px;margin:2px;display:block}.euiRangeLevel--primary{background-color:rgba(21,157,141,.3)}.euiRangeLevel--success{background-color:rgba(125,226,209,.3)}.euiRangeLevel--warning{background-color:rgba(255,206,122,.3)}.euiRangeLevel--danger{background-color:rgba(255,102,102,.3)}.euiRangeSlider{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;cursor:pointer;z-index:1;background:0 0;width:100%;height:40px;position:relative}.euiRangeSlider:disabled{cursor:not-allowed}.euiRangeSlider:disabled::-webkit-slider-thumb{cursor:not-allowed;box-shadow:none;background-color:#8d98a3;border-color:#8d98a3}.euiRangeSlider:disabled::-moz-range-thumb{cursor:not-allowed;box-shadow:none;background-color:#8d98a3;border-color:#8d98a3}.euiRangeSlider:disabled::-ms-thumb{cursor:not-allowed;box-shadow:none;background-color:#8d98a3;border-color:#8d98a3}.euiRangeSlider:disabled~.euiRangeThumb{cursor:not-allowed;box-shadow:none;background-color:#8d98a3;border-color:#8d98a3}.euiRangeSlider::-webkit-slider-thumb{cursor:pointer;background:#0a121a 50% no-repeat;border:1px solid #8d98a3;border-radius:14px;width:16px;height:16px;padding:0;transition:background-color .15s ease-in,border-color .15s ease-in;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiRangeSlider::-moz-range-thumb{cursor:pointer;background:#0a121a 50% no-repeat;border:1px solid #8d98a3;border-radius:14px;width:16px;height:16px;padding:0;transition:background-color .15s ease-in,border-color .15s ease-in;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiRangeSlider::-ms-thumb{cursor:pointer;background:#0a121a 50% no-repeat;border:1px solid #8d98a3;border-radius:14px;width:16px;height:16px;padding:0;transition:background-color .15s ease-in,border-color .15s ease-in;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiRangeSlider::-webkit-slider-runnable-track{background:#8d98a3;border:0 solid #8d98a3;border-radius:4px;width:100%;height:2px;transition:all .25s ease-in}.euiRangeSlider::-moz-range-track{background:#8d98a3;border:0 solid #8d98a3;border-radius:4px;width:100%;height:2px;transition:all .25s ease-in}.euiRangeSlider::-ms-fill-lower{background:#8d98a3;border:0 solid #8d98a3;border-radius:4px;width:100%;height:2px;transition:all .25s ease-in}.euiRangeSlider::-ms-fill-upper{background:#8d98a3;border:0 solid #8d98a3;border-radius:4px;width:100%;height:2px;transition:all .25s ease-in}.euiRangeSlider:focus{outline:none}.euiRangeSlider:focus-visible::-webkit-slider-thumb{box-shadow:0 0 0 3px rgba(21,157,141,.3)}.euiRangeSlider--hasFocus::-webkit-slider-thumb{box-shadow:0 0 0 3px rgba(21,157,141,.3)}.euiRangeSlider:focus-visible::-moz-range-thumb{box-shadow:0 0 0 3px rgba(21,157,141,.3)}.euiRangeSlider--hasFocus::-moz-range-thumb{box-shadow:0 0 0 3px rgba(21,157,141,.3)}.euiRangeSlider:focus-visible::-ms-thumb{box-shadow:0 0 0 3px rgba(21,157,141,.3)}.euiRangeSlider--hasFocus::-ms-thumb{box-shadow:0 0 0 3px rgba(21,157,141,.3)}.euiRangeSlider--hasFocus~.euiRangeThumb{border-color:#8d98a3}.euiRangeSlider:focus-visible~.euiRangeThumb{border-color:#8d98a3}.euiRangeSlider:focus-visible::-webkit-slider-runnable-track{background-color:#159d8d;border-color:#159d8d}.euiRangeSlider--hasFocus::-webkit-slider-runnable-track{background-color:#159d8d;border-color:#159d8d}.euiRangeSlider:focus-visible::-moz-range-track{background-color:#159d8d;border-color:#159d8d}.euiRangeSlider--hasFocus::-moz-range-track{background-color:#159d8d;border-color:#159d8d}.euiRangeSlider:focus-visible::-ms-fill-lower{background-color:#159d8d;border-color:#159d8d}.euiRangeSlider--hasFocus::-ms-fill-lower{background-color:#159d8d;border-color:#159d8d}.euiRangeSlider:focus-visible::-ms-fill-upper{background-color:#159d8d;border-color:#159d8d}.euiRangeSlider--hasFocus::-ms-fill-upper{background-color:#159d8d;border-color:#159d8d}.euiRangeSlider--hasFocus~.euiRangeHighlight .euiRangeHighlight__progress{background-color:#159d8d}.euiRangeSlider:focus-visible~.euiRangeHighlight .euiRangeHighlight__progress{background-color:#159d8d}.euiRangeSlider--hasFocus~.euiRangeTooltip .euiRangeTooltip__value{box-shadow:0 6px 12px -1px rgba(0,0,0,.2),0 4px 4px -1px rgba(0,0,0,.2),0 2px 2px rgba(0,0,0,.2)}.euiRangeSlider:focus-visible~.euiRangeTooltip .euiRangeTooltip__value{box-shadow:0 6px 12px -1px rgba(0,0,0,.2),0 4px 4px -1px rgba(0,0,0,.2),0 2px 2px rgba(0,0,0,.2)}.euiRangeSlider--hasFocus~.euiRangeTooltip .euiRangeTooltip__value.euiRangeTooltip__value--right,.euiRangeSlider--hasFocus~.euiRangeTooltip .euiRangeTooltip__value.euiRangeTooltip__value--left{transform:translate(0)translateY(-50%)scale(1.1)}.euiRangeSlider:focus-visible~.euiRangeTooltip .euiRangeTooltip__value.euiRangeTooltip__value--right{transform:translate(0)translateY(-50%)scale(1.1)}.euiRangeSlider:focus-visible~.euiRangeTooltip .euiRangeTooltip__value.euiRangeTooltip__value--left{transform:translate(0)translateY(-50%)scale(1.1)}.euiRangeSlider::-webkit-slider-thumb{-webkit-appearance:none;margin-top:-7px}.euiRangeSlider::-ms-thumb{margin-top:0}.euiRangeSlider::-moz-focus-outer{border:none}.euiRangeSlider::-ms-track{color:transparent;background:0 0;border-width:8px 0;border-color:transparent;width:100%;height:2px;transition:all .25s ease-in}.euiRangeSlider--hasTicks{height:20px}.euiRangeSlider--compressed{height:32px}.euiRangeSlider--compressed.euiRangeSlider--hasTicks{height:16px}.euiRangeSlider--hasRange::-webkit-slider-runnable-track{background-color:rgba(141,152,163,.4);border-color:rgba(141,152,163,.4)}.euiRangeSlider--hasRange::-moz-range-track{background-color:rgba(141,152,163,.4);border-color:rgba(141,152,163,.4)}.euiRangeSlider--hasRange::-ms-fill-lower{background-color:rgba(141,152,163,.4);border-color:rgba(141,152,163,.4)}.euiRangeSlider--hasRange::-ms-fill-upper{background-color:rgba(141,152,163,.4);border-color:rgba(141,152,163,.4)}.euiRangeThumb{cursor:pointer;content:"";pointer-events:none;z-index:1;background:#0a121a 50% no-repeat;border:1px solid #8d98a3;border-radius:14px;width:16px;height:16px;margin-top:-8px;padding:0;transition:background-color .15s ease-in,border-color .15s ease-in;position:absolute;top:50%;left:0;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiRangeThumb:focus{border-color:#159d8d;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiRangeThumb--hasTicks{top:25%}.euiRangeTicks{display:flex;position:absolute;top:8px;left:0;right:0}.euiRangeTicks--isCustom{left:2px;right:2px}.euiRangeTick{text-overflow:ellipsis;padding-top:16px;font-size:13.5px;position:absolute;overflow-x:hidden;transform:translate(-50%)}.euiRangeTick:not(.euiRangeTick--hasTickMark):before{content:"";background-color:#8d98a3;border-radius:100%;width:4px;height:4px;position:absolute;top:0;left:calc(50% - 2px)}.euiRangeTick .euiRangeTick__pseudo{background-color:#8d98a3;border-radius:100%;width:4px;height:4px;position:absolute;top:0}.euiRangeTick--isCustom{overflow-x:visible}.euiRangeTick--isMin,.euiRangeTick--isMax{transform:translate(0)}.euiRangeTick--isMin .euiRangeTick__pseudo{left:0}.euiRangeTick--isMax .euiRangeTick__pseudo{right:0}.euiRangeTick:enabled:hover,.euiRangeTick:focus,.euiRangeTick--selected{color:#159d8d}.euiRangeTick--selected{font-weight:500}.euiRangeTick:disabled{cursor:not-allowed}.euiRangeTicks--compressed{top:6px}.euiRangeTicks--compressed .euiRangeTick{padding-top:14px}.euiRangeTick__label{pointer-events:none}.euiRangeTooltip{pointer-events:none;z-index:2;width:calc(100% - 16px);margin-left:8px;display:block;position:absolute;top:0;bottom:0;left:0}.euiRangeTooltip__value{color:#fcfeff;background-color:#293847;border:1px solid #293847;border-radius:4px;max-width:256px;padding:2px 8px;font-size:.875rem;line-height:1.33333;transition:box-shadow .25s cubic-bezier(.694,.0482,.335,1),transform .25s cubic-bezier(.694,.0482,.335,1);position:absolute;top:50%}.euiRangeTooltip__value:after,.euiRangeTooltip__value:before{content:"";transform-origin:50%;background-color:#293847;border-radius:2px;width:12px;height:12px;position:absolute;bottom:-6px;left:50%}.euiRangeTooltip__value:before{background-color:#293847}.euiRangeTooltip__value.euiRangeTooltip__value--right{margin-left:24px}.euiRangeTooltip__value.euiRangeTooltip__value--right:before,.euiRangeTooltip__value.euiRangeTooltip__value--right:after{left:-5px}.euiRangeTooltip__value.euiRangeTooltip__value--right:before{margin-left:-1px}.euiRangeTooltip__value.euiRangeTooltip__value--left{margin-right:24px}.euiRangeTooltip__value.euiRangeTooltip__value--left:before,.euiRangeTooltip__value.euiRangeTooltip__value--left:after{left:auto;right:-5px}.euiRangeTooltip__value.euiRangeTooltip__value--left:before{margin-right:-1px}.euiRangeTooltip__value.euiRangeTooltip__value--right,.euiRangeTooltip__value.euiRangeTooltip__value--left{transform:translate(0)translateY(-50%)}.euiRangeTooltip__value.euiRangeTooltip__value--right:before,.euiRangeTooltip__value.euiRangeTooltip__value--right:after,.euiRangeTooltip__value.euiRangeTooltip__value--left:before,.euiRangeTooltip__value.euiRangeTooltip__value--left:after{bottom:50%;transform:translateY(50%)rotate(45deg)}.euiRangeTooltip__value--hasTicks{top:10px}.euiRangeTooltip--compressed .euiRangeTooltip__value--hasTicks{top:8px}.euiRangeTrack{flex-grow:1;align-self:flex-start;height:100%;position:relative}.euiRangeTrack--hasTicks{margin-left:1em;margin-right:1em}.euiRangeTrack--disabled{opacity:.25}.euiRangeWrapper{align-items:center;width:100%;max-width:400px;height:40px;display:flex}.euiRangeWrapper--fullWidth{max-width:100%}.euiRangeWrapper--compressed{height:32px}.euiRangeWrapper--inGroup{height:100%}.euiRangeWrapper>.euiFormControlLayout{width:auto}.euiRangeWrapper>.euiFormControlLayout.euiFormControlLayout--group{flex-shrink:0}.euiDualRange__slider::-webkit-slider-thumb{visibility:hidden}.euiDualRange__slider::-moz-range-thumb{visibility:hidden}.euiDualRange__slider::-ms-thumb{visibility:hidden}.euiSelect{width:100%;max-width:400px;height:40px;font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border:none;border-radius:0;padding:0 40px 0 12px;font-size:15.75px;font-weight:400;line-height:40px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 3px 2px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiSelect--fullWidth{max-width:100%}.euiSelect--compressed{height:32px}.euiSelect--inGroup{height:100%}@supports ((-moz-appearance:none)){.euiSelect{transition-property:box-shadow,background-image,background-size}}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiSelect{line-height:1em}}.euiSelect::-webkit-input-placeholder{color:#9fa6af;opacity:1}.euiSelect::placeholder{color:#9fa6af;opacity:1}.euiSelect::placeholder{color:#9fa6af;opacity:1}.euiSelect:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiSelect:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 4px 4px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiSelect:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiSelect:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiSelect:disabled::placeholder{color:#5b6875;opacity:1}.euiSelect:disabled::placeholder{color:#5b6875;opacity:1}.euiSelect[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiSelect:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiSelect:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiSelect:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiSelect:autofill{-webkit-text-fill-color:#dfe5ef}.euiSelect:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiSelect:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiSelect:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiSelect:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiSelect:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiSelect--compressed{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border-radius:2px;padding:8px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiSelect--compressed{transition-property:box-shadow,background-image,background-size}}.euiSelect--compressed:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiSelect--compressed:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiSelect--compressed:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiSelect--compressed:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiSelect--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiSelect--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiSelect--compressed[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiSelect--inGroup{border-radius:0;box-shadow:none!important}.euiSelect-isLoading{padding-right:62px}.euiSelect-isLoading.euiSelect--compressed{padding-right:54px}.euiSelect--compressed{padding-top:0;padding-bottom:0;padding-right:32px;line-height:32px}.euiSelect--inGroup{line-height:38px}.euiSelect--inGroup.euiSelect--compressed{line-height:30px}.euiSelect::-ms-expand{display:none}.euiSelect:focus::-ms-value{color:#dfe5ef;background:0 0}.euiSelect:-moz-focusring{color:transparent;text-shadow:0 0 #dfe5ef}.euiSuperSelect__listbox{scrollbar-width:thin;max-height:300px;overflow-x:hidden;overflow-y:auto}.euiSuperSelect__listbox::-webkit-scrollbar{width:16px;height:16px}.euiSuperSelect__listbox::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiSuperSelect__listbox::-webkit-scrollbar-corner{background-color:transparent}.euiSuperSelect__listbox::-webkit-scrollbar-track{background-color:transparent}.euiSuperSelect__item{padding:8px;font-size:.875rem;line-height:1.33333}.euiSuperSelect__item:hover{cursor:pointer;text-decoration:underline}.euiSuperSelect__item:focus{cursor:pointer;background-color:#0e4342;text-decoration:underline}.euiSuperSelect__item:disabled{cursor:not-allowed;color:#535a62;text-decoration:none}.euiSuperSelect__item--hasDividers:not(:last-of-type){border-bottom:1px solid #293847}.euiSuperSelectControl{width:100%;max-width:400px;height:40px;font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;text-align:left;text-overflow:ellipsis;white-space:nowrap;background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border:none;border-radius:0;padding:0 40px 0 12px;font-size:15.75px;font-weight:400;line-height:40px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;display:block;overflow:hidden;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 3px 2px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiSuperSelectControl--fullWidth{max-width:100%}.euiSuperSelectControl--compressed{height:32px}.euiSuperSelectControl--inGroup{height:100%}@supports ((-moz-appearance:none)){.euiSuperSelectControl{transition-property:box-shadow,background-image,background-size}}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiSuperSelectControl{line-height:1em}}.euiSuperSelectControl::-webkit-input-placeholder{color:#9fa6af;opacity:1}.euiSuperSelectControl::placeholder{color:#9fa6af;opacity:1}.euiSuperSelectControl::placeholder{color:#9fa6af;opacity:1}.euiSuperSelectControl:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiSuperSelectControl:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 4px 4px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiSuperSelectControl:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiSuperSelectControl:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiSuperSelectControl:disabled::placeholder{color:#5b6875;opacity:1}.euiSuperSelectControl:disabled::placeholder{color:#5b6875;opacity:1}.euiSuperSelectControl[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiSuperSelectControl:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiSuperSelectControl:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiSuperSelectControl:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiSuperSelectControl:autofill{-webkit-text-fill-color:#dfe5ef}.euiSuperSelectControl:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiSuperSelectControl:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiSuperSelectControl:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiSuperSelectControl:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiSuperSelectControl:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiSuperSelectControl--compressed{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border-radius:2px;padding:8px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiSuperSelectControl--compressed{transition-property:box-shadow,background-image,background-size}}.euiSuperSelectControl--compressed:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiSuperSelectControl--compressed:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiSuperSelectControl--compressed:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiSuperSelectControl--compressed:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiSuperSelectControl--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiSuperSelectControl--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiSuperSelectControl--compressed[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiSuperSelectControl--inGroup{border-radius:0;box-shadow:none!important}.euiSuperSelectControl-isLoading{padding-right:62px}.euiSuperSelectControl-isLoading.euiSuperSelectControl--compressed{padding-right:54px}.euiSuperSelectControl-isInvalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiSuperSelectControl--compressed{padding-top:0;padding-bottom:0;padding-right:32px;line-height:32px}.euiSuperSelectControl.euiSuperSelect--isOpen__button{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 4px 4px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiSwitch{align-items:flex-start;min-height:20px;display:inline-flex;position:relative}.euiSwitch .euiSwitch__label{cursor:pointer;vertical-align:middle;padding-left:8px;font-size:15.75px;line-height:20px;display:inline-block}.euiSwitch .euiSwitch__button{flex-shrink:0;line-height:0}.euiSwitch .euiSwitch__button:focus .euiSwitch__track{border-color:#159d8d;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiSwitch .euiSwitch__button:disabled:hover,.euiSwitch .euiSwitch__button:disabled~.euiSwitch__label:hover{cursor:not-allowed}.euiSwitch .euiSwitch__button:disabled .euiSwitch__body{background-color:rgba(91,104,117,.7)}.euiSwitch .euiSwitch__button:disabled .euiSwitch__thumb{box-shadow:none;background-color:rgba(91,104,117,.7);border-color:#293847}.euiSwitch .euiSwitch__button:disabled .euiSwitch__icon{fill:#a9b1b8}.euiSwitch .euiSwitch__button:disabled+.euiSwitch__label{color:#5b6875}.euiSwitch .euiSwitch__button[aria-checked=false] .euiSwitch__body{background-color:rgba(91,104,117,.7)}.euiSwitch .euiSwitch__button[aria-checked=false] .euiSwitch__thumb{left:0}.euiSwitch .euiSwitch__button[aria-checked=false] .euiSwitch__icon{right:-8px}.euiSwitch .euiSwitch__button[aria-checked=false] .euiSwitch__icon.euiSwitch__icon--checked{left:-34px;right:auto}.euiSwitch .euiSwitch__body{pointer-events:none;vertical-align:middle;border-radius:20px;width:44px;height:20px;display:inline-block;position:relative}.euiSwitch .euiSwitch__thumb{background:#0a121a 50% no-repeat;border:1px solid #575f66;border-radius:18px;padding:9px;transition:border-color .25s cubic-bezier(.34,1.61,.7,1),background-color .25s cubic-bezier(.34,1.61,.7,1),left .25s cubic-bezier(.34,1.61,.7,1),transform .25s cubic-bezier(.34,1.61,.7,1);display:inline-block;position:absolute;left:24px;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch .euiSwitch__track{border-radius:20px;position:absolute;top:0;bottom:0;left:0;right:0;overflow:hidden}.euiSwitch .euiSwitch__icon{fill:#dfe5ef;width:42px;height:16px;transition:left .25s cubic-bezier(.34,1.61,.7,1),right .25s cubic-bezier(.34,1.61,.7,1);position:absolute;top:2px;bottom:0;right:-34px}.euiSwitch .euiSwitch__icon--checked{fill:#0a121a;left:-8px;right:auto}.euiSwitch:hover .euiSwitch__button:not(:disabled) .euiSwitch__thumb{transform:scale(1.05)}.euiSwitch:hover .euiSwitch__button:active .euiSwitch__thumb{transform:scale(.95)}.euiSwitch.euiSwitch--compressed{min-height:16px}.euiSwitch.euiSwitch--compressed .euiSwitch__label{line-height:16px}.euiSwitch.euiSwitch--compressed .euiSwitch__body{border-radius:16px;width:28px;height:16px}.euiSwitch.euiSwitch--compressed .euiSwitch__thumb{background:#0a121a 50% no-repeat;border:1px solid #575f66;border-radius:12px;padding:6px;transition:border-color .25s cubic-bezier(.34,1.61,.7,1),background-color .25s cubic-bezier(.34,1.61,.7,1),left .25s cubic-bezier(.34,1.61,.7,1),transform .25s cubic-bezier(.34,1.61,.7,1);top:1px;left:13px;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch.euiSwitch--compressed .euiSwitch__track{border-radius:16px}.euiSwitch.euiSwitch--mini{min-height:10px}.euiSwitch.euiSwitch--mini .euiSwitch__label{font-size:13.5px;line-height:10px}.euiSwitch.euiSwitch--mini .euiSwitch__body{border-radius:10px;width:22px;height:10px}.euiSwitch.euiSwitch--mini .euiSwitch__thumb{background:#0a121a 50% no-repeat;border:1px solid #575f66;border-radius:6px;padding:3px;transition:border-color .25s cubic-bezier(.34,1.61,.7,1),background-color .25s cubic-bezier(.34,1.61,.7,1),left .25s cubic-bezier(.34,1.61,.7,1),transform .25s cubic-bezier(.34,1.61,.7,1);top:1px;left:13px;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch.euiSwitch--mini .euiSwitch__track{border-radius:10px}.euiSwitch.euiSwitch--compressed .euiSwitch__button[aria-checked=false] .euiSwitch__thumb,.euiSwitch.euiSwitch--mini .euiSwitch__button[aria-checked=false] .euiSwitch__thumb{left:1px}.euiSwitch.euiSwitch--compressed .euiSwitch__button[aria-checked=false] .euiSwitch__thumb,.euiSwitch.euiSwitch--compressed .euiSwitch__button[aria-checked=true]:disabled .euiSwitch__thumb,.euiSwitch.euiSwitch--mini .euiSwitch__button[aria-checked=false] .euiSwitch__thumb,.euiSwitch.euiSwitch--mini .euiSwitch__button[aria-checked=true]:disabled .euiSwitch__thumb{border-color:#575f66}.euiSwitch.euiSwitch--compressed .euiSwitch__button[aria-checked=true] .euiSwitch__thumb,.euiSwitch.euiSwitch--mini .euiSwitch__button[aria-checked=true] .euiSwitch__thumb{border-color:#159d8d}.euiSwitch.euiSwitch--base{cursor:pointer;vertical-align:middle;border:1px solid transparent;border-radius:4px;align-items:stretch;height:40px;padding:0 12px;line-height:40px}.euiSwitch.euiSwitch--base .euiSwitch__label{line-height:38px!important}.euiSwitch.euiSwitch--base.euiSwitch--compressed,.euiSwitch.euiSwitch--base.euiSwitch--mini{height:32px;line-height:32px}.euiSwitch.euiSwitch--base.euiSwitch--compressed .euiSwitch__label,.euiSwitch.euiSwitch--base.euiSwitch--mini .euiSwitch__label{line-height:30px!important}.euiSwitch.euiSwitch--base.euiSwitch-isDisabled{cursor:not-allowed;border-color:#4a515a}.euiSwitch.euiSwitch--base.euiSwitch-isDisabled:hover,.euiSwitch.euiSwitch--base.euiSwitch-isDisabled:focus{box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch.euiSwitch--base.euiSwitch-isDisabled:focus-within{box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--primary.euiSwitch--base{color:#159d8d;border-color:#159d8d;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}@media screen and (prefers-reduced-motion:no-preference){.euiSwitch--primary.euiSwitch--base{transition:background .25s ease-in-out}}.euiSwitch--primary.euiSwitch--base:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--primary.euiSwitch--base:not([class*=isDisabled]):hover,.euiSwitch--primary.euiSwitch--base:not([class*=isDisabled]):focus{background-color:rgba(21,157,141,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--primary.euiSwitch--base:not([class*=isDisabled]):focus-within{background-color:rgba(21,157,141,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--primary.euiSwitch--base:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(21,157,141,.15)}.euiSwitch--primary .euiSwitch__body{background-color:#159d8d}.euiSwitch--primary.euiSwitch--compressed .euiSwitch__button[aria-checked=true] .euiSwitch__thumb,.euiSwitch--primary.euiSwitch--mini .euiSwitch__button[aria-checked=true] .euiSwitch__thumb{border-color:#159d8d}.euiSwitch--accent.euiSwitch--base{color:#f990c0;border-color:#f990c0;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}@media screen and (prefers-reduced-motion:no-preference){.euiSwitch--accent.euiSwitch--base{transition:background .25s ease-in-out}}.euiSwitch--accent.euiSwitch--base:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--accent.euiSwitch--base:not([class*=isDisabled]):hover,.euiSwitch--accent.euiSwitch--base:not([class*=isDisabled]):focus{background-color:rgba(249,144,192,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--accent.euiSwitch--base:not([class*=isDisabled]):focus-within{background-color:rgba(249,144,192,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--accent.euiSwitch--base:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(249,144,192,.15)}.euiSwitch--accent .euiSwitch__body{background-color:#f990c0}.euiSwitch--accent.euiSwitch--compressed .euiSwitch__button[aria-checked=true] .euiSwitch__thumb,.euiSwitch--accent.euiSwitch--mini .euiSwitch__button[aria-checked=true] .euiSwitch__thumb{border-color:#f990c0}.euiSwitch--secondary.euiSwitch--base{color:#7de2d1;border-color:#7de2d1;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}@media screen and (prefers-reduced-motion:no-preference){.euiSwitch--secondary.euiSwitch--base{transition:background .25s ease-in-out}}.euiSwitch--secondary.euiSwitch--base:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--secondary.euiSwitch--base:not([class*=isDisabled]):hover,.euiSwitch--secondary.euiSwitch--base:not([class*=isDisabled]):focus{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--secondary.euiSwitch--base:not([class*=isDisabled]):focus-within{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--secondary.euiSwitch--base:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(125,226,209,.15)}.euiSwitch--secondary .euiSwitch__body{background-color:#7de2d1}.euiSwitch--secondary.euiSwitch--compressed .euiSwitch__button[aria-checked=true] .euiSwitch__thumb,.euiSwitch--secondary.euiSwitch--mini .euiSwitch__button[aria-checked=true] .euiSwitch__thumb{border-color:#7de2d1}.euiSwitch--success.euiSwitch--base{color:#7de2d1;border-color:#7de2d1;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}@media screen and (prefers-reduced-motion:no-preference){.euiSwitch--success.euiSwitch--base{transition:background .25s ease-in-out}}.euiSwitch--success.euiSwitch--base:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--success.euiSwitch--base:not([class*=isDisabled]):hover,.euiSwitch--success.euiSwitch--base:not([class*=isDisabled]):focus{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--success.euiSwitch--base:not([class*=isDisabled]):focus-within{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--success.euiSwitch--base:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(125,226,209,.15)}.euiSwitch--success .euiSwitch__body{background-color:#7de2d1}.euiSwitch--success.euiSwitch--compressed .euiSwitch__button[aria-checked=true] .euiSwitch__thumb,.euiSwitch--success.euiSwitch--mini .euiSwitch__button[aria-checked=true] .euiSwitch__thumb{border-color:#7de2d1}.euiSwitch--warning.euiSwitch--base{color:#ffce7a;border-color:#ffce7a;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}@media screen and (prefers-reduced-motion:no-preference){.euiSwitch--warning.euiSwitch--base{transition:background .25s ease-in-out}}.euiSwitch--warning.euiSwitch--base:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--warning.euiSwitch--base:not([class*=isDisabled]):hover,.euiSwitch--warning.euiSwitch--base:not([class*=isDisabled]):focus{background-color:rgba(255,206,122,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--warning.euiSwitch--base:not([class*=isDisabled]):focus-within{background-color:rgba(255,206,122,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--warning.euiSwitch--base:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(255,206,122,.15)}.euiSwitch--warning .euiSwitch__body{background-color:#ffce7a}.euiSwitch--warning.euiSwitch--compressed .euiSwitch__button[aria-checked=true] .euiSwitch__thumb,.euiSwitch--warning.euiSwitch--mini .euiSwitch__button[aria-checked=true] .euiSwitch__thumb{border-color:#ffce7a}.euiSwitch--danger.euiSwitch--base{color:#f66;border-color:#f66;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}@media screen and (prefers-reduced-motion:no-preference){.euiSwitch--danger.euiSwitch--base{transition:background .25s ease-in-out}}.euiSwitch--danger.euiSwitch--base:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--danger.euiSwitch--base:not([class*=isDisabled]):hover,.euiSwitch--danger.euiSwitch--base:not([class*=isDisabled]):focus{background-color:rgba(255,102,102,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--danger.euiSwitch--base:not([class*=isDisabled]):focus-within{background-color:rgba(255,102,102,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--danger.euiSwitch--base:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(255,102,102,.15)}.euiSwitch--danger .euiSwitch__body{background-color:#f66}.euiSwitch--danger.euiSwitch--compressed .euiSwitch__button[aria-checked=true] .euiSwitch__thumb,.euiSwitch--danger.euiSwitch--mini .euiSwitch__button[aria-checked=true] .euiSwitch__thumb{border-color:#f66}.euiSwitch--subdued.euiSwitch--base{color:#9fa6af;border-color:#9fa6af;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}@media screen and (prefers-reduced-motion:no-preference){.euiSwitch--subdued.euiSwitch--base{transition:background .25s ease-in-out}}.euiSwitch--subdued.euiSwitch--base:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--subdued.euiSwitch--base:not([class*=isDisabled]):hover,.euiSwitch--subdued.euiSwitch--base:not([class*=isDisabled]):focus{background-color:rgba(159,166,175,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--subdued.euiSwitch--base:not([class*=isDisabled]):focus-within{background-color:rgba(159,166,175,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--subdued.euiSwitch--base:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(159,166,175,.15)}.euiSwitch--subdued .euiSwitch__body{background-color:#9fa6af}.euiSwitch--subdued.euiSwitch--compressed .euiSwitch__button[aria-checked=true] .euiSwitch__thumb,.euiSwitch--subdued.euiSwitch--mini .euiSwitch__button[aria-checked=true] .euiSwitch__thumb{border-color:#9fa6af}.euiSwitch--ghost.euiSwitch--base{color:#fcfeff;border-color:#fcfeff;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}@media screen and (prefers-reduced-motion:no-preference){.euiSwitch--ghost.euiSwitch--base{transition:background .25s ease-in-out}}.euiSwitch--ghost.euiSwitch--base:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(10,18,26,.3)}.euiSwitch--ghost.euiSwitch--base:not([class*=isDisabled]):hover,.euiSwitch--ghost.euiSwitch--base:not([class*=isDisabled]):focus{background-color:rgba(252,254,255,.1);box-shadow:0 4px 8px rgba(10,18,26,.15),0 2px 2px -1px rgba(10,18,26,.3)}.euiSwitch--ghost.euiSwitch--base:not([class*=isDisabled]):focus-within{background-color:rgba(252,254,255,.1);box-shadow:0 4px 8px rgba(10,18,26,.15),0 2px 2px -1px rgba(10,18,26,.3)}.euiSwitch--ghost.euiSwitch--base:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(252,254,255,.15)}.euiSwitch--ghost .euiSwitch__body{background-color:#fcfeff}.euiSwitch--ghost.euiSwitch--compressed .euiSwitch__button[aria-checked=true] .euiSwitch__thumb,.euiSwitch--ghost.euiSwitch--mini .euiSwitch__button[aria-checked=true] .euiSwitch__thumb{border-color:#fcfeff}.euiSwitch--text.euiSwitch--base{color:#dfe5ef;border-color:#8d98a3;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}@media screen and (prefers-reduced-motion:no-preference){.euiSwitch--text.euiSwitch--base{transition:background .25s ease-in-out}}.euiSwitch--text.euiSwitch--base:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--text.euiSwitch--base:not([class*=isDisabled]):hover,.euiSwitch--text.euiSwitch--base:not([class*=isDisabled]):focus{background-color:rgba(141,152,163,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--text.euiSwitch--base:not([class*=isDisabled]):focus-within{background-color:rgba(141,152,163,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSwitch--text.euiSwitch--base:not([class*=isDisabled]):active{box-shadow:inset 1px 2px 8px rgba(141,152,163,.15)}.euiSwitch--text .euiSwitch__body{background-color:#8d98a3}.euiSwitch--text.euiSwitch--compressed .euiSwitch__button[aria-checked=true] .euiSwitch__thumb,.euiSwitch--text.euiSwitch--mini .euiSwitch__button[aria-checked=true] .euiSwitch__thumb{border-color:#8d98a3}.euiTextArea{width:100%;max-width:400px;height:40px;font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border:none;border-radius:0;padding:12px;font-size:15.75px;font-weight:400;line-height:1.33333;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 3px 2px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiTextArea--fullWidth{max-width:100%}.euiTextArea--compressed{height:32px}.euiTextArea--inGroup{height:100%}@supports ((-moz-appearance:none)){.euiTextArea{transition-property:box-shadow,background-image,background-size}}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiTextArea{line-height:1em}}.euiTextArea::-webkit-input-placeholder{color:#9fa6af;opacity:1}.euiTextArea::placeholder{color:#9fa6af;opacity:1}.euiTextArea::placeholder{color:#9fa6af;opacity:1}.euiTextArea:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiTextArea:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:0 1px 1px -1px rgba(0,0,0,.2),0 4px 4px -2px rgba(0,0,0,.2),inset 0 0 0 1px rgba(252,254,255,.1)}.euiTextArea:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiTextArea:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiTextArea:disabled::placeholder{color:#5b6875;opacity:1}.euiTextArea:disabled::placeholder{color:#5b6875;opacity:1}.euiTextArea[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiTextArea:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiTextArea:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiTextArea:-webkit-autofill{-webkit-text-fill-color:#dfe5ef}.euiTextArea:autofill{-webkit-text-fill-color:#dfe5ef}.euiTextArea:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiTextArea:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiTextArea:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiTextArea:-webkit-autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiTextArea:autofill~.euiFormControlLayoutIcons{color:#dfe5ef}.euiTextArea--compressed{background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border-radius:2px;padding:8px;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}@supports ((-moz-appearance:none)){.euiTextArea--compressed{transition-property:box-shadow,background-image,background-size}}.euiTextArea--compressed:invalid{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%);background-size:100%}.euiTextArea--compressed:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiTextArea--compressed:disabled{color:#5b6875;-webkit-text-fill-color:#5b6875;cursor:not-allowed;background:#0d161e;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiTextArea--compressed:disabled::-webkit-input-placeholder{color:#5b6875;opacity:1}.euiTextArea--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiTextArea--compressed:disabled::placeholder{color:#5b6875;opacity:1}.euiTextArea--compressed[readOnly]{cursor:default;background:rgba(10,18,26,.05);border-color:transparent;box-shadow:inset 0 0 0 1px rgba(252,254,255,.1)}.euiTextArea--inGroup{border-radius:0;box-shadow:none!important}.euiTextArea,.euiTextArea--compressed{height:auto}.euiTextArea--resizeVertical{resize:vertical}.euiTextArea--resizeHorizontal{resize:horizontal}.euiTextArea--resizeBoth{resize:both}.euiTextArea--resizeNone{resize:none}.euiHeader{z-index:999;background:#172430;border-bottom:1px solid #293847;justify-content:space-between;height:49px;display:flex;position:relative;box-shadow:0 2px 2px -1px rgba(0,0,0,.3),0 1px 5px -2px rgba(0,0,0,.3)}.euiHeader--fixed{z-index:1000;position:fixed;top:0;left:0;right:0}.euiHeader--fixed+.euiHeader--fixed{top:49px}.euiHeader--dark{background-color:#172430;border-bottom-color:#293847}.euiHeader--dark .euiHeaderLogo__text,.euiHeader--dark .euiHeaderLink,.euiHeader--dark .euiHeaderSectionItemButton{color:#fcfeff}.euiHeader--dark .euiHeaderLink-isActive{color:#159d8d}.euiHeader--dark .euiHeaderSectionItem:after{background:#101b25}.euiHeader--dark .euiHeaderLogo:focus,.euiHeader--dark .euiHeaderLink:focus,.euiHeader--dark .euiHeaderSectionItemButton:focus{background:#105854}.euiHeader--dark .euiHeaderSectionItemButton__notification--badge{box-shadow:0 0 0 1px #172430}.euiHeader--dark .euiHeaderSectionItemButton__notification--dot{stroke:#172430}.euiHeaderProfile{padding:16px}.euiHeaderLinks{display:flex}.euiHeaderLinks__list{white-space:nowrap;align-items:center;display:flex}.euiHeaderLinks__list--gutterXS>*{margin:0 4px}.euiHeaderLinks__list--gutterS>*{margin:0 8px}.euiHeaderLinks__list--gutterM>*{margin:0 12px}.euiHeaderLinks__list--gutterL>*{margin:0 24px}.euiHeaderLinks__mobileList .euiHeaderLink{width:100%;padding:8px;display:block}.euiHeaderLinks__mobileList .euiHeaderLink>span{justify-content:flex-start}.euiHeaderLogo{text-align:left;vertical-align:middle;white-space:nowrap;align-items:center;min-width:49px;height:48px;padding:0 13px 0 12px;font-weight:600;line-height:48px;display:inline-flex;position:relative}.euiHeaderLogo:hover{text-decoration:underline}.euiHeaderLogo:focus{background:#0e4342;text-decoration:underline}.euiHeaderLogo:focus,.euiHeaderLogo:hover{text-decoration:none}.euiHeaderLogo__text{color:#dfe5ef;letter-spacing:-.025em;padding-left:16px;font-size:1.25rem;font-weight:300;line-height:1.77778rem}@media only screen and (max-width:574px){.euiHeaderLogo{padding:0 12px}.euiHeaderLogo__icon.euiIcon--xLarge{width:24px;height:24px}.euiHeaderLogo__text{color:#dfe5ef;letter-spacing:-.02em;font-size:1rem;font-weight:400;line-height:1.33333rem}}.euiHeaderAlert{border-top:none;border-bottom:1px solid #293847;min-width:300px;margin-bottom:24px;padding:0 8px 24px;position:relative}.euiHeaderAlert .euiHeaderAlert__dismiss{opacity:0;transition:opacity .25s ease-in;position:absolute;top:12px;right:12px}.euiHeaderAlert:hover .euiHeaderAlert__dismiss,.euiHeaderAlert .euiHeaderAlert__dismiss:focus{opacity:1}.euiHeaderAlert .euiHeaderAlert__title{color:#dfe5ef;letter-spacing:-.02em;margin-bottom:8px;font-size:1rem;font-weight:600;line-height:1.33333rem}.euiHeaderAlert .euiHeaderAlert__text{margin-bottom:16px;font-size:.875rem;line-height:1.33333}.euiHeaderAlert .euiHeaderAlert__action{font-size:.875rem;line-height:1.33333}.euiHeaderAlert .euiHeaderAlert__date{color:#8d98a3;font-size:.75rem;line-height:1.33333}.euiHeaderBreadcrumbs{flex-grow:1;align-items:center;margin-left:12px;margin-right:12px;display:flex}.euiHeaderBreadcrumbs--simplified{margin-left:0;margin-right:0}.euiHeaderSection{flex-grow:0;flex-shrink:0;display:flex}.euiHeaderSection--grow,.euiHeaderSection--left{flex-grow:1}.euiHeaderSection--dontGrow{flex-grow:0}.euiHeaderSectionItem{align-items:center;display:flex;position:relative}.euiHeaderSectionItem:after{content:"";background:#293847;position:absolute;top:16px;bottom:0;left:0}.euiHeaderSectionItem--borderLeft:after{width:1px;left:0}.euiHeaderSectionItem--borderRight:after{width:1px;left:auto;right:0}@media only screen and (max-width:574px){.euiHeaderSectionItem{min-width:36px}.euiHeaderSectionItem--borderLeft:after,.euiHeaderSectionItem--borderRight:after{display:none}}.euiHeaderSectionItemButton{text-align:center;min-width:48px;height:48px;font-size:0;position:relative}.euiHeaderSectionItemButton__notification{position:absolute}.euiHeaderSectionItemButton__notification--dot{stroke:#172430;top:0;right:0}.euiHeaderSectionItemButton__notification--badge{top:9%;right:9%;box-shadow:0 0 0 1px #172430}.euiHeaderSectionItemButton__content{display:inline-block}@media only screen and (max-width:574px){.euiHeaderSectionItemButton{min-width:36px}.euiHeaderSectionItemButton__notification.euiHeaderSectionItemButton__notification--dot{width:16px;height:16px;top:9%}}.euiHealth{display:inline-block}.euiHealth--textSizeXS{font-size:.75rem;line-height:1.33333}.euiHealth--textSizeS{font-size:.875rem;line-height:1.33333}.euiHealth--textSizeM{font-size:1.125rem;line-height:1.33333}.euiHealth--textSizeInherit{font-size:inherit}.euiHorizontalRule{background-color:#293847;border:none;flex-grow:0;flex-shrink:0;height:1px}.euiHorizontalRule.euiHorizontalRule--full{width:100%}.euiHorizontalRule.euiHorizontalRule--half{width:50%;margin-left:auto;margin-right:auto}.euiHorizontalRule.euiHorizontalRule--quarter{width:25%;margin-left:auto;margin-right:auto}.euiHorizontalRule--marginXSmall{margin:8px 0}.euiHorizontalRule--marginSmall{margin:12px 0}.euiHorizontalRule--marginMedium{margin:16px 0}.euiHorizontalRule--marginLarge{margin:24px 0}.euiHorizontalRule--marginXLarge{margin:32px 0}.euiHorizontalRule--marginXXLarge{margin:40px 0}.euiIcon{vertical-align:middle;fill:currentColor;flex-shrink:0;display:inline-block;transform:translate(0)}.euiIcon:focus{opacity:1;background:#0e4342}.euiIcon--app{fill:#dfe5ef}.euiIcon--app .euiIcon__fillSecondary{fill:#7de2d1}.euiIcon-isLoading{opacity:.05;background-color:currentColor;border-radius:4px}.euiIcon-isLoaded{animation:.25s ease-in forwards euiIconLoading}.euiIcon--accent{color:#f990c0}.euiIcon--danger{color:#f66}.euiIcon--ghost{color:#fcfeff}.euiIcon--primary{color:#159d8d}.euiIcon--secondary,.euiIcon--success{color:#7de2d1}.euiIcon--subdued{color:#9fa6af}.euiIcon--text{color:#dfe5ef}.euiIcon--warning{color:#ffce7a}.euiIcon--inherit{color:inherit}.euiIcon--text,.euiIcon--text .euiIcon__fillSecondary,.euiIcon--subdued,.euiIcon--subdued .euiIcon__fillSecondary,.euiIcon--primary,.euiIcon--primary .euiIcon__fillSecondary,.euiIcon--customColor,.euiIcon--customColor .euiIcon__fillSecondary{fill:currentColor}.euiIcon__fillNegative{fill:#dfe3e8}.euiIcon--small{width:12px;height:12px}.euiIcon--medium{width:16px;height:16px}.euiIcon--large{width:24px;height:24px}.euiIcon--xLarge{width:32px;height:32px}.euiIcon--xxLarge{width:40px;height:40px}@keyframes euiIconLoading{0%{opacity:.05}to{opacity:1}}.euiImage{flex-shrink:0;max-width:100%;min-height:1px;line-height:0;display:inline-block;position:relative}.euiImage .euiImage__img{margin-bottom:0}.euiImage.euiImage--hasShadow .euiImage__img{box-shadow:0 6px 12px -1px rgba(0,0,0,.2),0 4px 4px -1px rgba(0,0,0,.2),0 2px 2px rgba(0,0,0,.2)}.euiImage .euiImage__button{cursor:pointer;transition:all .15s cubic-bezier(.694,.0482,.335,1);position:relative}.euiImage .euiImage__button:focus{outline:2px solid rgba(21,157,141,.3)}.euiImage .euiImage__button:hover .euiImage__icon{visibility:visible;fill-opacity:1}.euiImage .euiImage__button--fullWidth{width:100%}.euiImage.euiImage--allowFullScreen:hover .euiImage__caption{text-decoration:underline}.euiImage.euiImage--allowFullScreen:not(.euiImage--hasShadow) .euiImage__button:hover,.euiImage.euiImage--allowFullScreen:not(.euiImage--hasShadow) .euiImage__button:focus{box-shadow:0 6px 12px -1px rgba(0,0,0,.2),0 4px 4px -1px rgba(0,0,0,.2),0 2px 2px rgba(0,0,0,.2)}.euiImage.euiImage--allowFullScreen.euiImage--hasShadow .euiImage__button:hover,.euiImage.euiImage--allowFullScreen.euiImage--hasShadow .euiImage__button:focus{box-shadow:0 12px 24px rgba(0,0,0,.1),0 6px 12px rgba(0,0,0,.1),0 4px 4px rgba(0,0,0,.1),0 2px 2px rgba(0,0,0,.1)}.euiImage.euiImage--small .euiImage__img{width:6.66667rem}.euiImage.euiImage--medium .euiImage__img{width:11.1111rem}.euiImage.euiImage--large .euiImage__img{width:20rem}.euiImage.euiImage--xlarge .euiImage__img{width:33.3333rem}.euiImage.euiImage--fullWidth{width:100%}.euiImage.euiImage--original .euiImage__img{width:auto;max-width:100%}.euiImage.euiImage--floatLeft{float:left}.euiImage.euiImage--floatLeft[class*=ouiImage--margin]{margin-top:0;margin-left:0}.euiImage.euiImage--floatRight{float:right}.euiImage.euiImage--floatRight[class*=ouiImage--margin]{margin-top:0;margin-right:0}.euiImage.euiImage--marginSmall{margin:8px}.euiImage.euiImage--marginMedium{margin:16px}.euiImage.euiImage--marginLarge{margin:24px}.euiImage.euiImage--marginXlarge{margin:32px}.euiImage__img{vertical-align:middle;width:100%}.euiImage__caption{text-align:center;margin-top:4px;font-size:.875rem;line-height:1.33333}.euiImage__icon{visibility:hidden;fill-opacity:0;cursor:pointer;transition:fill-opacity .35s cubic-bezier(.694,.0482,.335,1);position:absolute;top:16px;right:16px}.euiImage-isFullScreen{max-width:80vw;max-height:80vh;animation:.5s cubic-bezier(.34,1.61,.7,1) euiImageFullScreen;position:relative}.euiImage-isFullScreen:hover .euiImage__button{box-shadow:0 12px 24px rgba(0,0,0,.1),0 6px 12px rgba(0,0,0,.1),0 4px 4px rgba(0,0,0,.1),0 2px 2px rgba(0,0,0,.1)}.euiImage-isFullScreen:hover .euiImage__caption{text-decoration:underline}.euiImage-isFullScreen__img{vertical-align:middle;cursor:pointer;max-width:80vw;max-height:80vh;transition:all .15s cubic-bezier(.694,.0482,.335,1)}.euiImage-isFullScreenCloseIcon{pointer-events:none;position:absolute;top:16px;right:16px}@keyframes euiImageFullScreen{0%{opacity:0;transform:translateY(64px)}to{opacity:1;transform:translateY(0)}}@media only screen and (max-width:574px){.euiImage.euiImage--floatLeft,.euiImage.euiImage--floatRight{float:none}.euiImage.euiImage--floatLeft[class*=ouiImage--margin],.euiImage.euiImage--floatRight[class*=ouiImage--margin]{margin-top:inherit;margin-right:inherit;margin-bottom:inherit;margin-left:inherit}}@media only screen and (min-width:575px) and (max-width:767px){.euiImage.euiImage--floatLeft,.euiImage.euiImage--floatRight{float:none}.euiImage.euiImage--floatLeft[class*=ouiImage--margin],.euiImage.euiImage--floatRight[class*=ouiImage--margin]{margin-top:inherit;margin-right:inherit;margin-bottom:inherit;margin-left:inherit}}@media only screen and (min-width:768px) and (max-width:991px){.euiImage.euiImage--floatLeft,.euiImage.euiImage--floatRight{float:none}.euiImage.euiImage--floatLeft[class*=ouiImage--margin],.euiImage.euiImage--floatRight[class*=ouiImage--margin]{margin-top:inherit;margin-right:inherit;margin-bottom:inherit;margin-left:inherit}}.euiKeyPadMenu{flex-flow:wrap;width:288px;max-width:100%;display:flex}.euiKeyPadMenuItem{font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#8d98a3;border:1px solid transparent;border-radius:4px;width:96px;height:96px;padding:4px;font-weight:400;transition:border-color .15s ease-in,box-shadow .15s ease-in;display:block}.euiKeyPadMenuItem:not(:disabled):hover,.euiKeyPadMenuItem:not(:disabled):focus{border-color:#293847;box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiKeyPadMenuItem:not(:disabled):hover .euiKeyPadMenuItem__icon,.euiKeyPadMenuItem:not(:disabled):focus .euiKeyPadMenuItem__icon{transform:translateY(0)}.euiKeyPadMenuItem:disabled{color:#535a62;cursor:not-allowed}.euiKeyPadMenuItem:disabled .euiKeyPadMenuItem__icon{-webkit-filter:grayscale();filter:grayscale()}.euiKeyPadMenuItem:disabled .euiKeyPadMenuItem__icon svg *{fill:#535a62}.euiKeyPadMenuItem__inner{flex-direction:column;justify-content:center;align-items:center;width:100%;height:100%;display:flex}.euiKeyPadMenuItem--hasBetaBadge .euiKeyPadMenuItem__inner{position:relative}.euiKeyPadMenuItem--hasBetaBadge .euiKeyPadMenuItem__inner .euiKeyPadMenuItem__betaBadgeWrapper{z-index:3;position:absolute;top:4px;right:8px}.euiKeyPadMenuItem--hasBetaBadge .euiKeyPadMenuItem__inner .euiKeyPadMenuItem__betaBadgeWrapper .euiKeyPadMenuItem__betaBadge:not(.euiBetaBadge--iconOnly){letter-spacing:3rem;padding:0 6px;overflow:hidden}.euiKeyPadMenuItem__betaBadge{color:#fcfeff;width:20px;height:20px;box-shadow:none;background-color:#293847;line-height:20px}.euiKeyPadMenuItem__betaBadge .euiBetaBadge__icon{width:12px;height:12px}.euiKeyPadMenuItem__icon{margin-bottom:12px;transition:transform .25s cubic-bezier(.34,1.61,.7,1);transform:translateY(2px)}.euiKeyPadMenuItem__label{text-align:center;font-size:13.5px;font-weight:500;line-height:16px}.euiLink{text-align:left;font-weight:600}.euiLink:hover{text-decoration:underline}.euiLink:focus{background:#0e4342;text-decoration:underline}.euiLink .euiLink__externalIcon{margin-left:4px}.euiLink.euiLink-disabled{cursor:default;text-decoration:none}.euiLink.euiLink--subdued{color:#9fa6af}.euiLink.euiLink--subdued:hover,.euiLink.euiLink--subdued:focus{color:#838c98;text-decoration:underline}.euiLink.euiLink--subdued:focus{background-color:#3e464e;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiLink.euiLink--primary{color:#159d8d}.euiLink.euiLink--primary:hover,.euiLink.euiLink--primary:focus{color:#0f7065;text-decoration:underline}.euiLink.euiLink--primary:focus{background-color:#0e4342;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiLink.euiLink--secondary{color:#7de2d1}.euiLink.euiLink--secondary:hover,.euiLink.euiLink--secondary:focus{color:#53d9c2;text-decoration:underline}.euiLink.euiLink--secondary:focus{background-color:#325b5a;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiLink.euiLink--success{color:#7de2d1}.euiLink.euiLink--success:hover,.euiLink.euiLink--success:focus{color:#53d9c2;text-decoration:underline}.euiLink.euiLink--success:focus{background-color:#325b5a;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiLink.euiLink--accent{color:#f990c0}.euiLink.euiLink--accent:hover,.euiLink.euiLink--accent:focus{color:#f660a5;text-decoration:underline}.euiLink.euiLink--accent:focus{background-color:#5e3e54;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiLink.euiLink--warning{color:#ffce7a}.euiLink.euiLink--warning:hover,.euiLink.euiLink--warning:focus{color:#ffbb47;text-decoration:underline}.euiLink.euiLink--warning:focus{background-color:#60543c;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiLink.euiLink--danger{color:#f66}.euiLink.euiLink--danger:hover,.euiLink.euiLink--danger:focus{color:#f33;text-decoration:underline}.euiLink.euiLink--danger:focus{background-color:#602f35;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiLink.euiLink--text{color:#dfe5ef}.euiLink.euiLink--text:hover,.euiLink.euiLink--text:focus{color:#bdc9de;text-decoration:underline}.euiLink.euiLink--text:focus{background-color:#555c65;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiLink.euiLink--ghost{color:#fcfeff}.euiLink.euiLink--ghost:hover,.euiLink.euiLink--ghost:focus{color:#c9edff;text-decoration:underline}.euiLink.euiLink--ghost:focus{background-color:#5f656a;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}button.euiLink{-webkit-user-select:text;-moz-user-select:text;-ms-user-select:text;user-select:text}.euiListGroup.euiListGroup-flush{border:none;padding:0}.euiListGroup.euiListGroup-bordered{border:1px solid #293847;border-radius:4px}.euiListGroup-maxWidthDefault{max-width:400px}.euiListGroup--gutterSmall{padding:8px}.euiListGroup--gutterSmall .euiListGroupItem:not(:first-of-type){margin-top:8px}.euiListGroup--gutterMedium{padding:16px}.euiListGroup--gutterMedium .euiListGroupItem:not(:first-of-type){margin-top:16px}.euiListGroupItem{border-radius:4px;align-items:center;padding:0;transition:background-color .15s;display:flex;position:relative}.euiListGroupItem.euiListGroupItem-isActive,.euiListGroupItem.euiListGroupItem-isClickable:hover{background-color:rgba(41,56,71,.25)}.euiListGroupItem.euiListGroupItem-isClickable:focus-within{background-color:rgba(41,56,71,.25)}.euiListGroupItem.euiListGroupItem--ghost.euiListGroupItem-isClickable:hover{background-color:rgba(252,254,255,.1)}.euiListGroupItem.euiListGroupItem--ghost.euiListGroupItem-isClickable:focus-within{background-color:rgba(252,254,255,.1)}.euiListGroupItem.euiListGroupItem-isClickable:hover .euiListGroupItem__button,.euiListGroupItem .euiListGroupItem__button:hover,.euiListGroupItem .euiListGroupItem__button:focus{text-decoration:underline}.euiListGroupItem.euiListGroupItem-isDisabled,.euiListGroupItem.euiListGroupItem-isDisabled:hover,.euiListGroupItem.euiListGroupItem-isDisabled:focus,.euiListGroupItem.euiListGroupItem-isDisabled .euiListGroupItem__button:hover,.euiListGroupItem.euiListGroupItem-isDisabled .euiListGroupItem__button:focus{color:#4a515a;cursor:not-allowed;background-color:transparent;text-decoration:none}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiListGroupItem__button:hover,.euiListGroupItem__button:focus{background-color:rgba(41,56,71,.25);border-radius:4px}.euiListGroupItem__button:hover .euiListGroupItem--ghost .euiListGroupItem__button:hover,.euiListGroupItem__button:hover .euiListGroupItem--ghost .euiListGroupItem__button:focus,.euiListGroupItem__button:focus .euiListGroupItem--ghost .euiListGroupItem__button:hover,.euiListGroupItem__button:focus .euiListGroupItem--ghost .euiListGroupItem__button:focus{background-color:rgba(252,254,255,.1)}}.euiListGroupItem__text,.euiListGroupItem__button{text-align:left;max-width:100%;line-height:24px;font-weight:inherit;flex:1 0 auto;align-items:center;padding:4px 8px;display:flex}.euiListGroupItem-hasExtraAction .euiListGroupItem__text,.euiListGroupItem-hasExtraAction .euiListGroupItem__button{max-width:calc(100% - 32px)}.euiListGroupItem--primary .euiListGroupItem__text:not(:disabled),.euiListGroupItem--primary .euiListGroupItem__button:not(:disabled){color:#159d8d}.euiListGroupItem--text .euiListGroupItem__text:not(:disabled),.euiListGroupItem--text .euiListGroupItem__button:not(:disabled){color:#dfe5ef}.euiListGroupItem--subdued .euiListGroupItem__text:not(:disabled),.euiListGroupItem--subdued .euiListGroupItem__button:not(:disabled){color:#9fa6af}.euiListGroupItem--ghost .euiListGroupItem__text:not(:disabled),.euiListGroupItem--ghost .euiListGroupItem__button:not(:disabled){color:#fcfeff}.euiListGroupItem__text .euiListGroupItem__icon,.euiListGroupItem__button .euiListGroupItem__icon{height:24px}.euiListGroupItem-isActive:not(.euiListGroupItem--ghost) .euiListGroupItem__text,.euiListGroupItem-isActive:not(.euiListGroupItem--ghost) .euiListGroupItem__button{color:#dfe5ef}.euiListGroupItem__label{white-space:nowrap;text-overflow:ellipsis;overflow:hidden}.euiListGroupItem__extraAction{opacity:0;margin-right:8px;transition:opacity .15s}.euiListGroupItem:not(.euiListGroupItem-isDisabled):focus .euiListGroupItem__extraAction,.euiListGroupItem:not(.euiListGroupItem-isDisabled):hover .euiListGroupItem__extraAction,.euiListGroupItem__extraAction.euiListGroupItem__extraAction-alwaysShow,.euiListGroupItem__extraAction:focus{opacity:1}.euiListGroupItem__icon{flex-grow:0;flex-shrink:0;align-self:flex-start;margin-right:12px}.euiListGroupItem--xSmall{font-size:13.5px}.euiListGroupItem--small{font-size:15.75px}.euiListGroupItem--medium{font-size:18px}.euiListGroupItem--large{font-size:22.5px}.euiListGroupItem--xSmall,.euiListGroupItem--small{letter-spacing:0;font-weight:500}.euiListGroupItem--xSmall .euiListGroupItem__button,.euiListGroupItem--xSmall .euiListGroupItem__text{line-height:16px}.euiListGroupItem--xSmall .euiListGroupItem__icon{height:16px}.euiListGroupItem--large .euiListGroupItem__button,.euiListGroupItem--large .euiListGroupItem__text{line-height:32px}.euiListGroupItem--large .euiListGroupItem__icon{height:32px}.euiListGroupItem--wrapText .euiListGroupItem__button,.euiListGroupItem--wrapText .euiListGroupItem__text{word-break:break-word;width:100%}.euiListGroupItem--wrapText .euiListGroupItem__label{white-space:inherit}.euiListGroup-flush .euiListGroupItem{border-radius:0}.euiListGroup-bordered .euiListGroupItem:first-child{border-top-left-radius:4px;border-top-right-radius:4px}.euiListGroup-bordered .euiListGroupItem:last-child{border-bottom-right-radius:4px;border-bottom-left-radius:4px}.euiListGroupItem__tooltip{width:100%}.euiPinnableListGroup__itemExtraAction svg{transform:rotate(45deg)}.euiPinnableListGroup__itemExtraAction-pinned:not(:hover):not(:focus){color:#6a747f}.euiLoadingDashboards{display:inline-block;position:relative}.euiLoadingDashboards--medium{width:16px}.euiLoadingDashboards--large{width:24px}.euiLoadingDashboards--xLarge{width:32px}.euiLoadingDashboards--xxLarge{width:40px}.euiLoadingLogo,.euiLoadingKibana{display:inline-block;position:relative}@media screen and (prefers-reduced-motion:no-preference){.euiLoadingLogo:before,.euiLoadingLogo:after,.euiLoadingKibana:before,.euiLoadingKibana:after{content:"";opacity:.2;z-index:1;border-radius:50%;width:90%;position:absolute;left:5%}.euiLoadingLogo:before,.euiLoadingKibana:before{animation:1s cubic-bezier(.694,.0482,.335,1) infinite euiLoadingKibanaPulsateAndFade;box-shadow:0 0 8px #fcfeff}.euiLoadingLogo:after,.euiLoadingKibana:after{background-color:#fcfeff;animation:1s cubic-bezier(.694,.0482,.335,1) infinite euiLoadingKibanaPulsate}}.euiLoadingLogo .euiLoadingLogo__icon,.euiLoadingLogo .euiLoadingKibana__icon,.euiLoadingKibana .euiLoadingLogo__icon,.euiLoadingKibana .euiLoadingKibana__icon{display:block}@media screen and (prefers-reduced-motion:no-preference){.euiLoadingLogo .euiLoadingLogo__icon,.euiLoadingLogo .euiLoadingKibana__icon,.euiLoadingKibana .euiLoadingLogo__icon,.euiLoadingKibana .euiLoadingKibana__icon{animation:1s cubic-bezier(.694,.0482,.335,1) infinite euiLoadingKibanaBounceMedium}}.euiLoadingLogo--medium,.euiLoadingKibana--medium{width:16px}.euiLoadingLogo--medium:before,.euiLoadingLogo--medium:after,.euiLoadingKibana--medium:before,.euiLoadingKibana--medium:after{height:3px;bottom:-4px}.euiLoadingLogo--medium .euiLoadingLogo__icon,.euiLoadingLogo--medium .euiLoadingKibana__icon,.euiLoadingKibana--medium .euiLoadingLogo__icon,.euiLoadingKibana--medium .euiLoadingKibana__icon{z-index:999;animation-name:euiLoadingKibanaBounceMedium}.euiLoadingLogo--large,.euiLoadingKibana--large{width:24px}.euiLoadingLogo--large:before,.euiLoadingLogo--large:after,.euiLoadingKibana--large:before,.euiLoadingKibana--large:after{height:6px;bottom:-8px}.euiLoadingLogo--large .euiLoadingLogo__icon,.euiLoadingLogo--large .euiLoadingKibana__icon,.euiLoadingKibana--large .euiLoadingLogo__icon,.euiLoadingKibana--large .euiLoadingKibana__icon{animation-name:euiLoadingKibanaBounceLarge}.euiLoadingLogo--xLarge,.euiLoadingKibana--xLarge{width:32px}.euiLoadingLogo--xLarge:before,.euiLoadingLogo--xLarge:after,.euiLoadingKibana--xLarge:before,.euiLoadingKibana--xLarge:after{height:8px;bottom:-12px}.euiLoadingLogo--xLarge .euiLoadingLogo__icon,.euiLoadingLogo--xLarge .euiLoadingKibana__icon,.euiLoadingKibana--xLarge .euiLoadingLogo__icon,.euiLoadingKibana--xLarge .euiLoadingKibana__icon{animation-name:euiLoadingKibanaBounceXLarge}@keyframes euiLoadingKibanaBounceMedium{50%{transform:translateY(-8px)}}@keyframes euiLoadingKibanaBounceLarge{50%{transform:translateY(-12px)}}@keyframes euiLoadingKibanaBounceXLarge{50%{transform:translateY(-16px)}}@keyframes euiLoadingKibanaPulsateAndFade{0%{opacity:0}50%{opacity:.1;transform:scale(.5)}to{opacity:0}}@keyframes euiLoadingKibanaPulsate{0%{opacity:.15}50%{opacity:.05;transform:scale(.5)}to{opacity:.15}}.euiLoadingElastic{display:inline-block;position:relative}.euiLoadingElastic--medium{width:16px}.euiLoadingElastic--large{width:24px}.euiLoadingElastic--xLarge{width:32px}.euiLoadingElastic--xxLarge{width:40px}.euiLoadingElastic path{-webkit-transform-style:preserve-3d;transform-style:preserve-3d;transform-origin:50%;animation-duration:1s;animation-timing-function:cubic-bezier(0,.63,.49,1);animation-iteration-count:infinite;animation-direction:alternate;animation-fill-mode:forwards}@media screen and (prefers-reduced-motion:no-preference){.euiLoadingElastic path{animation-name:euiLoadingElastic}}.euiLoadingElastic path:first-of-type{animation-delay:0s}.euiLoadingElastic path:nth-of-type(2){animation-delay:35ms}.euiLoadingElastic path:nth-of-type(3){animation-delay:.125s}.euiLoadingElastic path:nth-of-type(4){animation-delay:.155s}.euiLoadingElastic path:nth-of-type(5){animation-delay:75ms}.euiLoadingElastic path:nth-of-type(6){animation-delay:60ms}@keyframes euiLoadingElastic{0%{opacity:0;transform:scale3d(0,0,-.7)}40%{opacity:1;transform:scaleZ(2)}50%{transform:scale3d(.99,.99,2)}70%{transform:scale3d(.96,.96,-2.5)}to{transform:scale3d(.98,.98,2)}}.euiLoadingChart{z-index:500;height:32px;display:inline-block;overflow:hidden}.euiLoadingChart__bar{width:8px;height:100%;margin-bottom:-16px;margin-left:2px;display:inline-block}@media screen and (prefers-reduced-motion:no-preference){.euiLoadingChart__bar{animation:1s infinite euiLoadingChart}}.euiLoadingChart__bar:first-child{background-color:#54b399}@media screen and (prefers-reduced-motion:reduce){.euiLoadingChart__bar:first-child{transform:translateY(66%)}}.euiLoadingChart__bar:nth-child(2){background-color:#6092c0;animation-delay:.1s}@media screen and (prefers-reduced-motion:reduce){.euiLoadingChart__bar:nth-child(2){transform:translateY(44%)}}.euiLoadingChart__bar:nth-child(3){background-color:#d36086;animation-delay:.2s}@media screen and (prefers-reduced-motion:reduce){.euiLoadingChart__bar:nth-child(3){transform:translateY(22%)}}.euiLoadingChart__bar:nth-child(4){background-color:#9170b8;animation-delay:.3s}.euiLoadingChart--mono .euiLoadingChart__bar:first-child{background-color:#293847}.euiLoadingChart--mono .euiLoadingChart__bar:nth-child(2){background-color:#31404e}.euiLoadingChart--mono .euiLoadingChart__bar:nth-child(3){background-color:#3a4856}.euiLoadingChart--mono .euiLoadingChart__bar:nth-child(4){background-color:#42505d}.euiLoadingChart--medium{height:16px}.euiLoadingChart--medium>span{width:2px;margin-bottom:8px;margin-left:2px}.euiLoadingChart--large{height:24px}.euiLoadingChart--large>span{width:4px;margin-bottom:12px;margin-left:2px}.euiLoadingChart--xLarge{height:32px}.euiLoadingChart--xLarge>span{width:8px;margin-bottom:16px;margin-left:4px}@keyframes euiLoadingChart{0%{transform:translateY(0)}50%{transform:translateY(66%)}to{transform:translateY(0)}}.euiLoadingContent__loader{width:100%;display:block}.euiLoadingContent__singleLine{border-radius:4px;width:100%;height:16px;margin-bottom:8px;display:block;overflow:hidden}.euiLoadingContent__singleLine:last-child:not(:only-child){width:75%}.euiLoadingContent__singleLineBackground{background:linear-gradient(137deg,#253342 45%,#222f3c 50%,#253342 55%);width:220%;height:100%;display:block}@media screen and (prefers-reduced-motion:no-preference){.euiLoadingContent__singleLineBackground{animation:1.5s cubic-bezier(.694,.0482,.335,1) infinite euiLoadingContentGradientLoad}}@keyframes euiLoadingContentGradientLoad{0%{transform:translate(-53%)}to{transform:translate(0)}}.euiLoadingSpinner{border:2px solid #293847;border-top-color:#159d8d;border-radius:50%;flex-shrink:0;width:32px;height:32px;display:inline-block}@media screen and (prefers-reduced-motion:no-preference){.euiLoadingSpinner{animation:.6s linear infinite euiLoadingSpinner}}.euiLoadingSpinner--small{border-width:1px;width:8px;height:8px}.euiLoadingSpinner--medium{border-width:1px;width:16px;height:16px}.euiLoadingSpinner--large{width:24px;height:24px}.euiLoadingSpinner--xLarge{width:32px;height:32px}@keyframes euiLoadingSpinner{0%{transform:rotate(0)}to{transform:rotate(359deg)}}.euiMarkdownEditor--isPreviewing .euiMarkdownEditor__toggleContainer{display:none}.euiMarkdownEditor--fullHeight{flex-direction:column;height:100%;display:flex}.euiMarkdownEditor--fullHeight .euiMarkdownEditorTextArea{resize:none}.euiMarkdownEditor--fullHeight .euiMarkdownEditorDropZone{height:100%}.euiMarkdownEditorDropZone{flex-direction:column;min-height:150px;display:flex;position:relative}.euiMarkdownEditorDropZone__input{opacity:0;width:100%;height:100%;position:absolute;top:0;left:0;overflow:hidden}.euiMarkdownEditorDropZone__input:hover{cursor:pointer}.euiMarkdownEditorDropZone__input:hover:disabled{cursor:not-allowed}.euiMarkdownEditorDropZone--isDragging .euiMarkdownEditorFooter,.euiMarkdownEditorDropZone--isDragging .euiMarkdownEditorTextArea,.euiMarkdownEditorDropZone--isDragging .euiMarkdownEditorTextArea:focus{background-color:rgba(21,157,141,.1)!important}.euiMarkdownEditorDropZone--isDragging .euiMarkdownEditor:focus-within .euiMarkdownEditorTextArea{background-color:rgba(21,157,141,.1)!important}.euiMarkdownEditorDropZone--isDragging .euiMarkdownEditorTextArea,.euiMarkdownEditorDropZone--isDragging .euiMarkdownEditorTextArea:focus{background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%)!important}.euiMarkdownEditorDropZone--isDraggingError .euiMarkdownEditorFooter,.euiMarkdownEditorDropZone--isDraggingError .euiMarkdownEditorTextArea,.euiMarkdownEditorDropZone--isDraggingError .euiMarkdownEditorTextArea:focus{background-color:rgba(255,102,102,.1)!important}.euiMarkdownEditorDropZone--isDraggingError .euiMarkdownEditor:focus-within .euiMarkdownEditorTextArea{background-color:rgba(255,102,102,.1)!important}.euiMarkdownEditorDropZone--hasError .euiMarkdownEditorTextArea,.euiMarkdownEditorDropZone--hasError .euiMarkdownEditorTextArea:focus{background-image:linear-gradient(0deg,#f66,#f66 2px,transparent 2px,transparent 100%)!important}.euiMarkdownFormat{font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;font-weight:400}.euiMarkdownFormat--reversed{color:#101b25}.euiMarkdownFormat>div>:first-child{margin-top:0!important}.euiMarkdownFormat>div>*{margin-top:0;margin-bottom:1em}.euiMarkdownFormat>div>:last-child,.euiMarkdownFormat .euiCheckbox{margin-bottom:0!important}.euiMarkdownFormat .euiCheckbox+:not(.euiCheckbox){margin-top:1em}.euiMarkdownFormat p,.euiMarkdownFormat blockquote,.euiMarkdownFormat ul,.euiMarkdownFormat ol,.euiMarkdownFormat dl,.euiMarkdownFormat pre,.euiMarkdownFormat table{margin-top:0;margin-bottom:1em;line-height:1.5em}.euiMarkdownFormat strong{font-weight:600}.euiMarkdownFormat h1,.euiMarkdownFormat h2,.euiMarkdownFormat h3,.euiMarkdownFormat h4,.euiMarkdownFormat h5,.euiMarkdownFormat h6{margin-top:0;margin-bottom:.5em}.euiMarkdownFormat h1{font-size:2.25em;font-weight:300;line-height:1.33333em}.euiMarkdownFormat h2{font-size:1.75em;font-weight:300;line-height:1.42857em}.euiMarkdownFormat h3{font-size:1.25em;font-weight:600;line-height:1.6em}.euiMarkdownFormat h4{font-size:1em;font-weight:600;line-height:1.5em}.euiMarkdownFormat h5{font-size:.875em;font-weight:700;line-height:1.14286em}.euiMarkdownFormat h6{text-transform:uppercase;font-size:.75em;font-weight:700;line-height:1.33333em}.euiMarkdownFormat img{box-sizing:content-box;border-style:none;max-width:100%}.euiMarkdownFormat blockquote{border-left:.25em solid rgba(252,254,255,.15);padding:0 1em}.euiMarkdownFormat--reversed blockquote{border-left-color:rgba(10,18,26,.15)}.euiMarkdownFormat hr{background-color:rgba(252,254,255,.15);border:none;height:1px;margin:1.5em 0}.euiMarkdownFormat hr:before{content:"";display:table}.euiMarkdownFormat hr:after{clear:both;content:"";display:table}.euiMarkdownFormat ul,.euiMarkdownFormat ol{margin-top:0;margin-bottom:1em;padding-left:1.5em}.euiMarkdownFormat ul{list-style-type:disc}.euiMarkdownFormat ol{list-style-type:decimal}.euiMarkdownFormat ul ul{list-style-type:circle}.euiMarkdownFormat ol ol,.euiMarkdownFormat ul ol{list-style-type:lower-roman}.euiMarkdownFormat ul ul ol,.euiMarkdownFormat ul ol ol,.euiMarkdownFormat ol ul ol,.euiMarkdownFormat ol ol ol{list-style-type:lower-alpha}.euiMarkdownFormat dd{margin-left:0}.euiMarkdownFormat ul ul,.euiMarkdownFormat ul ol,.euiMarkdownFormat ol ol,.euiMarkdownFormat ol ul{margin-top:0;margin-bottom:0}.euiMarkdownFormat li>p{margin-bottom:.5em}.euiMarkdownFormat li+li{margin-top:.25em}.euiMarkdownFormat .task-list-item{list-style-type:none}.euiMarkdownFormat .task-list-item+.task-list-item{margin-top:.25em}.euiMarkdownFormat .task-list-item input{vertical-align:middle;margin:0 .2em .25em -1.6em}.euiMarkdownFormat table{border-spacing:0;border-collapse:collapse;border-left:1px solid rgba(252,254,255,.15);width:100%;display:block;overflow:auto}.euiMarkdownFormat td,.euiMarkdownFormat th{padding:0}.euiMarkdownFormat table th,.euiMarkdownFormat table td{border-top:1px solid rgba(252,254,255,.15);border-bottom:1px solid rgba(252,254,255,.15);padding:.25em .5em}.euiMarkdownFormat table th:last-child,.euiMarkdownFormat table td:last-child{border-right:1px solid rgba(252,254,255,.15)}.euiMarkdownFormat table tr{background-color:transparent;border-top:1px solid rgba(252,254,255,.15)}.euiMarkdownEditorFooter{background:#172430;border:1px solid #293847;align-items:center;padding:4px;display:inline-flex}.euiMarkdownEditorFooter__popover{width:300px}.euiMarkdownEditorFooter__actions{flex:1;display:inline-flex}.euiMarkdownEditorFooter__actions>button,.euiMarkdownEditorFooter__actions>span{align-self:center;margin-right:4px}.euiMarkdownEditorFooter__actions .euiMarkdownEditorFooter__uploadError{border-radius:4px;line-height:1;position:relative;left:-1px}.euiMarkdownEditorFooter__actions .euiMarkdownEditorFooter__uploadError>span{padding:0 4px}.euiMarkdownEditorFooter__help{justify-self:flex-end}.euiMarkdownEditorFooter__help>svg{width:26px}.euiMarkdownEditorFooter__errors>svg{color:#9fa6af}.euiMarkdownEditorPreview{scrollbar-width:thin;background:#0a121a;border:1px solid #293847;min-height:150px;padding:12px;overflow-y:auto}.euiMarkdownEditorPreview::-webkit-scrollbar{width:16px;height:16px}.euiMarkdownEditorPreview::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiMarkdownEditorPreview::-webkit-scrollbar-corner{background-color:transparent}.euiMarkdownEditorPreview::-webkit-scrollbar-track{background-color:transparent}.euiMarkdownEditorTextArea{font-family:var(--eui-font-family);-webkit-text-size-adjust:100%;-ms-text-size-adjust:100%;-webkit-font-kerning:normal;font-kerning:normal;color:#dfe5ef;scrollbar-width:thin;resize:vertical;background-color:#0e1721;background-repeat:no-repeat;background-size:0% 100%;border:1px solid #293847;border-bottom:none;width:100%;height:100%;min-height:150px;margin:0;padding:12px;font-size:15.75px;font-weight:400;line-height:1.33333;transition:box-shadow .15s ease-in,background-image .15s ease-in,background-size .15s ease-in,background-color .15s ease-in}@media screen and (-ms-high-contrast:active),screen and (-ms-high-contrast:none){.euiMarkdownEditorTextArea{line-height:1em}}.euiMarkdownEditorTextArea::-webkit-input-placeholder{color:#9fa6af;opacity:1}.euiMarkdownEditorTextArea::placeholder{color:#9fa6af;opacity:1}.euiMarkdownEditorTextArea::placeholder{color:#9fa6af;opacity:1}.euiMarkdownEditorTextArea::-webkit-scrollbar{width:16px;height:16px}.euiMarkdownEditorTextArea::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiMarkdownEditorTextArea::-webkit-scrollbar-corner{background-color:transparent}.euiMarkdownEditorTextArea::-webkit-scrollbar-track{background-color:transparent}.euiMarkdownEditorTextArea:focus{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%}.euiMarkdownEditor:focus-within .euiMarkdownEditorTextArea{background-color:#0a121a;background-image:linear-gradient(0deg,#159d8d,#159d8d 2px,transparent 2px,transparent 100%);background-size:100% 100%}.euiMarkdownEditorToolbar{background:#101b25;border:1px solid #293847;border-bottom:none;flex-wrap:wrap;padding:4px;display:flex}.euiMarkdownEditorToolbar__buttons{flex-wrap:wrap;flex:1;align-items:center;display:flex}.euiMarkdownEditorToolbar__buttons>*{margin-right:4px}.euiMarkdownEditorToolbar__divider{content:"";border-left:1px solid #293847;height:24px;margin-left:4px;padding-right:4px;display:block}.euiMarkdownTooltip__icon{transform:translateY(-1px)}.euiMark{color:#dfe5ef;background-color:transparent;font-weight:700}.euiModal{z-index:8000;background-color:#0a121a;border:1px solid #293847;border-radius:4px;min-width:400px;max-width:calc(100vw - 16px);animation:90ms cubic-bezier(.34,1.61,.7,1) euiModal;display:flex;position:relative;box-shadow:0 40px 64px rgba(0,0,0,.1),0 24px 32px rgba(0,0,0,.1),0 16px 16px rgba(0,0,0,.1),0 8px 8px rgba(0,0,0,.1),0 4px 4px rgba(0,0,0,.1),0 2px 2px rgba(0,0,0,.1)}.euiModal:focus{outline:none}.euiModal .euiModal__flex{flex-direction:column;flex:auto;max-height:75vh;display:flex;overflow:hidden}.euiModal--maxWidth-default{max-width:min(768px,100vw - 16px)}.euiModal--confirmation{min-width:400px}.euiModalHeader{flex-grow:0;flex-shrink:0;justify-content:space-between;align-items:center;padding:24px 40px 16px 24px;display:flex}.euiModalHeader__title{color:#dfe5ef;letter-spacing:-.04em;font-size:1.75rem;font-weight:300;line-height:2.22222rem}.euiModalBody{flex-direction:column;flex-grow:1;display:flex;overflow:hidden}.euiModalBody .euiModalBody__overflow{scrollbar-width:thin;contain:paint;height:100%;padding:8px 24px;overflow-x:hidden;overflow-y:auto;-webkit-mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%);mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%)}.euiModalBody .euiModalBody__overflow::-webkit-scrollbar{width:16px;height:16px}.euiModalBody .euiModalBody__overflow::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiModalBody .euiModalBody__overflow::-webkit-scrollbar-corner{background-color:transparent}.euiModalBody .euiModalBody__overflow::-webkit-scrollbar-track{background-color:transparent}.euiModalBody .euiModalBody__overflow:focus{outline:none}.euiModalBody .euiModalBody__overflow[tabindex="0"]:focus:focus-visible{outline-style:auto}.euiModalFooter{flex-grow:0;flex-shrink:0;justify-content:flex-end;padding:16px 24px 24px;display:flex}.euiModalFooter>*+*{margin-left:16px}.euiModalHeader+.euiModalFooter{padding-top:8px}.euiModalBody:last-of-type .euiModalBody__overflow{padding-bottom:24px}.euiModal__closeIcon{z-index:3;background-color:rgba(10,18,26,.9);position:absolute;top:4px;right:4px}@keyframes euiModal{0%{opacity:0;transform:translateY(32px)}to{opacity:1;transform:translateY(0)}}@media only screen and (max-width:574px){.euiModal{border:none;border-radius:0;position:fixed;top:0;bottom:0;left:0;right:0;width:100vw!important;min-width:0!important;max-width:none!important}.euiModal.euiModal--confirmation{top:auto;box-shadow:0 -40px 64px rgba(0,0,0,.1),0 -24px 32px rgba(0,0,0,.1),0 -16px 16px rgba(0,0,0,.1),0 -8px 8px rgba(0,0,0,.1)}.euiModal .euiModal__flex{max-height:100vh}.euiModalHeader{width:100%}.euiModalFooter{background:#101b25;justify-content:stretch;width:100%;padding:12px 24px!important}.euiModalFooter>*{flex:1}.euiModalFooter>*+*{margin-left:0}.euiModalBody{width:100%}.euiModalBody .euiModalBody__overflow{padding-bottom:24px}}@media only screen and (min-width:575px) and (max-width:767px){.euiModal{border:none;border-radius:0;position:fixed;top:0;bottom:0;left:0;right:0;width:100vw!important;min-width:0!important;max-width:none!important}.euiModal.euiModal--confirmation{top:auto;box-shadow:0 -40px 64px rgba(0,0,0,.1),0 -24px 32px rgba(0,0,0,.1),0 -16px 16px rgba(0,0,0,.1),0 -8px 8px rgba(0,0,0,.1)}.euiModal .euiModal__flex{max-height:100vh}.euiModalHeader{width:100%}.euiModalFooter{background:#101b25;justify-content:stretch;width:100%;padding:12px 24px!important}.euiModalFooter>*{flex:1}.euiModalFooter>*+*{margin-left:0}.euiModalBody{width:100%}.euiModalBody .euiModalBody__overflow{padding-bottom:24px}}.euiNotificationEvent{border-bottom:1px solid #293847;padding:12px 0 12px 12px;display:flex}.euiNotificationEvent:last-child{border-bottom:none}.euiNotificationEvent--withReadState{padding:12px 0 12px 8px}.euiNotificationEvent__title{color:#dfe5ef;letter-spacing:-.02em;font-size:1rem;font-weight:600;line-height:1.33333rem;display:flex}.euiNotificationEvent__title.euiLink{color:#159d8d}.euiNotificationEvent__title--isRead{color:#8d98a3!important}.euiNotificationEvent__readButton{margin-right:8px}.euiNotificationEvent__content{flex:1}.euiNotificationEvent__content>*+*{margin-top:8px;margin-right:12px}.euiNotificationEventMeta{flex-flow:wrap;justify-content:space-between;align-items:center;min-height:24px;margin-right:4px;display:flex;position:relative}.euiNotificationEventMeta--hasContextMenu{padding-right:24px}.euiNotificationEventMeta__contextMenuWrapper{position:absolute;top:0;right:0}.euiNotificationEventMeta__section{margin-right:8px}.euiNotificationEventMeta__section:first-child{flex:1;align-items:center;display:flex}.euiNotificationEventMeta__icon{margin-right:8px}.euiNotificationEventMeta__badge{max-width:100%;display:inline-grid}.euiNotificationEventMeta__time{color:#9fa6af;font-size:13.5px}.euiNotificationEventMessages{font-size:15.75px}.euiNotificationEventMessages__accordion{color:#8d98a3}.euiNotificationEventMessages__accordionButton{color:#159d8d}.euiNotificationEventMessages__accordionContent>*{padding-top:8px}.euiNotificationEventReadButton--isRead svg{fill:transparent;stroke-width:1px;stroke:#293847}.euiNotificationEventReadIcon{align-items:center;height:24px;margin:0 4px;display:flex}.euiNotificationEventReadIcon--isRead svg{fill:transparent;stroke-width:1px;stroke:#293847}.euiOverlayMask{background:rgba(41,56,71,.8);justify-content:center;align-items:center;padding-bottom:10vh;animation:.15s ease-in euiAnimFadeIn;display:flex;position:fixed;top:0;bottom:0;left:0;right:0}.euiBody-hasOverlayMask{overflow:hidden}.euiOverlayMask--aboveHeader{z-index:6000}.euiOverlayMask--belowHeader{z-index:1000}.euiPagination{align-items:center;display:flex}.euiPagination__compressedText{align-items:center;display:inline-flex;line-height:1!important}.euiPagination__compressedText>:first-child{margin-right:4px}.euiPagination__compressedText>:last-child{margin-left:4px}.euiPagination__list{align-items:baseline;display:flex}.euiPaginationButton{text-align:center;border-radius:4px;padding:0;font-size:15.75px}.euiPaginationButton-isActive{font-weight:700}.euiPaginationButton-isActive.euiPaginationButton-isActive{color:#159d8d}.euiPaginationButton-isActive.euiPaginationButton-isActive .euiButtonEmpty__content{cursor:default}.euiPaginationButton-isActive.euiPaginationButton-isActive,.euiPaginationButton-isActive.euiPaginationButton-isActive:hover{text-decoration:underline}.euiPaginationButton-isPlaceholder{color:#535a62;align-items:baseline;height:24px;padding:6px 8px 0;font-size:15.75px}@media only screen and (max-width:574px){.euiPaginationButton-isPlaceholder,.euiPaginationButton--hideOnMobile{display:none}}@media only screen and (min-width:575px) and (max-width:767px){.euiPaginationButton-isPlaceholder,.euiPaginationButton--hideOnMobile{display:none}}.euiPanel{background-color:#0a121a;border:1px solid #293847;border-radius:4px;flex-grow:1}.euiPanel.euiPanel--flexGrowZero{flex-grow:0}.euiPanel.euiPanel--noBorder{border:none}.euiPanel.euiPanel--hasShadow{border:1px solid #293847;box-shadow:0 2px 2px -1px rgba(0,0,0,.3),0 1px 5px -2px rgba(0,0,0,.3)}.euiPanel.euiPanel--isClickable{transition:all .15s cubic-bezier(.694,.0482,.335,1)}.euiPanel.euiPanel--isClickable:enabled{text-align:left;width:100%;display:block}.euiPanel.euiPanel--isClickable:hover,.euiPanel.euiPanel--isClickable:focus{cursor:pointer;transform:translateY(-2px);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiPanel.euiPanel--borderRadiusNone{border-radius:0}.euiPanel.euiPanel--borderRadiusMedium{border-radius:4px}.euiPanel.euiPanel--borderRadiusLarge{border-radius:8px}.euiPanel.euiPanel--borderRadiusXLarge{border-radius:16px}.euiPanel.euiPanel--transparent{background-color:transparent}.euiPanel.euiPanel--plain{background-color:#0a121a}.euiPanel.euiPanel--subdued{background-color:#172430}.euiPanel.euiPanel--accent{background-color:#52384c}.euiPanel.euiPanel--primary{background-color:#0d3c3d}.euiPanel.euiPanel--success{background-color:#2d5051}.euiPanel.euiPanel--warning{background-color:#544a37}.euiPanel.euiPanel--danger{background-color:#542b31}.euiPanel--paddingSmall{padding:8px}.euiPanel--paddingMedium{padding:16px}.euiPanel--paddingLarge{padding:24px}.euiSplitPanel{flex-direction:column;min-width:0;display:flex}.euiSplitPanel .euiSplitPanel__inner{flex-basis:0%;box-shadow:none!important;transform:none!important}.euiSplitPanel.euiSplitPanel-isResponsive.euiPanel--borderRadiusNone .euiSplitPanel__inner:first-child,.euiSplitPanel.euiPanel--borderRadiusNone .euiSplitPanel__inner:first-child{border-radius:-1px -1px 0 0}.euiSplitPanel.euiSplitPanel-isResponsive.euiPanel--borderRadiusNone .euiSplitPanel__inner:last-child,.euiSplitPanel.euiPanel--borderRadiusNone .euiSplitPanel__inner:last-child{border-radius:0 0 -1px -1px}.euiSplitPanel.euiSplitPanel-isResponsive.euiPanel--borderRadiusMedium .euiSplitPanel__inner:first-child,.euiSplitPanel.euiPanel--borderRadiusMedium .euiSplitPanel__inner:first-child{border-radius:3px 3px 0 0}.euiSplitPanel.euiSplitPanel-isResponsive.euiPanel--borderRadiusMedium .euiSplitPanel__inner:last-child,.euiSplitPanel.euiPanel--borderRadiusMedium .euiSplitPanel__inner:last-child{border-radius:0 0 3px 3px}.euiSplitPanel.euiSplitPanel-isResponsive.euiPanel--borderRadiusLarge .euiSplitPanel__inner:first-child,.euiSplitPanel.euiPanel--borderRadiusLarge .euiSplitPanel__inner:first-child{border-radius:7px 7px 0 0}.euiSplitPanel.euiSplitPanel-isResponsive.euiPanel--borderRadiusLarge .euiSplitPanel__inner:last-child,.euiSplitPanel.euiPanel--borderRadiusLarge .euiSplitPanel__inner:last-child{border-radius:0 0 7px 7px}.euiSplitPanel.euiSplitPanel-isResponsive.euiPanel--borderRadiusXLarge .euiSplitPanel__inner:first-child,.euiSplitPanel.euiPanel--borderRadiusXLarge .euiSplitPanel__inner:first-child{border-radius:15px 15px 0 0}.euiSplitPanel.euiSplitPanel-isResponsive.euiPanel--borderRadiusXLarge .euiSplitPanel__inner:last-child,.euiSplitPanel.euiPanel--borderRadiusXLarge .euiSplitPanel__inner:last-child{border-radius:0 0 15px 15px}.euiSplitPanel--row{flex-direction:row}.euiSplitPanel--row.euiSplitPanel-isResponsive{flex-direction:column}.euiSplitPanel--row.euiPanel--borderRadiusNone .euiSplitPanel__inner:first-child{border-radius:-1px 0 0 -1px}.euiSplitPanel--row.euiPanel--borderRadiusNone .euiSplitPanel__inner:last-child{border-radius:0 -1px -1px 0}.euiSplitPanel--row.euiPanel--borderRadiusMedium .euiSplitPanel__inner:first-child{border-radius:3px 0 0 3px}.euiSplitPanel--row.euiPanel--borderRadiusMedium .euiSplitPanel__inner:last-child{border-radius:0 3px 3px 0}.euiSplitPanel--row.euiPanel--borderRadiusLarge .euiSplitPanel__inner:first-child{border-radius:7px 0 0 7px}.euiSplitPanel--row.euiPanel--borderRadiusLarge .euiSplitPanel__inner:last-child{border-radius:0 7px 7px 0}.euiSplitPanel--row.euiPanel--borderRadiusXLarge .euiSplitPanel__inner:first-child{border-radius:15px 0 0 15px}.euiSplitPanel--row.euiPanel--borderRadiusXLarge .euiSplitPanel__inner:last-child{border-radius:0 15px 15px 0}.euiPage{background-color:#172430;flex-shrink:0;max-width:100%;display:flex}.euiPage--restrictWidth-default,.euiPage--restrictWidth-custom{width:100%;margin-left:auto;margin-right:auto}.euiPage--restrictWidth-default{max-width:1000px}.euiPage--grow{flex-grow:1}.euiPage--column{flex-direction:column}@media only screen and (max-width:574px){.euiPage{flex-direction:column}}@media only screen and (min-width:575px) and (max-width:767px){.euiPage{flex-direction:column}}.euiPage--paddingSmall{padding:8px}.euiPage--paddingSmall .euiPageSideBar{min-width:192px;margin-right:8px}@media only screen and (max-width:574px){.euiPage--paddingSmall .euiPageSideBar{margin-bottom:8px;margin-right:0}}@media only screen and (min-width:575px) and (max-width:767px){.euiPage--paddingSmall .euiPageSideBar{margin-bottom:8px;margin-right:0}}.euiPage--paddingSmall .euiPageBody>.euiPageHeader{margin-bottom:8px}.euiPage--paddingMedium{padding:16px}.euiPage--paddingMedium .euiPageSideBar{min-width:192px;margin-right:16px}@media only screen and (max-width:574px){.euiPage--paddingMedium .euiPageSideBar{margin-bottom:16px;margin-right:0}}@media only screen and (min-width:575px) and (max-width:767px){.euiPage--paddingMedium .euiPageSideBar{margin-bottom:16px;margin-right:0}}.euiPage--paddingMedium .euiPageBody>.euiPageHeader{margin-bottom:16px}.euiPage--paddingLarge{padding:24px}.euiPage--paddingLarge .euiPageSideBar{min-width:192px;margin-right:24px}@media only screen and (max-width:574px){.euiPage--paddingLarge .euiPageSideBar{margin-bottom:24px;margin-right:0}}@media only screen and (min-width:575px) and (max-width:767px){.euiPage--paddingLarge .euiPageSideBar{margin-bottom:24px;margin-right:0}}.euiPage--paddingLarge .euiPageBody>.euiPageHeader{margin-bottom:24px}.euiPageBody{flex-direction:column;flex:100%;align-items:stretch;min-width:0;max-width:100%;display:flex}.euiPageBody--restrictWidth-default,.euiPageBody--restrictWidth-custom{width:100%;margin-left:auto;margin-right:auto}.euiPageBody--restrictWidth-default{max-width:1000px}.euiPageBody.euiPageBody--borderRadiusNone{border-top-width:0;border-bottom-width:0;border-right-width:0}.euiPageBody--paddingSmall{padding:8px}.euiPageBody--paddingSmall>.euiPageHeader:not([class*=--padding]){border-bottom:1px solid #293847;margin-bottom:8px}.euiPageBody--paddingSmall>.euiPageHeader:not([class*=--padding]):not(.euiPageHeader--tabsAtBottom){padding-bottom:8px}.euiPageBody--paddingMedium{padding:16px}.euiPageBody--paddingMedium>.euiPageHeader:not([class*=--padding]){border-bottom:1px solid #293847;margin-bottom:16px}.euiPageBody--paddingMedium>.euiPageHeader:not([class*=--padding]):not(.euiPageHeader--tabsAtBottom){padding-bottom:16px}.euiPageBody--paddingLarge{padding:24px}.euiPageBody--paddingLarge>.euiPageHeader:not([class*=--padding]){border-bottom:1px solid #293847;margin-bottom:24px}.euiPageBody--paddingLarge>.euiPageHeader:not([class*=--padding]):not(.euiPageHeader--tabsAtBottom){padding-bottom:24px}.euiPageContent{width:100%;min-width:0}.euiPageContent.euiPageContent--borderRadiusNone{border-bottom-width:0;border-left-width:0;border-right-width:0}.euiPageContent.euiPageContent--verticalCenter{flex-grow:0;align-self:center;margin-top:auto;margin-bottom:auto}.euiPageContent.euiPageContent--horizontalCenter{flex-grow:0;width:auto;max-width:100%;margin-left:auto;margin-right:auto}.euiPageContentBody--restrictWidth-default,.euiPageContentBody--restrictWidth-custom{width:100%;margin-left:auto;margin-right:auto}.euiPageContentBody--restrictWidth-default{max-width:1000px}.euiPageContentBody--paddingSmall{padding:8px}.euiPageContentBody--paddingMedium{padding:16px}.euiPageContentBody--paddingLarge{padding:24px}.euiPageContentHeader{flex-direction:row;justify-content:space-between;align-items:center;display:flex}.euiPageContent[class*=paddingSmall] .euiPageContentHeader{margin-bottom:8px}.euiPageContent[class*=paddingMedium] .euiPageContentHeader{margin-bottom:16px}.euiPageContent[class*=paddingLarge] .euiPageContentHeader{margin-bottom:24px}@media only screen and (max-width:574px){.euiPageContentHeader--responsive{flex-direction:column;align-items:flex-start}}@media only screen and (min-width:575px) and (max-width:767px){.euiPageContentHeader--responsive{flex-direction:column;align-items:flex-start}}.euiPageContentHeaderSection+.euiPageContentHeaderSection{margin-left:32px}@media only screen and (max-width:574px){.euiPageContent[class*=paddingSmall] .euiPageContentHeader--responsive .euiPageContentHeaderSection+.euiPageContentHeaderSection{margin-top:4px;margin-left:0}.euiPageContent[class*=paddingMedium] .euiPageContentHeader--responsive .euiPageContentHeaderSection+.euiPageContentHeaderSection{margin-top:8px;margin-left:0}.euiPageContent[class*=paddingLarge] .euiPageContentHeader--responsive .euiPageContentHeaderSection+.euiPageContentHeaderSection{margin-top:12px;margin-left:0}}@media only screen and (min-width:575px) and (max-width:767px){.euiPageContent[class*=paddingSmall] .euiPageContentHeader--responsive .euiPageContentHeaderSection+.euiPageContentHeaderSection{margin-top:4px;margin-left:0}.euiPageContent[class*=paddingMedium] .euiPageContentHeader--responsive .euiPageContentHeaderSection+.euiPageContentHeaderSection{margin-top:8px;margin-left:0}.euiPageContent[class*=paddingLarge] .euiPageContentHeader--responsive .euiPageContentHeaderSection+.euiPageContentHeaderSection{margin-top:12px;margin-left:0}}.euiPageSideBar{flex:0;min-width:240px}.euiPageSideBar--paddingSmall{padding:8px}.euiPageSideBar--paddingMedium{padding:16px}.euiPageSideBar--paddingLarge{padding:24px}@media only screen and (max-width:574px){.euiPageSideBar{width:100%}}@media only screen and (min-width:575px) and (max-width:767px){.euiPageSideBar{width:100%}}@media only screen and (min-width:768px) and (max-width:991px){.euiPageSideBar--sticky{scrollbar-width:thin;flex-grow:1;max-height:100vh;position:-webkit-sticky;position:sticky;top:0;overflow-y:auto}.euiPageSideBar--sticky::-webkit-scrollbar{width:16px;height:16px}.euiPageSideBar--sticky::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiPageSideBar--sticky::-webkit-scrollbar-corner{background-color:transparent}.euiPageSideBar--sticky::-webkit-scrollbar-track{background-color:transparent}}@media only screen and (min-width:992px) and (max-width:1199px){.euiPageSideBar--sticky{scrollbar-width:thin;flex-grow:1;max-height:100vh;position:-webkit-sticky;position:sticky;top:0;overflow-y:auto}.euiPageSideBar--sticky::-webkit-scrollbar{width:16px;height:16px}.euiPageSideBar--sticky::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiPageSideBar--sticky::-webkit-scrollbar-corner{background-color:transparent}.euiPageSideBar--sticky::-webkit-scrollbar-track{background-color:transparent}}@media only screen and (min-width:1200px) and (max-width:1679px){.euiPageSideBar--sticky{scrollbar-width:thin;flex-grow:1;max-height:100vh;position:-webkit-sticky;position:sticky;top:0;overflow-y:auto}.euiPageSideBar--sticky::-webkit-scrollbar{width:16px;height:16px}.euiPageSideBar--sticky::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiPageSideBar--sticky::-webkit-scrollbar-corner{background-color:transparent}.euiPageSideBar--sticky::-webkit-scrollbar-track{background-color:transparent}}@media only screen and (min-width:1680px) and (max-width:1919px){.euiPageSideBar--sticky{scrollbar-width:thin;flex-grow:1;max-height:100vh;position:-webkit-sticky;position:sticky;top:0;overflow-y:auto}.euiPageSideBar--sticky::-webkit-scrollbar{width:16px;height:16px}.euiPageSideBar--sticky::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiPageSideBar--sticky::-webkit-scrollbar-corner{background-color:transparent}.euiPageSideBar--sticky::-webkit-scrollbar-track{background-color:transparent}}@media only screen and (min-width:1920px){.euiPageSideBar--sticky{scrollbar-width:thin;flex-grow:1;max-height:100vh;position:-webkit-sticky;position:sticky;top:0;overflow-y:auto}.euiPageSideBar--sticky::-webkit-scrollbar{width:16px;height:16px}.euiPageSideBar--sticky::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiPageSideBar--sticky::-webkit-scrollbar-corner{background-color:transparent}.euiPageSideBar--sticky::-webkit-scrollbar-track{background-color:transparent}}.euiPageHeader{flex-direction:row;flex-shrink:0;justify-content:space-between;align-items:center;width:100%;display:flex}.euiPageHeader--restrictWidth-default,.euiPageHeader--restrictWidth-custom{width:100%;margin-left:auto;margin-right:auto}.euiPageHeader--restrictWidth-default{max-width:1000px}.euiPageHeader--bottomBorder{border-bottom:1px solid #293847}.euiPageHeader--bottomBorder:not(.euiPageHeader--tabsAtBottom){padding-bottom:24px}.euiPageHeader--paddingSmall{padding:8px}.euiPageHeader--paddingSmall.euiPageHeader--tabsAtBottom{padding-bottom:0}.euiPageHeader--paddingSmall.euiPageHeader--tabsAtBottom.euiPageHeader--bottomBorder{margin-bottom:8px}.euiPageHeader--paddingMedium{padding:16px}.euiPageHeader--paddingMedium.euiPageHeader--tabsAtBottom{padding-bottom:0}.euiPageHeader--paddingMedium.euiPageHeader--tabsAtBottom.euiPageHeader--bottomBorder{margin-bottom:16px}.euiPageHeader--paddingLarge{padding:24px}.euiPageHeader--paddingLarge.euiPageHeader--tabsAtBottom{padding-bottom:0}.euiPageHeader--paddingLarge.euiPageHeader--tabsAtBottom.euiPageHeader--bottomBorder{margin-bottom:24px}.euiPageHeader--top{align-items:flex-start}.euiPageHeader--bottom{align-items:flex-end}.euiPageHeader--stretch{align-items:stretch}@media only screen and (max-width:574px){.euiPageHeader--responsive{flex-direction:column}.euiPageHeader--responsiveReverse{flex-direction:column-reverse}}@media only screen and (min-width:575px) and (max-width:767px){.euiPageHeader--responsive{flex-direction:column}.euiPageHeader--responsiveReverse{flex-direction:column-reverse}}.euiPageHeader .euiPageHeaderContent{width:100%}.euiPageHeaderContent__titleIcon{margin-right:16px;position:relative;top:-4px}@media only screen and (min-width:768px) and (max-width:991px){.euiPageHeaderContent__rightSideItems{flex-direction:row-reverse}}@media only screen and (min-width:992px) and (max-width:1199px){.euiPageHeaderContent__rightSideItems{flex-direction:row-reverse}}@media only screen and (min-width:1200px) and (max-width:1679px){.euiPageHeaderContent__rightSideItems{flex-direction:row-reverse}}@media only screen and (min-width:1680px) and (max-width:1919px){.euiPageHeaderContent__rightSideItems{flex-direction:row-reverse}}@media only screen and (min-width:1920px){.euiPageHeaderContent__rightSideItems{flex-direction:row-reverse}}.euiPageHeaderSection:not(:first-of-type){margin-left:32px}@media only screen and (max-width:574px){.euiPageHeader--responsive .euiPageHeaderSection{width:100%}.euiPageHeader--responsive .euiPageHeaderSection:not(:first-of-type){margin-top:16px;margin-left:0}.euiPageHeader--responsiveReverse .euiPageHeaderSection{width:100%}.euiPageHeader--responsiveReverse .euiPageHeaderSection:not(:first-of-type){margin-left:0}.euiPageHeader--responsiveReverse .euiPageHeaderSection:not(:last-of-type){margin-top:16px}}@media only screen and (min-width:575px) and (max-width:767px){.euiPageHeader--responsive .euiPageHeaderSection{width:100%}.euiPageHeader--responsive .euiPageHeaderSection:not(:first-of-type){margin-top:16px;margin-left:0}.euiPageHeader--responsiveReverse .euiPageHeaderSection{width:100%}.euiPageHeader--responsiveReverse .euiPageHeaderSection:not(:first-of-type){margin-left:0}.euiPageHeader--responsiveReverse .euiPageHeaderSection:not(:last-of-type){margin-top:16px}}.euiPopover{vertical-align:middle;max-width:100%;display:inline-block;position:relative}.euiPopover__anchor{display:inline-block}.euiPopover--displayBlock,.euiPopover--displayBlock .euiPopover__anchor{display:block}.euiPopover__panel{-webkit-backface-visibility:hidden;backface-visibility:hidden;pointer-events:none;opacity:0;visibility:hidden;min-width:112px;max-width:calc(100vw - 32px);transition:opacity 90ms cubic-bezier(.34,1.61,.7,1),visibility 90ms cubic-bezier(.34,1.61,.7,1);position:absolute;box-shadow:0 12px 24px rgba(0,0,0,.1),0 6px 12px rgba(0,0,0,.1),0 4px 4px rgba(0,0,0,.1),0 2px 2px rgba(0,0,0,.1)}.euiPopover__panel:not(.euiPopover__panel-isAttached){transition:opacity 90ms cubic-bezier(.34,1.61,.7,1),visibility 90ms cubic-bezier(.34,1.61,.7,1),transform .19s cubic-bezier(.34,1.61,.7,1);transform:translateY(0)translate(0)translateZ(0)}.euiPopover__panel.euiPopover__panel-isOpen{opacity:1;visibility:visible;pointer-events:auto}.euiPopover__panel .euiPopover__panelArrow{width:0;height:0;position:absolute}.euiPopover__panel .euiPopover__panelArrow:before,.euiPopover__panel .euiPopover__panelArrow:after{content:"";width:0;height:0;position:absolute}.euiPopover__panel .euiPopover__panelArrow.euiPopover__panelArrow--top:before{border-top:12px solid #293847;border-left:12px solid transparent;border-right:12px solid transparent;bottom:-10px}.euiPopover__panel .euiPopover__panelArrow.euiPopover__panelArrow--top:after{border-top:12px solid #0a121a;border-left:12px solid transparent;border-right:12px solid transparent;bottom:-9px}.euiPopover__panel .euiPopover__panelArrow.euiPopover__panelArrow--right:before{border-top:12px solid transparent;border-bottom:12px solid transparent;border-right:12px solid #293847;top:50%;left:-12px}.euiPopover__panel .euiPopover__panelArrow.euiPopover__panelArrow--right:after{border-top:12px solid transparent;border-bottom:12px solid transparent;border-right:12px solid #0a121a;top:50%;left:-11px}.euiPopover__panel .euiPopover__panelArrow.euiPopover__panelArrow--bottom:before{border-bottom:12px solid #293847;border-left:12px solid transparent;border-right:12px solid transparent;top:-12px}.euiPopover__panel .euiPopover__panelArrow.euiPopover__panelArrow--bottom:after{border-bottom:12px solid #0a121a;border-left:12px solid transparent;border-right:12px solid transparent;top:-11px}.euiPopover__panel .euiPopover__panelArrow.euiPopover__panelArrow--left:before{border-top:12px solid transparent;border-bottom:12px solid transparent;border-left:12px solid #293847;top:50%;right:-11px}.euiPopover__panel .euiPopover__panelArrow.euiPopover__panelArrow--left:after{border-top:12px solid transparent;border-bottom:12px solid transparent;border-left:12px solid #0a121a;top:50%;right:-10px}.euiPopover__panel.euiPopover__panel-noArrow .euiPopover__panelArrow{display:none}.euiPopover__panel.euiPopover__panel-isAttached.euiPopover__panel--bottom{border-top-color:rgba(41,56,71,.8);border-top-left-radius:0;border-top-right-radius:0}.euiPopover__panel.euiPopover__panel-isAttached.euiPopover__panel--top{border-bottom-color:rgba(41,56,71,.8);border-bottom-right-radius:0;border-bottom-left-radius:0;box-shadow:0 0 12px -1px rgba(0,0,0,.2),0 0 4px -1px rgba(0,0,0,.2),0 0 2px rgba(0,0,0,.2)}.euiPopover__panel.euiPopover__panel-isAttached.euiPopover__panel--top,.euiPopover__panel.euiPopover__panel-isOpen.euiPopover__panel--top{transform:translateY(8px)translateZ(0)}.euiPopover__panel.euiPopover__panel-isAttached.euiPopover__panel--bottom,.euiPopover__panel.euiPopover__panel-isOpen.euiPopover__panel--bottom{transform:translateY(-8px)translateZ(0)}.euiPopover__panel.euiPopover__panel-isOpen.euiPopover__panel--left{transform:translate(8px)translateZ(0)}.euiPopover__panel.euiPopover__panel-isOpen.euiPopover__panel--right{transform:translate(-8px)translateZ(0)}.euiPopoverTitle{color:#dfe5ef;letter-spacing:-.005em;text-transform:none;border-bottom:1px solid #293847;padding:12px;font-size:.875rem;font-weight:700;line-height:1.33333rem}.euiPopoverTitle--paddingNone{padding:0}.euiPopoverTitle--paddingSmall{padding:8px}.euiPopoverTitle--paddingMedium{padding:16px}.euiPopoverTitle--paddingLarge{padding:24px}.euiPopover__panel.euiPanel--paddingSmall .euiPopoverTitle{margin:-8px -8px 8px}.euiPopover__panel.euiPanel--paddingSmall .euiPopoverTitle:not([class*=ouiPopoverTitle--padding]){padding:12px 8px}.euiPopover__panel.euiPanel--paddingMedium .euiPopoverTitle{margin:-16px -16px 16px}.euiPopover__panel.euiPanel--paddingMedium .euiPopoverTitle:not([class*=ouiPopoverTitle--padding]){padding:12px 16px}.euiPopover__panel.euiPanel--paddingLarge .euiPopoverTitle{margin:-24px -24px 24px}.euiPopover__panel.euiPanel--paddingLarge .euiPopoverTitle:not([class*=ouiPopoverTitle--padding]){padding:12px 24px}.euiPopoverFooter{border-top:1px solid #293847;padding:12px;font-size:.875rem;line-height:1.33333}.euiPopoverFooter--paddingNone{padding:0}.euiPopoverFooter--paddingSmall{padding:8px}.euiPopoverFooter--paddingMedium{padding:16px}.euiPopoverFooter--paddingLarge{padding:24px}.euiPopover__panel.euiPanel--paddingSmall .euiPopoverFooter{margin:8px -8px -8px}.euiPopover__panel.euiPanel--paddingSmall .euiPopoverFooter:not([class*=ouiPopoverFooter--padding]){padding:12px 8px}.euiPopover__panel.euiPanel--paddingMedium .euiPopoverFooter{margin:16px -16px -16px}.euiPopover__panel.euiPanel--paddingMedium .euiPopoverFooter:not([class*=ouiPopoverFooter--padding]){padding:12px 16px}.euiPopover__panel.euiPanel--paddingLarge .euiPopoverFooter{margin:24px -24px -24px}.euiPopover__panel.euiPanel--paddingLarge .euiPopoverFooter:not([class*=ouiPopoverFooter--padding]){padding:12px 24px}.euiInputPopover{max-width:400px}.euiInputPopover.euiInputPopover--fullWidth{max-width:100%}.euiBody-hasPortalContent{position:relative}.euiProgress{background-color:#293847;position:relative;overflow:hidden}.euiProgress--xs{height:2px}.euiProgress--s{height:4px}.euiProgress--m{height:8px}.euiProgress--l{height:16px}.euiProgress--native{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;border:none;width:100%;display:block}.euiProgress--native::-webkit-progress-bar{background-color:#293847}.euiProgress--native::-webkit-progress-value{transition:width .25s linear}.euiProgress--native::-moz-progress-bar{transition:width .25s linear}.euiProgress--indeterminate:before{content:"";width:100%;animation:1s cubic-bezier(.694,.0482,.335,1) infinite euiProgress;position:absolute;top:0;bottom:0;left:0;transform:scaleX(0)translate(0%)}.euiProgress--fixed{z-index:1001;position:fixed}.euiProgress--absolute{position:absolute}.euiProgress--fixed,.euiProgress--absolute{background-color:transparent;top:0;left:0;right:0}.euiProgress--fixed.euiProgress--native::-webkit-progress-bar{background-color:transparent}.euiProgress--absolute.euiProgress--native::-webkit-progress-bar{background-color:transparent}.euiProgress--fixed.euiProgress--native::-moz-progress-bar{background-color:transparent}.euiProgress--absolute.euiProgress--native::-moz-progress-bar{background-color:transparent}.euiProgress--primary.euiProgress--native::-webkit-progress-value{background-color:#159d8d}.euiProgress--primary.euiProgress--native::-moz-progress-bar{background-color:#159d8d}.euiProgress--primary.euiProgress--indeterminate:before{background-color:#159d8d}.euiProgress__data--primary .euiProgress__valueText{color:#159d8d}.euiProgress--secondary.euiProgress--native::-webkit-progress-value{background-color:#7de2d1}.euiProgress--secondary.euiProgress--native::-moz-progress-bar{background-color:#7de2d1}.euiProgress--secondary.euiProgress--indeterminate:before{background-color:#7de2d1}.euiProgress__data--secondary .euiProgress__valueText{color:#7de2d1}.euiProgress--success.euiProgress--native::-webkit-progress-value{background-color:#7de2d1}.euiProgress--success.euiProgress--native::-moz-progress-bar{background-color:#7de2d1}.euiProgress--success.euiProgress--indeterminate:before{background-color:#7de2d1}.euiProgress__data--success .euiProgress__valueText{color:#7de2d1}.euiProgress--warning.euiProgress--native::-webkit-progress-value{background-color:#ffce7a}.euiProgress--warning.euiProgress--native::-moz-progress-bar{background-color:#ffce7a}.euiProgress--warning.euiProgress--indeterminate:before{background-color:#ffce7a}.euiProgress__data--warning .euiProgress__valueText{color:#ffce7a}.euiProgress--danger.euiProgress--native::-webkit-progress-value{background-color:#f66}.euiProgress--danger.euiProgress--native::-moz-progress-bar{background-color:#f66}.euiProgress--danger.euiProgress--indeterminate:before{background-color:#f66}.euiProgress__data--danger .euiProgress__valueText{color:#f66}.euiProgress--accent.euiProgress--native::-webkit-progress-value{background-color:#f990c0}.euiProgress--accent.euiProgress--native::-moz-progress-bar{background-color:#f990c0}.euiProgress--accent.euiProgress--indeterminate:before{background-color:#f990c0}.euiProgress__data--accent .euiProgress__valueText{color:#f990c0}.euiProgress--subdued.euiProgress--native::-webkit-progress-value{background-color:#9fa6af}.euiProgress--subdued.euiProgress--native::-moz-progress-bar{background-color:#9fa6af}.euiProgress--subdued.euiProgress--indeterminate:before{background-color:#9fa6af}.euiProgress__data--subdued .euiProgress__valueText{color:#9fa6af}.euiProgress--vis0.euiProgress--native::-webkit-progress-value{background-color:#54b399}.euiProgress--vis0.euiProgress--native::-moz-progress-bar{background-color:#54b399}.euiProgress--vis0.euiProgress--indeterminate:before{background-color:#54b399}.euiProgress__data--vis0 .euiProgress__valueText{color:#54b399}.euiProgress--vis1.euiProgress--native::-webkit-progress-value{background-color:#6092c0}.euiProgress--vis1.euiProgress--native::-moz-progress-bar{background-color:#6092c0}.euiProgress--vis1.euiProgress--indeterminate:before{background-color:#6092c0}.euiProgress__data--vis1 .euiProgress__valueText{color:#6092c0}.euiProgress--vis2.euiProgress--native::-webkit-progress-value{background-color:#d36086}.euiProgress--vis2.euiProgress--native::-moz-progress-bar{background-color:#d36086}.euiProgress--vis2.euiProgress--indeterminate:before{background-color:#d36086}.euiProgress__data--vis2 .euiProgress__valueText{color:#d5688c}.euiProgress--vis3.euiProgress--native::-webkit-progress-value{background-color:#9170b8}.euiProgress--vis3.euiProgress--native::-moz-progress-bar{background-color:#9170b8}.euiProgress--vis3.euiProgress--indeterminate:before{background-color:#9170b8}.euiProgress__data--vis3 .euiProgress__valueText{color:#9b7ebf}.euiProgress--vis4.euiProgress--native::-webkit-progress-value{background-color:#ca8eae}.euiProgress--vis4.euiProgress--native::-moz-progress-bar{background-color:#ca8eae}.euiProgress--vis4.euiProgress--indeterminate:before{background-color:#ca8eae}.euiProgress__data--vis4 .euiProgress__valueText{color:#ca8eae}.euiProgress--vis5.euiProgress--native::-webkit-progress-value{background-color:#d6bf57}.euiProgress--vis5.euiProgress--native::-moz-progress-bar{background-color:#d6bf57}.euiProgress--vis5.euiProgress--indeterminate:before{background-color:#d6bf57}.euiProgress__data--vis5 .euiProgress__valueText{color:#d6bf57}.euiProgress--vis6.euiProgress--native::-webkit-progress-value{background-color:#b9a888}.euiProgress--vis6.euiProgress--native::-moz-progress-bar{background-color:#b9a888}.euiProgress--vis6.euiProgress--indeterminate:before{background-color:#b9a888}.euiProgress__data--vis6 .euiProgress__valueText{color:#b9a888}.euiProgress--vis7.euiProgress--native::-webkit-progress-value{background-color:#da8b45}.euiProgress--vis7.euiProgress--native::-moz-progress-bar{background-color:#da8b45}.euiProgress--vis7.euiProgress--indeterminate:before{background-color:#da8b45}.euiProgress__data--vis7 .euiProgress__valueText{color:#da8b45}.euiProgress--vis8.euiProgress--native::-webkit-progress-value{background-color:#aa6556}.euiProgress--vis8.euiProgress--native::-moz-progress-bar{background-color:#aa6556}.euiProgress--vis8.euiProgress--indeterminate:before{background-color:#aa6556}.euiProgress__data--vis8 .euiProgress__valueText{color:#b67b6e}.euiProgress--vis9.euiProgress--native::-webkit-progress-value{background-color:#e7664c}.euiProgress--vis9.euiProgress--native::-moz-progress-bar{background-color:#e7664c}.euiProgress--vis9.euiProgress--indeterminate:before{background-color:#e7664c}.euiProgress__data--vis9 .euiProgress__valueText{color:#e7664c}.euiProgress--customColor.euiProgress--native::-webkit-progress-value{background-color:currentColor}.euiProgress--customColor.euiProgress--native::-moz-progress-bar{background-color:currentColor}.euiProgress--customColor.euiProgress--indeterminate:before{background-color:currentColor}@keyframes euiProgress{0%{transform:scaleX(1)translate(-100%)}to{transform:scaleX(1)translate(100%)}}.euiProgress__data{justify-content:space-between;display:flex}.euiProgress__label,.euiProgress__valueText{color:#dfe5ef;max-width:100%;font-size:.75rem;font-weight:400;line-height:1.33333;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiProgress__label{flex-grow:1}.euiProgress__label+.euiProgress__valueText{text-align:right;flex-grow:1;flex-shrink:0;padding-left:4px}.euiProgress__valueText{font-feature-settings:"tnum" 1;margin-left:auto}.euiProgress__data--l .euiProgress__label,.euiProgress__data--l .euiProgress__valueText{font-size:.875rem;line-height:1.33333}.euiTreeView__wrapper .euiTreeView{margin:0;list-style-type:none}.euiTreeView .euiTreeView{padding-left:24px}.euiTreeView__node{max-height:32px;line-height:32px}.euiTreeView__node--expanded{max-height:100vh}.euiTreeView__nodeInner{text-align-last:left;border-radius:4px;flex-direction:row;align-items:center;width:100%;max-width:100%;height:32px;padding-left:8px;display:flex;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiTreeView__nodeInner:focus{animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiTreeView__nodeInner:hover,.euiTreeView__nodeInner:active,.euiTreeView__nodeInner:focus{background-color:#555c65}.euiTreeView__nodeInner .euiTreeView__iconPlaceholder{width:32px}.euiTreeView__nodeLabel{max-width:100%;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiTreeView__iconWrapper{margin-top:-2px;margin-right:8px}.euiTreeView__iconWrapper .euiToken{margin-top:2px}.euiTreeView--compressed .euiTreeView__node{max-height:24px;line-height:24px}.euiTreeView--compressed .euiTreeView__node .euiTreeView__nodeInner{height:24px}.euiTreeView--compressed .euiTreeView__node .euiTreeView__iconWrapper{margin:0 6px 0 0}.euiTreeView--compressed .euiTreeView__node .euiTreeView__nodeLabel{margin-top:-1px}.euiTreeView--compressed .euiTreeView__node .euiTreeView__iconPlaceholder{width:24px}.euiTreeView--compressed .euiTreeView__node--expanded{max-height:100vh}.euiTreeView--withArrows .euiTreeView__expansionArrow{margin-right:4px}.euiTreeView--withArrows.euiTreeView .euiTreeView__nodeInner--withArrows .euiTreeView__iconWrapper{margin-left:0}.euiTreeView--withArrows.euiTreeView .euiTreeView__iconWrapper{margin-left:20px}.euiTreeView--withArrows.euiTreeView--compressed .euiTreeView__nodeInner--withArrows .euiTreeView__iconWrapper{margin-left:0}.euiTreeView--withArrows.euiTreeView--compressed .euiTreeView__iconWrapper{margin-left:16px}.euiResizableButton{z-index:1000;flex-shrink:0;position:relative}.euiResizableButton:before,.euiResizableButton:after{content:"";background-color:#dfe3e8;transition:width .15s,height .15s,transform .15s,background-color .15s;display:block;position:absolute;top:50%;left:50%}.euiResizableButton.euiResizableButton--horizontal{cursor:col-resize;width:16px;margin-left:-8px;margin-right:-8px}.euiResizableButton.euiResizableButton--horizontal:before,.euiResizableButton.euiResizableButton--horizontal:after{width:1px;height:12px}.euiResizableButton.euiResizableButton--horizontal:before{transform:translate(-2px,-50%)}.euiResizableButton.euiResizableButton--horizontal:after{transform:translate(1px,-50%)}.euiResizableButton.euiResizableButton--vertical{cursor:row-resize;height:16px;margin-top:-8px;margin-bottom:-8px}.euiResizableButton.euiResizableButton--vertical:before,.euiResizableButton.euiResizableButton--vertical:after{width:12px;height:1px}.euiResizableButton.euiResizableButton--vertical:before{transform:translate(-50%,-2px)}.euiResizableButton.euiResizableButton--vertical:after{transform:translate(-50%,1px)}.euiResizableButton:hover:not(:disabled):before,.euiResizableButton:hover:not(:disabled):after{background-color:#5b6875;transition-delay:.15s}.euiResizableButton:focus:not(:disabled){background-color:rgba(21,157,141,.1)}.euiResizableButton:focus:not(:disabled):before,.euiResizableButton:focus:not(:disabled):after{background-color:#159d8d;transition:width .15s 75ms,height .15s 75ms,transform .15s 75ms}.euiResizableButton:hover:not(:disabled).euiResizableButton--horizontal:before,.euiResizableButton:hover:not(:disabled).euiResizableButton--horizontal:after,.euiResizableButton:focus:not(:disabled).euiResizableButton--horizontal:before,.euiResizableButton:focus:not(:disabled).euiResizableButton--horizontal:after{height:100%}.euiResizableButton:hover:not(:disabled).euiResizableButton--horizontal:before,.euiResizableButton:focus:not(:disabled).euiResizableButton--horizontal:before{transform:translate(-1px,-50%)}.euiResizableButton:hover:not(:disabled).euiResizableButton--horizontal:after,.euiResizableButton:focus:not(:disabled).euiResizableButton--horizontal:after{transform:translateY(-50%)}.euiResizableButton:hover:not(:disabled).euiResizableButton--vertical:before,.euiResizableButton:hover:not(:disabled).euiResizableButton--vertical:after,.euiResizableButton:focus:not(:disabled).euiResizableButton--vertical:before,.euiResizableButton:focus:not(:disabled).euiResizableButton--vertical:after{width:100%}.euiResizableButton:hover:not(:disabled).euiResizableButton--vertical:before,.euiResizableButton:focus:not(:disabled).euiResizableButton--vertical:before{transform:translate(-50%,-1px)}.euiResizableButton:hover:not(:disabled).euiResizableButton--vertical:after,.euiResizableButton:focus:not(:disabled).euiResizableButton--vertical:after{transform:translate(-50%)}.euiResizableButton:disabled{display:none!important}.euiResizableToggleButton{z-index:1001;transition-property:background,box-shadow;position:absolute;box-shadow:0 2px 2px -1px rgba(0,0,0,.3);animation:none!important}.euiResizableToggleButton:focus{box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiResizableToggleButton-isCollapsed{box-shadow:none;background:0 0;border-radius:0}.euiResizableToggleButton:not(:focus):not(:active):not(.euiResizableToggleButton-isVisible):not(.euiResizableToggleButton-isCollapsed){-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;border-width:0;width:0;height:0;position:absolute;top:auto;left:-10000px;overflow:hidden}.euiResizableToggleButton--horizontal.euiResizableToggleButton.euiResizableToggleButton--after{top:50%;right:0;transform:translate(50%,-50%)}.euiResizableToggleButton--horizontal.euiResizableToggleButton.euiResizableToggleButton--after.euiResizableToggleButton--top{top:0;transform:translate(50%,16px)}.euiResizableToggleButton--horizontal.euiResizableToggleButton.euiResizableToggleButton--after.euiResizableToggleButton--bottom{top:auto;bottom:0;transform:translate(50%,-16px)}.euiResizableToggleButton--horizontal.euiResizableToggleButton.euiResizableToggleButton--before{top:50%;left:0;transform:translate(-50%,-50%)}.euiResizableToggleButton--horizontal.euiResizableToggleButton.euiResizableToggleButton--before.euiResizableToggleButton--top{top:0;transform:translate(-50%,16px)}.euiResizableToggleButton--horizontal.euiResizableToggleButton.euiResizableToggleButton--before.euiResizableToggleButton--bottom{top:auto;bottom:0;transform:translate(-50%,-16px)}.euiResizableToggleButton--horizontal.euiResizableToggleButton.euiResizableToggleButton-isCollapsed{height:100%;top:0!important;bottom:0!important;transform:none!important}.euiResizableToggleButton--horizontal.euiResizableToggleButton.euiResizableToggleButton-isCollapsed.euiResizableToggleButton--top{align-items:flex-start;padding-top:16px}.euiResizableToggleButton--horizontal.euiResizableToggleButton.euiResizableToggleButton-isCollapsed.euiResizableToggleButton--bottom{align-items:flex-end;padding-bottom:16px}.euiResizableToggleButton--vertical.euiResizableToggleButton.euiResizableToggleButton--after{top:100%;left:50%;transform:translate(-50%,-50%)}.euiResizableToggleButton--vertical.euiResizableToggleButton.euiResizableToggleButton--after.euiResizableToggleButton--left{left:0;transform:translate(16px,-50%)}.euiResizableToggleButton--vertical.euiResizableToggleButton.euiResizableToggleButton--after.euiResizableToggleButton--right{left:auto;right:0;transform:translate(-16px,-50%)}.euiResizableToggleButton--vertical.euiResizableToggleButton.euiResizableToggleButton--before{bottom:100%;left:50%;transform:translate(-50%,50%)}.euiResizableToggleButton--vertical.euiResizableToggleButton.euiResizableToggleButton--before.euiResizableToggleButton--left{left:0;transform:translate(16px,50%)}.euiResizableToggleButton--vertical.euiResizableToggleButton.euiResizableToggleButton--before.euiResizableToggleButton--right{left:auto;right:0;transform:translate(-16px,50%)}.euiResizableToggleButton--vertical.euiResizableToggleButton.euiResizableToggleButton-isCollapsed{width:100%;top:0!important;bottom:0!important;left:0!important;transform:none!important}.euiResizableToggleButton--vertical.euiResizableToggleButton.euiResizableToggleButton-isCollapsed.euiResizableToggleButton--left{justify-content:flex-start;padding-left:16px}.euiResizableToggleButton--vertical.euiResizableToggleButton.euiResizableToggleButton-isCollapsed.euiResizableToggleButton--right{justify-content:flex-end;padding-right:16px}.euiResizableContainer{width:100%;display:flex}.euiResizableContainer--vertical{flex-direction:column}.euiResizablePanel{position:relative}.euiResizablePanel--paddingSmall{padding:8px}.euiResizablePanel--paddingMedium{padding:16px}.euiResizablePanel--paddingLarge{padding:24px}.euiResizablePanel__content{height:100%}.euiResizablePanel__content:not([class*=plain]){border-width:0}.euiResizablePanel__content--scrollable{scrollbar-width:thin;overflow-y:auto}.euiResizablePanel__content--scrollable::-webkit-scrollbar{width:16px;height:16px}.euiResizablePanel__content--scrollable::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiResizablePanel__content--scrollable::-webkit-scrollbar-corner{background-color:transparent}.euiResizablePanel__content--scrollable::-webkit-scrollbar-track{background-color:transparent}.euiResizablePanel-isCollapsed{overflow:hidden}.euiResizablePanel-isCollapsed .euiResizablePanel__content *{display:none}.euiResizableContainer--horizontal .euiResizablePanel-isCollapsed{min-width:0!important}.euiResizableContainer--horizontal .euiResizablePanel--collapsible.euiResizablePanel-isCollapsed{min-width:24px!important}.euiResizableContainer--vertical .euiResizablePanel-isCollapsed{min-height:0!important}.euiResizableContainer--vertical .euiResizablePanel--collapsible.euiResizablePanel-isCollapsed{min-height:24px!important}.euiSchemaItem{border-radius:4px;align-items:center;gap:8px;padding:8px;display:flex}.euiSchemaItem:hover{background-color:#555c65}.euiSchemaItem:hover .euiSchemaItem__actions .euiButtonIcon{opacity:1;visibility:visible}.euiSchemaItem__icon{align-self:flex-start;margin:8px 0}.euiSchemaItem__label{flex:1;margin:8px 0}.euiSchemaItem__actions{gap:4px;display:flex}.euiSchemaItem__actions .euiButtonIcon{opacity:0;transition:opacity .25s cubic-bezier(.694,.0482,.335,1)}.euiSchemaItem__actions .euiButtonIcon:focus{opacity:1}.euiSchemaItem--withPanel{border:1px solid #293847;box-shadow:0 2px 2px -1px rgba(0,0,0,.3),0 1px 5px -2px rgba(0,0,0,.3)}.euiSchemaItem--withPanel:hover{background-color:#0f1923}.euiSchemaItem--compressed{gap:4px;padding:4px;font-size:13.5px}.euiSchemaItem--compressed .euiSchemaItem__icon{margin:6px 0 6px 4px}.euiSchemaItem--compressed .euiSchemaItem__label{flex:1;margin:6px 0}.euiSideNav__mobileToggle{text-align:left;border-bottom:1px solid #293847;width:100%;height:auto;padding:0 16px;font-size:20.25px;border-radius:0!important}.euiSideNav__mobileToggle .euiSideNav__mobileToggleText{padding:16px 0}.euiSideNav__mobileToggle .euiSideNav__mobileToggleContent{justify-content:space-between}.euiSideNav__heading{margin-bottom:24px}@media only screen and (max-width:574px){.euiSideNav__contentMobile-xs{visibility:hidden;opacity:0;max-height:0;padding:0 24px;overflow:hidden}.euiSideNav-isOpenMobile .euiSideNav__contentMobile-xs{visibility:visible;opacity:1;max-height:5000px;padding:24px}}@media only screen and (max-width:574px) and (prefers-reduced-motion:no-preference){.euiSideNav-isOpenMobile .euiSideNav__contentMobile-xs{transition:all .25s cubic-bezier(.694,.0482,.335,1)}}@media only screen and (min-width:575px) and (max-width:767px){.euiSideNav__contentMobile-s{visibility:hidden;opacity:0;max-height:0;padding:0 24px;overflow:hidden}.euiSideNav-isOpenMobile .euiSideNav__contentMobile-s{visibility:visible;opacity:1;max-height:5000px;padding:24px}}@media only screen and (min-width:575px) and (max-width:767px) and (prefers-reduced-motion:no-preference){.euiSideNav-isOpenMobile .euiSideNav__contentMobile-s{transition:all .25s cubic-bezier(.694,.0482,.335,1)}}@media only screen and (min-width:768px) and (max-width:991px){.euiSideNav__contentMobile-m{visibility:hidden;opacity:0;max-height:0;padding:0 24px;overflow:hidden}.euiSideNav-isOpenMobile .euiSideNav__contentMobile-m{visibility:visible;opacity:1;max-height:5000px;padding:24px}}@media only screen and (min-width:768px) and (max-width:991px) and (prefers-reduced-motion:no-preference){.euiSideNav-isOpenMobile .euiSideNav__contentMobile-m{transition:all .25s cubic-bezier(.694,.0482,.335,1)}}@media only screen and (min-width:992px) and (max-width:1199px){.euiSideNav__contentMobile-l{visibility:hidden;opacity:0;max-height:0;padding:0 24px;overflow:hidden}.euiSideNav-isOpenMobile .euiSideNav__contentMobile-l{visibility:visible;opacity:1;max-height:5000px;padding:24px}}@media only screen and (min-width:992px) and (max-width:1199px) and (prefers-reduced-motion:no-preference){.euiSideNav-isOpenMobile .euiSideNav__contentMobile-l{transition:all .25s cubic-bezier(.694,.0482,.335,1)}}@media only screen and (min-width:1200px) and (max-width:1679px){.euiSideNav__contentMobile-xl{visibility:hidden;opacity:0;max-height:0;padding:0 24px;overflow:hidden}.euiSideNav-isOpenMobile .euiSideNav__contentMobile-xl{visibility:visible;opacity:1;max-height:5000px;padding:24px}}@media only screen and (min-width:1200px) and (max-width:1679px) and (prefers-reduced-motion:no-preference){.euiSideNav-isOpenMobile .euiSideNav__contentMobile-xl{transition:all .25s cubic-bezier(.694,.0482,.335,1)}}@media only screen and (min-width:1680px) and (max-width:1919px){.euiSideNav__contentMobile-xxl{visibility:hidden;opacity:0;max-height:0;padding:0 24px;overflow:hidden}.euiSideNav-isOpenMobile .euiSideNav__contentMobile-xxl{visibility:visible;opacity:1;max-height:5000px;padding:24px}}@media only screen and (min-width:1680px) and (max-width:1919px) and (prefers-reduced-motion:no-preference){.euiSideNav-isOpenMobile .euiSideNav__contentMobile-xxl{transition:all .25s cubic-bezier(.694,.0482,.335,1)}}@media only screen and (min-width:1920px){.euiSideNav__contentMobile-xxxl{visibility:hidden;opacity:0;max-height:0;padding:0 24px;overflow:hidden}.euiSideNav-isOpenMobile .euiSideNav__contentMobile-xxxl{visibility:visible;opacity:1;max-height:5000px;padding:24px}}@media only screen and (min-width:1920px) and (prefers-reduced-motion:no-preference){.euiSideNav-isOpenMobile .euiSideNav__contentMobile-xxxl{transition:all .25s cubic-bezier(.694,.0482,.335,1)}}.euiSideNavItemButton{text-align:left;width:100%;color:inherit;padding:2px 0;font-size:.875rem;line-height:1.33333;display:block}.euiSideNavItemButton.euiSideNavItemButton--isClickable:not(:disabled):hover{cursor:pointer}.euiSideNavItemButton.euiSideNavItemButton--isClickable:not(:disabled):hover .euiSideNavItemButton__label,.euiSideNavItemButton.euiSideNavItemButton--isClickable:not(:disabled):focus .euiSideNavItemButton__label{text-decoration:underline}.euiSideNavItemButton.euiSideNavItemButton-isSelected{color:#21a293;font-weight:700}.euiSideNavItemButton.euiSideNavItemButton-isSelected .euiSideNavItemButton__label{text-decoration:underline}.euiSideNavItemButton:disabled{cursor:not-allowed;color:#535a62;text-decoration:none}.euiSideNavItemButton__content{align-items:center;display:flex}.euiSideNavItemButton__icon{margin-right:8px}.euiSideNavItemButton__labelContainer{min-width:0}.euiSideNavItemButton__label{flex-grow:1}.euiSideNavItemButton__label--truncated{max-width:100%;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiSideNavItem--root.euiSideNavItem--rootIcon>.euiSideNavItem__items{margin-left:24px}.euiSideNavItem--root>.euiSideNavItemButton{width:calc(100% + 16px);margin-bottom:8px;margin-left:-8px;padding:0 8px}.euiSideNavItem--root>.euiSideNavItemButton .euiSideNavItemButton__label{color:inherit;letter-spacing:-.02em;font-size:1rem;font-weight:600;line-height:1.33333rem}.euiSideNavItem--root>.euiSideNavItem__items{margin-left:0;position:static}.euiSideNavItem--root>.euiSideNavItem__items:after{display:none}.euiSideNavItem--root+.euiSideNavItem--root{margin-top:32px}.euiSideNavItem--trunk{color:#dfe5ef}.euiSideNavItem--trunk>.euiSideNavItemButton{width:calc(100% + 16px);margin-left:-8px;padding-left:8px;padding-right:8px}.euiSideNavItem--trunk>.euiSideNavItem__items{width:100%;margin-left:8px}.euiSideNavItem--branch{color:#9fa6af;position:relative}.euiSideNavItem--branch:after{content:"";background:#293847;width:1px;position:absolute;top:0;bottom:0;left:0}.euiSideNavItem--branch:last-of-type:after{height:12px}.euiSideNavItem--branch>.euiSideNavItemButton{padding-left:8px;padding-right:8px;position:relative}.euiSideNavItem--branch>.euiSideNavItemButton:after{content:"";background:#293847;width:4px;height:1px;position:absolute;top:12px;left:0}.euiSideNavItem--branch>.euiSideNavItem__items{margin-left:16px}.euiSideNavItem--emphasized{color:#dfe5ef;background:rgba(41,56,71,.3);box-shadow:100px 0 rgba(41,56,71,.3),-100px 0 rgba(41,56,71,.3)}.euiSideNavItem--emphasized>.euiSideNavItemButton{font-weight:700}.euiSideNavItem--emphasized .euiSideNavItem--emphasized{box-shadow:none;background:0 0}.euiSpacer{flex-shrink:0}.euiSpacer--xs{height:4px}.euiSpacer--s{height:8px}.euiSpacer--m{height:16px}.euiSpacer--l{height:24px}.euiSpacer--xl{height:32px}.euiSpacer--xxl{height:40px}.euiSearchBar__searchHolder{min-width:200px}@media only screen and (min-width:768px) and (max-width:991px){.euiSearchBar__filtersHolder{max-width:calc(100% - 16px)}}@media only screen and (min-width:992px) and (max-width:1199px){.euiSearchBar__filtersHolder{max-width:calc(100% - 16px)}}@media only screen and (min-width:1200px) and (max-width:1679px){.euiSearchBar__filtersHolder{max-width:calc(100% - 16px)}}@media only screen and (min-width:1680px) and (max-width:1919px){.euiSearchBar__filtersHolder{max-width:calc(100% - 16px)}}@media only screen and (min-width:1920px){.euiSearchBar__filtersHolder{max-width:calc(100% - 16px)}}.euiSelectable{flex-direction:column;display:flex}.euiSelectable-fullHeight{height:100%}.euiSelectableList:focus-within{animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiSelectableList-fullHeight{flex-grow:1}.euiSelectableList-bordered{border:1px solid #293847;border-radius:4px;overflow:hidden}.euiSelectableList__list{contain:paint;scrollbar-width:thin;-webkit-mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%);mask-image:linear-gradient(rgba(255,0,0,.1) 0%,red 7.5px,red calc(100% - 7.5px),rgba(255,0,0,.1) 100%)}.euiSelectableList__list::-webkit-scrollbar{width:16px;height:16px}.euiSelectableList__list::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiSelectableList__list::-webkit-scrollbar-corner{background-color:transparent}.euiSelectableList__list::-webkit-scrollbar-track{background-color:transparent}.euiSelectableList__groupLabel{color:#dfe5ef;letter-spacing:-.005em;border-bottom:1px solid #0d161e;align-items:center;padding:4px 12px;font-size:.75rem;font-weight:700;line-height:1.33333rem;display:flex}.euiSelectableListItem{text-align:left;color:#dfe5ef;cursor:pointer;width:100%;font-size:.875rem;line-height:1.33333;display:inline-flex}.euiSelectableListItem:not(:last-of-type){border-bottom:1px solid #0d161e}.euiSelectableListItem-isFocused:not([aria-disabled=true]),.euiSelectableListItem:hover:not([aria-disabled=true]){color:#159d8d;background-color:#0e4342}.euiSelectableListItem-isFocused:not([aria-disabled=true]) .euiSelectableListItem__text,.euiSelectableListItem:hover:not([aria-disabled=true]) .euiSelectableListItem__text{text-decoration:underline}.euiSelectableListItem[aria-disabled=true]{color:#5b6875;cursor:not-allowed}.euiSelectableListItem__content{align-items:center;width:100%;padding:4px 12px;display:flex}.euiSelectableListItem__icon,.euiSelectableListItem__prepend{flex-shrink:0;margin-right:12px}.euiSelectableListItem__append{flex-shrink:0;margin-left:12px}.euiSelectableListItem__text{flex-grow:1;max-width:100%;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiSelectableMessage{text-align:center;word-wrap:break-word;justify-content:center;align-items:center;padding:8px;display:flex}.euiSelectableMessage--bordered{border:1px solid #293847;border-radius:4px;overflow:hidden}.euiHeader--dark .euiSelectableTemplateSitewide .euiFormControlLayout{background-color:transparent}.euiHeader--dark .euiSelectableTemplateSitewide .euiFormControlLayout--group,.euiHeader--dark .euiSelectableTemplateSitewide .euiFormControlLayout input{box-shadow:inset 0 0 0 1px rgba(252,254,255,.3)}.euiHeader--dark .euiSelectableTemplateSitewide .euiFormControlLayout:not(:focus-within){color:rgba(252,254,255,.7)}.euiHeader--dark .euiSelectableTemplateSitewide .euiFormControlLayout:not(:focus-within) input{color:inherit;background-color:transparent}.euiHeader--dark .euiSelectableTemplateSitewide .euiFormControlLayout:not(:focus-within) input::-webkit-input-placeholder{color:rgba(252,254,255,.4);opacity:1}.euiHeader--dark .euiSelectableTemplateSitewide .euiFormControlLayout:not(:focus-within) input::-moz-placeholder{color:rgba(252,254,255,.4);opacity:1}.euiHeader--dark .euiSelectableTemplateSitewide .euiFormControlLayout:not(:focus-within) input::-webkit-input-placeholder{color:rgba(252,254,255,.4);opacity:1}.euiHeader--dark .euiSelectableTemplateSitewide .euiFormControlLayout:not(:focus-within) input::-ms-input-placeholder{color:rgba(252,254,255,.4);opacity:1}.euiHeader--dark .euiSelectableTemplateSitewide .euiFormControlLayout:not(:focus-within) input::placeholder{color:rgba(252,254,255,.4);opacity:1}.euiHeader--dark .euiSelectableTemplateSitewide .euiFormControlLayout:not(:focus-within) .euiFormControlLayout__append{color:inherit;background-color:transparent}.euiSelectableTemplateSitewide__listItem .euiSelectableListItem__text{text-decoration:none!important}.euiSelectableTemplateSitewide__listItem[class*=-isFocused]:not([aria-disabled=true]) .euiSelectableTemplateSitewide__listItemTitle,.euiSelectableTemplateSitewide__listItem:hover:not([aria-disabled=true]) .euiSelectableTemplateSitewide__listItemTitle{text-decoration:underline}.euiSelectableTemplateSitewide__optionMetasList{color:#9fa6af;margin-top:4px;font-size:13.5px;display:block}.euiSelectableTemplateSitewide__optionMeta:not(:last-of-type):after{content:"•";color:#9fa6af;margin:0 4px}.euiSelectableTemplateSitewide__optionMeta--application{color:#6092c0;font-weight:500}.euiSelectableTemplateSitewide__optionMeta--deployment{color:#54b399;font-weight:500}.euiSelectableTemplateSitewide__optionMeta--article{color:#9b7ebf;font-weight:500}.euiSelectableTemplateSitewide__optionMeta--case{color:#e7664c;font-weight:500}.euiSelectableTemplateSitewide__optionMeta--platform{color:#d6bf57;font-weight:500}.euiSplitButton__listbox{scrollbar-width:thin;max-height:300px;overflow-x:hidden;overflow-y:auto}.euiSplitButton__listbox::-webkit-scrollbar{width:16px;height:16px}.euiSplitButton__listbox::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiSplitButton__listbox::-webkit-scrollbar-corner{background-color:transparent}.euiSplitButton__listbox::-webkit-scrollbar-track{background-color:transparent}.euiSplitButton__item{padding:8px;font-size:.875rem;line-height:1.33333}.euiSplitButton__item:hover{cursor:pointer;text-decoration:underline}.euiSplitButton__item:focus{cursor:pointer;background-color:#0e4342;text-decoration:underline}.euiSplitButton__item:disabled{cursor:not-allowed;color:#535a62;text-decoration:none}.euiSplitButton__item--hasDividers:not(:last-of-type){border-bottom:1px solid #293847}.euiSplitButton button.euiSplitButtonControl--primary{border-width:0 1px 0 0;border-radius:0}.euiSplitButton button.euiSplitButtonControl--primary:hover,.euiSplitButton button.euiSplitButtonControl--primary:active,.euiSplitButton button.euiSplitButtonControl--primary:focus{transform:none}.euiSplitButton button.euiSplitButtonControl--dropdown{border-width:0;border-radius:0}.euiSplitButton button.euiSplitButtonControl--dropdown:hover,.euiSplitButton button.euiSplitButtonControl--dropdown:active,.euiSplitButton button.euiSplitButtonControl--dropdown:focus{transform:none}.euiSplitButton .euiSplitButtonControl{border:2px solid #293847;border-radius:4px}.euiSplitButton .euiSplitButtonHairline--primary:not([class*=isDisabled]){border-right-color:rgba(21,157,141,.2)}.euiSplitButton .euiSplitButtonHairline--primary.euiSplitButtonHairline--filled:not([class*=isDisabled]){border-right-color:#0f7065}.euiSplitButton .euiSplitButtonHairline--accent:not([class*=isDisabled]){border-right-color:rgba(249,144,192,.2)}.euiSplitButton .euiSplitButtonHairline--accent.euiSplitButtonHairline--filled:not([class*=isDisabled]){border-right-color:#f660a5}.euiSplitButton .euiSplitButtonHairline--secondary:not([class*=isDisabled]){border-right-color:rgba(125,226,209,.2)}.euiSplitButton .euiSplitButtonHairline--secondary.euiSplitButtonHairline--filled:not([class*=isDisabled]){border-right-color:#53d9c2}.euiSplitButton .euiSplitButtonHairline--success:not([class*=isDisabled]){border-right-color:rgba(125,226,209,.2)}.euiSplitButton .euiSplitButtonHairline--success.euiSplitButtonHairline--filled:not([class*=isDisabled]){border-right-color:#53d9c2}.euiSplitButton .euiSplitButtonHairline--warning:not([class*=isDisabled]){border-right-color:rgba(255,206,122,.2)}.euiSplitButton .euiSplitButtonHairline--warning.euiSplitButtonHairline--filled:not([class*=isDisabled]){border-right-color:#ffbb47}.euiSplitButton .euiSplitButtonHairline--danger:not([class*=isDisabled]){border-right-color:rgba(255,102,102,.2)}.euiSplitButton .euiSplitButtonHairline--danger.euiSplitButtonHairline--filled:not([class*=isDisabled]){border-right-color:#f33}.euiSplitButton .euiSplitButtonHairline--subdued:not([class*=isDisabled]){border-right-color:rgba(159,166,175,.2)}.euiSplitButton .euiSplitButtonHairline--subdued.euiSplitButtonHairline--filled:not([class*=isDisabled]){border-right-color:#838c98}.euiSplitButton .euiSplitButtonHairline--ghost:not([class*=isDisabled]){border-right-color:rgba(252,254,255,.2)}.euiSplitButton .euiSplitButtonHairline--ghost.euiSplitButtonHairline--filled:not([class*=isDisabled]){border-right-color:#c9edff}.euiSplitButton .euiSplitButtonHairline--text:not([class*=isDisabled]){border-right-color:rgba(141,152,163,.2)}.euiSplitButton .euiSplitButtonHairline--text.euiSplitButtonHairline--filled:not([class*=isDisabled]){border-right-color:#717f8c}.euiSplitButton .euiSplitButtonColor--primary{color:#159d8d;border-color:#159d8d}.euiSplitButton .euiSplitButtonColor--primary.euiSplitButtonColor--fill{color:#0a121a;background-color:#159d8d;border-color:#159d8d}.euiSplitButton .euiSplitButtonColor--primary.euiSplitButtonColor--fill:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--primary.euiSplitButtonColor--fill:not([class*=isDisabled]):focus{background-color:#128779;border-color:#128779}.euiSplitButton .euiSplitButtonColor--primary.euiSplitButtonColor--fill:not([class*=isDisabled]):focus-within{background-color:#128779;border-color:#128779}.euiSplitButton .euiSplitButtonColor--primary:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--primary:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--primary:not([class*=isDisabled]):focus{background-color:rgba(21,157,141,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--primary:not([class*=isDisabled]):focus-within{background-color:rgba(21,157,141,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--accent{color:#f990c0;border-color:#f990c0}.euiSplitButton .euiSplitButtonColor--accent.euiSplitButtonColor--fill{color:#0a121a;background-color:#f990c0;border-color:#f990c0}.euiSplitButton .euiSplitButtonColor--accent.euiSplitButtonColor--fill:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--accent.euiSplitButtonColor--fill:not([class*=isDisabled]):focus{background-color:#f878b2;border-color:#f878b2}.euiSplitButton .euiSplitButtonColor--accent.euiSplitButtonColor--fill:not([class*=isDisabled]):focus-within{background-color:#f878b2;border-color:#f878b2}.euiSplitButton .euiSplitButtonColor--accent:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--accent:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--accent:not([class*=isDisabled]):focus{background-color:rgba(249,144,192,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--accent:not([class*=isDisabled]):focus-within{background-color:rgba(249,144,192,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--secondary{color:#7de2d1;border-color:#7de2d1}.euiSplitButton .euiSplitButtonColor--secondary.euiSplitButtonColor--fill{color:#0a121a;background-color:#7de2d1;border-color:#7de2d1}.euiSplitButton .euiSplitButtonColor--secondary.euiSplitButtonColor--fill:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--secondary.euiSplitButtonColor--fill:not([class*=isDisabled]):focus{background-color:#68ddca;border-color:#68ddca}.euiSplitButton .euiSplitButtonColor--secondary.euiSplitButtonColor--fill:not([class*=isDisabled]):focus-within{background-color:#68ddca;border-color:#68ddca}.euiSplitButton .euiSplitButtonColor--secondary:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--secondary:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--secondary:not([class*=isDisabled]):focus{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--secondary:not([class*=isDisabled]):focus-within{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--success{color:#7de2d1;border-color:#7de2d1}.euiSplitButton .euiSplitButtonColor--success.euiSplitButtonColor--fill{color:#0a121a;background-color:#7de2d1;border-color:#7de2d1}.euiSplitButton .euiSplitButtonColor--success.euiSplitButtonColor--fill:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--success.euiSplitButtonColor--fill:not([class*=isDisabled]):focus{background-color:#68ddca;border-color:#68ddca}.euiSplitButton .euiSplitButtonColor--success.euiSplitButtonColor--fill:not([class*=isDisabled]):focus-within{background-color:#68ddca;border-color:#68ddca}.euiSplitButton .euiSplitButtonColor--success:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--success:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--success:not([class*=isDisabled]):focus{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--success:not([class*=isDisabled]):focus-within{background-color:rgba(125,226,209,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--warning{color:#ffce7a;border-color:#ffce7a}.euiSplitButton .euiSplitButtonColor--warning.euiSplitButtonColor--fill{color:#0a121a;background-color:#ffce7a;border-color:#ffce7a}.euiSplitButton .euiSplitButtonColor--warning.euiSplitButtonColor--fill:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--warning.euiSplitButtonColor--fill:not([class*=isDisabled]):focus{background-color:#ffc561;border-color:#ffc561}.euiSplitButton .euiSplitButtonColor--warning.euiSplitButtonColor--fill:not([class*=isDisabled]):focus-within{background-color:#ffc561;border-color:#ffc561}.euiSplitButton .euiSplitButtonColor--warning:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--warning:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--warning:not([class*=isDisabled]):focus{background-color:rgba(255,206,122,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--warning:not([class*=isDisabled]):focus-within{background-color:rgba(255,206,122,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--danger{color:#f66;border-color:#f66}.euiSplitButton .euiSplitButtonColor--danger.euiSplitButtonColor--fill{color:#0a121a;background-color:#f66;border-color:#f66}.euiSplitButton .euiSplitButtonColor--danger.euiSplitButtonColor--fill:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--danger.euiSplitButtonColor--fill:not([class*=isDisabled]):focus{background-color:#ff4d4d;border-color:#ff4d4d}.euiSplitButton .euiSplitButtonColor--danger.euiSplitButtonColor--fill:not([class*=isDisabled]):focus-within{background-color:#ff4d4d;border-color:#ff4d4d}.euiSplitButton .euiSplitButtonColor--danger:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--danger:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--danger:not([class*=isDisabled]):focus{background-color:rgba(255,102,102,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--danger:not([class*=isDisabled]):focus-within{background-color:rgba(255,102,102,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--subdued{color:#9fa6af;border-color:#9fa6af}.euiSplitButton .euiSplitButtonColor--subdued.euiSplitButtonColor--fill{color:#0a121a;background-color:#9fa6af;border-color:#9fa6af}.euiSplitButton .euiSplitButtonColor--subdued.euiSplitButtonColor--fill:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--subdued.euiSplitButtonColor--fill:not([class*=isDisabled]):focus{background-color:#9199a3;border-color:#9199a3}.euiSplitButton .euiSplitButtonColor--subdued.euiSplitButtonColor--fill:not([class*=isDisabled]):focus-within{background-color:#9199a3;border-color:#9199a3}.euiSplitButton .euiSplitButtonColor--subdued:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--subdued:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--subdued:not([class*=isDisabled]):focus{background-color:rgba(159,166,175,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--subdued:not([class*=isDisabled]):focus-within{background-color:rgba(159,166,175,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--ghost{color:#fcfeff;border-color:#fcfeff}.euiSplitButton .euiSplitButtonColor--ghost.euiSplitButtonColor--fill{color:#0a121a;background-color:#fcfeff;border-color:#fcfeff}.euiSplitButton .euiSplitButtonColor--ghost.euiSplitButtonColor--fill:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--ghost.euiSplitButtonColor--fill:not([class*=isDisabled]):focus{background-color:#e3f6ff;border-color:#e3f6ff}.euiSplitButton .euiSplitButtonColor--ghost.euiSplitButtonColor--fill:not([class*=isDisabled]):focus-within{background-color:#e3f6ff;border-color:#e3f6ff}.euiSplitButton .euiSplitButtonColor--ghost:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(10,18,26,.3)}.euiSplitButton .euiSplitButtonColor--ghost:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--ghost:not([class*=isDisabled]):focus{background-color:rgba(252,254,255,.1);box-shadow:0 4px 8px rgba(10,18,26,.15),0 2px 2px -1px rgba(10,18,26,.3)}.euiSplitButton .euiSplitButtonColor--ghost:not([class*=isDisabled]):focus-within{background-color:rgba(252,254,255,.1);box-shadow:0 4px 8px rgba(10,18,26,.15),0 2px 2px -1px rgba(10,18,26,.3)}.euiSplitButton .euiSplitButtonColor--text{color:#dfe5ef;border-color:#8d98a3}.euiSplitButton .euiSplitButtonColor--text.euiSplitButtonColor--fill{color:#0a121a;background-color:#8d98a3;border-color:#8d98a3}.euiSplitButton .euiSplitButtonColor--text.euiSplitButtonColor--fill:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--text.euiSplitButtonColor--fill:not([class*=isDisabled]):focus{background-color:#7f8b98;border-color:#7f8b98}.euiSplitButton .euiSplitButtonColor--text.euiSplitButtonColor--fill:not([class*=isDisabled]):focus-within{background-color:#7f8b98;border-color:#7f8b98}.euiSplitButton .euiSplitButtonColor--text:not([class*=isDisabled]){box-shadow:0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--text:not([class*=isDisabled]):hover,.euiSplitButton .euiSplitButtonColor--text:not([class*=isDisabled]):focus{background-color:rgba(141,152,163,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor--text:not([class*=isDisabled]):focus-within{background-color:rgba(141,152,163,.1);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiSplitButton .euiSplitButtonColor.euiSplitButtonColor-isDisabled.euiSplitButtonColor--ghost,.euiSplitButton .euiSplitButtonColor.euiSplitButtonColor-isDisabled.euiSplitButtonColor--ghost:hover,.euiSplitButton .euiSplitButtonColor.euiSplitButtonColor-isDisabled.euiSplitButtonColor--ghost:focus{color:#293847;border-color:#293847;box-shadow:0 2px 2px -1px rgba(10,18,26,.3)}.euiSplitButton .euiSplitButtonColor.euiSplitButtonColor-isDisabled.euiSplitButtonColor--ghost:focus-within{color:#293847;border-color:#293847;box-shadow:0 2px 2px -1px rgba(10,18,26,.3)}.euiSplitButton .euiSplitButtonColor.euiSplitButtonColor-isDisabled.euiSplitButtonColor--ghost.euiSplitButtonColor--fill{color:#5a6571;background-color:#293847}.euiStat .euiStat__title{color:#fcfeff}.euiStat .euiStat__title--subdued{color:#9fa6af}.euiStat .euiStat__title--primary{color:#159d8d}.euiStat .euiStat__title--secondary,.euiStat .euiStat__title--success{color:#7de2d1}.euiStat .euiStat__title--danger{color:#f66}.euiStat .euiStat__title--accent{color:#f990c0}.euiStat .euiStat__title-isLoading{animation:1.5s ease-in-out infinite euiStatPulse}.euiStat.euiStat--leftAligned{text-align:left;align-items:flex-start}.euiStat.euiStat--centerAligned{text-align:center;align-items:center}.euiStat.euiStat--rightAligned{text-align:right;align-items:flex-end}@keyframes euiStatPulse{0%{opacity:1}50%{opacity:.25}to{opacity:1}}.euiStepNumber{text-align:center;color:#0a121a;background-color:#159d8d;border-radius:32px;width:32px;height:32px;font-size:18px;font-weight:500;line-height:32px;display:inline-block}.euiStepNumber .euiStepNumber__icon{vertical-align:middle;position:relative;top:-2px}.euiStepNumber--small{text-align:center;color:#0a121a;background-color:#159d8d;border-radius:24px;width:24px;height:24px;font-size:13.5px;font-weight:500;line-height:24px;display:inline-block}.euiStepNumber--small .euiStepNumber__icon{top:-1px}.euiStepNumber--complete .euiStepNumber__icon{stroke:currentColor;stroke-width:.5px}@media screen and (prefers-reduced-motion:no-preference){.euiStepNumber--complete,.euiStepNumber--warning,.euiStepNumber--danger{animation:.15s cubic-bezier(.34,1.61,.7,1) euiGrow}}.euiStepNumber--loading{background:0 0}.euiStepNumber.euiStepNumber-isHollow{background-color:transparent;border:2px solid #159d8d}.euiStepNumber.euiStepNumber-isHollow .euiStepNumber__number{display:none}.euiStepNumber--warning{color:#ffce7a;background-color:#544a37}.euiStepNumber--danger{color:#ff7575;background-color:#542b31}.euiStepNumber--disabled,.euiStepNumber--incomplete{color:#9da7b0;background-color:#313a43}.euiStep:not(:last-of-type){background-image:linear-gradient(90deg,transparent 0,transparent 15px,#293847 15px,#293847 17px,transparent 17px,transparent 100%);background-position:0 40px;background-repeat:no-repeat}.euiStep--small:not(:last-of-type){background-position:-4px 32px}.euiStep--small .euiStep__content{margin-left:12px;padding-left:28px}.euiStep__titleWrapper{display:flex}.euiStep__circle{vertical-align:top;flex-shrink:0;margin-right:16px}.euiStep__title{font-weight:500}.euiStep__content{margin:8px 0 8px 16px;padding:16px 16px 32px 32px}.euiSubSteps{background-color:#101b25;margin-bottom:16px;padding:16px}.euiSubSteps>:last-child{margin-bottom:0}.euiText .euiSubSteps ol,.euiSubSteps ol{list-style-type:lower-alpha}.euiStepsHorizontal{background:rgba(16,27,37,.5);align-items:stretch;display:flex}.euiStepHorizontal__item{flex-grow:1;flex-basis:0%}.euiStepHorizontal__item:first-of-type>.euiStepHorizontal:before,.euiStepHorizontal__item:last-of-type>.euiStepHorizontal:after{display:none}.euiStepHorizontal{cursor:pointer;flex-direction:column;justify-content:flex-start;align-items:center;width:100%;padding:24px 16px 16px;display:flex;position:relative}.euiStepHorizontal:focus:not(.euiStepHorizontal-isDisabled) .euiStepHorizontal__title,.euiStepHorizontal:hover:not(.euiStepHorizontal-isDisabled) .euiStepHorizontal__title{text-decoration:underline}.euiStepHorizontal:focus:not(.euiStepHorizontal-isDisabled){outline:none}.euiStepHorizontal:focus:not(.euiStepHorizontal-isDisabled) .euiStepHorizontal__number{animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimateLarge!important}.euiStepHorizontal.euiStepHorizontal-isDisabled{cursor:not-allowed}.euiStepHorizontal:before,.euiStepHorizontal:after{content:"";z-index:0;background-color:#293847;width:calc(50% - 16px);height:1px;position:absolute;top:40px}.euiStepHorizontal:before{left:0}.euiStepHorizontal:after{right:0}.euiStepHorizontal__number{z-index:1;transition:all .15s ease-in-out;position:relative}.euiStepHorizontal__title{color:#dfe5ef;letter-spacing:-.02em;text-align:center;margin-top:8px;font-size:1rem;font-weight:400;line-height:1.33333rem}.euiStepHorizontal-isDisabled .euiStepHorizontal__title{color:#8d98a3}.euiStepHorizontal-isComplete:before,.euiStepHorizontal-isComplete:after{background-color:#159d8d;height:2px}.euiStepHorizontal-isSelected .euiStepHorizontal__number:not([class*=danger]):not([class*=warning]):not([class*=loading]){box-shadow:0 2px 2px -1px rgba(39,139,127,.3)}.euiStepHorizontal-isSelected:before{background-color:#159d8d;height:2px}@media only screen and (max-width:574px){.euiStepHorizontal{padding-top:16px}.euiStepHorizontal:before,.euiStepHorizontal:after{top:32px}.euiStepHorizontal__title{display:none}}@media only screen and (min-width:575px) and (max-width:767px){.euiStepHorizontal{padding-top:16px}.euiStepHorizontal:before,.euiStepHorizontal:after{top:32px}.euiStepHorizontal__title{display:none}}.euiSuggestItem{white-space:nowrap;flex-grow:1;align-items:center;font-size:13.5px;display:flex}.euiSuggestItem.euiSuggestItem-isClickable{text-align:left;width:100%}.euiSuggestItem.euiSuggestItem-isClickable:hover,.euiSuggestItem.euiSuggestItem-isClickable:focus{cursor:pointer;background-color:#101b25}.euiSuggestItem.euiSuggestItem-isClickable:hover .euiSuggestItem__type,.euiSuggestItem.euiSuggestItem-isClickable:focus .euiSuggestItem__type{color:#dfe3e8}.euiSuggestItem .euiSuggestItem__type--tint0{color:#5cb79e;background-color:#204240}.euiSuggestItem .euiSuggestItem__type--tint1{color:#7da6cc;background-color:#24384c}.euiSuggestItem .euiSuggestItem__type--tint2{color:#db7e9c;background-color:#46293a}.euiSuggestItem .euiSuggestItem__type--tint3{color:#a990c8;background-color:#332e49}.euiSuggestItem .euiSuggestItem__type--tint4{color:#cd94b2;background-color:#443746}.euiSuggestItem .euiSuggestItem__type--tint5{color:#d6bf57;background-color:#47462c}.euiSuggestItem .euiSuggestItem__type--tint6{color:#b9a888;background-color:#3f3f3b}.euiSuggestItem .euiSuggestItem__type--tint7{color:#de9657;background-color:#483627}.euiSuggestItem .euiSuggestItem__type--tint8{color:#c08e83;background-color:#3a2b2c}.euiSuggestItem .euiSuggestItem__type--tint9{color:#eb836e;background-color:#4c2b29}.euiSuggestItem .euiSuggestItem__type--tint10{color:#9da7b0;background-color:#313a43}.euiSuggestItem .euiSuggestItem__label,.euiSuggestItem .euiSuggestItem__type,.euiSuggestItem .euiSuggestItem__description{flex-direction:column;flex-grow:0;display:flex}.euiSuggestItem .euiSuggestItem__type{text-align:center;flex-shrink:0;flex-basis:auto;justify-content:center;align-items:center;width:32px;height:32px;padding:4px;position:relative;overflow:hidden}.euiSuggestItem .euiSuggestItem__label{max-width:100%;font-family:var(--eui-code-font-family);letter-spacing:normal;text-overflow:ellipsis;color:#dfe5ef;padding:4px 8px;line-height:1.5;display:block;overflow:hidden;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width20{flex-basis:20%;min-width:20%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width21{flex-basis:21%;min-width:21%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width22{flex-basis:22%;min-width:22%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width23{flex-basis:23%;min-width:23%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width24{flex-basis:24%;min-width:24%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width25{flex-basis:25%;min-width:25%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width26{flex-basis:26%;min-width:26%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width27{flex-basis:27%;min-width:27%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width28{flex-basis:28%;min-width:28%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width29{flex-basis:29%;min-width:29%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width30{flex-basis:30%;min-width:30%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width31{flex-basis:31%;min-width:31%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width32{flex-basis:32%;min-width:32%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width33{flex-basis:33%;min-width:33%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width34{flex-basis:34%;min-width:34%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width35{flex-basis:35%;min-width:35%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width36{flex-basis:36%;min-width:36%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width37{flex-basis:37%;min-width:37%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width38{flex-basis:38%;min-width:38%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width39{flex-basis:39%;min-width:39%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width40{flex-basis:40%;min-width:40%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width41{flex-basis:41%;min-width:41%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width42{flex-basis:42%;min-width:42%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width43{flex-basis:43%;min-width:43%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width44{flex-basis:44%;min-width:44%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width45{flex-basis:45%;min-width:45%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width46{flex-basis:46%;min-width:46%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width47{flex-basis:47%;min-width:47%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width48{flex-basis:48%;min-width:48%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width49{flex-basis:49%;min-width:49%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width50{flex-basis:50%;min-width:50%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width51{flex-basis:51%;min-width:51%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width52{flex-basis:52%;min-width:52%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width53{flex-basis:53%;min-width:53%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width54{flex-basis:54%;min-width:54%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width55{flex-basis:55%;min-width:55%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width56{flex-basis:56%;min-width:56%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width57{flex-basis:57%;min-width:57%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width58{flex-basis:58%;min-width:58%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width59{flex-basis:59%;min-width:59%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width60{flex-basis:60%;min-width:60%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width61{flex-basis:61%;min-width:61%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width62{flex-basis:62%;min-width:62%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width63{flex-basis:63%;min-width:63%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width64{flex-basis:64%;min-width:64%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width65{flex-basis:65%;min-width:65%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width66{flex-basis:66%;min-width:66%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width67{flex-basis:67%;min-width:67%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width68{flex-basis:68%;min-width:68%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width69{flex-basis:69%;min-width:69%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width70{flex-basis:70%;min-width:70%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width71{flex-basis:71%;min-width:71%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width72{flex-basis:72%;min-width:72%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width73{flex-basis:73%;min-width:73%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width74{flex-basis:74%;min-width:74%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width75{flex-basis:75%;min-width:75%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width76{flex-basis:76%;min-width:76%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width77{flex-basis:77%;min-width:77%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width78{flex-basis:78%;min-width:78%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width79{flex-basis:79%;min-width:79%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width80{flex-basis:80%;min-width:80%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width81{flex-basis:81%;min-width:81%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width82{flex-basis:82%;min-width:82%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width83{flex-basis:83%;min-width:83%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width84{flex-basis:84%;min-width:84%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width85{flex-basis:85%;min-width:85%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width86{flex-basis:86%;min-width:86%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width87{flex-basis:87%;min-width:87%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width88{flex-basis:88%;min-width:88%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width89{flex-basis:89%;min-width:89%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__label--width90{flex-basis:90%;min-width:90%}.euiSuggestItem .euiSuggestItem__label.euiSuggestItem__labelDisplay--expand{flex-shrink:1;flex-basis:auto}.euiSuggestItem .euiSuggestItem__description{color:#8d98a3;flex-basis:auto;padding-top:2px;display:block}.euiSuggestItem .euiSuggestItem__description.euiSuggestItem__description--wrap{word-break:break-word;white-space:normal;line-height:14px;overflow-wrap:break-word!important;word-wrap:break-word!important}.euiSuggestItem .euiSuggestItem__description.euiSuggestItem__description--truncate{max-width:100%;line-height:1.33333;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiSuggestItem .euiSuggestItem__description:empty{flex-grow:0;margin-left:0}.euiSuggestInput__statusIcon{background-color:transparent!important}.euiTable{font-feature-settings:"calt" 1,"kern" 1,"liga" 1,"tnum" 1;table-layout:fixed;border-collapse:collapse;background-color:#0a121a;border:none;width:100%;font-size:.875rem;line-height:1.33333}.euiTable.euiTable--auto{table-layout:auto}.euiTableCaption{position:relative}@media only screen and (min-width:768px) and (max-width:991px){.euiTable--compressed .euiTableCellContent{padding:4px;font-size:.75rem;line-height:1.33333}}@media only screen and (min-width:992px) and (max-width:1199px){.euiTable--compressed .euiTableCellContent{padding:4px;font-size:.75rem;line-height:1.33333}}@media only screen and (min-width:1200px) and (max-width:1679px){.euiTable--compressed .euiTableCellContent{padding:4px;font-size:.75rem;line-height:1.33333}}@media only screen and (min-width:1680px) and (max-width:1919px){.euiTable--compressed .euiTableCellContent{padding:4px;font-size:.75rem;line-height:1.33333}}@media only screen and (min-width:1920px){.euiTable--compressed .euiTableCellContent{padding:4px;font-size:.75rem;line-height:1.33333}}.euiTableFooterCell,.euiTableHeaderCell{vertical-align:middle;font-weight:inherit;text-align:inherit;color:#dfe5ef;letter-spacing:-.005em;border-top:none;border-bottom:1px solid #293847;font-size:.875rem;font-weight:500;line-height:1.33333rem}.euiTableFooterCell .euiTableHeaderButton,.euiTableHeaderCell .euiTableHeaderButton{text-align:left;font-weight:500}.euiTableFooterCell .euiTableCellContent__text,.euiTableHeaderCell .euiTableCellContent__text{font-size:.75rem;font-weight:600;line-height:1.33333}.euiTableHeaderButton{color:inherit;width:100%;font-size:.875rem;line-height:1.33333}.euiTableHeaderButton:hover .euiTableCellContent__text,.euiTableHeaderButton:focus .euiTableCellContent__text{color:#159d8d;text-decoration:underline}.euiTableHeaderButton:hover .euiTableSortIcon,.euiTableHeaderButton:focus .euiTableSortIcon{fill:#159d8d}.euiTableSortIcon{flex-shrink:0;margin-left:4px}.euiTableHeaderButton-isSorted .euiTableSortIcon{fill:#dfe5ef}.euiTableHeaderCellCheckbox{vertical-align:middle;font-weight:inherit;text-align:inherit;vertical-align:middle;border-top:none;border-bottom:1px solid #293847;width:32px}.euiTableRow:hover{background-color:#0f1923}.euiTableRow.euiTableRow-isClickable:hover{cursor:pointer;background-color:rgba(21,157,141,.05)}.euiTableRow.euiTableRow-isClickable:focus{background-color:rgba(21,157,141,.1)}.euiTableRow.euiTableRow-isExpandedRow{background-color:#0f1923}.euiTableRow.euiTableRow-isExpandedRow.euiTableRow-isSelectable .euiTableCellContent{padding-left:40px}.euiTableRow.euiTableRow-isSelected,.euiTableRow.euiTableRow-isSelected+.euiTableRow.euiTableRow-isExpandedRow .euiTableRowCell{background-color:#0e4342}.euiTableRow.euiTableRow-isSelected:hover,.euiTableRow.euiTableRow-isSelected:hover+.euiTableRow.euiTableRow-isExpandedRow .euiTableRowCell{background-color:#0e3e3e}.euiTableRowCell{vertical-align:middle;font-weight:inherit;text-align:inherit;color:#dfe5ef;border-top:1px solid #293847;border-bottom:1px solid #293847}.euiTableRowCell.euiTableRowCell--isMobileHeader{display:none}.euiTableRowCellCheckbox{vertical-align:middle;font-weight:inherit;text-align:inherit;vertical-align:middle;border-top:1px solid #293847;border-bottom:1px solid #293847;width:32px}.euiTableFooterCell{background-color:#101b25;border-bottom:none}.euiTableCellContent{align-items:center;padding:8px;display:flex;overflow:hidden}.euiTableCellContent__text{word-break:break-word;text-overflow:ellipsis;min-width:0;overflow-wrap:break-word!important;word-wrap:break-word!important}.euiTableCellContent--alignRight{text-align:right;justify-content:flex-end}.euiTableCellContent--alignCenter{text-align:center;justify-content:center}.euiTableHeaderCell,.euiTableFooterCell,.euiTableCellContent--truncateText{white-space:nowrap}.euiTableHeaderCell .euiTableCellContent__text,.euiTableFooterCell .euiTableCellContent__text,.euiTableCellContent--truncateText .euiTableCellContent__text{overflow:hidden}.euiTableCellContent--overflowingContent{white-space:normal;word-break:break-all;word-break:break-word;overflow:visible}.euiTableCellContent--showOnHover>:not(:first-child){margin-left:8px}.euiTableRow-hasActions .euiTableCellContent--showOnHover .euiTableCellContent__hoverItem{opacity:.7;-webkit-filter:grayscale();filter:grayscale();flex-shrink:0;transition:opacity .25s cubic-bezier(.694,.0482,.335,1),-webkit-filter .25s cubic-bezier(.694,.0482,.335,1),filter .25s cubic-bezier(.694,.0482,.335,1)}.euiTableRow-hasActions .euiTableCellContent--showOnHover .expandedItemActions__completelyHide,.euiTableRow-hasActions .euiTableCellContent--showOnHover .expandedItemActions__completelyHide:disabled,.euiTableRow-hasActions .euiTableCellContent--showOnHover .expandedItemActions__completelyHide:disabled:hover,.euiTableRow-hasActions .euiTableCellContent--showOnHover .expandedItemActions__completelyHide:disabled:focus,.euiTableRow:hover .euiTableRow-hasActions .euiTableCellContent--showOnHover .expandedItemActions__completelyHide:disabled{-webkit-filter:grayscale(0%);filter:grayscale(0%);opacity:0}.euiTableRow-hasActions:hover .euiTableCellContent--showOnHover .euiTableCellContent__hoverItem:not(:disabled),.euiTableRow-hasActions:hover .euiTableCellContent--showOnHover .euiTableCellContent__hoverItem:not(:disabled):hover,.euiTableRow-hasActions:hover .euiTableCellContent--showOnHover .euiTableCellContent__hoverItem:not(:disabled):focus{opacity:1;-webkit-filter:grayscale(0%);filter:grayscale(0%)}.euiTableRow-isExpandedRow .euiTableCellContent{animation:.25s cubic-bezier(.694,.0482,.335,1) forwards growExpandedRow;overflow:hidden}@keyframes growExpandedRow{0%{max-height:0}99%{max-height:100vh}to{max-height:unset}}.euiTableRowCell__mobileHeader{display:none}@media only screen and (max-width:574px){.euiTableRowCell--hideForMobile{display:none!important}}@media only screen and (min-width:575px) and (max-width:767px){.euiTableRowCell--hideForMobile{display:none!important}}@media only screen and (min-width:768px) and (max-width:991px){.euiTableRowCell--hideForDesktop{display:none!important}}@media only screen and (min-width:992px) and (max-width:1199px){.euiTableRowCell--hideForDesktop{display:none!important}}@media only screen and (min-width:1200px) and (max-width:1679px){.euiTableRowCell--hideForDesktop{display:none!important}}@media only screen and (min-width:1680px) and (max-width:1919px){.euiTableRowCell--hideForDesktop{display:none!important}}@media only screen and (min-width:1920px){.euiTableRowCell--hideForDesktop{display:none!important}}@media only screen and (max-width:574px){.euiTable.euiTable--responsive thead,.euiTable.euiTable--responsive tfoot{display:none}.euiTable.euiTable--responsive .euiTableRowCell__mobileHeader{color:#8d98a3;max-width:100%;min-height:24px;margin-bottom:-8px;padding:8px 8px 0;font-size:.6875rem;display:block;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiTableRowCell:only-child .euiTable.euiTable--responsive .euiTableRowCell__mobileHeader{min-height:0}.euiTable.euiTable--responsive .euiTableRowCell--enlargeForMobile{font-size:1rem;line-height:1.33333}.euiTable.euiTable--responsive .euiTableRowCell--isMobileFullWidth{width:100%}.euiTable.euiTable--responsive .euiTableRowCell--isMobileFullWidth .euiTableCellContent--alignCenter{text-align:center;justify-content:center}.euiTable.euiTable--responsive .euiTableRow{background-color:#0a121a;border:1px solid #293847;border-radius:4px;flex-grow:1}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--flexGrowZero{flex-grow:0}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--noBorder{border:none}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--hasShadow{border:1px solid #293847;box-shadow:0 2px 2px -1px rgba(0,0,0,.3),0 1px 5px -2px rgba(0,0,0,.3)}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--isClickable{transition:all .15s cubic-bezier(.694,.0482,.335,1)}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--isClickable:enabled{text-align:left;width:100%;display:block}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--isClickable:hover,.euiTable.euiTable--responsive .euiTableRow.euiTableRow--isClickable:focus{cursor:pointer;transform:translateY(-2px);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--borderRadiusNone{border-radius:0}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--borderRadiusMedium{border-radius:4px}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--borderRadiusLarge{border-radius:8px}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--borderRadiusXLarge{border-radius:16px}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--transparent{background-color:transparent}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--plain{background-color:#0a121a}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--subdued{background-color:#172430}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--accent{background-color:#52384c}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--primary{background-color:#0d3c3d}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--success{background-color:#2d5051}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--warning{background-color:#544a37}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--danger{background-color:#542b31}.euiTable.euiTable--responsive .euiTableRow{background-color:#0a121a;border-radius:4px;flex-wrap:wrap;margin-bottom:8px;padding:8px;display:flex;box-shadow:0 2px 2px -1px rgba(0,0,0,.3),0 1px 5px -2px rgba(0,0,0,.3)}.euiTable.euiTable--responsive .euiTableRow:hover{background-color:#0a121a}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandable,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-hasActions{background-image:linear-gradient(90deg,rgba(91,104,117,.1) 0,rgba(91,104,117,.1) 1px,transparent 1px,transparent 100%);background-position-x:right;background-repeat:no-repeat;background-size:40px 100%;padding-right:40px;position:relative}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandable .euiTableRowCell--isExpander,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-hasActions .euiTableRowCell--hasActions{width:24px;min-width:0;position:absolute;top:14.6667px;right:8px}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandable .euiTableRowCell--isExpander:before,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-hasActions .euiTableRowCell--hasActions:before{display:none}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandable .euiTableRowCell--isExpander .euiTableCellContent,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-hasActions .euiTableRowCell--hasActions .euiTableCellContent{flex-direction:column;padding:0}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandable .euiTableRowCell--isExpander .euiTableCellContent .euiLink,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-hasActions .euiTableRowCell--hasActions .euiTableCellContent .euiLink{padding:4px}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-hasActions.euiTableRow-isExpandable .euiTableRowCell--isExpander{top:auto;bottom:16px;right:0}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isSelectable{padding-left:36px;position:relative}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isSelectable .euiTableRowCellCheckbox{position:absolute;top:8px;left:4px}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isSelected,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isSelected:hover,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isSelected+.euiTableRow.euiTableRow-isExpandedRow,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isSelected:hover+.euiTableRow.euiTableRow-isExpandedRow .euiTableRowCell{background-color:#0e4342}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandedRow{z-index:2;background-image:linear-gradient(90deg,rgba(91,104,117,.1) 0,rgba(91,104,117,.1) 1px,transparent 1px,transparent 100%);background-position-x:right;background-repeat:no-repeat;background-size:40px 100%;border-top:none;border-top-left-radius:0;border-top-right-radius:0;margin-top:-16px;padding-left:8px;position:relative;box-shadow:0 2px 2px -1px rgba(0,0,0,.3),0 1px 5px -2px rgba(0,0,0,.3)}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandedRow:hover{background-color:#0a121a}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandedRow .euiTableRowCell{width:calc(100% - 40px)}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandedRow .euiTableRowCell:before{display:none}.euiTable.euiTable--responsive .euiTableRowCell{border:none;min-width:50%;display:block}.euiTable.euiTable--responsive .euiTableRowCellCheckbox{border:none}.euiTable.euiTable--responsive .euiTableRow-hasActions .euiTableCellContent--showOnHover>*{margin-left:0}.euiTable.euiTable--responsive .euiTableRow-hasActions .euiTableCellContent--showOnHover .expandedItemActions__completelyHide{display:none}.euiTable.euiTable--responsive .euiTableRow-hasActions .euiTableCellContent--showOnHover .euiTableCellContent__hoverItem{opacity:1;-webkit-filter:none;filter:none;margin-bottom:8px;margin-left:0}.euiTable.euiTable--responsive .euiTableCellContent--alignRight,.euiTable.euiTable--responsive .euiTableCellContent--alignCenter{justify-content:flex-start}}@media only screen and (min-width:575px) and (max-width:767px){.euiTable.euiTable--responsive thead,.euiTable.euiTable--responsive tfoot{display:none}.euiTable.euiTable--responsive .euiTableRowCell__mobileHeader{color:#8d98a3;max-width:100%;min-height:24px;margin-bottom:-8px;padding:8px 8px 0;font-size:.6875rem;display:block;text-overflow:ellipsis!important;white-space:nowrap!important;word-wrap:normal!important;overflow:hidden!important}.euiTableRowCell:only-child .euiTable.euiTable--responsive .euiTableRowCell__mobileHeader{min-height:0}.euiTable.euiTable--responsive .euiTableRowCell--enlargeForMobile{font-size:1rem;line-height:1.33333}.euiTable.euiTable--responsive .euiTableRowCell--isMobileFullWidth{width:100%}.euiTable.euiTable--responsive .euiTableRowCell--isMobileFullWidth .euiTableCellContent--alignCenter{text-align:center;justify-content:center}.euiTable.euiTable--responsive .euiTableRow{background-color:#0a121a;border:1px solid #293847;border-radius:4px;flex-grow:1}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--flexGrowZero{flex-grow:0}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--noBorder{border:none}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--hasShadow{border:1px solid #293847;box-shadow:0 2px 2px -1px rgba(0,0,0,.3),0 1px 5px -2px rgba(0,0,0,.3)}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--isClickable{transition:all .15s cubic-bezier(.694,.0482,.335,1)}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--isClickable:enabled{text-align:left;width:100%;display:block}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--isClickable:hover,.euiTable.euiTable--responsive .euiTableRow.euiTableRow--isClickable:focus{cursor:pointer;transform:translateY(-2px);box-shadow:0 4px 8px rgba(0,0,0,.15),0 2px 2px -1px rgba(0,0,0,.3)}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--borderRadiusNone{border-radius:0}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--borderRadiusMedium{border-radius:4px}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--borderRadiusLarge{border-radius:8px}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--borderRadiusXLarge{border-radius:16px}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--transparent{background-color:transparent}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--plain{background-color:#0a121a}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--subdued{background-color:#172430}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--accent{background-color:#52384c}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--primary{background-color:#0d3c3d}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--success{background-color:#2d5051}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--warning{background-color:#544a37}.euiTable.euiTable--responsive .euiTableRow.euiTableRow--danger{background-color:#542b31}.euiTable.euiTable--responsive .euiTableRow{background-color:#0a121a;border-radius:4px;flex-wrap:wrap;margin-bottom:8px;padding:8px;display:flex;box-shadow:0 2px 2px -1px rgba(0,0,0,.3),0 1px 5px -2px rgba(0,0,0,.3)}.euiTable.euiTable--responsive .euiTableRow:hover{background-color:#0a121a}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandable,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-hasActions{background-image:linear-gradient(90deg,rgba(91,104,117,.1) 0,rgba(91,104,117,.1) 1px,transparent 1px,transparent 100%);background-position-x:right;background-repeat:no-repeat;background-size:40px 100%;padding-right:40px;position:relative}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandable .euiTableRowCell--isExpander,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-hasActions .euiTableRowCell--hasActions{width:24px;min-width:0;position:absolute;top:14.6667px;right:8px}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandable .euiTableRowCell--isExpander:before,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-hasActions .euiTableRowCell--hasActions:before{display:none}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandable .euiTableRowCell--isExpander .euiTableCellContent,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-hasActions .euiTableRowCell--hasActions .euiTableCellContent{flex-direction:column;padding:0}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandable .euiTableRowCell--isExpander .euiTableCellContent .euiLink,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-hasActions .euiTableRowCell--hasActions .euiTableCellContent .euiLink{padding:4px}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-hasActions.euiTableRow-isExpandable .euiTableRowCell--isExpander{top:auto;bottom:16px;right:0}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isSelectable{padding-left:36px;position:relative}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isSelectable .euiTableRowCellCheckbox{position:absolute;top:8px;left:4px}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isSelected,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isSelected:hover,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isSelected+.euiTableRow.euiTableRow-isExpandedRow,.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isSelected:hover+.euiTableRow.euiTableRow-isExpandedRow .euiTableRowCell{background-color:#0e4342}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandedRow{z-index:2;background-image:linear-gradient(90deg,rgba(91,104,117,.1) 0,rgba(91,104,117,.1) 1px,transparent 1px,transparent 100%);background-position-x:right;background-repeat:no-repeat;background-size:40px 100%;border-top:none;border-top-left-radius:0;border-top-right-radius:0;margin-top:-16px;padding-left:8px;position:relative;box-shadow:0 2px 2px -1px rgba(0,0,0,.3),0 1px 5px -2px rgba(0,0,0,.3)}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandedRow:hover{background-color:#0a121a}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandedRow .euiTableRowCell{width:calc(100% - 40px)}.euiTable.euiTable--responsive .euiTableRow.euiTableRow-isExpandedRow .euiTableRowCell:before{display:none}.euiTable.euiTable--responsive .euiTableRowCell{border:none;min-width:50%;display:block}.euiTable.euiTable--responsive .euiTableRowCellCheckbox{border:none}.euiTable.euiTable--responsive .euiTableRow-hasActions .euiTableCellContent--showOnHover>*{margin-left:0}.euiTable.euiTable--responsive .euiTableRow-hasActions .euiTableCellContent--showOnHover .expandedItemActions__completelyHide{display:none}.euiTable.euiTable--responsive .euiTableRow-hasActions .euiTableCellContent--showOnHover .euiTableCellContent__hoverItem{opacity:1;-webkit-filter:none;filter:none;margin-bottom:8px;margin-left:0}.euiTable.euiTable--responsive .euiTableCellContent--alignRight,.euiTable.euiTable--responsive .euiTableCellContent--alignCenter{justify-content:flex-start}}.euiTableHeaderMobile,.euiTableHeaderCell--hideForDesktop{display:none}@media only screen and (max-width:574px){.euiTableHeaderMobile{justify-content:flex-end;padding:8px 0;display:flex}.euiTableSortMobile{display:block}}@media only screen and (min-width:575px) and (max-width:767px){.euiTableHeaderMobile{justify-content:flex-end;padding:8px 0;display:flex}.euiTableSortMobile{display:block}}.euiTabs{scrollbar-width:thin;flex-shrink:0;max-width:100%;display:flex;position:relative;overflow-x:auto;overflow-y:hidden}.euiTabs::-webkit-scrollbar{width:16px;height:16px}.euiTabs::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiTabs::-webkit-scrollbar-corner{background-color:transparent}.euiTabs::-webkit-scrollbar-track{background-color:transparent}.euiTabs::-webkit-scrollbar{height:3px}.euiTabs:not(.euiTabs--condensed):before{content:"";background-color:#293847;height:1px;position:absolute;bottom:0;left:0;right:0}.euiTab{color:#dfe5ef;cursor:pointer;background-color:transparent;padding:12px 16px;font-size:1rem;line-height:1.33333;transition:color .25s cubic-bezier(.694,.0482,.335,1),background-color .25s cubic-bezier(.694,.0482,.335,1);position:relative}.euiTab:hover:not(.euiTab-isSelected){text-decoration:underline}.euiTab:focus{outline-offset:-3px;background-color:#0e4342;text-decoration:underline}.euiTab:focus:before{content:"";background-color:#293847;height:1px;position:absolute;bottom:0;left:0;right:0}.euiTab.euiTab-isSelected{color:#159d8d;cursor:default}.euiTab.euiTab-isSelected:after{content:" ";background-color:#159d8d;width:100%;height:2px;animation:.15s cubic-bezier(.694,.0482,.335,1) euiTab;position:absolute;bottom:0;left:0}.euiTab.euiTab-isDisabled{color:#535a62}.euiTab.euiTab-isDisabled:hover{color:#535a62;cursor:not-allowed;text-decoration:none}.euiTab.euiTab-isDisabled:after{background-color:#535a62}.euiTabs--small .euiTab{padding:8px;font-size:.875rem}.euiTabs--condensed .euiTab{padding:8px 4px;font-weight:600}.euiTabs--condensed .euiTab:focus{background-color:#0e4342}.euiTabs--condensed .euiTab:focus:before{display:none}.euiTabs--condensed .euiTab-isSelected{text-decoration:none}.euiTabs--condensed .euiTab+.euiTab{margin-left:16px}.euiTabs--small.euiTabs--condensed .euiTab{padding-top:6px;padding-bottom:6px}.euiTabs--large.euiTabs--condensed .euiTab+.euiTab{margin-left:24px}.euiTabs--expand .euiTab{flex-grow:1;flex-basis:0%}.euiTab__content{text-overflow:ellipsis;white-space:nowrap;transition:transform .15s cubic-bezier(.34,1.61,.7,1);display:block;overflow:hidden;transform:translateY(0)}@keyframes euiTab{0%{transform:scaleX(0)}to{transform:scaleX(1)}}.euiTextDiff del{color:#f66}.euiTextDiff ins{color:#7de2d1}.euiTitle+.euiTitle{margin-top:24px}.euiTitle--uppercase{text-transform:uppercase}.euiTitle--xxxsmall{color:#dfe5ef;letter-spacing:-.005em;font-size:.75rem;font-weight:700;line-height:1.33333rem}.euiTitle--xxsmall{color:#dfe5ef;letter-spacing:-.005em;font-size:.875rem;font-weight:700;line-height:1.33333rem}.euiTitle--xsmall{color:#dfe5ef;letter-spacing:-.02em;font-size:1rem;font-weight:600;line-height:1.33333rem}.euiTitle--small{color:#dfe5ef;letter-spacing:-.025em;font-size:1.25rem;font-weight:500;line-height:1.77778rem}.euiTitle--medium{color:#dfe5ef;letter-spacing:-.04em;font-size:1.75rem;font-weight:300;line-height:2.22222rem}.euiTitle--large{color:#dfe5ef;letter-spacing:-.03em;font-size:2.25rem;font-weight:300;line-height:2.66667rem}.euiGlobalToastList{scrollbar-width:thin;z-index:9000;scrollbar-width:none;flex-direction:column;align-items:stretch;width:400px;max-height:100vh;display:flex;position:fixed;bottom:0;overflow-y:auto}.euiGlobalToastList::-webkit-scrollbar-thumb{background-color:rgba(141,152,163,.5);background-clip:content-box;border:6px solid transparent}.euiGlobalToastList::-webkit-scrollbar-corner{background-color:transparent}.euiGlobalToastList::-webkit-scrollbar-track{background-color:transparent}.euiGlobalToastList::-webkit-scrollbar{width:0;height:0}.euiGlobalToastList:not(:empty){padding:16px}.euiGlobalToastList--right:not(:empty){padding-left:64px;right:0}.euiGlobalToastList--left:not(:empty){padding-right:64px;left:0}.euiGlobalToastListItem{opacity:1;margin-bottom:16px;animation:.25s cubic-bezier(.694,.0482,.335,1) euiShowToast}.euiGlobalToastListItem:first-child{margin-top:auto}.euiGlobalToastListItem:last-child{margin-bottom:0}.euiGlobalToastListItem.euiGlobalToastListItem-isDismissed{opacity:0;transition:opacity .25s}@keyframes euiShowToast{0%{opacity:0;transform:translateY(24px)scale(.9)}to{opacity:1;transform:translateY(0)scale(1)}}@media only screen and (max-width:574px){.euiGlobalToastList:not(:empty){width:100%;padding-left:16px;padding-right:16px;left:0}}@media only screen and (min-width:575px) and (max-width:767px){.euiGlobalToastList:not(:empty){width:100%;padding-left:16px;padding-right:16px;left:0}}.euiToast{background-color:#0a121a;border:1px solid #293847;width:100%;padding:16px;position:relative;box-shadow:0 40px 64px rgba(0,0,0,.1),0 24px 32px rgba(0,0,0,.1),0 16px 16px rgba(0,0,0,.1),0 8px 8px rgba(0,0,0,.1),0 4px 4px rgba(0,0,0,.1),0 2px 2px rgba(0,0,0,.1)}.euiToast:hover .euiToast__closeButton,.euiToast:focus .euiToast__closeButton{opacity:1}.euiToast__closeButton{-webkit-appearance:none;-moz-appearance:none;-ms-appearance:none;appearance:none;opacity:0;line-height:0;transition:opacity .15s cubic-bezier(.694,.0482,.335,1);position:absolute;top:16px;right:16px}.euiToast__closeButton svg{fill:#4a515a}.euiToast__closeButton:hover svg{fill:#dfe5ef}.euiToast__closeButton:focus{opacity:1;background-color:#0e4342}.euiToast__closeButton:focus svg{fill:#159d8d}.euiToast--primary{border-top:2px solid #159d8d}.euiToast--success{border-top:2px solid #7de2d1}.euiToast--warning{border-top:2px solid #ffce7a}.euiToast--danger{border-top:2px solid #f66}.euiToastHeader{align-items:baseline;padding-right:24px;display:flex}.euiToastHeader>*+*{margin-left:8px}.euiToastHeader__icon{fill:#dfe5ef;flex:none;transform:translateY(2px)}.euiToastHeader__title{color:#dfe5ef;letter-spacing:-.02em;word-break:break-word;font-size:1rem;font-weight:300;line-height:1.33333rem;overflow-wrap:break-word!important;word-wrap:break-word!important}.euiToastHeader--withBody{margin-bottom:8px}.euiToastBody{word-wrap:break-word}.euiToken{justify-content:center;align-items:center;display:inline-flex}.euiToken svg{height:100%;margin:auto}.euiToken--circle{border-radius:50%}.euiToken--square{border-radius:3px}.euiToken--xsmall{width:12px;height:12px}.euiToken--xsmall.euiToken--rectangle{padding:0 4px}.euiToken--small{width:16px;height:16px}.euiToken--small.euiToken--rectangle{padding:0 4px}.euiToken--medium{width:24px;height:24px}.euiToken--medium.euiToken--rectangle{padding:0 8px}.euiToken--large{width:32px;height:32px}.euiToken--large.euiToken--rectangle{padding:0 8px}.euiToken--rectangle{box-sizing:content-box}.euiToken--euiColorVis0{color:#54b399}.euiToken--euiColorVis0.euiToken--light{color:#5cb79e;background-color:#204240;box-shadow:inset 0 0 0 1px #28524d}.euiToken--euiColorVis0.euiToken--dark{color:#0a121a;background-color:#6dccb1}.euiToken--euiColorVis1{color:#6092c0}.euiToken--euiColorVis1.euiToken--light{color:#7da6cc;background-color:#24384c;box-shadow:inset 0 0 0 1px #2c455c}.euiToken--euiColorVis1.euiToken--dark{color:#0a121a;background-color:#79aad9}.euiToken--euiColorVis2{color:#d36086}.euiToken--euiColorVis2.euiToken--light{color:#db7e9c;background-color:#46293a;box-shadow:inset 0 0 0 1px #5a3145}.euiToken--euiColorVis2.euiToken--dark{color:#0a121a;background-color:#ee789d}.euiToken--euiColorVis3{color:#9170b8}.euiToken--euiColorVis3.euiToken--light{color:#a990c8;background-color:#332e49;box-shadow:inset 0 0 0 1px #403859}.euiToken--euiColorVis3.euiToken--dark{color:#0a121a;background-color:#a987d1}.euiToken--euiColorVis4{color:#ca8eae}.euiToken--euiColorVis4.euiToken--light{color:#cd94b2;background-color:#443746;box-shadow:inset 0 0 0 1px #574455}.euiToken--euiColorVis4.euiToken--dark{color:#0a121a;background-color:#e4a6c7}.euiToken--euiColorVis5{color:#d6bf57}.euiToken--euiColorVis5.euiToken--light{color:#d6bf57;background-color:#47462c;box-shadow:inset 0 0 0 1px #5c5732}.euiToken--euiColorVis5.euiToken--dark{color:#0a121a;background-color:#f1d86f}.euiToken--euiColorVis6{color:#b9a888}.euiToken--euiColorVis6.euiToken--light{color:#b9a888;background-color:#3f3f3b;box-shadow:inset 0 0 0 1px #504e46}.euiToken--euiColorVis6.euiToken--dark{color:#0a121a;background-color:#d2c0a0}.euiToken--euiColorVis7{color:#da8b45}.euiToken--euiColorVis7.euiToken--light{color:#de9657;background-color:#483627;box-shadow:inset 0 0 0 1px #5d422b}.euiToken--euiColorVis7.euiToken--dark{color:#0a121a;background-color:#f5a35c}.euiToken--euiColorVis8{color:#aa6556}.euiToken--euiColorVis8.euiToken--light{color:#c08e83;background-color:#3a2b2c;box-shadow:inset 0 0 0 1px #4a3332}.euiToken--euiColorVis8.euiToken--dark{color:#0a121a;background-color:#c47c6c}.euiToken--euiColorVis9{color:#e7664c}.euiToken--euiColorVis9.euiToken--light{color:#eb836e;background-color:#4c2b29;box-shadow:inset 0 0 0 1px #62342e}.euiToken--euiColorVis9.euiToken--dark{color:#0a121a;background-color:#ff7e62}.euiToken--euiColorVis10{color:#9c9da0}.euiToken--euiColorVis10.euiToken--light{color:#a6a7aa;background-color:#363c42;box-shadow:inset 0 0 0 1px #444a50}.euiToken--euiColorVis10.euiToken--dark{color:#0a121a;background-color:#9c9da0}.euiToken--euiColorVis11{color:#d74987}.euiToken--euiColorVis11.euiToken--light{color:#e179a7;background-color:#48233b;box-shadow:inset 0 0 0 1px #5c2846}.euiToken--euiColorVis11.euiToken--dark{color:#0a121a;background-color:#d74987}.euiToken--euiColorVis12{color:#0d70ca}.euiToken--euiColorVis12.euiToken--light{color:#559bda;background-color:#0b2e4f;box-shadow:inset 0 0 0 1px #0b3860}.euiToken--euiColorVis12.euiToken--dark{color:#fcfeff;background-color:#0d70ca}.euiToken--euiColorVis13{color:#0c8967}.euiToken--euiColorVis13.euiToken--light{color:#4ba990;background-color:#0b3631;box-shadow:inset 0 0 0 1px #0b4239}.euiToken--euiColorVis13.euiToken--dark{color:#fcfeff;background-color:#0c8967}.euiToken--euiColorVis14{color:#6e28c3}.euiToken--euiColorVis14.euiToken--light{color:#a377d9;background-color:#28194d;box-shadow:inset 0 0 0 1px #321b5e}.euiToken--euiColorVis14.euiToken--dark{color:#fcfeff;background-color:#6e28c3}.euiToken--euiColorVis15{color:#d76813}.euiToken--euiColorVis15.euiToken--light{color:#df843f;background-color:#482c18;box-shadow:inset 0 0 0 1px #5c3417}.euiToken--euiColorVis15.euiToken--dark{color:#0a121a;background-color:#d76813}.euiToken--gray{color:#5b6875}.euiToken--gray.euiToken--light{color:#8c969f;background-color:#222c35;box-shadow:inset 0 0 0 1px #2a343e}.euiToken--gray.euiToken--dark{color:#fcfeff;background-color:#5b6875}.euiToolTip{color:#fcfeff;z-index:9000;overflow-wrap:break-word;opacity:0;background-color:#293847;border-radius:4px;max-width:256px;padding:8px;font-size:.75rem;line-height:1.33333;animation:90ms ease-out forwards euiToolTipTop;position:absolute;box-shadow:0 12px 24px rgba(10,18,26,.1),0 6px 12px rgba(10,18,26,.1),0 4px 4px rgba(10,18,26,.1),0 2px 2px rgba(10,18,26,.1)}.euiToolTip .euiToolTip__arrow{content:"";transform-origin:50%;background-color:#293847;border-radius:2px;width:12px;height:12px;position:absolute;transform:translateY(-7px)rotate(45deg)}.euiToolTip.euiToolTip--right{animation-name:euiToolTipRight}.euiToolTip.euiToolTip--right .euiToolTip__arrow{transform:translate(-5px)rotate(45deg)}.euiToolTip.euiToolTip--bottom{animation-name:euiToolTipBottom}.euiToolTip.euiToolTip--bottom .euiToolTip__arrow{transform:translateY(-5px)rotate(45deg)}.euiToolTip.euiToolTip--left{animation-name:euiToolTipLeft}.euiToolTip.euiToolTip--left .euiToolTip__arrow{transform:translate(-7px)rotate(45deg)}.euiToolTip .euiToolTip__title{border-bottom:1px solid #3a4148;margin-bottom:4px;padding-bottom:4px;font-weight:700}.euiToolTipAnchor{display:inline-block}.euiToolTipAnchor [disabled]{pointer-events:none}.euiToolTipAnchor.euiToolTipAnchor--displayBlock{display:block}@keyframes euiToolTipTop{0%{opacity:0}to{opacity:1}}@keyframes euiToolTipBottom{0%{opacity:0}to{opacity:1}}@keyframes euiToolTipLeft{0%{opacity:0}to{opacity:1}}@keyframes euiToolTipRight{0%{opacity:0}to{opacity:1}}.euiTour--minWidth-default{min-width:240px}.euiTourHeader{border-bottom:none;margin-bottom:8px!important}.euiTourHeader .euiTourHeader__title{margin-top:0}.euiTourHeader__subtitle{color:#8d98a3}.euiTourFooter{background-color:#101b25;margin-top:24px!important}.euiTour .euiTour__beacon{pointer-events:none;opacity:0;transition:opacity 0s .35s;position:absolute}.euiTour .euiPopover__panelArrow.euiPopover__panelArrow--right .euiTour__beacon{opacity:1;top:6px;left:-24px}.euiTour .euiPopover__panelArrow.euiPopover__panelArrow--left .euiTour__beacon{opacity:1;top:6px;left:12px}.euiTour .euiPopover__panelArrow.euiPopover__panelArrow--top:after{border-top-color:#101b25}.euiTour .euiPopover__panelArrow.euiPopover__panelArrow--top .euiTour__beacon{opacity:1;top:12px;left:6px}.euiTour .euiPopover__panelArrow.euiPopover__panelArrow--bottom .euiTour__beacon{opacity:1;top:-24px;left:6px}.euiTourStepIndicator{display:inline-block}.euiText{color:inherit;clear:both;font-size:1rem;font-weight:400;line-height:1.5rem}.euiText a:not([class]){color:#159d8d}.euiText a:not([class]):hover,.euiText a:not([class]):focus{color:#0f7065;text-decoration:underline}.euiText a:not([class]):focus{background-color:#0e4342;animation:.35s cubic-bezier(.694,.0482,.335,1) forwards focusRingAnimate!important}.euiText img{width:100%;display:block}.euiText ul{list-style:outside}.euiText ol{list-style:decimal}.euiText blockquote{text-align:center;letter-spacing:normal;margin-left:auto;margin-right:auto;font-style:italic;position:relative}.euiText blockquote p:last-child{margin-bottom:0}.euiText blockquote:before,.euiText blockquote:after{content:"";background:#8d98a3;width:50%;height:2px;position:absolute;right:0;transform:translate(-50%)}.euiText blockquote:before{top:0}.euiText blockquote:after{bottom:0}.euiText h1,.euiText h2,.euiText h3,.euiText h4,.euiText h5,.euiText h6{margin-bottom:.5rem}.euiText *+h2,.euiText *+h3,.euiText *+h4,.euiText *+h5,.euiText *+h6{margin-top:2rem}.euiText h1{color:#dfe5ef;letter-spacing:-.03em;font-size:2.25rem;font-weight:300;line-height:2.66667rem}.euiText h2{color:#dfe5ef;letter-spacing:-.04em;font-size:1.75rem;font-weight:300;line-height:2.22222rem}.euiText h3{color:#dfe5ef;letter-spacing:-.025em;font-size:1.25rem;font-weight:500;line-height:1.77778rem}.euiText h4,.euiText dt{color:#dfe5ef;letter-spacing:-.02em;font-size:1rem;font-weight:600;line-height:1.33333rem}.euiText h5{color:#dfe5ef;letter-spacing:-.005em;font-size:.875rem;font-weight:700;line-height:1.33333rem}.euiText h6{color:#dfe5ef;letter-spacing:-.005em;text-transform:uppercase;font-size:.75rem;font-weight:700;line-height:1.33333rem}.euiText pre{white-space:pre-wrap;color:#dfe5ef;background:#101b25}.euiText pre,.euiText pre code{display:block}.euiText code{font-family:var(--eui-code-font-family);letter-spacing:normal;font-weight:400;line-height:1.5;display:inline-block}.euiText p,.euiText ul,.euiText ol,.euiText dl,.euiText blockquote,.euiText img,.euiText pre{margin-bottom:1.5rem}.euiText ul,.euiText ol{margin-left:1.5rem}.euiText blockquote{padding:1.5rem;font-size:1.125rem}.euiText dd+dt{margin-top:1rem}.euiText dt,.euiText .eui-definitionListReverse dd{font-size:1rem;line-height:1.5rem}.euiText .eui-definitionListReverse dt{color:#dfe5ef;font-size:.75rem}.euiText small{font-size:.875rem}.euiText pre{padding:18px}.euiText code{font-size:.9rem}.euiText.euiText--constrainedWidth{min-width:75%;max-width:36em}.euiText>:last-child,.euiText .euiTextColor>:last-child{margin-bottom:0!important}.euiText--small{font-size:.875rem;line-height:1.3125rem}.euiText--small p,.euiText--small ul,.euiText--small ol,.euiText--small dl,.euiText--small blockquote,.euiText--small img,.euiText--small pre{margin-bottom:1.3125rem}.euiText--small ul,.euiText--small ol{margin-left:1.3125rem}.euiText--small blockquote{padding:1.3125rem;font-size:.984375rem}.euiText--small dd+dt{margin-top:.875rem}.euiText--small dt,.euiText--small .eui-definitionListReverse dd{font-size:.875rem;line-height:1.3125rem}.euiText--small .eui-definitionListReverse dt{color:#dfe5ef;font-size:.65625rem}.euiText--small small{font-size:.765625rem}.euiText--small pre{padding:15.75px}.euiText--small code{font-size:.7875rem}.euiText--extraSmall{font-size:.75rem;line-height:1.125rem}.euiText--extraSmall p,.euiText--extraSmall ul,.euiText--extraSmall ol,.euiText--extraSmall dl,.euiText--extraSmall blockquote,.euiText--extraSmall img,.euiText--extraSmall pre{margin-bottom:1.125rem}.euiText--extraSmall ul,.euiText--extraSmall ol{margin-left:1.125rem}.euiText--extraSmall blockquote{padding:1.125rem;font-size:.84375rem}.euiText--extraSmall dd+dt{margin-top:.75rem}.euiText--extraSmall dt,.euiText--extraSmall .eui-definitionListReverse dd{font-size:.75rem;line-height:1.125rem}.euiText--extraSmall .eui-definitionListReverse dt{color:#dfe5ef;font-size:.5625rem}.euiText--extraSmall small{font-size:.65625rem}.euiText--extraSmall pre{padding:13.5px}.euiText--extraSmall code{font-size:.675rem}.euiTextColor--default{color:#dfe5ef}.euiTextColor--subdued{color:#9fa6af}.euiTextColor--secondary,.euiTextColor--success{color:#7de2d1}.euiTextColor--accent{color:#f990c0}.euiTextColor--warning{color:#ffce7a}.euiTextColor--danger{color:#f66}.euiTextColor--ghost{color:#fcfeff;color:#fcfeff!important}.euiTextAlign--left{text-align:left}.euiTextAlign--right{text-align:right}.euiTextAlign--center{text-align:center}